bcv_parser::regexps.space = "[\\s\\xa0]"
bcv_parser::regexps.escaped_passage = ///
	(?:^ | [^\x1f\x1e\dA-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ] )	# Beginning of string or not in the middle of a word or immediately following another book. Only count a book if it's part of a sequence: `Matt5John3` is OK, but not `1Matt5John3`
		(
			# Start inverted book/chapter (cb)
			(?:
				  (?: ch (?: apters? | a?pts?\.? | a?p?s?\.? )? \s*
					\d+ \s* (?: [\u2013\u2014\-] | through | thru | to) \s* \d+ \s*
					(?: from | of | in ) (?: \s+ the \s+ book \s+ of )?\s* )
				| (?: ch (?: apters? | a?pts?\.? | a?p?s?\.? )? \s*
					\d+ \s*
					(?: from | of | in ) (?: \s+ the \s+ book \s+ of )?\s* )
				| (?: \d+ (?: th | nd | st ) \s*
					ch (?: apter | a?pt\.? | a?p?\.? )? \s* #no plurals here since it's a single chapter
					(?: from | of | in ) (?: \s+ the \s+ book \s+ of )? \s* )
			)? # End inverted book/chapter (cb)
			\x1f(\d+)(?:/\d+)?\x1f		#book
				(?:
				    /\d+\x1f				#special Psalm chapters
				  | [\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014]
				  | title (?! [a-z] )		#could be followed by a number
				  | глави | глава | verse | ff | - | и
				  | [аб] (?! \w )			#a-e allows 1:1a
				  | $						#or the end of the string
				 )+
		)
	///gi
# These are the only valid ways to end a potential passage match. The closing parenthesis allows for fully capturing parentheses surrounding translations (ESV**)**. The last one, `[\d\x1f]` needs not to be +; otherwise `Gen5ff` becomes `\x1f0\x1f5ff`, and `adjust_regexp_end` matches the `\x1f5` and incorrectly dangles the ff.
bcv_parser::regexps.match_end_split = ///
	  \d \W* title
	| \d \W* ff (?: [\s\xa0*]* \.)?
	| \d [\s\xa0*]* [аб] (?! \w )
	| \x1e (?: [\s\xa0*]* [)\]\uff09] )? #ff09 is a full-width closing parenthesis
	| [\d\x1f]
	///gi
bcv_parser::regexps.control = /[\x1e\x1f]/g
bcv_parser::regexps.pre_book = "[^A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ]"

bcv_parser::regexps.first = "(?:Прва|Прво|1|I)\\.?#{bcv_parser::regexps.space}*"
bcv_parser::regexps.second = "(?:Втора|Второ|2|II)\\.?#{bcv_parser::regexps.space}*"
bcv_parser::regexps.third = "(?:Трета|Трето|3|III)\\.?#{bcv_parser::regexps.space}*"
bcv_parser::regexps.range_and = "(?:[&\u2013\u2014-]|и|-)"
bcv_parser::regexps.range_only = "(?:[\u2013\u2014-]|-)"
# Each book regexp should return two parenthesized objects: an optional preliminary character and the book itself.
bcv_parser::regexps.get_books = (include_apocrypha, case_sensitive) ->
	books = [
		osis: ["Ps"]
		apocrypha: true
		extra: "2"
		regexp: ///(\b)( # Don't match a preceding \d like usual because we only want to match a valid OSIS, which will never have a preceding digit.
			Ps151
			# Always follwed by ".1"; the regular Psalms parser can handle `Ps151` on its own.
			)(?=\.1)///g # Case-sensitive because we only want to match a valid OSIS.
	,
		osis: ["Gen"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Прв[ао][\s\xa0]*книга[\s\xa0]*Мојсеева|(?:[1I](?:\.[\s\xa0]*книга[\s\xa0]*Мојсеева|[\s\xa0]*книга[\s\xa0]*Мојсеева))|Настанување|Битие|Gen)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Exod"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Втор[ао][\s\xa0]*книга[\s\xa0]*Мојсеева|II(?:\.[\s\xa0]*книга[\s\xa0]*Мојсеева|[\s\xa0]*книга[\s\xa0]*Мојсеева)|2(?:\.[\s\xa0]*книга[\s\xa0]*Мојсеева|[\s\xa0]*книга[\s\xa0]*Мојсеева)|Излез|Exod)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Bel"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		Bel
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Lev"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Трета[\s\xa0]*книга[\s\xa0]*Мојсеева|Левит(?:ска(?:[\s\xa0]*книга)?)?|Lev)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Num"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Четврта[\s\xa0]*книга[\s\xa0]*Мојсеева|Броеви|Num)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Sir"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		Sir
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Wis"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*Мудрост[\s\xa0]*Соломонова|Wis)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Lam"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Плач(?:от[\s\xa0]*на[\s\xa0]*Еремија|[\s\xa0]*(?:на[\s\xa0]*Еремиин|Еремиин))|Lam)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["EpJer"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		EpJer
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Rev"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Откровение|Rev)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["PrMan"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		PrMan
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Deut"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:П(?:етта[\s\xa0]*книга[\s\xa0]*Мојсеева|овторени[\s\xa0]*закони)|Второзаконие|Deut)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Josh"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*на[\s\xa0]*Исус[\s\xa0]*Невин|Исус[\s\xa0]*Навин|Ј[ео]шуа|Josh)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Judg"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*на[\s\xa0]*израелеви[\s\xa0]*судии|Судии|Judg)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Ruth"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Ruth|Рут)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["1Esd"]
		apocrypha: true
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		1Esd
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["2Esd"]
		apocrypha: true
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		2Esd
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Isa"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Иса(?:ија|ја)|Isa)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["2Sam"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Втор(?:[ао][\s\xa0]*(?:книга[\s\xa0]*Самоилова|Самуил))|II(?:\.[\s\xa0]*(?:книга[\s\xa0]*Самоилова|Самуил)|[\s\xa0]*(?:книга[\s\xa0]*Самоилова|Самуил))|2(?:\.[\s\xa0]*(?:книга[\s\xa0]*Самоилова|Самуил)|[\s\xa0]*(?:книга[\s\xa0]*Самоилова|Самуил)|Sam))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["1Sam"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Прв(?:[ао][\s\xa0]*(?:книга[\s\xa0]*Самоилова|Самуил))|I(?:\.[\s\xa0]*(?:книга[\s\xa0]*Самоилова|Самуил)|[\s\xa0]*(?:книга[\s\xa0]*Самоилова|Самуил))|1(?:\.[\s\xa0]*(?:книга[\s\xa0]*Самоилова|Самуил)|[\s\xa0]*(?:книга[\s\xa0]*Самоилова|Самуил)|Sam))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["2Kgs"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Втор(?:[ао][\s\xa0]*(?:книга[\s\xa0]*за[\s\xa0]*царевите|Цареви))|II(?:\.[\s\xa0]*(?:книга[\s\xa0]*за[\s\xa0]*царевите|Цареви)|[\s\xa0]*(?:книга[\s\xa0]*за[\s\xa0]*царевите|Цареви))|2(?:\.[\s\xa0]*(?:книга[\s\xa0]*за[\s\xa0]*царевите|Цареви)|[\s\xa0]*(?:книга[\s\xa0]*за[\s\xa0]*царевите|Цареви)|Kgs))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["1Kgs"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Прв(?:[ао][\s\xa0]*(?:книга[\s\xa0]*за[\s\xa0]*царевите|Цареви))|I(?:\.[\s\xa0]*(?:книга[\s\xa0]*за[\s\xa0]*царевите|Цареви)|[\s\xa0]*(?:книга[\s\xa0]*за[\s\xa0]*царевите|Цареви))|1(?:\.[\s\xa0]*(?:книга[\s\xa0]*за[\s\xa0]*царевите|Цареви)|[\s\xa0]*(?:книга[\s\xa0]*за[\s\xa0]*царевите|Цареви)|Kgs))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["2Chr"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Втор(?:[ао][\s\xa0]*(?:книга[\s\xa0]*летописи|Летописи))|II(?:\.[\s\xa0]*(?:книга[\s\xa0]*летописи|Летописи)|[\s\xa0]*(?:книга[\s\xa0]*летописи|Летописи))|2(?:\.[\s\xa0]*(?:книга[\s\xa0]*летописи|Летописи)|[\s\xa0]*(?:книга[\s\xa0]*летописи|Летописи)|Chr))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["1Chr"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Прв(?:[ао][\s\xa0]*(?:книга[\s\xa0]*летописи|Летописи))|I(?:\.[\s\xa0]*(?:книга[\s\xa0]*летописи|Летописи)|[\s\xa0]*(?:книга[\s\xa0]*летописи|Летописи))|1(?:\.[\s\xa0]*(?:книга[\s\xa0]*летописи|Летописи)|[\s\xa0]*(?:книга[\s\xa0]*летописи|Летописи)|Chr))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Ezra"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Ezra|Езра)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Neh"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Не(?:хемија|емија)|Neh)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["GkEsth"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		GkEsth
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Esth"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Ест(?:ира|ер)|Esth)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Job"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Job|Јов)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Ps"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Псалми|Ps)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["PrAzar"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		PrAzar
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Prov"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Пословици|Изреки|Prov)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Eccl"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Проповедник|Eccl)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["SgThree"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		SgThree
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Song"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Песна(?:та[\s\xa0]*на(?:д[\s\xa0]*песните|[\s\xa0]*Соломон)|[\s\xa0]*над[\s\xa0]*песните)|Црковни[\s\xa0]*химни|Song)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Jer"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Еремија|Jer)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Ezek"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Езекиел|Ezek)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Dan"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Дани(?:ел|л)|Dan)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Hos"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Осија|Хошеа|Hos)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Joel"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Joel|Јо[еи]л)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Amos"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Amos|Амос)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Obad"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Овадија|Авдиј|Obad)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Jonah"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Jonah|Јона)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Mic"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Мих(?:еј|а)|Mic)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Nah"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Наум|Nah)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Hab"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Ха[бв]акук|Hab)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Zeph"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:С(?:ефанија|офонија)|Zeph)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Hag"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Хагај|Агеј|Hag)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Zech"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Захарија|Zech)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Mal"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Малахија|Mal)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Matt"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Евангелие(?:то[\s\xa0]*според[\s\xa0]*Матеј|[\s\xa0]*според[\s\xa0]*Матеј)|Матеј|Matt)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Mark"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Евангелие(?:то[\s\xa0]*според[\s\xa0]*Марко|[\s\xa0]*според[\s\xa0]*Марко)|Марко|Mark)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Luke"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Евангелие(?:то[\s\xa0]*според[\s\xa0]*Лука|[\s\xa0]*според[\s\xa0]*Лука)|Luke|Лука)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["1John"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Прв(?:[ао][\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Јован|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Јован)|Јован(?:ово)?))|I(?:\.[\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Јован|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Јован)|Јован(?:ово)?)|[\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Јован|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Јован)|Јован(?:ово)?))|1(?:\.[\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Јован|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Јован)|Јован(?:ово)?)|[\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Јован|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Јован)|Јован(?:ово)?)|John))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["2John"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Втор(?:[ао][\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Јован|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Јован)|Јован(?:ово)?))|II(?:\.[\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Јован|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Јован)|Јован(?:ово)?)|[\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Јован|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Јован)|Јован(?:ово)?))|2(?:\.[\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Јован|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Јован)|Јован(?:ово)?)|[\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Јован|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Јован)|Јован(?:ово)?)|John))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["3John"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Трет(?:[ао][\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Јован|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Јован)|Јован(?:ово)?))|III(?:\.[\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Јован|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Јован)|Јован(?:ово)?)|[\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Јован|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Јован)|Јован(?:ово)?))|3(?:\.[\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Јован|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Јован)|Јован(?:ово)?)|[\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Јован|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Јован)|Јован(?:ово)?)|John))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["John"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Евангелие(?:то[\s\xa0]*според[\s\xa0]*Јован|[\s\xa0]*според[\s\xa0]*Јован)|Јован|John)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Acts"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Acts|Дела(?:[\s\xa0]*(?:на[\s\xa0]*(?:светите[\s\xa0]*апостоли|апостолите)|Ап))?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Rom"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Рим|Римјани(?:те)?|Rom)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["2Cor"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Втор(?:[ао][\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Коринт|Корин(?:[кќ]аните|тјани)))|II(?:\.[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Коринт|Корин(?:[кќ]аните|тјани))|[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Коринт|Корин(?:[кќ]аните|тјани)))|2(?:\.[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Коринт|Корин(?:[кќ]аните|тјани))|[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Коринт|Корин(?:[кќ]аните|тјани))|Cor))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["1Cor"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Прв(?:[ао][\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Коринт|Корин(?:[кќ]аните|тјани)))|I(?:\.[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Коринт|Корин(?:[кќ]аните|тјани))|[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Коринт|Корин(?:[кќ]аните|тјани)))|1(?:\.[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Коринт|Корин(?:[кќ]аните|тјани))|[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Коринт|Корин(?:[кќ]аните|тјани))|Cor))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Gal"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Галатија|Галат(?:јани|ите)|Gal)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Eph"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Ефес|Ефе(?:шаните|сјани)|Eph)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Phil"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Филипи|Филипјани(?:те)?|Phil)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Col"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Колос|Коло(?:шаните|сјани)|Col)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["2Thess"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Втор(?:[ао][\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Солун|Солун(?:ците|јани)))|II(?:\.[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Солун|Солун(?:ците|јани))|[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Солун|Солун(?:ците|јани)))|2(?:\.[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Солун|Солун(?:ците|јани))|[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Солун|Солун(?:ците|јани))|Thess))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["1Thess"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Прв(?:[ао][\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Солун|Солун(?:ците|јани)))|I(?:\.[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Солун|Солун(?:ците|јани))|[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Солун|Солун(?:ците|јани)))|1(?:\.[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Солун|Солун(?:ците|јани))|[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*христијаните[\s\xa0]*во[\s\xa0]*Солун|Солун(?:ците|јани))|Thess))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["2Tim"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Втор(?:[ао][\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*Тимотеј|Тимотеј))|II(?:\.[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*Тимотеј|Тимотеј)|[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*Тимотеј|Тимотеј))|2(?:\.[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*Тимотеј|Тимотеј)|[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*Тимотеј|Тимотеј)|Tim))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["1Tim"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Прв(?:[ао][\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*Тимотеј|Тимотеј))|I(?:\.[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*Тимотеј|Тимотеј)|[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*Тимотеј|Тимотеј))|1(?:\.[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*Тимотеј|Тимотеј)|[\s\xa0]*(?:писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*Тимотеј|Тимотеј)|Tim))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Titus"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*Тит|Titus|Тит)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Phlm"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Писмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Павле[\s\xa0]*до[\s\xa0]*Филемон|Фил[еи]мон|Phlm)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Heb"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Писмо[\s\xa0]*до[\s\xa0]*Евреите|Евреи(?:те)?|Heb)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Jas"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:П(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Јаков|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Јаков)|Јаков|Jas)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["2Pet"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Втор(?:[ао][\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Петар|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Петар)|Пет(?:рово|ар)))|II(?:\.[\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Петар|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Петар)|Пет(?:рово|ар))|[\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Петар|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Петар)|Пет(?:рово|ар)))|2(?:\.[\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Петар|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Петар)|Пет(?:рово|ар))|[\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Петар|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Петар)|Пет(?:рово|ар))|Pet))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["1Pet"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Прв(?:[ао][\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Петар|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Петар)|Пет(?:рово|ар)))|I(?:\.[\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Петар|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Петар)|Пет(?:рово|ар))|[\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Петар|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Петар)|Пет(?:рово|ар)))|1(?:\.[\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Петар|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Петар)|Пет(?:рово|ар))|[\s\xa0]*(?:п(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Петар|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Петар)|Пет(?:рово|ар))|Pet))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Jude"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:П(?:ослание[\s\xa0]*на[\s\xa0]*апостол[\s\xa0]*Јуда|исмо[\s\xa0]*од[\s\xa0]*апостол[\s\xa0]*Јуда)|Jude|Јуда)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Tob"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		Tob
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Jdt"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		Jdt
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Bar"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		Bar
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Sus"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		Sus
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["2Macc"]
		apocrypha: true
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		2Macc
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["3Macc"]
		apocrypha: true
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		3Macc
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["4Macc"]
		apocrypha: true
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		4Macc
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["1Macc"]
		apocrypha: true
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		1Macc
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	]
	# Short-circuit the look if we know we want all the books.
	return books if include_apocrypha is true and case_sensitive is "none"
	# Filter out books in the Apocrypha if we don't want them. `Array.map` isn't supported below IE9.
	out = []
	for book in books
		continue if include_apocrypha is false and book.apocrypha? and book.apocrypha is true
		if case_sensitive is "books"
			book.regexp = new RegExp book.regexp.source, "g"
		out.push book
	out

# Default to not using the Apocrypha
bcv_parser::regexps.books = bcv_parser::regexps.get_books false, "none"
