bcv_parser::regexps.space = "[\\s\\xa0]"
bcv_parser::regexps.escaped_passage = ///
	(?:^ | [^\x1f\x1e\dA-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ] )	# Beginning of string or not in the middle of a word or immediately following another book. Only count a book if it's part of a sequence: `Matt5John3` is OK, but not `1Matt5John3`
		(
			# Start inverted book/chapter (cb)
			(?:
				  (?: ch (?: apters? | a?pts?\.? | a?p?s?\.? )? \s*
					\d+ \s* (?: [\u2013\u2014\-] | through | thru | to) \s* \d+ \s*
					(?: from | of | in ) (?: \s+ the \s+ book \s+ of )?\s* )
				| (?: ch (?: apters? | a?pts?\.? | a?p?s?\.? )? \s*
					\d+ \s*
					(?: from | of | in ) (?: \s+ the \s+ book \s+ of )?\s* )
				| (?: \d+ (?: th | nd | st ) \s*
					ch (?: apter | a?pt\.? | a?p?\.? )? \s* #no plurals here since it's a single chapter
					(?: from | of | in ) (?: \s+ the \s+ book \s+ of )? \s* )
			)? # End inverted book/chapter (cb)
			\x1f(\d+)(?:/\d+)?\x1f		#book
				(?:
				    /\d+\x1f				#special Psalm chapters
				  | [\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014]
				  | title (?! [a-z] )		#could be followed by a number
				  | розділ | глави | глава | вірші | розд | вірш | гл | ff | - | і
				  | [aаб] (?! \w )			#a-e allows 1:1a
				  | $						#or the end of the string
				 )+
		)
	///gi
# These are the only valid ways to end a potential passage match. The closing parenthesis allows for fully capturing parentheses surrounding translations (ESV**)**. The last one, `[\d\x1f]` needs not to be +; otherwise `Gen5ff` becomes `\x1f0\x1f5ff`, and `adjust_regexp_end` matches the `\x1f5` and incorrectly dangles the ff.
bcv_parser::regexps.match_end_split = ///
	  \d \W* title
	| \d \W* ff (?: [\s\xa0*]* \.)?
	| \d [\s\xa0*]* [aаб] (?! \w )
	| \x1e (?: [\s\xa0*]* [)\]\uff09] )? #ff09 is a full-width closing parenthesis
	| [\d\x1f]
	///gi
bcv_parser::regexps.control = /[\x1e\x1f]/g
bcv_parser::regexps.pre_book = "[^A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ]"

bcv_parser::regexps.first = "(?:Перша|Перше|1-ше|1-[ае]|1|I)\\.?#{bcv_parser::regexps.space}*"
bcv_parser::regexps.second = "(?:Друга|Друге|2-ге|2-[ае]|2|II)\\.?#{bcv_parser::regexps.space}*"
bcv_parser::regexps.third = "(?:Третя|Третє|3-тє|3-[ае]|3|III)\\.?#{bcv_parser::regexps.space}*"
bcv_parser::regexps.range_and = "(?:[&\u2013\u2014-]|і|-)"
bcv_parser::regexps.range_only = "(?:[\u2013\u2014-]|-)"
# Each book regexp should return two parenthesized objects: an optional preliminary character and the book itself.
bcv_parser::regexps.get_books = (include_apocrypha, case_sensitive) ->
	books = [
		osis: ["Ps"]
		apocrypha: true
		extra: "2"
		regexp: ///(\b)( # Don't match a preceding \d like usual because we only want to match a valid OSIS, which will never have a preceding digit.
			Ps151
			# Always follwed by ".1"; the regular Psalms parser can handle `Ps151` on its own.
			)(?=\.1)///g # Case-sensitive because we only want to match a valid OSIS.
	,
		osis: ["Gen"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Перш[ае][\s\xa0]*книга[\s\xa0]*Мо(?:[ий]сеева)|I(?:\.[\s\xa0]*книга[\s\xa0]*Мо[ий]сеева|[\s\xa0]*книга[\s\xa0]*Мо[ий]сеева)|Buttja|1(?:-?(?:ше(?:\.[\s\xa0]*книга[\s\xa0]*Мо[ий]сеева|[\s\xa0]*книга[\s\xa0]*Мо[ий]сеева)|[ае](?:\.[\s\xa0]*книга[\s\xa0]*Мо(?:[ий]сеева|[\s\xa0]*книга[\s\xa0]*Мо[ий]сеева)))|\.[\s\xa0]*книга[\s\xa0]*Мо[ий]сеева|[\s\xa0]*(?:книга[\s\xa0]*Мо[ий]сеева|М))|Gen|Бу(?:г|т(?:тя)?))|1-?[ае][\s\xa0]*книга[\s\xa0]*Мо(?:[ий]сеева)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Exod"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Друг[ае][\s\xa0]*книга[\s\xa0]*Мо(?:[ий]сеева)|II(?:\.[\s\xa0]*книга[\s\xa0]*Мо[ий]сеева|[\s\xa0]*книга[\s\xa0]*Мо[ий]сеева)|Vy[hȟ]id|Exod|2(?:-?(?:ге(?:\.[\s\xa0]*книга[\s\xa0]*Мо[ий]сеева|[\s\xa0]*книга[\s\xa0]*Мо[ий]сеева)|[ае](?:\.[\s\xa0]*книга[\s\xa0]*Мо(?:[ий]сеева|[\s\xa0]*книга[\s\xa0]*Мо[ий]сеева)))|\.[\s\xa0]*книга[\s\xa0]*Мо[ий]сеева|[\s\xa0]*(?:книга[\s\xa0]*Мо[ий]сеева|М))|Вих(?:ід)?)|2-?[ае][\s\xa0]*книга[\s\xa0]*Мо(?:[ий]сеева)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Bel"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Bel|Бел(?:[\s\xa0]*і[\s\xa0]*дракон)?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Lev"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Трет[яє][\s\xa0]*книга[\s\xa0]*Мо(?:[ий]сеева)|III(?:\.[\s\xa0]*книга[\s\xa0]*Мо[ий]сеева|[\s\xa0]*книга[\s\xa0]*Мо[ий]сеева)|Левит|3(?:-?(?:тє(?:\.[\s\xa0]*книга[\s\xa0]*Мо[ий]сеева|[\s\xa0]*книга[\s\xa0]*Мо[ий]сеева)|[ае](?:\.[\s\xa0]*книга[\s\xa0]*Мо(?:[ий]сеева|[\s\xa0]*книга[\s\xa0]*Мо[ий]сеева)))|\.[\s\xa0]*книга[\s\xa0]*Мо[ий]сеева|[\s\xa0]*(?:книга[\s\xa0]*Мо[ий]сеева|М))|Lev(?:yt)?)|3-?[ае][\s\xa0]*книга[\s\xa0]*Мо(?:[ий]сеева)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Num"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:IV(?:\.[\s\xa0]*книга[\s\xa0]*Мо[ий]сеева|[\s\xa0]*книга[\s\xa0]*Мо[ий]сеева)|[CČ]ysla|4(?:\.[\s\xa0]*книга[\s\xa0]*Мо[ий]сеева|[\s\xa0]*(?:книга[\s\xa0]*Мо[ий]сеева|М))|Num|Ч(?:етверта[\s\xa0]*книга[\s\xa0]*Мо[ий]сеева|ис(?:ла)?))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Sir"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Премудрість[\s\xa0]*Ісуса,[\s\xa0]*сина[\s\xa0]*Сирахова|Книга[\s\xa0]*Сираха|Бен[\s\xa0]*Сираха|Еклесіаст|Sir|Сир(?:аха)?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Wis"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*(?:Премудрості[\s\xa0]*Соломона|Мудрости)|Прем(?:удрість[\s\xa0]*Соломона)?|Wis|Муд(?:рости)?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Lam"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Pla[cč][\s\xa0]*Jeremi[iï]|Плач(?:[\s\xa0]*Єремі[ії])?|Lam)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["EpJer"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Послання[\s\xa0]*Єремі[ії]|Лист[\s\xa0]*Єремі[ії]|EpJer)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Rev"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Ob['’]javlennja[\s\xa0]*Ivana[\s\xa0]*Bohoslova|Відкриття[\s\xa0]*Івана|Апок(?:[aá]ліпсис|а(?:́ліпсис|л[iíі]псис))|О(?:б(?:['’]явлення[\s\xa0]*(?:св(?:\.[\s\xa0]*(?:Івана[\s\xa0]*Богослова|[ИЙ]оана[\s\xa0]*Богослова)|[\s\xa0]*(?:Івана[\s\xa0]*Богослова|[ИЙ]оана[\s\xa0]*Богослова))|Івана[\s\xa0]*Богослова))|дкр(?:овення[\s\xa0]*Івана[\s\xa0]*Богослова|иттє))|Rev)|Об(?:['’]явлення)?
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["PrMan"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		PrMan
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Deut"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Povtorennja[\s\xa0]*Zakonu|Deut|Втор(?:озаконня)?|П(?:['’]ята[\s\xa0]*книга[\s\xa0]*Мо(?:[ий]сеева)|овт(?:орення[\s\xa0]*Закону|\.[\s\xa0]*Закону|[\s\xa0]*Закону)?)|5[\s\xa0]*М)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Josh"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*(?:Ісуса[\s\xa0]*Навина|Єгошу[ії])|Isus[\s\xa0]*Navyn|І(?:сус(?:а[\s\xa0]*Навина|[\s\xa0]*Навин)|\.[\s\xa0]*Нав|[\s\xa0]*Нав)|Josh|Нав|Єг(?:ошу[ії])?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Judg"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Knyha[\s\xa0]*Suddiv|Книга[\s\xa0]*Суддів|Judg|Суд(?:дів)?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Ruth"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*Рут|Ruth?|Рут)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["1Esd"]
		apocrypha: true
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Перш[ае][\s\xa0]*Ездр[аи]|I(?:\.[\s\xa0]*Ездр[аи]|[\s\xa0]*Ездр[аи])|1(?:-?(?:ше(?:\.[\s\xa0]*Ездр[аи]|[\s\xa0]*Ездр[аи])|(?:[ае](?:\.[\s\xa0]*Ездр[аи]|[\s\xa0]*Ездр[аи])))|\.[\s\xa0]*Ездр[аи]|[\s\xa0]*Езд(?:р[аи])?|Esd))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["2Esd"]
		apocrypha: true
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Друг(?:[ае][\s\xa0]*(?:книга[\s\xa0]*Ездри|Ездр[аи]))|II(?:\.[\s\xa0]*(?:книга[\s\xa0]*Ездри|Ездр[аи])|[\s\xa0]*(?:книга[\s\xa0]*Ездри|Ездр[аи]))|2(?:-?(?:ге(?:\.[\s\xa0]*(?:книга[\s\xa0]*Ездри|Ездр[аи])|[\s\xa0]*(?:книга[\s\xa0]*Ездри|Ездр[аи]))|(?:[ае](?:\.[\s\xa0]*(?:книга[\s\xa0]*Ездри|Ездр[аи])|[\s\xa0]*(?:книга[\s\xa0]*Ездри|Ездр[аи]))))|\.[\s\xa0]*(?:книга[\s\xa0]*Ездри|Ездр[аи])|[\s\xa0]*(?:книга[\s\xa0]*Ездри|Езд(?:р[аи])?)|Esd))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Isa"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*(?:пророка[\s\xa0]*Іса[ії]|Іса[ий][ії])|Isa(?:ja)?|Іс(?:а[яії])?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["2Sam"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Друг[ае][\s\xa0]*(?:книга[\s\xa0]*Саму(?:[ії]лова|Samu[iï]l|Саму(?:[ії]л(?:ова)?)))|II(?:\.[\s\xa0]*(?:книга[\s\xa0]*Саму[ії]лова|Samu[iï]l|Саму(?:[ії]л(?:ова)?))|[\s\xa0]*(?:книга[\s\xa0]*Саму[ії]лова|Samu[iï]l|Саму(?:[ії]л(?:ова)?)))|2(?:-?(?:ге(?:\.[\s\xa0]*(?:книга[\s\xa0]*Саму[ії]лова|Samu[iï]l|Саму(?:[ії]л(?:ова)?))|[\s\xa0]*(?:книга[\s\xa0]*Саму[ії]лова|Samu[iï]l|Саму(?:[ії]л(?:ова)?)))|[ае](?:\.[\s\xa0]*(?:книга[\s\xa0]*Саму(?:[ії]лова|Samu[iï]l|Саму(?:[ії]л(?:ова)?))|[\s\xa0]*(?:книга[\s\xa0]*Саму[ії]лова|Samu[iï]l|Саму(?:[ії]л(?:ова)?)))))|\.[\s\xa0]*(?:книга[\s\xa0]*Саму[ії]лова|Samu[iï]l|Саму(?:[ії]л(?:ова)?))|[\s\xa0]*(?:книга[\s\xa0]*Саму[ії]лова|Samu[iï]l|Сам(?:у(?:[ії]л(?:ова)?))?)|Sam))|(?:Друг[ае][\s\xa0]*(?:Samu(?:[iï]l|Саму(?:[ії]л(?:ова)?)))|2-?[ае](?:\.[\s\xa0]*(?:Samu(?:[iï]l|Саму(?:[ії]л(?:ова)?))|[\s\xa0]*(?:книга[\s\xa0]*Саму[ії]лова|Samu[iï]l|Саму(?:[ії]л(?:ова)?)))))|(?:Друг(?:[ае][\s\xa0]*Саму(?:[ії]л(?:ова)?))|2-?(?:[ае](?:\.[\s\xa0]*Саму(?:[ії]л(?:ова)?)|[\s\xa0]*(?:книга[\s\xa0]*Саму[ії]лова|Samu[iï]l|Саму(?:[ії]л(?:ова)?)))))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["1Sam"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Перш[ае][\s\xa0]*(?:книга[\s\xa0]*Саму(?:[ії]лова|Samu[iï]l|Саму(?:[ії]л(?:ова)?)))|I(?:\.[\s\xa0]*(?:книга[\s\xa0]*Саму[ії]лова|Samu[iï]l|Саму(?:[ії]л(?:ова)?))|[\s\xa0]*(?:книга[\s\xa0]*Саму[ії]лова|Samu[iï]l|Саму(?:[ії]л(?:ова)?)))|1(?:-?(?:ше(?:\.[\s\xa0]*(?:книга[\s\xa0]*Саму[ії]лова|Samu[iï]l|Саму(?:[ії]л(?:ова)?))|[\s\xa0]*(?:книга[\s\xa0]*Саму[ії]лова|Samu[iï]l|Саму(?:[ії]л(?:ова)?)))|[ае](?:\.[\s\xa0]*(?:книга[\s\xa0]*Саму(?:[ії]лова|Samu[iï]l|Саму(?:[ії]л(?:ова)?))|[\s\xa0]*(?:книга[\s\xa0]*Саму[ії]лова|Samu[iï]l|Саму(?:[ії]л(?:ова)?)))))|\.[\s\xa0]*(?:книга[\s\xa0]*Саму[ії]лова|Samu[iï]l|Саму(?:[ії]л(?:ова)?))|[\s\xa0]*(?:книга[\s\xa0]*Саму[ії]лова|Samu[iï]l|Сам(?:у(?:[ії]л(?:ова)?))?)|Sam))|(?:Перш[ае][\s\xa0]*(?:Samu(?:[iï]l|Саму(?:[ії]л(?:ова)?)))|1-?[ае](?:\.[\s\xa0]*(?:Samu(?:[iï]l|Саму(?:[ії]л(?:ова)?))|[\s\xa0]*(?:книга[\s\xa0]*Саму[ії]лова|Samu[iï]l|Саму(?:[ії]л(?:ова)?)))))|(?:Перш(?:[ае][\s\xa0]*Саму(?:[ії]л(?:ова)?))|1-?(?:[ае](?:\.[\s\xa0]*Саму(?:[ії]л(?:ова)?)|[\s\xa0]*(?:книга[\s\xa0]*Саму[ії]лова|Samu[iï]l|Саму(?:[ії]л(?:ова)?)))))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["2Kgs"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Четверта[\s\xa0]*Царів|Друг(?:[ае][\s\xa0]*(?:книга[\s\xa0]*царів|Cariv|царів))|I(?:I(?:\.[\s\xa0]*(?:книга[\s\xa0]*царів|Cariv|царів)|[\s\xa0]*(?:книга[\s\xa0]*царів|Cariv|царів))|V(?:\.[\s\xa0]*Царів|[\s\xa0]*Царів))|4(?:\.[\s\xa0]*Царів|[\s\xa0]*Царів)|2(?:-?(?:ге(?:\.[\s\xa0]*(?:книга[\s\xa0]*царів|Cariv|царів)|[\s\xa0]*(?:книга[\s\xa0]*царів|Cariv|царів))|(?:[ае](?:\.[\s\xa0]*(?:книга[\s\xa0]*царів|Cariv|царів)|[\s\xa0]*(?:книга[\s\xa0]*царів|Cariv|царів))))|\.[\s\xa0]*(?:книга[\s\xa0]*царів|Cariv|царів)|[\s\xa0]*(?:книга[\s\xa0]*царів|Cariv|царів|Цар)|Kgs))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["1Kgs"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Перш(?:[ае][\s\xa0]*(?:книга[\s\xa0]*царів|Cariv|царів))|Трет[яє][\s\xa0]*Царів|3(?:-?(?:тє(?:\.[\s\xa0]*Царів|[\s\xa0]*Царів)|(?:[ае](?:\.[\s\xa0]*Царів|[\s\xa0]*Царів)))|\.[\s\xa0]*Царів|[\s\xa0]*Царів)|I(?:II(?:\.[\s\xa0]*Царів|[\s\xa0]*Царів)|\.[\s\xa0]*(?:книга[\s\xa0]*царів|Cariv|царів)|[\s\xa0]*(?:книга[\s\xa0]*царів|Cariv|царів))|1(?:-?(?:ше(?:\.[\s\xa0]*(?:книга[\s\xa0]*царів|Cariv|царів)|[\s\xa0]*(?:книга[\s\xa0]*царів|Cariv|царів))|(?:[ае](?:\.[\s\xa0]*(?:книга[\s\xa0]*царів|Cariv|царів)|[\s\xa0]*(?:книга[\s\xa0]*царів|Cariv|царів))))|\.[\s\xa0]*(?:книга[\s\xa0]*царів|Cariv|царів)|[\s\xa0]*(?:книга[\s\xa0]*царів|Cariv|царів|Цар)|Kgs))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["2Chr"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Друг(?:[ае][\s\xa0]*(?:книга[\s\xa0]*хроніки?|Літопису|[HȞ]roniky|хроніки|Хроніка?))|II(?:\.[\s\xa0]*(?:книга[\s\xa0]*хроніки?|Літопису|[HȞ]roniky|хроніки|Хроніка?)|[\s\xa0]*(?:книга[\s\xa0]*хроніки?|Літопису|[HȞ]roniky|хроніки|Хроніка?))|2(?:-?(?:ге(?:\.[\s\xa0]*(?:книга[\s\xa0]*хроніки?|Літопису|[HȞ]roniky|хроніки|Хроніка?)|[\s\xa0]*(?:книга[\s\xa0]*хроніки?|Літопису|[HȞ]roniky|хроніки|Хроніка?))|(?:[ае](?:\.[\s\xa0]*(?:книга[\s\xa0]*хроніки?|Літопису|[HȞ]roniky|хроніки|Хроніка?)|[\s\xa0]*(?:книга[\s\xa0]*хроніки?|Літопису|[HȞ]roniky|хроніки|Хроніка?))))|\.[\s\xa0]*(?:книга[\s\xa0]*хроніки?|Літопису|[HȞ]roniky|хроніки|Хроніка?)|[\s\xa0]*(?:книга[\s\xa0]*хроніки?|Літопису|[HȞ]roniky|хроніки|Хр(?:оніка?)?)|Chr))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["1Chr"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Перш(?:[ае][\s\xa0]*(?:книга[\s\xa0]*хроніки?|Літопису|[HȞ]roniky|хроніки|Хроніка?))|I(?:\.[\s\xa0]*(?:книга[\s\xa0]*хроніки?|Літопису|[HȞ]roniky|хроніки|Хроніка?)|[\s\xa0]*(?:книга[\s\xa0]*хроніки?|Літопису|[HȞ]roniky|хроніки|Хроніка?))|1(?:-?(?:ше(?:\.[\s\xa0]*(?:книга[\s\xa0]*хроніки?|Літопису|[HȞ]roniky|хроніки|Хроніка?)|[\s\xa0]*(?:книга[\s\xa0]*хроніки?|Літопису|[HȞ]roniky|хроніки|Хроніка?))|(?:[ае](?:\.[\s\xa0]*(?:книга[\s\xa0]*хроніки?|Літопису|[HȞ]roniky|хроніки|Хроніка?)|[\s\xa0]*(?:книга[\s\xa0]*хроніки?|Літопису|[HȞ]roniky|хроніки|Хроніка?))))|\.[\s\xa0]*(?:книга[\s\xa0]*хроніки?|Літопису|[HȞ]roniky|хроніки|Хроніка?)|[\s\xa0]*(?:книга[\s\xa0]*хроніки?|Літопису|[HȞ]roniky|хроніки|Хр(?:оніка?)?)|Chr))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Ezra"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*Ездри|Ez(?:dra|ra)|Єзд(?:ри)?|Езд(?:р[аи])?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Neh"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*Неемі[ії]|Не(?:ем(?:і[яії])?|єм(?:і[ії])?)|Ne(?:emija|h))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["GkEsth"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		GkEsth
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Esth"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*Ес(?:тер|фір)|Est(?:er|h)|Ес(?:фір|т(?:ер)?))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Job"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*[ІИЙ]ова|Іова|Jo[bv]|[ИЙ]ова?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Ps"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*Псалмів|Ps(?:almy)?|Пс(?:ал(?:ти́р|м(?:ів|и)))?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["PrAzar"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Молитва[\s\xa0]*Азарі[ії]|PrAzar)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Prov"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*При(?:повісте[ий][\s\xa0]*Соломонових|казок[\s\xa0]*Соломонових)|Pr(?:ypovisti|ov)|Пр(?:и(?:пові(?:док|ст(?:е(?:[ий](?:[\s\xa0]*соломонових)?)|і))|каз(?:ки|ок)|тч(?:і(?:[\s\xa0]*Соломона)?)?))?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Eccl"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Проповідника|К(?:нига[\s\xa0]*Ек(?:клезіястова|лезіястова)|оге́лет)|E(?:kklezijast|ccl)|Ек(?:кл(?:езіяст(?:ова|а)?)?|л(?:езіястова)?))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["SgThree"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Пісня[\s\xa0]*трьох[\s\xa0]*отроків|SgThree)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Song"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*Пісні[\s\xa0]*Пісень[\s\xa0]*Соломона|Pisnja[\s\xa0]*nad[\s\xa0]*pisnjamy|Song|П(?:\.[\s\xa0]*П|існ(?:я[\s\xa0]*(?:над[\s\xa0]*піснями(?:[\s\xa0]*Соломона)?|Пісне[ий])|і[\s\xa0]*Пісень)?|[\s\xa0]*П))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Jer"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*пророка[\s\xa0]*Єремі[ії]|Jer(?:emija)?|Єр(?:емі[яії])?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Ezek"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*пророка[\s\xa0]*Єзекі[ії]ля|Jezeki[iï]l['’]|Ezek|Єз(?:екі[ії]л[аья])?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Dan"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*пророка[\s\xa0]*Дани[ії]ла|Dan(?:y[iï]l)?|Дан(?:и[ії]ла?)?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Hos"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*пророка[\s\xa0]*Осі[ії]|Osija|Hos|Ос(?:і[яії])?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Joel"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*(?:пророка[\s\xa0]*[ИЙ]оіла|[ИЙ]оіла)|Jo[eiï]l|(?:[ИЙ]о(?:і(?:ла?|н)|ї[лн])))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Amos"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*пророка[\s\xa0]*Амоса|Amos|Ам(?:оса?)?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Obad"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*пророка[\s\xa0]*[АО]вдія|Авдія|O(?:vdij|bad)|Ов(?:д(?:і[ийя])?)?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Jonah"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*пророка[\s\xa0]*[ИЙ]они|Jonah?|[ИЙ]он[аи])
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Mic"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*пророка[\s\xa0]*М[иі]хея|M(?:y[hȟ]ej|ic)|М(?:их(?:е[ийя])?|іх(?:ея)?))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Nah"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*пророка[\s\xa0]*Наума|Наума?|Na(?:um|h))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Hab"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*пророка[\s\xa0]*Авакума|Avakum|Hab|Ав(?:акума?)?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Zeph"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*пророка[\s\xa0]*Софоні[ії]|Sofonija|Zeph|Соф(?:оні[яії])?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Hag"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*(?:пророка[\s\xa0]*Огія|Огія)|Аггея|Ohij|Hag|Ог(?:і[ийя])?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Zech"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*(?:пророка[\s\xa0]*Захарія|Захарі[ії])|Z(?:a[hȟ]arij|ech)|Зах(?:арі[ийяії])?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Mal"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*(?:пророка[\s\xa0]*Малахі[ії]|Малахі[ії])|Mal(?:a[hȟ]ija)?|Мал(?:ахі[яії])?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Matt"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Jevanhelije[\s\xa0]*vid[\s\xa0]*Matvija|Євангелі(?:я[\s\xa0]*від[\s\xa0]*(?:св(?:\.[\s\xa0]*Матвія|[\s\xa0]*Матвія)|Матвія)|є[\s\xa0]*від[\s\xa0]*(?:св(?:\.[\s\xa0]*Матвія|[\s\xa0]*Матвія)|Мат(?:вія|ея)))|Від[\s\xa0]*Матвія|Matt|М(?:ат(?:вія|е[ий])?|т))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["2Macc"]
		apocrypha: true
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Друг[ае][\s\xa0]*(?:книга[\s\xa0]*Макаве(?:[ії]в|Макаве[ії]в))|II(?:\.[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в)|[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в))|2(?:-?(?:ге(?:\.[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в)|[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в))|[ае](?:\.[\s\xa0]*(?:книга[\s\xa0]*Макаве(?:[ії]в|Макаве[ії]в)|[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в))))|\.[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в)|Macc|[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|М(?:ак(?:аве[ії]в)?|к))))|(?:Друг[ае][\s\xa0]*Макаве(?:[ії]в)|2-?[ае](?:\.[\s\xa0]*Макаве(?:[ії]в|[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в))))|2-?[ае][\s\xa0]*(?:книга[\s\xa0]*Макаве(?:[ії]в|Макаве[ії]в))|2-?[ае][\s\xa0]*Макаве(?:[ії]в)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["3Macc"]
		apocrypha: true
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Трет[яє][\s\xa0]*(?:книга[\s\xa0]*Макаве(?:[ії]в|Макаве[ії]в))|III(?:\.[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в)|[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в))|3(?:-?(?:тє(?:\.[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в)|[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в))|[ае](?:\.[\s\xa0]*(?:книга[\s\xa0]*Макаве(?:[ії]в|Макаве[ії]в)|[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в))))|\.[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в)|Macc|[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|М(?:ак(?:аве[ії]в)?|к))))|(?:Трет[яє][\s\xa0]*Макаве(?:[ії]в)|3-?[ае](?:\.[\s\xa0]*Макаве(?:[ії]в|[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в))))|3-?[ае][\s\xa0]*(?:книга[\s\xa0]*Макаве(?:[ії]в|Макаве[ії]в))|3-?[ае][\s\xa0]*Макаве(?:[ії]в)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["4Macc"]
		apocrypha: true
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Четверта[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в)|IV(?:\.[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в)|[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в))|4(?:\.[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в)|Macc|[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|М(?:ак(?:аве[ії]в)?|к))))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["1Macc"]
		apocrypha: true
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Перш[ае][\s\xa0]*(?:книга[\s\xa0]*Макаве(?:[ії]в|Макаве[ії]в))|I(?:\.[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в)|[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в))|1(?:-?(?:ше(?:\.[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в)|[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в))|[ае](?:\.[\s\xa0]*(?:книга[\s\xa0]*Макаве(?:[ії]в|Макаве[ії]в)|[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в))))|\.[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в)|Macc|[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|М(?:ак(?:аве[ії]в)?|к))))|(?:Перш[ае][\s\xa0]*Макаве(?:[ії]в)|1-?[ае](?:\.[\s\xa0]*Макаве(?:[ії]в|[\s\xa0]*(?:книга[\s\xa0]*Макаве[ії]в|Макаве[ії]в))))|1-?[ае][\s\xa0]*(?:книга[\s\xa0]*Макаве(?:[ії]в|Макаве[ії]в))|1-?[ае][\s\xa0]*Макаве(?:[ії]в)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Mark"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Jevanhelije[\s\xa0]*vid[\s\xa0]*Marka|Євангелі(?:[яє][\s\xa0]*від[\s\xa0]*(?:св(?:\.[\s\xa0]*Марка|[\s\xa0]*Марка)|Марка))|Від[\s\xa0]*Марка|Mark|М(?:арк[ао]|[кр]))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Luke"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Jevanhelije[\s\xa0]*vid[\s\xa0]*Luky|Євангелі(?:я[\s\xa0]*від[\s\xa0]*(?:св(?:\.[\s\xa0]*Луки|[\s\xa0]*Луки)|Луки)|є[\s\xa0]*від[\s\xa0]*(?:св(?:\.[\s\xa0]*Луки|[\s\xa0]*Луки)|Лу(?:[\s\xa0]*ки|ки)))|Від[\s\xa0]*Луки|Luke|Л(?:ук[аи]|к))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["1John"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Per[sš]e[\s\xa0]*poslannja[\s\xa0]*apostola[\s\xa0]*Ivana|Перш(?:[ае][\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана)))|I(?:\.[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана))|[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана)))|1(?:-?(?:ше(?:\.[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана))|[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана)))|(?:[ае](?:\.[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана))|[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана)))))|\.[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана))|John|[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|в(?:ана)?))))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["2John"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Druhe[\s\xa0]*poslannja[\s\xa0]*apostola[\s\xa0]*Ivana|Послання[\s\xa0]*до[\s\xa0]*Тита|Друг(?:[ае][\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана)))|II(?:\.[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана))|[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана)))|2(?:-?(?:ге(?:\.[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана))|[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана)))|(?:[ае](?:\.[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана))|[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана)))))|\.[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана))|John|[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|в(?:ана)?))))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["3John"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Tretje[\s\xa0]*poslannja[\s\xa0]*apostola[\s\xa0]*Ivana|Трет(?:[яє][\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана)))|III(?:\.[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана))|[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана)))|3(?:-?(?:тє(?:\.[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана))|[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана)))|(?:[ае](?:\.[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана))|[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана)))))|\.[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|вана))|John|[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*св(?:\.[\s\xa0]*апостола[\s\xa0]*Іоанна|[\s\xa0]*апостола[\s\xa0]*Іоанна)|послання[\s\xa0]*апостола[\s\xa0]*Івана|Послання[\s\xa0]*Івана|[ИЙ]оаново|І(?:оанна|в(?:ана)?))))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["John"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Євангелі(?:я[\s\xa0]*від[\s\xa0]*(?:св(?:\.[\s\xa0]*Івана|[\s\xa0]*Івана)|Івана)|є[\s\xa0]*від[\s\xa0]*(?:св(?:\.[\s\xa0]*[ИЙ]оана|[\s\xa0]*[ИЙ]оана)|Івана))|Від[\s\xa0]*Івана|J(?:evanhelije[\s\xa0]*vid[\s\xa0]*Ivana|ohn)|[ИЙ]оана?|І(?:в(?:ана)?|н))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Acts"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Dijannja[\s\xa0]*svjaty[hȟ][\s\xa0]*apostoliv|Acts|Ді(?:ян(?:ня(?:[\s\xa0]*Святих[\s\xa0]*Апостолів)?)?|(?:[ії](?:[\s\xa0]*(?:святих[\s\xa0]*апостолів|Апостолів))?)))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Rom"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Poslannja[\s\xa0]*apostola[\s\xa0]*Pavla[\s\xa0]*do[\s\xa0]*rymljan|Послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*римлян|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*римлян)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*римлян|до[\s\xa0]*римлян)|До[\s\xa0]*римлян|Rom|Рим(?:ляни?)?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["2Cor"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		2[\s\xa0]*Коринтяни|(?:Druhe[\s\xa0]*poslannja[\s\xa0]*apostola[\s\xa0]*Pavla[\s\xa0]*do[\s\xa0]*korynfjan|Друг(?:[ае][\s\xa0]*(?:послання[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*коринфян|Послання[\s\xa0]*до[\s\xa0]*Коринтян|до[\s\xa0]*коринтян|Корин(?:тяни|фян)|коринтян))|II(?:\.[\s\xa0]*(?:послання[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*коринфян|Послання[\s\xa0]*до[\s\xa0]*Коринтян|до[\s\xa0]*коринтян|Корин(?:тяни|фян)|коринтян)|[\s\xa0]*(?:послання[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*коринфян|Послання[\s\xa0]*до[\s\xa0]*Коринтян|до[\s\xa0]*коринтян|Корин(?:тяни|фян)|коринтян))|2(?:-?(?:ге(?:\.[\s\xa0]*(?:послання[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*коринфян|Послання[\s\xa0]*до[\s\xa0]*Коринтян|до[\s\xa0]*коринтян|Корин(?:тяни|фян)|коринтян)|[\s\xa0]*(?:послання[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*коринфян|Послання[\s\xa0]*до[\s\xa0]*Коринтян|до[\s\xa0]*коринтян|Корин(?:тяни|фян)|коринтян))|(?:[ае](?:\.[\s\xa0]*(?:послання[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*коринфян|Послання[\s\xa0]*до[\s\xa0]*Коринтян|до[\s\xa0]*коринтян|Корин(?:тяни|фян)|коринтян)|[\s\xa0]*(?:послання[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*коринфян|Послання[\s\xa0]*до[\s\xa0]*Коринтян|до[\s\xa0]*коринтян|Корин(?:тяни|фян)|коринтян))))|\.[\s\xa0]*(?:послання[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*коринфян|Послання[\s\xa0]*до[\s\xa0]*Коринтян|до[\s\xa0]*коринтян|Корин(?:тяни|фян)|коринтян)|[\s\xa0]*(?:послання[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*коринфян|Послання[\s\xa0]*до[\s\xa0]*Коринтян|до[\s\xa0]*коринтян|коринтян|Кор(?:инфян)?)|Cor))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["1Cor"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		1[\s\xa0]*Коринтяни|(?:Per[sš]e[\s\xa0]*poslannja[\s\xa0]*apostola[\s\xa0]*Pavla[\s\xa0]*do[\s\xa0]*korynfjan|Перш(?:[ае][\s\xa0]*(?:послання[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*коринфян|Послання[\s\xa0]*до[\s\xa0]*Коринтян|до[\s\xa0]*коринтян|Корин(?:тяни|фян)|коринтян))|I(?:\.[\s\xa0]*(?:послання[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*коринфян|Послання[\s\xa0]*до[\s\xa0]*Коринтян|до[\s\xa0]*коринтян|Корин(?:тяни|фян)|коринтян)|[\s\xa0]*(?:послання[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*коринфян|Послання[\s\xa0]*до[\s\xa0]*Коринтян|до[\s\xa0]*коринтян|Корин(?:тяни|фян)|коринтян))|1(?:-?(?:ше(?:\.[\s\xa0]*(?:послання[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*коринфян|Послання[\s\xa0]*до[\s\xa0]*Коринтян|до[\s\xa0]*коринтян|Корин(?:тяни|фян)|коринтян)|[\s\xa0]*(?:послання[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*коринфян|Послання[\s\xa0]*до[\s\xa0]*Коринтян|до[\s\xa0]*коринтян|Корин(?:тяни|фян)|коринтян))|(?:[ае](?:\.[\s\xa0]*(?:послання[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*коринфян|Послання[\s\xa0]*до[\s\xa0]*Коринтян|до[\s\xa0]*коринтян|Корин(?:тяни|фян)|коринтян)|[\s\xa0]*(?:послання[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*коринфян|Послання[\s\xa0]*до[\s\xa0]*Коринтян|до[\s\xa0]*коринтян|Корин(?:тяни|фян)|коринтян))))|\.[\s\xa0]*(?:послання[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*коринфян|Послання[\s\xa0]*до[\s\xa0]*Коринтян|до[\s\xa0]*коринтян|Корин(?:тяни|фян)|коринтян)|[\s\xa0]*(?:послання[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*коринфян|Послання[\s\xa0]*до[\s\xa0]*Коринтян|до[\s\xa0]*коринтян|коринтян|Кор(?:инфян)?)|Cor))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Gal"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Poslannja[\s\xa0]*apostola[\s\xa0]*Pavla[\s\xa0]*do[\s\xa0]*halativ|По(?:[\s\xa0]*слання[\s\xa0]*до[\s\xa0]*Галатів|слання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*галатів|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*галатів)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*галатів|до[\s\xa0]*галатів))|До[\s\xa0]*галатів|Gal|Гал(?:ат(?:яни|ів))?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Eph"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Poslannja[\s\xa0]*apostola[\s\xa0]*Pavla[\s\xa0]*do[\s\xa0]*efesjan|По(?:[\s\xa0]*слан[\s\xa0]*ня[\s\xa0]*до[\s\xa0]*Єфесян|слання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*ефесян|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*ефесян)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*ефесян|до[\s\xa0]*ефесян))|До[\s\xa0]*ефесян|Eph|Єф|Еф(?:есяни?)?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Phil"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*филип['’]ян|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*филип['’]ян)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*филип['’]ян|до[\s\xa0]*(?:Філіп['’]ян|филип['’]ян))|P(?:oslannja[\s\xa0]*apostola[\s\xa0]*Pavla[\s\xa0]*do[\s\xa0]*fylyp['’]jan|hil)|Ф(?:ил(?:ип(?:['’]яни|яни))?|лп))|(?:До[\s\xa0]*филип['’]ян|Филип[’']ян)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Col"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Poslannja[\s\xa0]*apostola[\s\xa0]*Pavla[\s\xa0]*do[\s\xa0]*kolosjan|Послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*колосян|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*колосян)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*колосян|до[\s\xa0]*Колосян)|До[\s\xa0]*колоссян|Col|Кол(?:ос(?:сян|яни?))?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["2Thess"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Druhe[\s\xa0]*poslannja[\s\xa0]*apostola[\s\xa0]*Pavla[\s\xa0]*do[\s\xa0]*solunjan|Друг(?:[ае][\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|до[\s\xa0]*(?:фессалонікі[ий]ців|с(?:алонікі[ий]ців|олунян)))|фессалонікі[ий]ців|до[\s\xa0]*солунян|Солун(?:ьці|ян)))|II(?:\.[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|до[\s\xa0]*(?:фессалонікі[ий]ців|с(?:алонікі[ий]ців|олунян)))|фессалонікі[ий]ців|до[\s\xa0]*солунян|Солун(?:ьці|ян))|[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|до[\s\xa0]*(?:фессалонікі[ий]ців|с(?:алонікі[ий]ців|олунян)))|фессалонікі[ий]ців|до[\s\xa0]*солунян|Солун(?:ьці|ян)))|2(?:-?(?:ге(?:\.[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|до[\s\xa0]*(?:фессалонікі[ий]ців|с(?:алонікі[ий]ців|олунян)))|фессалонікі[ий]ців|до[\s\xa0]*солунян|Солун(?:ьці|ян))|[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|до[\s\xa0]*(?:фессалонікі[ий]ців|с(?:алонікі[ий]ців|олунян)))|фессалонікі[ий]ців|до[\s\xa0]*солунян|Солун(?:ьці|ян)))|(?:[ае](?:\.[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|до[\s\xa0]*(?:фессалонікі[ий]ців|с(?:алонікі[ий]ців|олунян)))|фессалонікі[ий]ців|до[\s\xa0]*солунян|Солун(?:ьці|ян))|[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|до[\s\xa0]*(?:фессалонікі[ий]ців|с(?:алонікі[ий]ців|олунян)))|фессалонікі[ий]ців|до[\s\xa0]*солунян|Солун(?:ьці|ян)))))|\.[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|до[\s\xa0]*(?:фессалонікі[ий]ців|с(?:алонікі[ий]ців|олунян)))|фессалонікі[ий]ців|до[\s\xa0]*солунян|Солун(?:ьці|ян))|Thess|[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|до[\s\xa0]*(?:фессалонікі[ий]ців|с(?:алонікі[ий]ців|олунян)))|фессалонікі[ий]ців|до[\s\xa0]*солунян|Сол(?:ун(?:ьці|ян))?)))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["1Thess"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Per[sš]e[\s\xa0]*poslannja[\s\xa0]*apostola[\s\xa0]*Pavla[\s\xa0]*do[\s\xa0]*solunjan|Перш(?:[ае][\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|до[\s\xa0]*(?:фессалонікі[ий]ців|с(?:алонікі[ий]ців|олунян)))|фессалонікі[ий]ців|до[\s\xa0]*солунян|Солун(?:ьці|ян)))|I(?:\.[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|до[\s\xa0]*(?:фессалонікі[ий]ців|с(?:алонікі[ий]ців|олунян)))|фессалонікі[ий]ців|до[\s\xa0]*солунян|Солун(?:ьці|ян))|[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|до[\s\xa0]*(?:фессалонікі[ий]ців|с(?:алонікі[ий]ців|олунян)))|фессалонікі[ий]ців|до[\s\xa0]*солунян|Солун(?:ьці|ян)))|1(?:-?(?:ше(?:\.[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|до[\s\xa0]*(?:фессалонікі[ий]ців|с(?:алонікі[ий]ців|олунян)))|фессалонікі[ий]ців|до[\s\xa0]*солунян|Солун(?:ьці|ян))|[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|до[\s\xa0]*(?:фессалонікі[ий]ців|с(?:алонікі[ий]ців|олунян)))|фессалонікі[ий]ців|до[\s\xa0]*солунян|Солун(?:ьці|ян)))|(?:[ае](?:\.[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|до[\s\xa0]*(?:фессалонікі[ий]ців|с(?:алонікі[ий]ців|олунян)))|фессалонікі[ий]ців|до[\s\xa0]*солунян|Солун(?:ьці|ян))|[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|до[\s\xa0]*(?:фессалонікі[ий]ців|с(?:алонікі[ий]ців|олунян)))|фессалонікі[ий]ців|до[\s\xa0]*солунян|Солун(?:ьці|ян)))))|\.[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|до[\s\xa0]*(?:фессалонікі[ий]ців|с(?:алонікі[ий]ців|олунян)))|фессалонікі[ий]ців|до[\s\xa0]*солунян|Солун(?:ьці|ян))|Thess|[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*солунян|до[\s\xa0]*(?:фессалонікі[ий]ців|с(?:алонікі[ий]ців|олунян)))|фессалонікі[ий]ців|до[\s\xa0]*солунян|Сол(?:ун(?:ьці|ян))?)))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["2Tim"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Druhe[\s\xa0]*poslannja[\s\xa0]*apostola[\s\xa0]*Pavla[\s\xa0]*do[\s\xa0]*Tymofija|Друг(?:[ае][\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Тимофія|до[\s\xa0]*Тимо(?:тея|фія)|Тимофію)|Ти(?:­мофія|мо(?:те[ий]|фію))))|II(?:\.[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Тимофія|до[\s\xa0]*Тимо(?:тея|фія)|Тимофію)|Ти(?:­мофія|мо(?:те[ий]|фію)))|[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Тимофія|до[\s\xa0]*Тимо(?:тея|фія)|Тимофію)|Ти(?:­мофія|мо(?:те[ий]|фію))))|2(?:-?(?:ге(?:\.[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Тимофія|до[\s\xa0]*Тимо(?:тея|фія)|Тимофію)|Ти(?:­мофія|мо(?:те[ий]|фію)))|[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Тимофія|до[\s\xa0]*Тимо(?:тея|фія)|Тимофію)|Ти(?:­мофія|мо(?:те[ий]|фію))))|(?:[ае](?:\.[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Тимофія|до[\s\xa0]*Тимо(?:тея|фія)|Тимофію)|Ти(?:­мофія|мо(?:те[ий]|фію)))|[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Тимофія|до[\s\xa0]*Тимо(?:тея|фія)|Тимофію)|Ти(?:­мофія|мо(?:те[ий]|фію))))))|\.[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Тимофія|до[\s\xa0]*Тимо(?:тея|фія)|Тимофію)|Ти(?:­мофія|мо(?:те[ий]|фію)))|[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Тимофія|до[\s\xa0]*Тимо(?:тея|фія)|Тимофію)|Ти(?:­мофія|м(?:о(?:те[ий]|фію))?))|Tim))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["1Tim"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Per[sš]e[\s\xa0]*poslannja[\s\xa0]*apostola[\s\xa0]*Pavla[\s\xa0]*do[\s\xa0]*Tymofija|Перш(?:[ае][\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Тимофія|до[\s\xa0]*Тимо(?:тея|фія)|Тимофію)|Ти(?:­мофія|мо(?:те[ий]|фію))))|I(?:\.[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Тимофія|до[\s\xa0]*Тимо(?:тея|фія)|Тимофію)|Ти(?:­мофія|мо(?:те[ий]|фію)))|[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Тимофія|до[\s\xa0]*Тимо(?:тея|фія)|Тимофію)|Ти(?:­мофія|мо(?:те[ий]|фію))))|1(?:-?(?:ше(?:\.[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Тимофія|до[\s\xa0]*Тимо(?:тея|фія)|Тимофію)|Ти(?:­мофія|мо(?:те[ий]|фію)))|[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Тимофія|до[\s\xa0]*Тимо(?:тея|фія)|Тимофію)|Ти(?:­мофія|мо(?:те[ий]|фію))))|(?:[ае](?:\.[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Тимофія|до[\s\xa0]*Тимо(?:тея|фія)|Тимофію)|Ти(?:­мофія|мо(?:те[ий]|фію)))|[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Тимофія|до[\s\xa0]*Тимо(?:тея|фія)|Тимофію)|Ти(?:­мофія|мо(?:те[ий]|фію))))))|\.[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Тимофія|до[\s\xa0]*Тимо(?:тея|фія)|Тимофію)|Ти(?:­мофія|мо(?:те[ий]|фію)))|[\s\xa0]*(?:послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Ти­мофія)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Тимофія|до[\s\xa0]*Тимо(?:тея|фія)|Тимофію)|Ти(?:­мофія|м(?:о(?:те[ий]|фію))?))|Tim))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Titus"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Poslannja[\s\xa0]*apostola[\s\xa0]*Pavla[\s\xa0]*do[\s\xa0]*Tyta|Послан(?:ня[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Тита|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Тита)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Тита)|[\s\xa0]*ня[\s\xa0]*до[\s\xa0]*Тита)|До[\s\xa0]*Тита|Titus|Тита?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Phlm"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Филимона|[\s\xa0]*апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Филимона)|апостола[\s\xa0]*Павла[\s\xa0]*до[\s\xa0]*Филимона|до[\s\xa0]*Фили(?:пі[ий]ців|мона))|До[\s\xa0]*Филимона|P(?:oslannja[\s\xa0]*apostola[\s\xa0]*Pavla[\s\xa0]*do[\s\xa0]*Fylymona|hlm)|Ф(?:илим(?:она?)?|лм))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Heb"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Poslannja[\s\xa0]*do[\s\xa0]*jevre[iï]v|Послан(?:[\s\xa0]*ня[\s\xa0]*до[\s\xa0]*Євре[ії]в|ня[\s\xa0]*до[\s\xa0]*євре[ії]в)|До[\s\xa0]*євре[ії]в|Heb|Євр(?:е[ії]в?)?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Jas"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Poslannja[\s\xa0]*apostola[\s\xa0]*Jakova|Соборне[\s\xa0]*послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Якова|[\s\xa0]*апостола[\s\xa0]*Якова)|Якова)|Послання[\s\xa0]*(?:апостола[\s\xa0]*Якова|Якова)|Jas|Як(?:ова?)?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["2Pet"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Druhe[\s\xa0]*poslannja[\s\xa0]*apostola[\s\xa0]*Petra|Друг(?:[ае][\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Петра|[\s\xa0]*апостола[\s\xa0]*Петра)|апостола[\s\xa0]*Петра|Петра)|послання[\s\xa0]*(?:апостола[\s\xa0]*Петра|Петра)|Петр(?:ово|а)))|II(?:\.[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Петра|[\s\xa0]*апостола[\s\xa0]*Петра)|апостола[\s\xa0]*Петра|Петра)|послання[\s\xa0]*(?:апостола[\s\xa0]*Петра|Петра)|Петр(?:ово|а))|[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Петра|[\s\xa0]*апостола[\s\xa0]*Петра)|апостола[\s\xa0]*Петра|Петра)|послання[\s\xa0]*(?:апостола[\s\xa0]*Петра|Петра)|Петр(?:ово|а)))|2(?:-?(?:ге(?:\.[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Петра|[\s\xa0]*апостола[\s\xa0]*Петра)|апостола[\s\xa0]*Петра|Петра)|послання[\s\xa0]*(?:апостола[\s\xa0]*Петра|Петра)|Петр(?:ово|а))|[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Петра|[\s\xa0]*апостола[\s\xa0]*Петра)|апостола[\s\xa0]*Петра|Петра)|послання[\s\xa0]*(?:апостола[\s\xa0]*Петра|Петра)|Петр(?:ово|а)))|(?:[ае](?:\.[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Петра|[\s\xa0]*апостола[\s\xa0]*Петра)|апостола[\s\xa0]*Петра|Петра)|послання[\s\xa0]*(?:апостола[\s\xa0]*Петра|Петра)|Петр(?:ово|а))|[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Петра|[\s\xa0]*апостола[\s\xa0]*Петра)|апостола[\s\xa0]*Петра|Петра)|послання[\s\xa0]*(?:апостола[\s\xa0]*Петра|Петра)|Петр(?:ово|а)))))|\.[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Петра|[\s\xa0]*апостола[\s\xa0]*Петра)|апостола[\s\xa0]*Петра|Петра)|послання[\s\xa0]*(?:апостола[\s\xa0]*Петра|Петра)|Петр(?:ово|а))|[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Петра|[\s\xa0]*апостола[\s\xa0]*Петра)|апостола[\s\xa0]*Петра|Петра)|послання[\s\xa0]*(?:апостола[\s\xa0]*Петра|Петра)|Пет(?:р(?:ово|а)?)?)|Pet))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["1Pet"]
		regexp: ///(^|[^0-9A-Za-zªµºÀ-ÖØ-öø-ɏЀ-ҁ҃-҇Ҋ-ԧḀ-ỿⱠ-Ɀⷠ-ⷿꙀ-꙯ꙴ-꙽ꙿ-ꚗꚟꜢ-ꞈꞋ-ꞎꞐ-ꞓꞠ-Ɦꟸ-ꟿ])(
		(?:Per[sš]e[\s\xa0]*poslannja[\s\xa0]*apostola[\s\xa0]*Petra|Перш(?:[ае][\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Петра|[\s\xa0]*апостола[\s\xa0]*Петра)|апостола[\s\xa0]*Петра|Петра)|послання[\s\xa0]*(?:апостола[\s\xa0]*Петра|Петра)|Петр(?:ово|а)))|I(?:\.[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Петра|[\s\xa0]*апостола[\s\xa0]*Петра)|апостола[\s\xa0]*Петра|Петра)|послання[\s\xa0]*(?:апостола[\s\xa0]*Петра|Петра)|Петр(?:ово|а))|[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Петра|[\s\xa0]*апостола[\s\xa0]*Петра)|апостола[\s\xa0]*Петра|Петра)|послання[\s\xa0]*(?:апостола[\s\xa0]*Петра|Петра)|Петр(?:ово|а)))|1(?:-?(?:ше(?:\.[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Петра|[\s\xa0]*апостола[\s\xa0]*Петра)|апостола[\s\xa0]*Петра|Петра)|послання[\s\xa0]*(?:апостола[\s\xa0]*Петра|Петра)|Петр(?:ово|а))|[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Петра|[\s\xa0]*апостола[\s\xa0]*Петра)|апостола[\s\xa0]*Петра|Петра)|послання[\s\xa0]*(?:апостола[\s\xa0]*Петра|Петра)|Петр(?:ово|а)))|(?:[ае](?:\.[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Петра|[\s\xa0]*апостола[\s\xa0]*Петра)|апостола[\s\xa0]*Петра|Петра)|послання[\s\xa0]*(?:апостола[\s\xa0]*Петра|Петра)|Петр(?:ово|а))|[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Петра|[\s\xa0]*апостола[\s\xa0]*Петра)|апостола[\s\xa0]*Петра|Петра)|послання[\s\xa0]*(?:апостола[\s\xa0]*Петра|Петра)|Петр(?:ово|а)))))|\.[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Петра|[\s\xa0]*апостола[\s\xa0]*Петра)|апостола[\s\xa0]*Петра|Петра)|послання[\s\xa0]*(?:апостола[\s\xa0]*Петра|Петра)|Петр(?:ово|а))|[\s\xa0]*(?:соборне[\s\xa0]*послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Петра|[\s\xa0]*апостола[\s\xa0]*Петра)|апостола[\s\xa0]*Петра|Петра)|послання[\s\xa0]*(?:апостола[\s\xa0]*Петра|Петра)|Пет(?:р(?:ово|а)?)?)|Pet))
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Jude"]
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Poslannja[\s\xa0]*apostola[\s\xa0]*Judy|Соборне[\s\xa0]*послання[\s\xa0]*(?:св(?:\.[\s\xa0]*апостола[\s\xa0]*Юди|[\s\xa0]*апостола[\s\xa0]*Юди)|Юди)|Послання[\s\xa0]*(?:апостола[\s\xa0]*Юди|Іуди|Юди)|Jude|Іуд|Юд[аи]?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Tob"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*Товита|Tob|Тов(?:ита?)?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Jdt"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Книга[\s\xa0]*Юдити|Юдити|Jdt)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Bar"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Bar|Вар(?:уха)?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	,
		osis: ["Sus"]
		apocrypha: true
		regexp: ///(^|#{bcv_parser::regexps.pre_book})(
		(?:Sus|Сус(?:анна)?)
			)(?:(?=[\d\s\xa0.:,;\x1e\x1f&\(\)（）\[\]/"'\*=~\-\u2013\u2014])|$)///gi
	]
	# Short-circuit the look if we know we want all the books.
	return books if include_apocrypha is true and case_sensitive is "none"
	# Filter out books in the Apocrypha if we don't want them. `Array.map` isn't supported below IE9.
	out = []
	for book in books
		continue if include_apocrypha is false and book.apocrypha? and book.apocrypha is true
		if case_sensitive is "books"
			book.regexp = new RegExp book.regexp.source, "g"
		out.push book
	out

# Default to not using the Apocrypha
bcv_parser::regexps.books = bcv_parser::regexps.get_books false, "none"
