bcv_parser = require("../../js/ascii_bcv_parser.js").bcv_parser

describe "Parsing", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.options.osis_compaction_strategy = "b"
		p.options.sequence_combination_strategy = "combine"

	it "should round-trip OSIS references", ->
		p.set_options osis_compaction_strategy: "bc"
		books = ["Gen","Exod","Lev","Num","Deut","Josh","Judg","Ruth","1Sam","2Sam","1Kgs","2Kgs","1Chr","2Chr","Ezra","Neh","Esth","Job","Ps","Prov","Eccl","Song","Isa","Jer","Lam","Ezek","Dan","Hos","Joel","Amos","Obad","Jonah","Mic","Nah","Hab","Zeph","Hag","Zech","Mal","Matt","Mark","Luke","John","Acts","Rom","1Cor","2Cor","Gal","Eph","Phil","Col","1Thess","2Thess","1Tim","2Tim","Titus","Phlm","Heb","Jas","1Pet","2Pet","1John","2John","3John","Jude","Rev"]
		for book in books
			bc = book + ".1"
			bcv = bc + ".1"
			bcv_range = bcv + "-" + bc + ".2"
			expect(p.parse(bc).osis()).toEqual bc
			expect(p.parse(bcv).osis()).toEqual bcv
			expect(p.parse(bcv_range).osis()).toEqual bcv_range

	it "should round-trip OSIS Apocrypha references", ->
		p.set_options osis_compaction_strategy: "bc", ps151_strategy: "b"
		p.include_apocrypha true
		books = ["Tob","Jdt","GkEsth","Wis","Sir","Bar","PrAzar","Sus","Bel","SgThree","EpJer","1Macc","2Macc","3Macc","4Macc","1Esd","2Esd","PrMan","Ps151"]
		for book in books
			bc = book + ".1"
			bcv = bc + ".1"
			bcv_range = bcv + "-" + bc + ".2"
			expect(p.parse(bc).osis()).toEqual bc
			expect(p.parse(bcv).osis()).toEqual bcv
			expect(p.parse(bcv_range).osis()).toEqual bcv_range
		p.set_options ps151_strategy: "bc"
		expect(p.parse("Ps151.1").osis()).toEqual "Ps.151"
		expect(p.parse("Ps151.1.1").osis()).toEqual "Ps.151.1"
		expect(p.parse("Ps151.1-Ps151.2").osis()).toEqual "Ps.151.1-Ps.151.2"
		p.include_apocrypha false
		for book in books
			bc = book + ".1"
			expect(p.parse(bc).osis()).toEqual ""

	it "should handle a preceding character", ->
		expect(p.parse(" Gen 1").osis()).toEqual "Gen.1"
		expect(p.parse("Matt5John3").osis()).toEqual "Matt.5,John.3"
		expect(p.parse("1Ps 1").osis()).toEqual ""
		expect(p.parse("11Sam 1").osis()).toEqual ""

describe "Localized book Gen (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Gen (ascii)", ->
		`
		expect(p.parse("Ensimmainen Mooseksen kirja 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Kitabu cha Kwanza cha Musa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ksiega Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ksiega Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ksiegi Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ksiegi Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ksiega Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ksiega Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ksiegi Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ksiegi Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ksiega Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ksiega Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ksiegi Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ksiegi Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ks. Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ks. Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ks. Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ks. Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ks. Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ks. Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ks Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ks Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ks Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ks Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ks Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ks Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Ensimmainen Mooseksen 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvni kniha Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ksiega Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ksiega Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ksiegi Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ksiegi Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ksiega Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ksiega Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ksiegi Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ksiegi Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prva kniha Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ksiega Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ksiega Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ksiegi Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ksiegi Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ksiega Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ksiega Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ksiegi Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ksiegi Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvy list Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mooseksen kirja 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. kniha Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mooseksen kirja 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. kniha Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mooseksen kirja 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 kniha Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ks. Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ks. Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mooseksen kirja 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I kniha Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ks. Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ks. Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("liv Konmansman an 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ks. Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ks. Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ks Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ks Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Forsta Moseboken 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ks. Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ks. Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ks Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ks Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Purwaning Dumadi 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("utpattiko pustak 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ks Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ks Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Erste Buch Mose 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Fyrsta bok Mose 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ks Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ks Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Kniha stvorenia 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Knjiga Postanka 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvni Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 k. Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Forsta Mosebok 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Fyrsta Mosebok 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Ksiega Rodzaju 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Ksiegi Rodzaju 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prva Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvy Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 k Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Liber Genesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Mojz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Mojz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Mojz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Buch Mose 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mooseksen 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Moseboken 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Eerste Mozes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mooseksen 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("K. stvorenia 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Kniha povodu 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Buch Mose 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mooseksen 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Moseboken 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mooseksen 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("K stvorenia 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Ks. Rodzaju 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mosebog 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mosebok 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Atiyakamam 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Elso Mozes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Erste Mose 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mosebok 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Konmansman 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Ks Rodzaju 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mosebog 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mosebok 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1e. Mozes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Beresjiet 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneeses 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneesus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneises 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneisis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneisus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gennieses 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genniesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genniesus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genniises 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genniisis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genniisus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mosebok 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("K. povodu 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Zanafilla 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("utpattiko 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mozes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1e Mozes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Bilowgii 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneeses 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneesus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneises 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneisis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneisus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genieses 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geniesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geniesus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geniises 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geniisis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geniisus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneses 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gennesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gennesus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gennises 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gennisis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gennisus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mozes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("K povodu 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Postanak 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Teremtes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mozes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mojz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mose 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Facerea 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneses 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genesus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genezis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genises 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genisis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genisus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gennsis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Henesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mozes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mojz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Mozes I 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Utpaati 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("utpatti 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mojz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Moos 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mose 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mos 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Buttja 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genesa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genese 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genesi 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneza 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gensis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mojz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mos 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Mwanzo 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Moj 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mos 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Moz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mo 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Moj 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mos 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Jenez 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("utpat 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mo 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Post 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Rodz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gen 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Jen 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Mwa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Rdz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Ter 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Zan 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Ge 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gn 1:1").osis()).toEqual("Gen.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ENSIMMAINEN MOOSEKSEN KIRJA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("KITABU CHA KWANZA CHA MUSA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KSIEGA MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KSIEGI MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KSIEGA MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KSIEGI MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KSIEGA MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KSIEGI MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KS. MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KS. MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KS. MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KS. MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KS. MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KS. MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KS MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KS MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KS MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KS MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KS MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KS MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ENSIMMAINEN MOOSEKSEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNI KNIHA MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KSIEGA MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KSIEGI MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KSIEGA MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KSIEGI MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVA KNIHA MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KSIEGA MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KSIEGI MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KSIEGA MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KSIEGI MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVY LIST MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOOSEKSEN KIRJA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KNIHA MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOOSEKSEN KIRJA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KNIHA MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOOSEKSEN KIRJA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KNIHA MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KS. MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KS. MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOOSEKSEN KIRJA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KNIHA MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KS. MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KS. MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("LIV KONMANSMAN AN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KS. MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KS. MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KS MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KS MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("FORSTA MOSEBOKEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KS. MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KS. MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KS MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KS MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PURWANING DUMADI 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("UTPATTIKO PUSTAK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KS MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KS MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ERSTE BUCH MOSE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("FYRSTA BOK MOSE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KS MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KS MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("KNIHA STVORENIA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("KNJIGA POSTANKA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNI MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 K. MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("FORSTA MOSEBOK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("FYRSTA MOSEBOK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("KSIEGA RODZAJU 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("KSIEGI RODZAJU 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVA MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVY MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 K MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("LIBER GENESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA MOJZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE MOJZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY MOJZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. BUCH MOSE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOOSEKSEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOSEBOKEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("EERSTE MOZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOOSEKSEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("K. STVORENIA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("KNIHA POVODU 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 BUCH MOSE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOOSEKSEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOSEBOKEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOOSEKSEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("K STVORENIA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("KS. RODZAJU 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOSEBOG 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOSEBOK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ATIYAKAMAM 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ELSO MOZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ERSTE MOSE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOSEBOK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("KONMANSMAN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("KS RODZAJU 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOSEBOG 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOSEBOK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1E. MOZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("BERESJIET 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNEESES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNEESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNEESUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNEISES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNEISIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNEISUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNIESES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNIESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNIESUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNIISES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNIISIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNIISUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOSEBOK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("K. POVODU 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ZANAFILLA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("UTPATTIKO 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1E MOZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("BILOWGII 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEESES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEESUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEISES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEISIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEISUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENIESES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENIESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENIESUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENIISES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENIISIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENIISUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNESES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNESUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNISES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNISIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNISUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("K POVODU 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("POSTANAK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("TEREMTES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOJZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOSE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("FACEREA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENESES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENESUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEZIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENISES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENISIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENISUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNEIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNSIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("HENESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOJZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("MOZES I 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("UTPAATI 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("UTPATTI 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOJZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOOS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOSE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("BUTTJA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENESA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENESE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENESI 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEZA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENSIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOJZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("MWANZO 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOJ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MO 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOJ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("JENEZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("UTPAT 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MO 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("POST 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("RODZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("JEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("MWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("RDZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("TER 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ZAN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GN 1:1").osis()).toEqual("Gen.1.1")
		`
		true
describe "Localized book Exod (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Exod (ascii)", ->
		`
		expect(p.parse("Kitabu cha Pili cha Musa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druga Ksiega Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druga Ksiegi Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Drugi Ksiega Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Drugi Ksiegi Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Toinen Mooseksen kirja 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druha kniha Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy kniha Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Ksiega Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Ksiegi Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Ksiega Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Ksiegi Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druga Ks. Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Drugi Ks. Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy list Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Ksiega Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Ksiegi Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Ksiega Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Ksiegi Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druga Ks Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Drugi Ks Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mooseksen kirja 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. kniha Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mooseksen kirja 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. kniha Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mooseksen kirja 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II kniha Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Ks. Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mooseksen kirja 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 kniha Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Ks. Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Ks. Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Ks Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("liv delivrans lan 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Ks. Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Ks Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druga Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Drugi Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Ks Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Toinen Mooseksen 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Zweite Buch Mose 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Ks Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Andra Moseboken 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druha Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 k. Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Knjiga Izlaska 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Ksiega Wyjscia 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Ksiegi Wyjscia 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Onnur bok Mose 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 k Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Anden Mosebog 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Andra Mosebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Andre Mosebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Annen Mosebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mooseksen 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Masodik Mozes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Onnur Mosebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Buch Mose 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mooseksen 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Moseboken 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mooseksen 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Liber Exodus 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Tweede Mozes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Yattirakamam 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Buch Mose 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mooseksen 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Moseboken 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mosebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Ks. Wyjscia 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Pangentasan 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Zweite Mose 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mosebog 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mosebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Baxniintii 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druga Mojz 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Drugi Mojz 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mosebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Ks Wyjscia 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mosebog 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mosebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2e. Mozes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Anden Mos 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Andre Mos 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Delivrans 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mozes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Kivonulas 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mozes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2e Mozes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mozes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mojz 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Mozes II 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Nirgaman 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mozes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mojz 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mose 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Ecsodus 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Egzodus 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mojz 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mos 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Iesirea 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Izlazak 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mojz 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Moos 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mose 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mos 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Eksodi 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Eksodo 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exodis 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exodul 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exodus 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Moj 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mos 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Kutoka 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Sjemot 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("nirgam 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Moj 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mos 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Moz 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mo 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Dalja 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Egzod 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Esodo 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exode 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exodo 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exods 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Vyhid 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mo 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mz 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exod 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Bax 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Dal 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Ecs 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Egz 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Eks 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exd 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exo 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Izl 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Kiv 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Kut 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Wyj 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Ex 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Wj 1:1").osis()).toEqual("Exod.1.1")
		p.include_apocrypha(false)
		expect(p.parse("KITABU CHA PILI CHA MUSA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGA KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGA KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGI KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGI KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("TOINEN MOOSEKSEN KIRJA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHA KNIHA MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY KNIHA MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGA KS. MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGI KS. MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY LIST MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGA KS MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGI KS MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOOSEKSEN KIRJA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KNIHA MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOOSEKSEN KIRJA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KNIHA MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOOSEKSEN KIRJA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KNIHA MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KS. MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOOSEKSEN KIRJA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KNIHA MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KS. MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KS. MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KS MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("LIV DELIVRANS LAN 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KS. MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KS MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGA MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGI MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KS MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("TOINEN MOOSEKSEN 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ZWEITE BUCH MOSE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KS MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ANDRA MOSEBOKEN 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHA MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 K. MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KNJIGA IZLASKA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KSIEGA WYJSCIA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KSIEGI WYJSCIA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ONNUR BOK MOSE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 K MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ANDEN MOSEBOG 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ANDRA MOSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ANDRE MOSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ANNEN MOSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOOSEKSEN 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("MASODIK MOZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ONNUR MOSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. BUCH MOSE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOOSEKSEN 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOSEBOKEN 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOOSEKSEN 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("LIBER EXODUS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("TWEEDE MOZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("YATTIRAKAMAM 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 BUCH MOSE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOOSEKSEN 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOSEBOKEN 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KS. WYJSCIA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("PANGENTASAN 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ZWEITE MOSE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOSEBOG 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("BAXNIINTII 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGA MOJZ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGI MOJZ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KS WYJSCIA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOSEBOG 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2E. MOZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ANDEN MOS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ANDRE MOS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DELIVRANS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KIVONULAS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2E MOZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOJZ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("MOZES II 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("NIRGAMAN 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOJZ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOSE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ECSODUS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EGZODUS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOJZ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("IESIREA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("IZLAZAK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOJZ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOOS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOSE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EKSODI 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EKSODO 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXODIS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXODUL 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXODUS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOJ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KUTOKA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("SJEMOT 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("NIRGAM 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOJ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOZ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MO 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DALJA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EGZOD 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ESODO 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXODE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXODO 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXODS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("VYHID 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MO 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MZ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXOD 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("BAX 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DAL 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ECS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EGZ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EKS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXD 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXO 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("IZL 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KIV 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KUT 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("WYJ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EX 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("WJ 1:1").osis()).toEqual("Exod.1.1")
		`
		true
describe "Localized book Bel (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Bel (ascii)", ->
		`
		expect(p.parse("Istoria omorarii balaurului si a sfaramarii lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Danieli na Makuhani wa Beli 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Opowiadaniem o Belu i wezu 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Histoia Beli et draconis 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel og dragen i Babylon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Si Bel at ang Dragon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel and the Serpent 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel und Vom Drachen 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel and the Dragon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel y el Serpiente 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria Balaurului 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Baal es a sarkany 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel & the Serpent 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel and the Snake 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel at ang Dragon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel et le Serpent 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel et le serpent 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel ja lohikaarme 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel & the Dragon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel es a sarkany 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel et le Dragon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel et le dragon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel och Ormguden 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel & the Snake 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel and Serpent 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel en de draak 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel et draconis 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel si dragonul 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel y el Dragon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel a'r Ddraig 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel and Dragon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel a’r Ddraig 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel e il Drago 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel e o Dragao 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel e o dragao 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel og drekinn 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel & Serpent 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel and Snake 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel og Dragen 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel og draken 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel & Dragon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel & Snake 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bela i weza 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel a drak 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel 1:1").osis()).toEqual("Bel.1.1")
		`
		true
describe "Localized book Phlm (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Phlm (ascii)", ->
		`
		expect(p.parse("Poslannja apostola Pavla do Fylymona 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilemonukku Elutiya Nirupam 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pavlova poslanica Filemonu 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Paulus' Brev til Filemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Paulus’ Brev til Filemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Paulus’ brev til Filemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Epistulam ad Philemonem 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Bref Pals til Filemons 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Epistula ad Philemonem 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Brevet till Filemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Waraka kwa Filemoni 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Barua kwa Filemoni 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Brevet til Filemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Lettera a Filemone 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Poslanica Filemonu 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Kirje Filemonille 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("List do Filemona 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("List Filemonovi 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemonbrevet 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ad Philemonem 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Kang Filemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemonille 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Kay Filemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Philemonhoz 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilemonukku 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemonhoz 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemonovi 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Philemonem 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemonit 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemona 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemone 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemoni 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemonu 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Philemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemom 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filimon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phlemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phlimon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Philem 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filem 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filim 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phile 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phlmn 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Film 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Flmn 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phlm 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phmn 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Flm 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Fmn 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phm 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Fi 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Fm 1:1").osis()).toEqual("Phlm.1.1")
		p.include_apocrypha(false)
		expect(p.parse("POSLANNJA APOSTOLA PAVLA DO FYLYMONA 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILEMONUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PAVLOVA POSLANICA FILEMONU 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PAULUS' BREV TIL FILEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PAULUS’ BREV TIL FILEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PAULUS’ BREV TIL FILEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("EPISTULAM AD PHILEMONEM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("BREF PALS TIL FILEMONS 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("EPISTULA AD PHILEMONEM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("BREVET TILL FILEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("WARAKA KWA FILEMONI 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("BARUA KWA FILEMONI 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("BREVET TIL FILEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("LETTERA A FILEMONE 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("POSLANICA FILEMONU 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("KIRJE FILEMONILLE 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("LIST DO FILEMONA 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("LIST FILEMONOVI 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMONBREVET 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("AD PHILEMONEM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("KANG FILEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMONILLE 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("KAY FILEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHILEMONHOZ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILEMONUKKU 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMONHOZ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMONOVI 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHILEMONEM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMONIT 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMONA 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMONE 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMONI 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMONU 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHILEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMOM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILIMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHLEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHLIMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHILEM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILIM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHILE 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHLMN 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FLMN 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHLM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHMN 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FLM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FMN 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FI 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FM 1:1").osis()).toEqual("Phlm.1.1")
		`
		true
describe "Localized book Lev (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Lev (ascii)", ->
		`
		expect(p.parse("liv Prensip lavi nan Bondye 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzecia Ksiega Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzecia Ksiegi Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Kitabu cha Tatu cha Musa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzeci Ksiega Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzeci Ksiegi Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Ksiega Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Ksiegi Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Kolmas Mooseksen kirja 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretia kniha Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzecia Ks. Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Ksiega Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Ksiegi Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Treti kniha Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzeci Ks. Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzecia Ks Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Ksiega Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Ksiegi Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mooseksen kirja 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. kniha Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzeci Ks Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Ksiega Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Ksiegi Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mooseksen kirja 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III kniha Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Ks. Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mooseksen kirja 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. kniha Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Ks. Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Ks Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzecia Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mooseksen kirja 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 kniha Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Ks. Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Ks Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzeci Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("leviharuko pustak 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Ks. Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Ks Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Dritte Buch Mose 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Kolmas Mooseksen 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Laaivyavyavastha 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitski zakonik 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tredje Moseboken 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretia Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Ks Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Liber Leviticus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Mambo ya Walawi 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Treti Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 k. Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Harmadik Mozes 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mooseksen 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tredje Mosebog 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tredje Mosebok 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 k Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3e. Moseboken 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mooseksen 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Leviyarakamam 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Buch Mose 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mooseksen 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Moseboken 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3e Moseboken 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mosebok 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Laawiyiintii 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzecia Mojz 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Buch Mose 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mooseksen 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Moseboken 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3e. Mosebok 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Derde Mozes 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Dritte Mose 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mosebok 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzeci Mojz 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mosebog 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mosebok 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3e Mosebok 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mozes 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Leviticusi 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tredje Mos 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("leviharuko 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mosebog 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mosebok 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3e. Mozes 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mozes 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mojz 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lebitikus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lefiticus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levetecus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Leveticus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitecus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Leviticos 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Leviticul 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Leviticus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitiket 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitikus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitique 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Livetecus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Liveticus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Livitecus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Liviticus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Mozes III 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mozes 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3e Mozes 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mojz 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mos 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Kaimaman 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lebitico 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lebitiko 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levetcus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitcus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitico 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitiku 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Livetcus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Livitcus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mozes 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mojz 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mose 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Moj 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mos 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitak 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitic 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitik 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Vajikra 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Wajikra 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mojz 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Moos 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mose 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mos 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Walawi 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Moj 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mos 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Moz 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mo 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levyt 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("lewiy 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mo 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mz 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Kapl 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Laaw 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levi 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Kpl 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Law 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Leb 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lef 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lev 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Wal 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Le 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lv 1:1").osis()).toEqual("Lev.1.1")
		p.include_apocrypha(false)
		expect(p.parse("LIV PRENSIP LAVI NAN BONDYE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECIA KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECIA KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KITABU CHA TATU CHA MUSA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECI KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECI KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KOLMAS MOOSEKSEN KIRJA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETIA KNIHA MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECIA KS. MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETI KNIHA MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECI KS. MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECIA KS MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOOSEKSEN KIRJA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KNIHA MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECI KS MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOOSEKSEN KIRJA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KNIHA MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KS. MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOOSEKSEN KIRJA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KNIHA MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KS. MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KS MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECIA MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOOSEKSEN KIRJA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KNIHA MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KS. MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KS MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECI MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVIHARUKO PUSTAK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KS. MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KS MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("DRITTE BUCH MOSE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KOLMAS MOOSEKSEN 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LAAIVYAVYAVASTHA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITSKI ZAKONIK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TREDJE MOSEBOKEN 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETIA MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KS MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LIBER LEVITICUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("MAMBO YA WALAWI 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETI MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 K. MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("HARMADIK MOZES 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOOSEKSEN 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TREDJE MOSEBOG 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TREDJE MOSEBOK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 K MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3E. MOSEBOKEN 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOOSEKSEN 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVIYARAKAMAM 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. BUCH MOSE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOOSEKSEN 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOSEBOKEN 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3E MOSEBOKEN 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOSEBOK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LAAWIYIINTII 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECIA MOJZ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 BUCH MOSE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOOSEKSEN 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOSEBOKEN 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3E. MOSEBOK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("DERDE MOZES 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("DRITTE MOSE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOSEBOK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECI MOJZ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOSEBOG 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOSEBOK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3E MOSEBOK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOZES 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITICUSI 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TREDJE MOS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVIHARUKO 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOSEBOG 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOSEBOK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3E. MOZES 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOZES 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOJZ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEBITIKUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEFITICUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVETECUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVETICUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITECUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITICOS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITICUL 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITICUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITIKET 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITIKUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITIQUE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LIVETECUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LIVETICUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LIVITECUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LIVITICUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("MOZES III 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOZES 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3E MOZES 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOJZ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KAIMAMAN 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEBITICO 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEBITIKO 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVETCUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITCUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITICO 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITIKU 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LIVETCUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LIVITCUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOZES 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOJZ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOSE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOJ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITAK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITIC 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITIK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("VAJIKRA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("WAJIKRA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOJZ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOOS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOSE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("WALAWI 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOJ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOZ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MO 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVYT 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEWIY 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MO 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MZ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KAPL 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LAAW 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVI 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KPL 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LAW 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEB 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEF 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEV 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("WAL 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LV 1:1").osis()).toEqual("Lev.1.1")
		`
		true
describe "Localized book 2Thess (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Thess (ascii)", ->
		`
		expect(p.parse("Tecalonikkiyarukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhe poslannja apostola Pavla do solunjan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Paulus' Andet Brev til Thessalonikerne 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Paulus’ Andet Brev til Thessalonikerne 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Paulus’ andre brev til tessalonikerne 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Pavlova druga poslanica Solunjanima 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Seconda lettera ai Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Toinen Kirje tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Waraka wa Pili kwa Wathesalonike 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Waraka wa Pili kwa Wathesaloniki 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Barua ya Pili kwa Wathesalonike 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Epistula II ad Thessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Epistula ad Thessalonicenses II 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Mga Taga- Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Mga Taga- Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Kirje tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Mga Taga Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Mga Taga Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Kirje tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Kirje tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Kirje tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga Solunjanima Poslanica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga poslanica Solunjanima 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Mga Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Mga Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Masodik Thesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Toinen Tessalonikalaiskirje 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga List do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Drugi List do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Masodik Tesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Toinen Tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Andra Thessalonikerbrevet 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Deuxiemes Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Solunjanima Poslanica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Solunjanima Poslanica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Andra Tessalonikerbrevet 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Deuxieme Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Deuxiemes Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Solunjanima Poslanica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. List do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Mga Taga- Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Mga Taga- Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessalonikalaiskirje 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Solunjanima Poslanica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. List do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Taga- Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Taga- Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonikalaiskirje 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Anden Thessalonikerbrev 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Andet Thessalonikerbrev 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Deuxieme Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha list Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II List do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Mga Taga- Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Mga Taga- Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessalonikalaiskirje 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Mga Taga Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Mga Taga Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Segunda Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Segundo Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tweede Thessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 List do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Taga- Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Taga- Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonikalaiskirje 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Taga Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Taga Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Taga-Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Taga-Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonikerbrevet 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Andre tessalonikerbrev 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Tessalonicenskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Tessalonicenskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Mga Taga Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Mga Taga Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Segundo Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Segundo Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tweede Tessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ad Thessalonicenses II 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Taga Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Taga Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Taga-Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Taga-Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonikerbrevet 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonikerbrevet 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2eme. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Mga Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Mga Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. list Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Masodik Thesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Seconda Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Secondo Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Segundo Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Segundo Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Zweite Thessalonicher 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tecalonikkiyarukku 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonikerbrevet 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thaissaluneekiyon 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonikerbrev 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. list Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2de. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e. Thessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2eme Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2eme. Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Anden Tessalonikerne 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Andre Tessalonikerne 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga Tesalonicensow 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Drugi Tesalonicensow 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha list Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Mga Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Mga Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II list Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessalonicenskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Masodik Tesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thaissaluneekiyon 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonikerbrev 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 e. Thesalonikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 i. Thesalonikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 list Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonicenskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tessalonikerbrev 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o. Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o. Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2a. Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2d. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2de Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2de. Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e Thessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e. Tessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2eme Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o. Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Dezyem Tesalonikyen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessalonicenskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Thessalonicenses II 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonicenskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 e Thesalonikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 i Thesalonikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tessalonikerbrev 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Taga-Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Taga-Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o. Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o. Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2a Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2d Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2d. Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2de Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e Tessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e. Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o. Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o. Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Andre Tessaloniker 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Drugi Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonicensow 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. list Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Pili Wathesalonike 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tesoloniika Labaad 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Taga-Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Taga-Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonicensow 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonikerne 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonicher 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. list Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2d Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o. Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o. Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga Solunjanima 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonicensow 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II list Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Wathesalonike 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonicensow 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonikerne 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonicher 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 e. Selanikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 i. Selanikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 list Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Wathesalonike 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Dezyem Tesalonik 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Wathesalonike 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesaloniceni 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonikyen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Wathesalonike II 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Wathesalonike 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 e Selanikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 i Selanikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesaloniceni 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonikyen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessaloniker 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesaloniceni 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonikyen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Solunjanima 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesaloniika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesaloniceni 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonikyen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessaloniker 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Selanikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Solunjanima 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesaloniika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Solunjanima 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesaloniika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Masodik Thessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Selanikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Solunjanima 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesaloniika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonik 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Masodik Tessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonik 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonik 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tweede Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonik 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Anden Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tweede Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Andre Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tweede Tes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e. Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Sol 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Sol 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Pili Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e. Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Te 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Te 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Pili The 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e. Tes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Sol 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. The 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Pili Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Sol 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. The 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e Tes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Sol 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II The 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Te 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Sol 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 The 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Te 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Te 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Te 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Ts 1:1").osis()).toEqual("2Thess.1.1")
		p.include_apocrypha(false)
		expect(p.parse("TECALONIKKIYARUKKU ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHE POSLANNJA APOSTOLA PAVLA DO SOLUNJAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("PAULUS' ANDET BREV TIL THESSALONIKERNE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("PAULUS’ ANDET BREV TIL THESSALONIKERNE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("PAULUS’ ANDRE BREV TIL TESSALONIKERNE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("PAVLOVA DRUGA POSLANICA SOLUNJANIMA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECONDA LETTERA AI TESSALONICESI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TOINEN KIRJE TESSALONIKALAISILLE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("WARAKA WA PILI KWA WATHESALONIKE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("WARAKA WA PILI KWA WATHESALONIKI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("BARUA YA PILI KWA WATHESALONIKE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("EPISTULA II AD THESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("EPISTULA AD THESSALONICENSES II 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("IKALAWANG MGA TAGA- TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("IKALAWANG MGA TAGA- TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. KIRJE TESSALONIKALAISILLE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("IKALAWANG MGA TAGA TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("IKALAWANG MGA TAGA TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. KIRJE TESSALONIKALAISILLE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II KIRJE TESSALONIKALAISILLE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 KIRJE TESSALONIKALAISILLE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGA SOLUNJANIMA POSLANICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGA POSLANICA SOLUNJANIMA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("IKALAWANG MGA TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("IKALAWANG MGA TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("MASODIK THESSZALONIKAIAKHOZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TOINEN TESSALONIKALAISKIRJE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGA LIST DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGI LIST DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("MASODIK TESSZALONIKAIAKHOZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TOINEN TESSALONIKALAISILLE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ANDRA THESSALONIKERBREVET 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DEUXIEMES THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA KNIHA TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. SOLUNJANIMA POSLANICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. SOLUNJANIMA POSLANICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ANDRA TESSALONIKERBREVET 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DEUXIEME THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DEUXIEMES THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA KNIHA TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY LIST TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II SOLUNJANIMA POSLANICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. LIST DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. MGA TAGA- TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. MGA TAGA- TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESSALONIKALAISKIRJE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 SOLUNJANIMA POSLANICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. LIST DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. MGA TAGA- TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. MGA TAGA- TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSALONIKALAISKIRJE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ANDEN THESSALONIKERBREV 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ANDET THESSALONIKERBREV 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DEUXIEME THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA LIST TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY LIST TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II LIST DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II MGA TAGA- TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II MGA TAGA- TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESSALONIKALAISKIRJE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. MGA TAGA TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. MGA TAGA TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESSALONIKALAISILLE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSZALONIKAIAKHOZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("IKALAWANG TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("IKALAWANG TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SEGUNDA TESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SEGUNDO TESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TWEEDE THESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 LIST DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 MGA TAGA- TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 MGA TAGA- TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSALONIKALAISKIRJE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. MGA TAGA TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. MGA TAGA TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. MGA TAGA-TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. MGA TAGA-TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSALONIKALAISILLE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIKERBREVET 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSZALONIKAIAKHOZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ANDRE TESSALONIKERBREV 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA TESSALONICENSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA KNIHA SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY TESSALONICENSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II MGA TAGA TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II MGA TAGA TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESSALONIKALAISILLE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSZALONIKAIAKHOZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESSZALONIKAIAKHOZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONICIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SEGUNDO TESALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SEGUNDO TESALONISENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TWEEDE TESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("AD THESSALONICENSES II 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 MGA TAGA TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 MGA TAGA TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 MGA TAGA-TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 MGA TAGA-TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSALONIKALAISILLE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIKERBREVET 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSZALONIKAIAKHOZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSALONIKERBREVET 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSZALONIKAIAKHOZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2EME. THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA KNIHA SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY LIST SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESSZALONIKAIAKHOZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. MGA TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. MGA TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. LIST TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("MASODIK THESSZALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONAIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONCIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONIAANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONIIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONIOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONOIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECONDA TESSALONICESI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECONDO TESSALONICESI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SEGUNDO TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SEGUNDO TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ZWEITE THESSALONICHER 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TECALONIKKIYARUKKU 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSALONIKERBREVET 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSZALONIKAIAKHOZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. MGA TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. MGA TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THAISSALUNEEKIYON 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIKERBREV 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. LIST TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2DE. THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E. THESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2EME THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2EME. THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONICIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ANDEN TESSALONIKERNE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ANDRE TESSALONIKERNE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGA TESALONICENSOW 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGI TESALONICENSOW 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA LIST SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY LIST SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II MGA TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II MGA TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II LIST TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESSALONICENSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("IKALAWANG TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("IKALAWANG TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("MASODIK TESSZALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESALONIIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONEANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 MGA TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 MGA TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THAISSALUNEEKIYON 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIKERBREV 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 E. THESALONIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 I. THESALONIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 LIST TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSALONICENSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSALONIKERBREV 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.O. TESALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.O. TESALONISENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2A. TESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2D. THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2DE THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2DE. THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E THESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E. TESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E. THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2EME THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONICIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONAIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONCIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONIAANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONIIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONIOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONOIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2O. TESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DEZYEM TESALONIKYEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESSALONICENSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONICIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONAIN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONION 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSOLONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("THESSALONICENSES II 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSALONICENSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 E THESALONIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 I THESALONIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K. TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSALONIKERBREV 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TAGA-TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TAGA-TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONICIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.O TESALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.O TESALONISENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.O. TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.O. TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2A TESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2D THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2D. THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2DE THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E TESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E. THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONAIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONCIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONIAANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONIIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONIOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONOIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESALONIIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONEANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2O TESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2O. TESALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2O. TESALONISENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ANDRE TESSALONIKER 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGA TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGI TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONICIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONICENSOW 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONISENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONAIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONCIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIAANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONOIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. LIST SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("PILI WATHESALONIKE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TESOLONIIKA LABAAD 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TAGA-TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TAGA-TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONICIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K. TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONICENSOW 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONISENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSALONIKERNE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONAIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONCIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIAANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONICHER 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONOIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. LIST SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.O TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.O TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2D THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESALONIIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONEANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONAIN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONION 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSOLONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2O TESALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2O TESALONISENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2O. TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2O. TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGA SOLUNJANIMA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONICENSOW 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONISENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONAIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONCIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIAANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONOIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II LIST SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESSALONICESI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALONIIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONEANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIAID 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSZALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. WATHESALONIKE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONICENSOW 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONISENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSALONIKERNE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONAIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONCIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIAANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONICHER 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONOIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 E. SELANIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 I. SELANIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 LIST SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSALONICESI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONIIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONEANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIAID 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSZALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. WATHESALONIKE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONAIN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONION 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSOLONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2O TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2O TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DEZYEM TESALONIK 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESSALONICESI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALONIIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONEANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIAID 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSZALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II WATHESALONIKE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONICENI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONIKYEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESSZALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALONIAID 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONAIN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONION 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSOLONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("WATHESALONIKE II 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSALONICESI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONIIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONEANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIAID 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSZALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 WATHESALONIKE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 E SELANIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 I SELANIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K. SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONICENI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONIKYEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSALONIKER 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSZALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONIAID 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONAIN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONION 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSOLONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONICENI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONIKYEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESSZALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALONIAID 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONAIN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONION 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSOLONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. SOLUNJANIMA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONIIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONICENI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONIKYEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSALONIKER 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSZALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONIAID 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONAIN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONION 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSOLONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K. SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. SELANIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. SOLUNJANIMA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONIIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II SOLUNJANIMA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONIIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("MASODIK THESSZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 SELANIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 SOLUNJANIMA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONIIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONIK 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("MASODIK TESSZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONIK 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONIK 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THSSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TWEEDE THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONIK 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ANDEN THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TWEEDE TESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THSSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ANDRE TESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TWEEDE TES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E. THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THSSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA SOL 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY SOL 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESSZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THSSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("PILI THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND TH 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THSSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E. TESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA TE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY TE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESSZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THSSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("PILI THE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THSSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E TESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E. TES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. TH 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. SOL 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("PILI TH 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. SOL 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E TES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND TH 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II SOL 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TH 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 SOL 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TH 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TH 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TH 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TS 1:1").osis()).toEqual("2Thess.1.1")
		`
		true
describe "Localized book 1Thess (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Thess (ascii)", ->
		`
		expect(p.parse("Tecalonikkiyarukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Perse poslannja apostola Pavla do solunjan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Ensimmainen Kirje tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Paulus' 1. Brev til Thessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Paulus’ 1. Brev til Thessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Paulus' 1 Brev til Thessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Paulus’ 1 Brev til Thessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pavlova prva poslanica Solunjanima 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Waraka wa Kwanza kwa Wathesalonike 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Waraka wa Kwanza kwa Wathesaloniki 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Barua ya Kwanza kwa Wathesalonike 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Ensimmainen Tessalonikalaiskirje 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Ensimmainen Tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Epistula I ad Thessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Epistula ad Thessalonicenses I 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prima lettera ai Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsza List do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsze List do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwszy List do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Kirje tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Kirje tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Kirje tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Kirje tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Forsta Thessalonikerbrevet 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Solunjanima Poslanica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva poslanica Solunjanima 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Mga Taga- Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Mga Taga- Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Forsta Tessalonikerbrevet 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premieres Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Mga Taga Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Mga Taga Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Solunjanima Poslanica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Elso Thesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Solunjanima Poslanica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premiere Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premieres Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premiers Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primeira Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primeiro Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Mga Taga- Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Mga Taga- Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Solunjanima Poslanica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. List do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Taga- Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Taga- Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonikalaiskirje 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Eerste Thessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Elso Tesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Solunjanima Poslanica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. List do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Mga Taga- Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Mga Taga- Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessalonikalaiskirje 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsza Tesalonicensow 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsze Tesalonicensow 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwszy Tesalonicensow 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premier Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premiere Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premiers Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni list Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Mga Taga Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Mga Taga Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Mga Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Mga Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 List do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Taga- Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Taga- Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonikalaiskirje 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Taga Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Taga Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Taga-Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Taga-Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonikerbrevet 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Eerste Tessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I List do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Mga Taga- Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Mga Taga- Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessalonikalaiskirje 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Mga Taga Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Mga Taga Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premier Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primero Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primero Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Tessalonicenskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Taga Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Taga Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Taga-Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Taga-Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonikerbrevet 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonikerbrevet 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ere. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Mga Taga Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Mga Taga Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsza Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsze Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwszy Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primer Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primer Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primero Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primero Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Mga Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Mga Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ad Thessalonicenses I 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tecalonikkiyarukku 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonikerbrevet 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thaissaluneekiyon 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonikerbrev 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. list Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e. Thessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1er. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ere Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ere. Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1re. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Erste Thessalonicher 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Mga Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Mga Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. list Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Kwanza Wathesalonike 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primer Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primer Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni list Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thaissaluneekiyon 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonikerbrev 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 e. Thesalonikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 i. Thesalonikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 list Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonicenskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tessalonikerbrev 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o. Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o. Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1a. Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e Thessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e. Tessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1er Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1er. Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ere Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o. Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1re Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1re. Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Mga Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Mga Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I list Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessalonicenskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premye Tesalonikyen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prima Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primo Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonicenskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 e Thesalonikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 i Thesalonikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tessalonikerbrev 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Taga-Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Taga-Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o. Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o. Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1a Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e Tessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1er Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o. Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o. Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1re Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Elso Thesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessalonicenskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tesoloniika Kowaad 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonicenses I 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Taga-Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Taga-Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonicensow 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonicher 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. list Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o. Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o. Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Elso Tesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonicensow 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. list Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonicensow 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonicher 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 e. Selanikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 i. Selanikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 list Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Wathesalonike 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonicensow 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I list Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Wathesalonike 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premye Tesalonik 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Solunjanima 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Wathesalonike 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 e Selanikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 i Selanikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesaloniceni 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonikyen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessaloniker 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Wathesalonike 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesaloniceni 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonikyen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Wathesalonike I 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesaloniceni 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonikyen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessaloniker 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Selanikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Solunjanima 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesaloniika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesaloniceni 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonikyen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Solunjanima 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesaloniika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Selanikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Solunjanima 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesaloniika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Solunjanima 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesaloniika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonik 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Eerste Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonik 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonik 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Eerste Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Elso Thessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonik 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Kwanza Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Eerste Tes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Elso Tessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Kwanza The 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e. Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Kwanza Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Sol 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e. Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Te 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e. Tes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Sol 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. The 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e Tes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Sol 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. The 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Sol 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 The 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Te 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Sol 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I The 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Te 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Te 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Ts 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Te 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Th 1:1").osis()).toEqual("1Thess.1.1")
		p.include_apocrypha(false)
		expect(p.parse("TECALONIKKIYARUKKU ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PERSE POSLANNJA APOSTOLA PAVLA DO SOLUNJAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ENSIMMAINEN KIRJE TESSALONIKALAISILLE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PAULUS' 1. BREV TIL THESSALONIKERNE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PAULUS’ 1. BREV TIL THESSALONIKERNE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PAULUS' 1 BREV TIL THESSALONIKERNE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PAULUS’ 1 BREV TIL THESSALONIKERNE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PAVLOVA PRVA POSLANICA SOLUNJANIMA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("WARAKA WA KWANZA KWA WATHESALONIKE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("WARAKA WA KWANZA KWA WATHESALONIKI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("BARUA YA KWANZA KWA WATHESALONIKE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ENSIMMAINEN TESSALONIKALAISKIRJE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ENSIMMAINEN TESSALONIKALAISILLE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("EPISTULA I AD THESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("EPISTULA AD THESSALONICENSES I 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMA LETTERA AI TESSALONICESI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZA LIST DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZE LIST DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZY LIST DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. KIRJE TESSALONIKALAISILLE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. KIRJE TESSALONIKALAISILLE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 KIRJE TESSALONIKALAISILLE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I KIRJE TESSALONIKALAISILLE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FORSTA THESSALONIKERBREVET 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA SOLUNJANIMA POSLANICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA POSLANICA SOLUNJANIMA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNANG MGA TAGA- TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNANG MGA TAGA- TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FORSTA TESSALONIKERBREVET 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMIERES THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNANG MGA TAGA TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNANG MGA TAGA TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. SOLUNJANIMA POSLANICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ELSO THESSZALONIKAIAKHOZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. SOLUNJANIMA POSLANICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMIERE THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMIERES THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMIERS THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMEIRA TESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMEIRO TESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA KNIHA TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNA MGA TAGA- TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNA MGA TAGA- TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 SOLUNJANIMA POSLANICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. LIST DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. MGA TAGA- TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. MGA TAGA- TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSALONIKALAISKIRJE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("EERSTE THESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ELSO TESSZALONIKAIAKHOZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I SOLUNJANIMA POSLANICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. LIST DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. MGA TAGA- TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. MGA TAGA- TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESSALONIKALAISKIRJE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZA TESALONICENSOW 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZE TESALONICENSOW 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZY TESALONICENSOW 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMIER THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMIERE THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMIERS THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA KNIHA TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI LIST TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY LIST TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNA MGA TAGA TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNA MGA TAGA TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNANG MGA TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNANG MGA TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 LIST DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 MGA TAGA- TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 MGA TAGA- TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSALONIKALAISKIRJE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. MGA TAGA TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. MGA TAGA TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. MGA TAGA-TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. MGA TAGA-TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSALONIKALAISILLE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIKERBREVET 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSZALONIKAIAKHOZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("EERSTE TESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I LIST DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I MGA TAGA- TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I MGA TAGA- TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESSALONIKALAISKIRJE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. MGA TAGA TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. MGA TAGA TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESSALONIKALAISILLE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSZALONIKAIAKHOZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMIER THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMERO TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMERO TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI TESSALONICENSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY LIST TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 MGA TAGA TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 MGA TAGA TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 MGA TAGA-TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 MGA TAGA-TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSALONIKALAISILLE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIKERBREVET 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSZALONIKAIAKHOZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSALONIKERBREVET 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSZALONIKAIAKHOZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ERE. THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I MGA TAGA TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I MGA TAGA TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESSALONIKALAISILLE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSZALONIKAIAKHOZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESSZALONIKAIAKHOZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZA TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZE TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZY TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMER TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMER TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMERO TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMERO TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA KNIHA SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNA MGA TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNA MGA TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("AD THESSALONICENSES I 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TECALONIKKIYARUKKU 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSALONIKERBREVET 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSZALONIKAIAKHOZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. MGA TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. MGA TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THAISSALUNEEKIYON 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIKERBREV 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. LIST TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1E. THESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ER. THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ERE THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ERE. THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1RE. THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ERSTE THESSALONICHER 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESSZALONIKAIAKHOZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. MGA TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. MGA TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. LIST TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("KWANZA WATHESALONIKE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMER TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMER TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA KNIHA SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI LIST SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY LIST SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 MGA TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 MGA TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THAISSALUNEEKIYON 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIKERBREV 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 E. THESALONIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 I. THESALONIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 LIST TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSALONICENSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSALONIKERBREV 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.O. TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.O. TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1A. TESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1E THESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1E. TESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ER THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ER. THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ERE THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1O. TESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1RE THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1RE. THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I MGA TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I MGA TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I LIST TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESSALONICENSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMYE TESALONIKYEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMA TESSALONICESI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMO TESSALONICESI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY LIST SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNANG TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNANG TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSALONICENSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 E THESALONIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 I THESALONIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K. TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSALONIKERBREV 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TAGA-TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TAGA-TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.O TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.O TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.O. TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.O. TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1A TESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1E TESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ER THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1O TESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1O. TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1O. TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1RE THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ELSO THESSZALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESSALONICENSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TESOLONIIKA KOWAAD 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONICENSES I 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TAGA-TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TAGA-TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K. TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONICENSOW 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSALONIKERNE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONICHER 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. LIST SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.O TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.O TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1O TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1O TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1O. TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1O. TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ELSO TESSZALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONICENSOW 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. LIST SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNA TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNA TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONICENSOW 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSALONIKERNE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONICHER 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 E. SELANIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 I. SELANIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 LIST SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSALONICESI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIAID 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSZALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. WATHESALONIKE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1O TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1O TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONICENSOW 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I LIST SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESSALONICESI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIAID 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSZALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. WATHESALONIKE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMYE TESALONIK 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA SOLUNJANIMA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNANG TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNANG TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSALONICESI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIAID 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSZALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 WATHESALONIKE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 E SELANIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 I SELANIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K. SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONICENI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONIKYEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSALONIKER 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSZALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONIAID 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESSALONICESI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIAID 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSZALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I WATHESALONIKE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONICENI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONIKYEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESSZALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALONIAID 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("WATHESALONIKE I 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONICENI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONIKYEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSALONIKER 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSZALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONIAID 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K. SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. SELANIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. SOLUNJANIMA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONIIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONICENI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONIKYEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESSZALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALONIAID 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. SOLUNJANIMA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONIIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNA TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNA TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 SELANIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 SOLUNJANIMA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONIIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I SOLUNJANIMA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONIIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONIK 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("EERSTE THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONIK 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONIK 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("EERSTE TESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ELSO THESSZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THSSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONIK 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("KWANZA THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THSSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("EERSTE TES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ELSO TESSZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("KWANZA THE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1E. THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THSSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("KWANZA TH 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI SOL 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THSSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1E THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1E. TESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST TH 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESSZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THSSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI TE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THSSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1E TESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1E. TES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. TH 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESSZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THSSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. SOL 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1E TES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST TH 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. SOL 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 SOL 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TH 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I SOL 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TH 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TH 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TH 1:1").osis()).toEqual("1Thess.1.1")
		`
		true
describe "Localized book 2Kgs (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Kgs (ascii)", ->
		`
		expect(p.parse("Kitabu cha Pili cha Wafalme 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga knjiga o Kraljevima 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Cartea a patra a Regilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Fjerde Kongerigernes Bog 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Toinen Kuninkaiden kirja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha kniha kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy kniha kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kuninkaiden kirja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kuninkaiden kirja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Kongerigernes Bog 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kuninkaiden kirja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kuninkaiden kirja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Kongerigernes Bog 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Cartea IV a Regilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiega Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiegi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiega Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiegi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. kniha kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrta kniha Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. kniha kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Andra Konungaboken 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha kniha Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II kniha kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Ikalawang Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Toinen Kuninkaiden 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 kniha kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Boqorradii Labaad 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy list Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiega Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiegi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiega Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiegi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Andra Kungaboken 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Dezyem liv Wa yo 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Kraljevima 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks. Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks. Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiega Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiegi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II a Imparatilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Ikaapat Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Masodik Kiralyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiega Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiegi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Konungaboken 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Fourth Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Brenhinoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kuninkaiden 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Tweede Koningen 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Konungaboken 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 e. Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 i. Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Brenhinoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kuninkaiden 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 e. Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 i. Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Anden Kongebog 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Andre Kongebok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Deuxiemes Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Brenhinoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kuninkaiden 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Boqorradii 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Breninoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kraljevima 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks. Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Ikalawang Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Liber II Regum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Zweite Koenige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Brenhinoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kuninkaiden 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 e Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 i Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Boqorradii 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Breninoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kraljevima 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks. Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kungaboken 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 e Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 i Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4th. Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Deuxieme Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Boqorradii 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Breninoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kraljevima 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks. Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Para Raja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Quarta Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Quarto Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Segundo Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrta Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Zweite Konige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Boqorradii 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Breninoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kraljevima 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks. Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kungaboken 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Para Raja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e. Koningen 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4th Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Para Raja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Imparati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kiralyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Koningen 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Regnorum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Pili Wafalme 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Segunda Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Segundo Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Irajakkal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Para Raja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 k. Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Imparati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kiralyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kongebog 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kongebok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Koningen 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e Koningen 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 k. Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Regnorum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Imparati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kiralyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Koningen 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Wafalme 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Regnorum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Kiralyok II 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Masodik Kir 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Imparati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kiralyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kongebog 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kongebok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Koningen 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 k Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Koenige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Wafalme 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2.o. Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2eme. Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Regnorum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 k Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4a. Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4o. Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Anden Kong 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Andre Kong 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Kral 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Kral 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Wafalme 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Seconda Re 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Secondo Re 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Tweede Kon 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Wafalme II 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Koenige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Wafalme 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Konige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2.o Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2de. Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2eme Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2o. Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4a Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4o Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Dezyem Wa 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Regum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Tweede Ko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Konige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Regum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2a. Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2d. Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2de Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e. Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2o Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2o. Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Kr 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Kr 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Regum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kral 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Pili Fal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Regum II 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Regum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kong 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kral 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Raja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2a Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2d Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e. Kon 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2o Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kral 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Boq 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Fal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Imp 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kir 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kon 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Reg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Vua 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Bren 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kong 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kral 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Krol 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kung 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Raja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Rees 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Reye 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Reys 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ryes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Boq 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Fal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Imp 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kir 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kon 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Reg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Vua 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e Kon 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e. Ko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Boq 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Fal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Imp 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kir 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kon 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Reg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Vua 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kr 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Re 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Wa 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Boq 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Fal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Imp 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kir 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kon 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Krl 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kun 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ree 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Reg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Res 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Rey 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Rye 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Rys 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Vua 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kr 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Wa 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e Ko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kr 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Re 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Wa 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ha 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kr 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Mb 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Rs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ry 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Wa 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 R 1:1").osis()).toEqual("2Kgs.1.1")
		p.include_apocrypha(false)
		expect(p.parse("KITABU CHA PILI CHA WAFALME 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KNJIGA O KRALJEVIMA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("CARTEA A PATRA A REGILOR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("CZWARTA KSIEGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("CZWARTA KSIEGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("FJERDE KONGERIGERNES BOG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("TOINEN KUNINKAIDEN KIRJA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIEGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIEGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIEGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIEGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("CZWARTA KS. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KNIHA KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY KNIHA KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KUNINKAIDEN KIRJA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KUNINKAIDEN KIRJA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KONGERIGERNES BOG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("CZWARTA KS KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KUNINKAIDEN KIRJA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIEGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIEGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KSIEGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KSIEGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KUNINKAIDEN KIRJA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIEGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIEGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KONGERIGERNES BOG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KSIEGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KSIEGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("CARTEA IV A REGILOR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KS. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIEGA KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIEGI KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KS. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIEGA KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIEGI KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIEGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIEGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KNIHA KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KSIEGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KSIEGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("STVRTA KNIHA KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIEGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIEGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KNIHA KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KSIEGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KSIEGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ANDRA KONUNGABOKEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KS KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KS KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KNIHA KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KNIHA KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IKALAWANG MGA HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("TOINEN KUNINKAIDEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KNIHA KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("BOQORRADII LABAAD 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY LIST KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KS. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIEGA KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIEGI KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KS. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KS. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIEGA KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIEGI KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KS. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ANDRA KUNGABOKEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DEZYEM LIV WA YO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KRALJEVIMA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KS. KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KS. KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KS. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIEGA KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIEGI KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II A IMPARATILOR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KS KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KS. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KS KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IKAAPAT MGA HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("MASODIK KIRALYOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KS. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIEGA KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIEGI KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KONUNGABOKEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KS KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KS. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KS KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KS KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KS KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("FOURTH KINGDOMS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KS KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. BRENHINOEDD 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KUNINKAIDEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KS KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("TWEEDE KONINGEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KONUNGABOKEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KS KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 E. MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 I. MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. BRENHINOEDD 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KUNINKAIDEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KS KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 E. MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 I. MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ANDEN KONGEBOG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ANDRE KONGEBOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DEUXIEMES ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II BRENHINOEDD 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KUNINKAIDEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. BOQORRADII 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. BRENINOEDD 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KRALJEVIMA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KS. KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IKALAWANG HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("LIBER II REGUM 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ZWEITE KOENIGE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 BRENHINOEDD 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KUNINKAIDEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 E MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 I MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. BOQORRADII 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. BRENINOEDD 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KRALJEVIMA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KS. KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KUNGABOKEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 E MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 I MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4TH. KINGDOMS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DEUXIEME ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II BOQORRADII 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II BRENINOEDD 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KRALJEVIMA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KS. KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KS KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. PARA RAJA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("QUARTA REINOS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("QUARTO REINOS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SEGUNDO REYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("STVRTA KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ZWEITE KONIGE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 BOQORRADII 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 BRENINOEDD 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KRALJEVIMA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KS. KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KUNGABOKEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KS KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. PARA RAJA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2E. KONINGEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4TH KINGDOMS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KS KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II PARA RAJA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. IMPARATI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KIRALYOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KONINGEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. MGA HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KINGDOMS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. MGA HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. REGNORUM 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("PILI WAFALME 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KINGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SEGUNDA REIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SEGUNDO REIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 IRAJAKKAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KS KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 PARA RAJA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 K. KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. IMPARATI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KIRALYOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KONGEBOG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KONGEBOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KONINGEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. MGA HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2E KONINGEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 K. KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KINGDOMS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. MGA HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. REGNORUM 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II IMPARATI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KIRALYOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KONINGEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II MGA HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. WAFALME 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KINGDOMS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV MGA HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV REGNORUM 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("KIRALYOK II 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("MASODIK KIR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KIGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KING 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KINS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KNGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 IMPARATI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KIRALYOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KONGEBOG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KONGEBOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KONINGEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 MGA HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 K KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KOENIGE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. WAFALME 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2.O. REYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2EME. ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KINGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KINGDOMS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 MGA HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 REGNORUM 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 K KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4A. REINOS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4O. REINOS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ANDEN KONG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ANDRE KONG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KRAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY KRAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II WAFALME 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. REINOS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KIG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KIN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KNS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECONDA RE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECONDO RE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("TWEEDE KON 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("WAFALME II 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KOENIGE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 WAFALME 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KONIGE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2.O REYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2DE. ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2EME ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KINGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KIGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KING 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KINS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KNGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2O. REYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. REINOS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4A REINOS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4O REINOS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DEZYEM WA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. CARIV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KINGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. REGUM 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. REYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV REINOS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("TWEEDE KO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KONIGE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. CARIV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KINGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. REGUM 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. REYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2A. REIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2D. ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2DE ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2E. ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KIGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KING 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KINS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KNGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KIG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KIN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KNS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2O REYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2O. REIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 REINOS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY KR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II CARIV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KINGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II REGUM 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II REYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KIGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KING 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KINS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KNGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KRAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. REGI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. REIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. REGI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("PILI FAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("REGUM II 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 CARIV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KINGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 REGUM 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 REYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KIGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KING 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KINS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KNGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KONG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KRAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. RAJA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. REGI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. REIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2A REIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2D ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2E ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2E. KON 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KIG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KIN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KNS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2O REIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. REGI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KIGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KING 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KINS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KNGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KRAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II REGI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II REIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. BOQ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. FAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. IMP 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KIG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KIN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KIR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KNS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KON 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. REG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. VUA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV REGI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 BREN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KIGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KING 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KINS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KNGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KONG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KRAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KROL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KUNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RAJA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 REES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 REGI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 REIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 REYE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 REYS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. BOQ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. FAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. IMP 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KIG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KIN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KIR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KNS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KON 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. REG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. VUA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2E KON 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2E. KO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 REGI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II BOQ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II FAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II IMP 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KIG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KIN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KIR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KNS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KON 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II REG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II VUA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. RE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. WA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 BOQ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 FAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 IMP 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KIG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KIN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KIR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KNS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KON 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KRL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KUN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 REE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 REG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 REY 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RYE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RYS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 VUA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. WA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2E KO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II RE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II WA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 HA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 MB 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RY 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 WA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 R 1:1").osis()).toEqual("2Kgs.1.1")
		`
		true
describe "Localized book 1Kgs (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Kgs (ascii)", ->
		`
		expect(p.parse("Ensimmainen Kuninkaiden kirja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kitabu cha Kwanza cha Wafalme 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Cartea a treia a Regilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva knjiga o Kraljevima 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tredje Kongerigernes Bog 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Ensimmainen Kuninkaiden 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiega Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiegi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiega Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiegi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiega Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiegi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni kniha kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kuninkaiden kirja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Kongerigernes Bog 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Cartea III a Regilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Fyrri bok konunganna 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kuninkaiden kirja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kuninkaiden kirja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Kongerigernes Bog 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Forsta Konungaboken 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kuninkaiden kirja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks. Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks. Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks. Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretia kniha Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. kniha kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. kniha kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 kniha kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Boqorradii Kowaad 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Forsta Kungaboken 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I kniha kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Ikatlong Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva kniha Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiega Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiegi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Fyrri Konungabok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiega Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiegi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Premye liv Wa yo 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvy list Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiega Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiegi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Konungaboken 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Eerste Koningen 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiega Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiegi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I a Imparatilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva Kraljevima 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni Kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Terceira Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Terceiro Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Konungaboken 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 e. Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 i. Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Brenhinoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kuninkaiden 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 e. Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 i. Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Brenhinoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kuninkaiden 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kwanza Wafalme 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Premieres Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Third Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Unang Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Brenhinoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kuninkaiden 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 e Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 i Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Boqorradii 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Breninoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kraljevima 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks. Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kungaboken 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 e Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 i Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3rd. Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Elso Kiralyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Erste Koenige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Brenhinoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kuninkaiden 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Boqorradii 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Breninoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kraljevima 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks. Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Regnorum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Liber I Regum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Premiere Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Premiers Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Primeira Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Primeiro Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Primero Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretia Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Boqorradii 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Breninoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kraljevima 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks. Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kungaboken 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Para Raja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1e. Koningen 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3rd Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Erste Konige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Boqorradii 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Breninoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kraljevima 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks. Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Para Raja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Regnorum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Premier Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Primer Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Treti Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Una Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Irajakkal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Para Raja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 k. Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Imparati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kiralyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kongebog 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kongebok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Koningen 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1e Koningen 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 k. Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Regnorum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Para Raja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Imparati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kiralyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Koningen 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvy Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Imparati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kiralyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kongebog 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kongebok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Koningen 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 k Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Koenige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Wafalme 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1.o. Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ere. Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Regnorum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 k Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3a. Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3o. Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Eerste Kon 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Imparati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kiralyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Koningen 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Wafalme 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kiralyok I 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kwanza Fal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni Kral 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Unang Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Koenige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Wafalme 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Konige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1.o Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1er. Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ere Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1o. Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1re. Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3a Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3o Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Eerste Ko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Wafalme 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Premye Wa 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Wafalme I 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Konige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Regum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1a. Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1er Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1o Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1o. Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1re Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Elso Kir 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Ks 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Regum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prima Re 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Primo Re 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni Kr 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Una Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Regum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kong 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kral 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Raja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1a Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1e. Kon 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1o Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Ks 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Regum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kral 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Regum I 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Bren 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kong 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kral 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Krol 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kung 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Raja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Rees 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Reye 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Reys 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ryes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Boq 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Fal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Imp 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kir 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kon 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Reg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Vua 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1e Kon 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1e. Ko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Ks 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kral 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Boq 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Fal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Imp 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kir 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kon 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Reg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Vua 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Boq 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Fal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Imp 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kir 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kon 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Krl 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kun 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ree 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Reg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Res 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Rey 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Rye 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Rys 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Vua 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kr 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Wa 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1e Ko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Boq 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Fal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Imp 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kir 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kon 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Reg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Vua 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kr 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Re 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Wa 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ha 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kr 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Mb 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Rs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ry 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Wa 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kr 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Re 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Wa 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 R 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kin 1:1").osis()).toEqual("1Kgs.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ENSIMMAINEN KUNINKAIDEN KIRJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("KITABU CHA KWANZA CHA WAFALME 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("CARTEA A TREIA A REGILOR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVA KNJIGA O KRALJEVIMA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TREDJE KONGERIGERNES BOG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECIA KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECIA KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ENSIMMAINEN KUNINKAIDEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECI KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECI KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIEGA KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIEGI KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIEGA KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIEGI KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIEGA KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIEGI KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNI KNIHA KRALOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECIA KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KUNINKAIDEN KIRJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KONGERIGERNES BOG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("CARTEA III A REGILOR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FYRRI BOK KONUNGANNA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KUNINKAIDEN KIRJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECI KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECIA KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KUNINKAIDEN KIRJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KONGERIGERNES BOG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FORSTA KONUNGABOKEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KUNINKAIDEN KIRJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KS. KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KS. KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KS. KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRETIA KNIHA KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECI KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KNIHA KRALOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KNIHA KRALOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KS KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KS KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KS KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KNIHA KRALOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("BOQORRADII KOWAAD 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FORSTA KUNGABOKEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KNIHA KRALOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("IKATLONG MGA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVA KNIHA KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIEGA KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIEGI KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FYRRI KONUNGABOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIEGA KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIEGI KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PREMYE LIV WA YO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVY LIST KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIEGA KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIEGI KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KONUNGABOKEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("EERSTE KONINGEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIEGA KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIEGI KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I A IMPARATILOR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVA KRALJEVIMA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNI KRALOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TERCEIRA REINOS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TERCEIRO REINOS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KONUNGABOKEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 E. MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 I. MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. BRENHINOEDD 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KUNINKAIDEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 E. MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 I. MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. BRENHINOEDD 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KUNINKAIDEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("KWANZA WAFALME 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PREMIERES ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("THIRD KINGDOMS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("UNANG MGA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 BRENHINOEDD 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KUNINKAIDEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 E MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 I MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. BOQORRADII 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. BRENINOEDD 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KRALJEVIMA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KS. KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KUNGABOKEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 E MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 I MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3RD. KINGDOMS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ELSO KIRALYOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ERSTE KOENIGE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I BRENHINOEDD 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KUNINKAIDEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. BOQORRADII 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. BRENINOEDD 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KRALJEVIMA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KS. KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KINGDOMS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. MGA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. REGNORUM 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("LIBER I REGUM 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PREMIERE ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PREMIERS ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRIMEIRA REIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRIMEIRO REIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRIMERO REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRETIA KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 BOQORRADII 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 BRENINOEDD 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KRALJEVIMA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KS. KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KUNGABOKEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KRALOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KS KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. PARA RAJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1E. KONINGEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3RD KINGDOMS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ERSTE KONIGE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I BOQORRADII 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I BRENINOEDD 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KRALJEVIMA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KS. KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KRALOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KS KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. PARA RAJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KINGDOMS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III MGA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III REGNORUM 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PREMIER ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRIMER REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRETI KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("UNA MGA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 IRAJAKKAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KRALOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KS KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 PARA RAJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 K. KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. IMPARATI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KIRALYOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KONGEBOG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KONGEBOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KONINGEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. MGA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1E KONINGEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 K. KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KINGDOMS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. MGA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. REGNORUM 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KRALOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KS KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I PARA RAJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. IMPARATI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KIRALYOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KONINGEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. MGA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. REINOS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVA KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVY KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 IMPARATI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KIRALYOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KONGEBOG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KONGEBOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KONINGEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 MGA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 K KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KOENIGE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. WAFALME 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1.O. REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ERE. ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KINGDOMS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 MGA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 REGNORUM 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 K KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3A. REINOS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3O. REINOS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("EERSTE KON 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KIGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KING 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KINS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I IMPARATI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KIRALYOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KONINGEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I MGA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. WAFALME 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III REINOS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("KIRALYOK I 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("KWANZA FAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNI KRAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("UNANG HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KOENIGE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 WAFALME 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KONIGE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1.O REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ER. ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ERE ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1O. REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1RE. ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KIGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KING 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KINS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. REINOS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3A REINOS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3O REINOS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("EERSTE KO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KIG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KIN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KNS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I WAFALME 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. REGI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PREMYE WA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("WAFALME I 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KONIGE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. CARIV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. REGUM 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1A. REIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ER ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1O REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1O. REIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1RE ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KIGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KING 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KINS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KIG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KIN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KNS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 REINOS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ELSO KIR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. CARIV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. REGUM 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III REGI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRIMA RE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRIMO RE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNI KR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("UNA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 CARIV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 REGUM 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KIGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KING 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KINS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KONG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KRAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. RAJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. REGI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. REIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1A REIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1E. KON 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1O REIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KIG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KIN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KNS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. REGI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I CARIV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I REGUM 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KIGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KING 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KINS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KRAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. REGI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. REIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("REGUM I 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 BREN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KIGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KING 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KINS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KONG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KRAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KROL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KUNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RAJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 REES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 REGI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 REIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 REYE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 REYS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. BOQ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. FAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. IMP 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KIG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KIN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KIR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KNS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KON 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. REG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. VUA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1E KON 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1E. KO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 REGI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KIGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KING 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KINS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KRAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I REGI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I REIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. BOQ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. FAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. IMP 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KIG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KIN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KIR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KNS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KON 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. REG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. VUA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 BOQ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 FAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 IMP 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KIG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KIN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KIR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KNS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KON 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KRL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KUN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 REE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 REG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 REY 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RYE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RYS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 VUA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. WA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1E KO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I BOQ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I FAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I IMP 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KIG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KIN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KIR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KNS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KON 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I REG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I VUA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. RE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. WA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 HA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 MB 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RY 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 WA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I RE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I WA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 R 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("KIN 1:1").osis()).toEqual("1Kgs.1.1")
		`
		true
describe "Localized book EpJer (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: EpJer (ascii)", ->
		`
		expect(p.parse("The Epistle of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Pismo Jeremije proroka 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("The Letter of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ang Liham ni Jeremias 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Epistola lui Ieremia 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("La Carta de Jeremias 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("The Let. of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Epistle of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("The Ep. of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("The Let of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Letter of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Lettera di Geremia 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("The Ep of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Brief des Jeremia 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Brief van Jeremia 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Carta de Jeremias 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Epistle of Jeremy 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Epitre de Jeremie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Liham ni Jeremias 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Barua ya Yeremia 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Jeremijino pismo 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Let. of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Llythyr Jeremeia 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep. of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Jeremias levele 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Jeremiasov list 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Let of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("List Jeremiasza 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("List Jeremjasuv 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Oratio Ieremiae 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Carta Jeremias 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Jeremian kirje 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Jeremias' Brev 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Jeremias’ Brev 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Jeremias brev 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Bref Jeremia 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep. Jeremie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep Jeremie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Cart. Jer 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Carta Jer 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Cart Jer 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep. Jer 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Let-ger 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Lih Jer 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Or. Ier 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Br Jer 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep Jer 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Jer br 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Or Ier 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("EpJer 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Jerbr 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("BJer 1:1").osis()).toEqual("EpJer.1.1")
		`
		true
describe "Localized book Lam (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Lam (ascii)", ->
		`
		expect(p.parse("Chante pou plenn So lavil Jerizalem 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plangerile profetului Ieremia 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Baroorashadii Yeremyaah 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentacoes de Jeremias 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentations de Jeremie 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plangerile lui Ieremia 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentacje Jeremiasza 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Maombolezo ya Yeremia 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Klagelieder Jeremias 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Aklat ng Pananaghoy 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Jeremijine tuzaljke 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Aklat ng Pagtaghoy 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Galarnad Jeremiah 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Jeremias siralmai 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Ksiega Lamentacji 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Ksiegi Lamentacji 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Kidung Pangadhuh 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Treny Jeremiasza 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Jeremiasov Plac 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Kidung Pasambat 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Mga Lamentasyon 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Mga Pagbangotan 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremiasov 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremiasuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremjasuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("yarmiyako vilap 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Ks. Lamentacji 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Baroorashadii 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Klaagliederen 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Kniha narekov 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Ks Lamentacji 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentaciones 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentationes 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamintaciones 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Valitusvirret 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Jeremias sir 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Klagesangene 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Klagovisorna 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentacione 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentations 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentazioni 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamintacione 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamintations 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Mga Panaghoy 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremii 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Klagelieder 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Kniha narku 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamantasyon 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentacije 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentacoes 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentation 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamintation 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pagbangotan 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("K. narekov 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentacje 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Maombolezo 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Vilapageet 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("K narekov 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Zalospevy 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Galarnad 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Panaghoy 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plangeri 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pulampal 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Siralmak 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Tuzaljke 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Vajtimet 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("wilapgit 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Baroor 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Klaagl 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Klages 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Nareky 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Siralm 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Zalosp 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Ai Ca 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Galar 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Panag 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plang 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plenn 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Siral 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Treny 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Valit 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Klag 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Klgl 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Hlj 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lam 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Mao 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Nar 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Omb 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Tuz 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Vaj 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Kl 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lm 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pl 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Tr 1:1").osis()).toEqual("Lam.1.1")
		p.include_apocrypha(false)
		expect(p.parse("CHANTE POU PLENN SO LAVIL JERIZALEM 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLANGERILE PROFETULUI IEREMIA 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("BAROORASHADII YEREMYAAH 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTACOES DE JEREMIAS 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTATIONS DE JEREMIE 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLANGERILE LUI IEREMIA 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTACJE JEREMIASZA 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("MAOMBOLEZO YA YEREMIA 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KLAGELIEDER JEREMIAS 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("AKLAT NG PANANAGHOY 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("JEREMIJINE TUZALJKE 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("AKLAT NG PAGTAGHOY 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("GALARNAD JEREMIAH 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("JEREMIAS SIRALMAI 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KSIEGA LAMENTACJI 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KSIEGI LAMENTACJI 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KIDUNG PANGADHUH 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("TRENY JEREMIASZA 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("JEREMIASOV PLAC 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KIDUNG PASAMBAT 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("MGA LAMENTASYON 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("MGA PAGBANGOTAN 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMIASOV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMIASUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMJASUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("YARMIYAKO VILAP 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KS. LAMENTACJI 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("BAROORASHADII 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KLAAGLIEDEREN 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KNIHA NAREKOV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KS LAMENTACJI 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTACIONES 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTATIONES 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMINTACIONES 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("VALITUSVIRRET 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("JEREMIAS SIR 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KLAGESANGENE 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KLAGOVISORNA 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTACIONE 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTATIONS 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTAZIONI 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMINTACIONE 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMINTATIONS 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("MGA PANAGHOY 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMII 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KLAGELIEDER 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KNIHA NARKU 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMANTASYON 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTACIJE 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTACOES 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTATION 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMINTATION 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PAGBANGOTAN 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("K. NAREKOV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTACJE 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("MAOMBOLEZO 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("VILAPAGEET 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("K NAREKOV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ZALOSPEVY 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("GALARNAD 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PANAGHOY 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLANGERI 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PULAMPAL 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("SIRALMAK 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("TUZALJKE 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("VAJTIMET 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("WILAPGIT 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("BAROOR 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KLAAGL 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KLAGES 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("NAREKY 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("SIRALM 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ZALOSP 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("AI CA 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("GALAR 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PANAG 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLANG 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLENN 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("SIRAL 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("TRENY 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("VALIT 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KLAG 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KLGL 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("HLJ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAM 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("MAO 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("NAR 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("OMB 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("TUZ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("VAJ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KL 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LM 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PL 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("TR 1:1").osis()).toEqual("Lam.1.1")
		`
		true
describe "Localized book Num (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Num (ascii)", ->
		`
		expect(p.parse("Czwarta Ksiega Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Czwarta Ksiegi Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Kitabu cha Nne cha Musa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrta kniha Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Czwarta Ks. Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Neljas Mooseksen kirja 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Stvrta kniha Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Czwarta Ks Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Ksiega Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Ksiegi Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Ksiega Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Ksiegi Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Ksiega Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Ksiegi Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Ksiega Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Ksiegi Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mooseksen kirja 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. kniha Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mooseksen kirja 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. kniha Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Czwarta Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mooseksen kirja 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV kniha Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Ks. Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mooseksen kirja 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 kniha Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Ks. Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Ks. Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Ks Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Ks. Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Ks Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrta Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjarde Moseboken 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Ks Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Neljas Mooseksen 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Stvrta Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Vierte Buch Mose 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("liv Resansman an 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Ks Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 k. Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjarde Mosebok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjerde Mosebog 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjerde Mosebok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Knjiga Brojeva 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("gantiko pustak 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 k Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mooseksen 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Buch Mose 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mooseksen 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Moseboken 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Czwarta Mojz 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mooseksen 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ksiega Liczb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ksiegi Liczb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Liber Numeri 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Vierde Mozes 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Buch Mose 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mooseksen 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Moseboken 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mosebok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Mga Numeros 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Vierte Mose 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mosebog 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mosebok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjerde Mos 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mosebok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Mga Bilang 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Mga Numero 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mosebog 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mosebok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ennakamam 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mozes 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ks. Liczb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Resansman 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mozes 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Bamidbar 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Bemidbar 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mozes 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mojz 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ks Liczb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Mozes IV 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Tirintii 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Wilangan 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mozes 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mojz 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mose 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Brojevi 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ginatee 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mojz 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mos 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Nombres 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Numberi 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Numbers 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Numerii 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Numeros 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("gantiko 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mojz 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Moos 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mose 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mos 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Hesabu 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Moj 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mos 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Number 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Numeri 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Numero 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Numrat 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Szamok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ganana 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Moj 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mos 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Moz 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mo 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Cysla 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Liczb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mo 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mz 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Nomb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Nonb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Numb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Szam 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Bil 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Nom 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Num 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Res 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Tir 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Lb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Nb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Nm 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("No 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Nu 1:1").osis()).toEqual("Num.1.1")
		p.include_apocrypha(false)
		expect(p.parse("CZWARTA KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CZWARTA KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("KITABU CHA NNE CHA MUSA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTA KNIHA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CZWARTA KS. MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NELJAS MOOSEKSEN KIRJA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("STVRTA KNIHA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CZWARTA KS MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOOSEKSEN KIRJA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KNIHA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOOSEKSEN KIRJA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KNIHA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CZWARTA MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOOSEKSEN KIRJA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KNIHA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KS. MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOOSEKSEN KIRJA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KNIHA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KS. MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KS. MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KS MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KS. MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KS MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJARDE MOSEBOKEN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KS MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NELJAS MOOSEKSEN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("STVRTA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("VIERTE BUCH MOSE 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("LIV RESANSMAN AN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KS MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 K. MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJARDE MOSEBOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJERDE MOSEBOG 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJERDE MOSEBOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("KNJIGA BROJEVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("GANTIKO PUSTAK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 K MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOOSEKSEN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. BUCH MOSE 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOOSEKSEN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOSEBOKEN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CZWARTA MOJZ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOOSEKSEN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("KSIEGA LICZB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("KSIEGI LICZB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("LIBER NUMERI 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("VIERDE MOZES 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 BUCH MOSE 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOOSEKSEN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOSEBOKEN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOSEBOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("MGA NUMEROS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("VIERTE MOSE 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOSEBOG 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOSEBOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJERDE MOS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOSEBOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("MGA BILANG 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("MGA NUMERO 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOSEBOG 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOSEBOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ENNAKAMAM 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOZES 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("KS. LICZB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("RESANSMAN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOZES 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("BAMIDBAR 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("BEMIDBAR 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOZES 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOJZ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("KS LICZB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("MOZES IV 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("TIRINTII 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("WILANGAN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOZES 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOJZ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOSE 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("BROJEVI 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("GINATEE 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOJZ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NOMBRES 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUMBERI 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUMBERS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUMERII 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUMEROS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("GANTIKO 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOJZ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOOS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOSE 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("HESABU 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOJ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUMBER 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUMERI 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUMERO 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUMRAT 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("SZAMOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("GANANA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOJ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOZ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MO 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CYSLA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("LICZB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MO 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MZ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NOMB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NONB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUMB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("SZAM 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("BIL 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NOM 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUM 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("RES 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("TIR 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("LB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NM 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NO 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NU 1:1").osis()).toEqual("Num.1.1")
		`
		true
describe "Localized book Sus (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Sus (ascii)", ->
		`
		expect(p.parse("Susanne et les deux vieillards 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Suzanne et les deux vieillards 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susanne et les vieillards 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Suzanne et les vieillards 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Fortellingen om Susanna 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Opowiadaniem o Zuzannie 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susanna und die Alten 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susanna ja vanhimmat 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Zsuzsanna es a venek 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Historia de Susana 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Historia Susannae 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Storia di Susanna 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Istoria Susanei 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susanna i badet 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susanna im Bade 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susanne au bain 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Suzanne au bain 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Si Susana 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Zsuzsanna 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Shoshana 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susannae 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susannah 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susanei 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susanna 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susanne 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Suzanne 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Swsanna 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Zuzanna 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susana 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Suzana 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Zuzana 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Zuzane 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Zsuzs 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Zsuz 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Sus 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Suz 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Zuz 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Su 1:1").osis()).toEqual("Sus.1.1")
		`
		true
describe "Localized book Sir (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Sir (ascii)", ->
		`
		expect(p.parse("Cartea intelepciunii lui Isus, fiul lui Sirah 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ang Karunungan ni Jesus, Anak ni Sirac 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ang Karunungan ni Jesus Anak ni Sirac 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("The Wisdom of Jesus, Son of Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("The Wisdom of Jesus Son of Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("The Wisdom of Jesus ben Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Wisdom of Jesus, Son of Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Wijsheid van Jozua Ben Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Wisdom of Jesus Son of Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Karunungan ng Anak ni Sirac 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Wisdom of Jesus ben Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Wijsheid van Jezus Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Oratio Iesu filii Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Wijsheid van Ben Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Kitab Yesus bin Sirakh 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("La Sagesse de Ben Sira 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Jeesus Siirakin kirja 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Kniha Sirachovho syna 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Jesus Siirakin kirja 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Liber Ecclesiasticus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sapienza di Siracide 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Jesus Syraks vishet 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Kniha Ekleziastikus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sagesse de Ben Sira 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("K. Sirachovho syna 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Kniha Sirachovcova 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sapienza di Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("K Sirachovho syna 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirak bolcsessege 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("K. Ekleziastikus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Kniha Sirachovca 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("K Ekleziastikus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("K. Sirachovcova 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Knjiga Sirahova 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Madrosc Syracha 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Yoshua bin Sira 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ecclesiasticul 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ecclesiasticus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ecclesiastique 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ecclusiasticus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ekklesiastikus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ekklesyastikus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("K Sirachovcova 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Siirakin kirja 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ecclesiastico 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ekklesiastiko 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ekklesyastiko 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Eklesiastikus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Eklesyastikus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("K. Sirachovca 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirakin kirja 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Eclesiastico 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ekkleziastik 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Eklesiastiko 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Eklesyastiko 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Eklezjastyka 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Jesus Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Jezus Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("K Sirachovca 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirachovcova 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ecleziastic 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Eklezjastyk 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirachovec 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Siraks Bog 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Siraks bok 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Siracidas 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Siracides 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirak fia 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirakidas 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirakides 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Siraksbok 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ben Sira 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Siirakin 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Siracida 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Siracide 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirakida 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirakide 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirakin 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Syracha 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ecclus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirakh 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirac 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirak 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Syrak 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Eccs 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ekli 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sira 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sir 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Syr 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("YbS 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Si 1:1").osis()).toEqual("Sir.1.1")
		`
		true
describe "Localized book PrMan (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: PrMan (ascii)", ->
		`
		expect(p.parse("Orazione di Manasse Re di Giuda 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Ang Panalangin ni Manases 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Rugaciunea regelui Manase 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("The Prayers of Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("The Prayer of Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("La Oracion de Manases 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Oratio regis Manassae 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Panalangin ni Manases 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Rugaciunea lui Manase 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("La Priere de Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Preghiera di Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("The Prayers Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Dalangin ni Manases 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manasesova modlitba 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Orazione di Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Prayers of Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("The Prayer Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manassen rukouksen 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Modlitwa Manassesa 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Oracion de Manases 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Prayer of Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("The Pr of Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Gebet des Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Prece de Manasses 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Priere de Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Dasal ni Manases 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manasse imadsaga 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Modlitbu Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Prayers Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Oratio Manassae 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Prayer Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("The Pr Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Gebet Manasses 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Gweddi Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manassze imaja 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Pr of Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Gebet Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manasses’ bon 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manasses bon 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manasse bon 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Pr Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Pr. Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Pr Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Geb Man 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Or. Man 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Pr. Man 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Man ru 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manase 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Or Man 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Pr Man 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("PrMan 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("BMn 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Man 1:1").osis()).toEqual("PrMan.1.1")
		`
		true
describe "Localized book Acts (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Acts (ascii)", ->
		`
		expect(p.parse("Mabuting Balita ayon sa Espiritu Santo 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Mabuting Balita ng Espiritu Santo 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Ebanghelyo ng Espiritu Santo 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Handelingen van de apostelen 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Los Hechos de los Apostoles 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Dijannja svjatyh apostoliv 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Az apostolok cselekedetei 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Handelingen der apostelen 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Mga Gawa ng mga Apostoles 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("The Acts of the Apostles 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Hechos de los Apostoles 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Mga Gawa ng mga Apostol 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apostolok cselekedetei 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Buhat sa mga Apostoles 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Mga Gawa ng mga Alagad 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apostlenes gjerninger 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Dziejach Apostolskich 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Acts of the Apostles 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apostlenes Gerninger 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apostlenes-gjerninge 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Atti degli Apostoli 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Falimaha Rasuullada 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Faptele Apostolilor 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Gawa ng mga Apostol 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Lelakone Para Rasul 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Actau'r Apostolion 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Actau’r Apostolion 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apostelgjerningene 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apostlagarningarna 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Atos dos Apostolos 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Dzieje Apostolskie 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Veprat e Apostujve 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Veprat e apostujve 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Actes des Apotres 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Actus Apostolorum 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Ang Mga Binuhatan 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apostelgeschichte 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Fapte Apostolilor 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Gawa ng Apostoles 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Matendo ya Mitume 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Skutky apostolske 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Djela apostolska 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Praeriton Ke Kam 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Skutky apostolov 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("preritharuka kam 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apostolien teot 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Appostalar Pani 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Skutky apostolu 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Aksyon apot yo 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Travay apot yo 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Cselekedetek 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Dzieje Apost 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Postulasagan 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Handelingen 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Los Hechos 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Mga Gawain 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Para Rasul 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Akdezapot 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apostolok 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Az ApCsel 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Binuhatan 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Gerninger 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Ap. Csel 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Mga Gawa 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Ap Csel 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Faptele 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Matendo 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Actsss 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ApCsel 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Dzieje 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Hechos 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Skutky 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Travay 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Veprat 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Actau 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Actes 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Actss 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Actus 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Ap. t 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Dz Ap 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("F. Ap 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Fapte 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Acta 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Acts 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Ap t 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Ap.G 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Ap.t 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Atos 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Atti 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("F Ap 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Fapt 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Gawa 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Hand 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Hech 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Teot 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Act 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ApG 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apg 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apt 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Bin 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("F.A 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Fal 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Fap 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Hch 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Hec 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Hnd 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Mdo 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Vep 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Ac 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("At 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Dj 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Dz 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("FA 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Gw 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Hc 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Sk 1:1").osis()).toEqual("Acts.1.1")
		p.include_apocrypha(false)
		expect(p.parse("MABUTING BALITA AYON SA ESPIRITU SANTO 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("MABUTING BALITA NG ESPIRITU SANTO 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("EBANGHELYO NG ESPIRITU SANTO 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HANDELINGEN VAN DE APOSTELEN 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("LOS HECHOS DE LOS APOSTOLES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("DIJANNJA SVJATYH APOSTOLIV 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AZ APOSTOLOK CSELEKEDETEI 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HANDELINGEN DER APOSTELEN 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("MGA GAWA NG MGA APOSTOLES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("THE ACTS OF THE APOSTLES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HECHOS DE LOS APOSTOLES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("MGA GAWA NG MGA APOSTOL 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APOSTOLOK CSELEKEDETEI 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("BUHAT SA MGA APOSTOLES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("MGA GAWA NG MGA ALAGAD 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APOSTLENES GJERNINGER 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("DZIEJACH APOSTOLSKICH 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTS OF THE APOSTLES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APOSTLENES GERNINGER 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APOSTLENES-GJERNINGE 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ATTI DEGLI APOSTOLI 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("FALIMAHA RASUULLADA 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("FAPTELE APOSTOLILOR 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("GAWA NG MGA APOSTOL 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("LELAKONE PARA RASUL 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTAU'R APOSTOLION 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTAU’R APOSTOLION 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APOSTELGJERNINGENE 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APOSTLAGARNINGARNA 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ATOS DOS APOSTOLOS 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("DZIEJE APOSTOLSKIE 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("VEPRAT E APOSTUJVE 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("VEPRAT E APOSTUJVE 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTES DES APOTRES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTUS APOSTOLORUM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ANG MGA BINUHATAN 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APOSTELGESCHICHTE 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("FAPTE APOSTOLILOR 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("GAWA NG APOSTOLES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("MATENDO YA MITUME 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("SKUTKY APOSTOLSKE 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("DJELA APOSTOLSKA 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRAERITON KE KAM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("SKUTKY APOSTOLOV 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRERITHARUKA KAM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APOSTOLIEN TEOT 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APPOSTALAR PANI 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("SKUTKY APOSTOLU 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AKSYON APOT YO 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("TRAVAY APOT YO 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("CSELEKEDETEK 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("DZIEJE APOST 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("POSTULASAGAN 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HANDELINGEN 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("LOS HECHOS 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("MGA GAWAIN 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PARA RASUL 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AKDEZAPOT 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APOSTOLOK 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AZ APCSEL 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("BINUHATAN 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("GERNINGER 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AP. CSEL 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("MGA GAWA 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AP CSEL 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("FAPTELE 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("MATENDO 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTSSS 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APCSEL 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("DZIEJE 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HECHOS 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("SKUTKY 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("TRAVAY 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("VEPRAT 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTAU 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTSS 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTUS 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AP. T 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("DZ AP 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("F. AP 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("FAPTE 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTA 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTS 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AP T 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AP.G 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AP.T 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ATOS 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ATTI 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("F AP 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("FAPT 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("GAWA 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HAND 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HECH 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("TEOT 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACT 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APG 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APG 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APT 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("BIN 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("F.A 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("FAL 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("FAP 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HCH 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HEC 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HND 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("MDO 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("VEP 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AC 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AT 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("DJ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("DZ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("FA 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("GW 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HC 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("SK 1:1").osis()).toEqual("Acts.1.1")
		`
		true
describe "Localized book Rev (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Rev (ascii)", ->
		`
		expect(p.parse("Apocalypsis Ioannis Apostoli 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ob'javlennja Ivana Bohoslova 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ob’javlennja Ivana Bohoslova 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Opinberunarbok Johannesar 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttina Vicetankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalipsa Swietego Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Openbaring van Johannes 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalipse de Sao Joao 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalisse di Giovanni 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjavenie Apostola Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johannes Uppenbarelse 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjavenie svateho Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johanneksen ilmestys 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johannes' Abenbaring 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johannes' apenbaring 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johannes’ Abenbaring 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johannes’ apenbaring 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Opinberun Johannesar 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjeveni svateho Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalipsa lui Ioan 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalipsis ni Juan 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalypsis Ioannis 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalipsa sw. Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalipsis ni Juan 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johannesapokalypsen 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Objawienie sw. Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalipse de Joao 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalypse de Jean 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalipsa sw Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johannes apokalyps 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Objawienie sw Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Otkrivenje Ivanovo 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ksiega Apokalipsy 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ksiega Objawienia 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ksiegi Apokalipsy 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ksiegi Objawienia 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Uppenbarelseboken 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Abenbaringsbogen 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apenbaringsboken 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johs. Abenbaring 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Opinberunarbokin 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Pahayag kay Juan 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Prakashaitavakya 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ufunua wa Yohana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ufunuo wa Yohana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ufunuo wa Yohane 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Janos jelenesei 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johs Abenbaring 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Objawienie Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("El Apocalipsis 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ks. Apokalipsy 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ks. Objawienia 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttina 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjeveni Janovo 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Aabenbaringen 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ilmestyskirja 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Kniha Zjeveni 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ks Apokalipsy 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ks Objawienia 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjavenie Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Abenbaringen 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apenbaringen 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalipszis 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Openbaringen 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("prakatikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalipsis 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalypsis 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalipsis 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalypsen 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Kitab Wahyu 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Offenbarung 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revalations 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revelations 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revolations 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Rivelazione 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apenbaring 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalipsa 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalipse 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalisse 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalypse 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalipsa 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalypsa 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Datguddiad 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Objawienie 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Openbaring 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Otkrivenje 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Rebelasyon 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revalation 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revelasyon 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revelation 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revlations 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revolation 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalyps 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalips 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Gipadayag 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Jelenesek 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Muujintii 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Pamedaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revlation 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ilmestys 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjavenie 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Datgudd 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Pahayag 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zbulesa 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjeveni 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ufunuo 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Openb 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revel 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Wahyu 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apoc 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Muuj 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Offb 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjav 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apc 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apk 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apo 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Dat 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ilm 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Jel 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Obj 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Opb 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Otk 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Pah 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Rev 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Riv 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ufu 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Upp 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zbu 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjv 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ap 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Op 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Rv 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Uf 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zb 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zj 1:1").osis()).toEqual("Rev.1.1")
		p.include_apocrypha(false)
		expect(p.parse("APOCALYPSIS IOANNIS APOSTOLI 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OB'JAVLENNJA IVANA BOHOSLOVA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OB’JAVLENNJA IVANA BOHOSLOVA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OPINBERUNARBOK JOHANNESAR 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTINA VICETANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALIPSA SWIETEGO JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OPENBARING VAN JOHANNES 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALIPSE DE SAO JOAO 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALISSE DI GIOVANNI 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJAVENIE APOSTOLA JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHANNES UPPENBARELSE 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJAVENIE SVATEHO JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHANNEKSEN ILMESTYS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHANNES' ABENBARING 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHANNES' APENBARING 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHANNES’ ABENBARING 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHANNES’ APENBARING 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OPINBERUN JOHANNESAR 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJEVENI SVATEHO JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALIPSA LUI IOAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALIPSIS NI JUAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALYPSIS IOANNIS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALIPSA SW. JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALIPSIS NI JUAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHANNESAPOKALYPSEN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OBJAWIENIE SW. JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALIPSE DE JOAO 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALYPSE DE JEAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALIPSA SW JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHANNES APOKALYPS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OBJAWIENIE SW JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OTKRIVENJE IVANOVO 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KSIEGA APOKALIPSY 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KSIEGA OBJAWIENIA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KSIEGI APOKALIPSY 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KSIEGI OBJAWIENIA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("UPPENBARELSEBOKEN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ABENBARINGSBOGEN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APENBARINGSBOKEN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHS. ABENBARING 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OPINBERUNARBOKIN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("PAHAYAG KAY JUAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("PRAKASHAITAVAKYA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("UFUNUA WA YOHANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("UFUNUO WA YOHANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("UFUNUO WA YOHANE 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JANOS JELENESEI 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHS ABENBARING 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OBJAWIENIE JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("EL APOCALIPSIS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KS. APOKALIPSY 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KS. OBJAWIENIA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTINA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJEVENI JANOVO 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("AABENBARINGEN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ILMESTYSKIRJA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KNIHA ZJEVENI 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KS APOKALIPSY 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KS OBJAWIENIA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJAVENIE JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ABENBARINGEN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APENBARINGEN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALIPSZIS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OPENBARINGEN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("PRAKATIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALIPSIS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALYPSIS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALIPSIS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALYPSEN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KITAB WAHYU 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OFFENBARUNG 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVALATIONS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVELATIONS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVOLATIONS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("RIVELAZIONE 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APENBARING 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALIPSA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALIPSE 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALISSE 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALYPSE 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALIPSA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALYPSA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("DATGUDDIAD 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OBJAWIENIE 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OPENBARING 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OTKRIVENJE 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REBELASYON 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVALATION 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVELASYON 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVELATION 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVLATIONS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVOLATION 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALYPS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALIPS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("GIPADAYAG 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JELENESEK 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("MUUJINTII 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("PAMEDARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVLATION 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ILMESTYS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJAVENIE 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("DATGUDD 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("PAHAYAG 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZBULESA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJEVENI 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("UFUNUO 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OPENB 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVEL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("WAHYU 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOC 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("MUUJ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OFFB 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJAV 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APC 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APK 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APO 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("DAT 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ILM 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JEL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OBJ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OPB 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OTK 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("PAH 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REV 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("RIV 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("UFU 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("UPP 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZBU 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJV 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("AP 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OP 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("RV 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("UF 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZB 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJ 1:1").osis()).toEqual("Rev.1.1")
		`
		true
describe "Localized book PrAzar (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: PrAzar (ascii)", ->
		`
		expect(p.parse("Ang Panalangin ni Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("The Prayers of Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Panalangin ni Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Rugaciunea lui Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("The Prayer of Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("The Prayers of Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("The Prayer of Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azarjasova modlitba 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("La Priere d'Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("La Priere d'Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("La Priere d’Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("La Priere d’Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Preghiera di Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Cantico de Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Modlitwa Azariasza 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Oracion de Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Prayers of Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Prayer of Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Prayers of Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("The Pr of Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azarias imadsaga 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Gebed van Azarja 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Gebet des Asarja 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Prayer of Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Priere d'Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Priere d'Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Priere d’Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Priere d’Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Salmo de Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("The Pr of Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Piesn Azariasza 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Asarjan rukous 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Gweddi Asarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Oratio Azariae 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azarias imaja 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Pr of Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Asarias’ bon 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Asarjas’ bon 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Pr of Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Asarias bon 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Asarjas bon 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Or. Azar 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Pr. Azar 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Sal Azar 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Asar ru 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Or Azar 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Pr Azar 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Geb As 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("PrAzar 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Or Az 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("PrAzr 1:1").osis()).toEqual("PrAzar.1.1")
		`
		true
describe "Localized book SgThree (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: SgThree (ascii)", ->
		`
		expect(p.parse("Kolmen nuoren miehen ollessa tulisessa patsissa 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Lobgesang der drei jungen Manner im Feuerofen 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Der Gesang der Drei Manner im feurigen Ofen 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cantico dei tre giovani nella fornace 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Canto de los Tres Jovenes Hebreos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Himno de los Tres Jovenes Hebreos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Canto de los Tres Jovenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Himno de los Tres Jovenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the Three Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Gezang der drie mannen in het vuur 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Awit ng Tatlong Banal na Kabataan 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Canto de los Tres Jovenes Hebreos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Canto de los 3 Jovenes Hebreos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Himno de los 3 Jovenes Hebreos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Kolmen miehen kiitosvirsi tulessa 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Canto de los Tres Jovenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Canto de los 3 Jovenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Himno de los 3 Jovenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Himno de los Tres Jovenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Lobgesang der drei jungen Manner 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Traja mladenci v rozpalenej peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Awit ng Tatlong Kabataang Banal 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piesen mladencov v ohnivej peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the Three Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of Three Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the 3 Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the Three Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Canto de los 3 Jovenes Hebreos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Himno de los 3 Jovenes Hebreos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Canto de los 3 Jovenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Himno de los 3 Jovenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Lobgesang der 3 jungen Manner 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Lied van de drie jongemannen 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mladencu v horici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the Three Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of Three Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the 3 Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the Three Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of 3 Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of Three Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the 3 Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cantarea celor trei tineri 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cantique des Trois Enfants 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the Three Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cantarea celor trei evrei 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cantico dei tre fanciulli 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Canto de los Tres Jovenes 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Himno de los Tres Jovenes 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Kolmen miehen kiitosvirsi 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Tri muzi v rozpalene peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Awit ng Tatlong Kabataan 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the Three Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of Three Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the 3 Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cantico dos Tres Jovens 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Harom fiatalember eneke 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of 3 Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of Three Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the 3 Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of 3 Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Awit ng Tatlong Binata 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cantique des 3 Enfants 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Canto de los 3 Jovenes 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("De tre mannens lovsang 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Himno de los 3 Jovenes 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the Three Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of Three Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the 3 Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Wimbo wa Vijana Watatu 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Hymnus trium puerorum 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cantico dos 3 Jovens 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Kolmen nuoren miehen 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of Three Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the 3 Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of 3 Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Der Gesang der Drei 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of 3 Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Awit ng 3 Kabataan 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of Three Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the 3 Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of 3 Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("De tre menns sang 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of 3 Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Tatlong Kabataan 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Can y Tri Llanc 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Gesang der Drei 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Three. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Can y Tri Lanc 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Three. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Three Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Three. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of 3 Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Kolmen miehen 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Three Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Three. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Three Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Three Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Three. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Th. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Tres Jovenes 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Aw ng 3 Kab 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Three. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Th. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Three Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Three. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of 3. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Th Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Th. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Trei tineri 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Three Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Three. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of 3. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Th Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Th. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Three Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of 3 Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of 3. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Th Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song Three 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("3 Jovenes 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Three Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of 3 Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of 3. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Th Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Th. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of 3 Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Sng Three 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("3 tineri 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Th. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of 3 Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. 3. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Th Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Th. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Sg Three 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Ct 3 Jo 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S 3. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Th Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Th. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. 3 Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. 3. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Th Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("SgThree 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Ct 3 E 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S 3 Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S 3. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Th Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. 3 Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Sg Thr 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S 3 Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("C3J 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("L3J 1:1").osis()).toEqual("SgThree.1.1")
		`
		true
describe "Localized book 2Pet (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Pet (ascii)", ->
		`
		expect(p.parse("Peturu Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhe poslannja apostola Petra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Seconda lettera di Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga Petrova Poslanica 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga Petrova poslanica 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Waraka wa Pili wa Petro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Barua ya Pili ya Petro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga List sw. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Drugi List sw. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petrova Poslanica 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Toinen Pietarin kirje 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("patrusko dostro patra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petrova Poslanica 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga List sw Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Drugi List sw Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petrova Poslanica 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("petracem dusre patra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petrova Poslanica 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. List sw. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. List sw. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Andra Petrusbrevet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha kniha Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II List sw. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. List sw Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pietarin kirje 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 List sw. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. List sw Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pietarin kirje 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga List Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Drugi List Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha list Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy Petrov list 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy list Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy list Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Epistula II Petri 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Epistula Petri II 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II List sw Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pietarin kirje 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peters Andet Brev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peters andre brev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Petrus andra brev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Segundo San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 List sw Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pietarin kirje 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Anden Petersbrev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Andet Petersbrev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Andre Petersbrev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Deuxiemes Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petrusbrevet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Deuxieme Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. List Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. list Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Ikalawang Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Toinen Pietarin 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petrusbrevet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. List Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. list Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.o. San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II List Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II list Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Seconda Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Secondo Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 List Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 list Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petersbrev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.o San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2o. San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Butros Labaad 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Masodik Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Segunda Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Segundo Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Tweede Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Zweite Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petersbrev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 e. Pjetrit 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 i. Pjetrit 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2eme. Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2o San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Andre Peters 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Drugi Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pietarin 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 e Pjetrit 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 i Pjetrit 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 k. Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pietarin 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. patrusko 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2de. Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2eme Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Anden Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Andre Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga Piotr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Drugi Piotr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pietarin 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Masodik Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Tweede Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pietarin 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 k Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 patrusko 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 petracem 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pataras 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pjetrit 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.o. Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2d. Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2de Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e. Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e. Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Dezyem Pie 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Dezyem Pye 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Butros 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pili Petro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Tweede Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pataras 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pjetrit 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Butros 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Peters 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.o Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2a. Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2d Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2o. Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Anden Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Andre Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Butros 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petri 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petru 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Piotr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Butros 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Peters 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Peturu 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 patras 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petri 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petru 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Piotr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2a Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e. Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2o Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petri 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petru 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Piotr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pedr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Phia 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Petri II 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Petro II 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pili Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petri 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petru 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Piotr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pedr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Phia 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e. Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pedr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Phia 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. But 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pie 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pye 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pedr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Phia 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Piet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. But 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pie 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pye 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II But 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pie 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pye 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 But 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Ped 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pie 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pje 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pye 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pd 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pi 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pj 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 P 1:1").osis()).toEqual("2Pet.1.1")
		p.include_apocrypha(false)
		expect(p.parse("PETURU ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHE POSLANNJA APOSTOLA PETRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECONDA LETTERA DI PIETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGA PETROVA POSLANICA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGA PETROVA POSLANICA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("WARAKA WA PILI WA PETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("BARUA YA PILI YA PETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGA LIST SW. PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGI LIST SW. PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETROVA POSLANICA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("TOINEN PIETARIN KIRJE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PATRUSKO DOSTRO PATRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETROVA POSLANICA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGA LIST SW PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGI LIST SW PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETROVA POSLANICA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETRACEM DUSRE PATRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETROVA POSLANICA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. LIST SW. PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. LIST SW. PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ANDRA PETRUSBREVET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHA KNIHA PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II LIST SW. PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. LIST SW PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PIETARIN KIRJE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 LIST SW. PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. LIST SW PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PIETARIN KIRJE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGA LIST PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGI LIST PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHA LIST PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHY PETROV LIST 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHY LIST PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHY LIST PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("EPISTULA II PETRI 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("EPISTULA PETRI II 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II LIST SW PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PIETARIN KIRJE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETERS ANDET BREV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETERS ANDRE BREV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETRUS ANDRA BREV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SEGUNDO SAN PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 LIST SW PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PIETARIN KIRJE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ANDEN PETERSBREV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ANDET PETERSBREV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ANDRE PETERSBREV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DEUXIEMES PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETRUSBREVET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DEUXIEME PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. LIST PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. LIST PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("IKALAWANG PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("TOINEN PIETARIN 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETRUSBREVET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. LIST PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. LIST PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.O. SAN PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II LIST PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II LIST PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECONDA PIETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECONDO PIETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 LIST PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 LIST PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETERSBREV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.O SAN PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2O. SAN PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("BUTROS LABAAD 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGA PETROVA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHA PETROVA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHY PETROVA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. SAN PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("MASODIK PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SEGUNDA PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SEGUNDO PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("TWEEDE PETRUS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ZWEITE PETRUS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETERSBREV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 E. PJETRIT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 I. PJETRIT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. SAN PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2EME. PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2O SAN PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ANDRE PETERS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGA PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGI PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHA PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHA PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHY PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHY PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II SAN PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PIETARIN 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 SAN PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 E PJETRIT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 I PJETRIT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 K. PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PIETARIN 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PATRUSKO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2DE. PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2EME PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ANDEN PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ANDRE PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGA PIOTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGI PIOTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PIETARIN 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETROVA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("MASODIK PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PETE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("TWEEDE PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PIETARIN 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 K PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PATRUSKO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETRACEM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PATARAS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETROVA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PJETRIT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.O. PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2D. PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2DE PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2E. PETRUS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2E. PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DEZYEM PIE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DEZYEM PYE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHA PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHY PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETROVA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. BUTROS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETRUS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PIETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PILI PETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("TWEEDE PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PATARAS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETROVA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PJETRIT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. BUTROS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETERS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETRUS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PIETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.O PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2A. PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2D PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2E PETRUS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2E PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PETE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2O. PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ANDEN PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ANDRE PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II BUTROS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETRUS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PIETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETRI 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETRU 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PIOTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 BUTROS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETERS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETRUS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETURU 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PIETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PATRAS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETRI 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETRU 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PIOTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2A PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2E. PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PETE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2O PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHA PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHY PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETRI 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETRU 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PIOTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PEDR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PHIA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETRI II 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETRO II 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PILI PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETRI 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETRU 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PIOTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PEDR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PHIA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2E PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2E. PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHA P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHY P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PEDR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PHIA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. BUT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PIE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PYE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PEDR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PHIA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PIET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. BUT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PIE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PYE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2E PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II BUT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PIE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PYE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 BUT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PED 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PIE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PJE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PYE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PD 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PI 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PJ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 P 1:1").osis()).toEqual("2Pet.1.1")
		`
		true
describe "Localized book 1Pet (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Pet (ascii)", ->
		`
		expect(p.parse("Peturu Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Perse poslannja apostola Petra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Ensimmainen Pietarin kirje 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Fyrra almenna bref Peturs 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Waraka wa Kwanza wa Petro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Barua ya Kwanza ya Petro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsza List sw. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsze List sw. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwszy List sw. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsza List sw Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsze List sw Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwszy List sw Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prima lettera di Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prva Petrova Poslanica 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prva Petrova poslanica 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("patrusko pahilo patra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("petracem pahile patra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petrova Poslanica 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Ensimmainen Pietarin 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petrova Poslanica 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsza List Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsze List Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwszy List Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petrova Poslanica 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Forsta Petrusbrevet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petrova Poslanica 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. List sw. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. List sw. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Petrus forsta brev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 List sw. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. List sw Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pietarin kirje 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I List sw. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. List sw Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pietarin kirje 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Primero San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prva kniha Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvni list Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 List sw Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pietarin kirje 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Epistula I Petri 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Epistula Petri I 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Fyrra Petursbref 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I List sw Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pietarin kirje 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premieres Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Primer San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvy Petrov list 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvy list Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petrusbrevet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsza Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsze Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwszy Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premiere Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premiers Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petrusbrevet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. List Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. list Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.o. San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. List Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. list Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Peters 1. Brev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsza Piotr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsze Piotr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwszy Piotr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premier Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Primeira Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Primeiro Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 List Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 list Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petersbrev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.o San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1o. San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Butros Kowaad 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Eerste Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I List Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I list Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Peters 1 Brev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Primero Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvni Petrova 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petersbrev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 e. Pjetrit 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 i. Pjetrit 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ere. Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1o San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Erste Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Kwanza Petro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prima Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Primer Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Primo Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prva Petrova 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvni Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 e Pjetrit 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 i Pjetrit 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 k. Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pietarin 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. patrusko 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1er. Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ere Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1re. Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Eerste Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pietarin 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prva Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvy Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Unang Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pietarin 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 k Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 patrusko 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 petracem 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pataras 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petrova 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pjetrit 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.o. Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1e. Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1er Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1re Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Eerste Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Elso Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pietarin 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petrova 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Kwanza Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premye Pie 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premye Pye 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvni Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pataras 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petrova 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pjetrit 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Butros 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Peters 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.o Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1a. Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1e Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1o. Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petrova 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Butros 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Una Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Butros 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Peters 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Peturu 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 patras 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petri 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petru 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Piotr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1a Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1e. Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1o Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Elso Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Butros 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petri 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petru 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Piotr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvni Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petri 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petru 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Piotr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pedr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Phia 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1e Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1e. Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petri 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petru 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Piotr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pedr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Phia 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Petri I 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Petro I 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvni P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pedr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Phia 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Piet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. But 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pie 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pye 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1e Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pedr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Phia 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. But 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pie 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pye 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 But 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Ped 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pie 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pje 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pye 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I But 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pie 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pye 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pd 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pi 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pj 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I P 1:1").osis()).toEqual("1Pet.1.1")
		p.include_apocrypha(false)
		expect(p.parse("PETURU ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PERSE POSLANNJA APOSTOLA PETRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ENSIMMAINEN PIETARIN KIRJE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FYRRA ALMENNA BREF PETURS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("WARAKA WA KWANZA WA PETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("BARUA YA KWANZA YA PETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZA LIST SW. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZE LIST SW. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZY LIST SW. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZA LIST SW PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZE LIST SW PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZY LIST SW PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRIMA LETTERA DI PIETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVA PETROVA POSLANICA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVA PETROVA POSLANICA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PATRUSKO PAHILO PATRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETRACEM PAHILE PATRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETROVA POSLANICA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ENSIMMAINEN PIETARIN 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETROVA POSLANICA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZA LIST PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZE LIST PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZY LIST PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETROVA POSLANICA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FORSTA PETRUSBREVET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETROVA POSLANICA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. LIST SW. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. LIST SW. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETRUS FORSTA BREV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 LIST SW. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. LIST SW PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PIETARIN KIRJE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I LIST SW. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. LIST SW PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PIETARIN KIRJE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRIMERO SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVA KNIHA PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVNI LIST PETRUV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 LIST SW PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PIETARIN KIRJE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("EPISTULA I PETRI 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("EPISTULA PETRI I 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FYRRA PETURSBREF 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I LIST SW PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PIETARIN KIRJE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PREMIERES PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRIMER SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVY PETROV LIST 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVY LIST PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETRUSBREVET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZA PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZE PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZY PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PREMIERE PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PREMIERS PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETRUSBREVET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. LIST PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. LIST PETRUV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.O. SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. LIST PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. LIST PETRUV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETERS 1. BREV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZA PIOTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZE PIOTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZY PIOTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PREMIER PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRIMEIRA PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRIMEIRO PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 LIST PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 LIST PETRUV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETERSBREV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.O SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1O. SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("BUTROS KOWAAD 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("EERSTE PETRUS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I LIST PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I LIST PETRUV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETERS 1 BREV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRIMERO PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVNI PETROVA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETERSBREV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 E. PJETRIT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 I. PJETRIT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ERE. PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1O SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ERSTE PETRUS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("KWANZA PETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRIMA PIETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRIMER PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRIMO PIETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVA PETROVA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVNI PETRUV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 E PJETRIT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 I PJETRIT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 K. PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PIETARIN 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PATRUSKO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ER. PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ERE PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1RE. PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("EERSTE PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PIETARIN 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVA PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVY PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("UNANG PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PIETARIN 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 K PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PATRUSKO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETRACEM 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PATARAS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETROVA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PJETRIT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.O. PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1E. PETRUS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ER PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1RE PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("EERSTE PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ELSO PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PETE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PIETARIN 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETROVA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("KWANZA PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PREMYE PIE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PREMYE PYE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVNI PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PATARAS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETROVA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PJETRIT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. BUTROS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETERS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETRUS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETRUV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PIETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.O PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1A. PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1E PETRUS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1O. PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PETE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETROVA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. BUTROS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETRUS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETRUV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PIETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("UNA PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 BUTROS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETERS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETRUS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETRUV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETURU 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PIETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PATRAS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETRI 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETRU 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PIOTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1A PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1E. PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1O PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PETE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ELSO PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I BUTROS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETRUS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETRUV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PIETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETRI 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETRU 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PIOTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVNI PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETRI 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETRU 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PIOTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PEDR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PHIA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1E PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1E. PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETRI 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETRU 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PIOTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PEDR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PHIA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETRI I 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETRO I 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVNI P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PEDR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PHIA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PIET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. BUT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PIE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PYE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1E PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PEDR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PHIA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. BUT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PIE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PYE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 BUT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PED 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PIE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PJE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PYE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I BUT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PIE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PYE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PD 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PI 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PJ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I P 1:1").osis()).toEqual("1Pet.1.1")
		`
		true
describe "Localized book Rom (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Rom (ascii)", ->
		`
		expect(p.parse("Poslannja apostola Pavla do rymljan 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Pavlova poslanica Rimljanima 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Uromarukku Elutiya Nirupam 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Paulus' Brev til Romerne 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Paulus’ Brev til Romerne 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Paulus’ brev til romerne 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Bref Pals til Romverja 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Poslanica Rimljanima 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Epistula ad Romanos 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Kirje roomalaisille 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Sulat sa mga Romano 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Layang Paulus Roma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Lettera ai Romani 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Waraka kwa Waroma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Waraka kwa Warumi 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romiharulai patra 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Barua kwa Waroma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("List do Rzymian 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romkarams patra 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Mga Taga- Roma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Roomalaiskirje 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Mga Taga Roma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Mga Taga-Roma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romeinenbrief 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Roomalaisille 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("List Rimanom 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("List Rimanum 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rhufeiniaid 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romarbrevet 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romerbrevet 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romiharulai 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rimljanima 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romaiakhoz 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Taga- Roma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Uromarukku 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ad Romanos 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Taga Roma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romkarams 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romakeve 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romeinen 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rimanom 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rimanum 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rimskym 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romains 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romands 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romanos 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romerne 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romiyon 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rzymian 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Roamns 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Roemer 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romani 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romano 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romans 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romasn 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rpmans 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Waroma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Warumi 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Roman 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romen 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romer 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rooma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rhuf 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rmns 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Roma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Roms 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Room 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rzym 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rim 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rmn 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rms 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rom 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Ros 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rum 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rm 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Ro 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rz 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("R 1:1").osis()).toEqual("Rom.1.1")
		p.include_apocrypha(false)
		expect(p.parse("POSLANNJA APOSTOLA PAVLA DO RYMLJAN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("PAVLOVA POSLANICA RIMLJANIMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("UROMARUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("PAULUS' BREV TIL ROMERNE 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("PAULUS’ BREV TIL ROMERNE 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("PAULUS’ BREV TIL ROMERNE 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("BREF PALS TIL ROMVERJA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("POSLANICA RIMLJANIMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("EPISTULA AD ROMANOS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("KIRJE ROOMALAISILLE 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("SULAT SA MGA ROMANO 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("LAYANG PAULUS ROMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("LETTERA AI ROMANI 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("WARAKA KWA WAROMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("WARAKA KWA WARUMI 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMIHARULAI PATRA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("BARUA KWA WAROMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("LIST DO RZYMIAN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMKARAMS PATRA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("MGA TAGA- ROMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROOMALAISKIRJE 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("MGA TAGA ROMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("MGA TAGA-ROMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMEINENBRIEF 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROOMALAISILLE 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("LIST RIMANOM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("LIST RIMANUM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RHUFEINIAID 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMARBREVET 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMERBREVET 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMIHARULAI 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RIMLJANIMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMAIAKHOZ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("TAGA- ROMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("UROMARUKKU 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("AD ROMANOS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("TAGA ROMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMKARAMS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMAKEVE 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMEINEN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RIMANOM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RIMANUM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RIMSKYM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMAINS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMANDS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMANOS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMERNE 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMIYON 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RZYMIAN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROAMNS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROEMER 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMANI 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMANO 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMANS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMASN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RPMANS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("WAROMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("WARUMI 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMAN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMEN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMER 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROOMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RHUF 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RMNS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROOM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RZYM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RIM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RMN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RMS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RUM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RO 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RZ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("R 1:1").osis()).toEqual("Rom.1.1")
		`
		true
describe "Localized book Song (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Song (ascii)", ->
		`
		expect(p.parse("El Cantar de los Cantares 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantare de los Cantares 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantar de los Cantares 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantique des Cantiques 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantique des cantiques 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Canticos dos Canticos 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Salomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Salomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Solomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Solomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Ang Awit ng mga Awit 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantarea lui Solomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantico dos Canticos 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Salomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Salomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Solomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Solomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Saloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Salomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Soloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Solomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Velpiesen Salamunova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Ang Awit ni Salomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Ang Awit ni Solomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantarea Cantarilor 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantarea cantarilor 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantares de Salomao 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantico Superlativo 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantico dei Cantici 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantico dei cantici 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantico di Salomone 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Canticum Canticorum 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Canticum canticorum 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Kantiku i Kantikeve 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Musthikaning Kidung 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piesn nad Piesniami 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pisnja nad pisnjamy 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pjesma nad pjesmama 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Saloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Salomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Soloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Solomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantico de Salomao 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Gabaygii Sulaymaan 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hohelied Salomonis 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Songs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hoheslied Salomos 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piesen Salamunova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pisen Salamounova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Salomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Salomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Solomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Solomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Songs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Song 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Awit ng mga Awit 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Awit sa mga Awit 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Kantid de Kantik 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Salomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Salomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Solomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Solomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Saloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Salomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Soloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Solomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Song 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Awit ni Salomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Awit ni Solomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Saloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Salomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Soloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Solomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Wimbo Ulio Bora 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Caniad Solomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Chante Salomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Laulujen laulu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piesn Salomona 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Songs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piesen piesni 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Salamon eneke 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Songs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Song 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cant. Cantic 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Enekek eneke 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Kidung Agung 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Korkea veisu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Song 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Unnatappattu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cant Cantic 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pisen pisni 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Reshthageet 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hoga visan 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hohes Lied 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Wimbo Bora 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantiques 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hoheslied 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Kantikulo 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Velpiesen 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Caniadau 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantares 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Canticos 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantique 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Gabaygii 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hohelied 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hooglied 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("gitratna 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Aw ni S 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantari 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantico 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Kantiko 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Laul. l 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Chante 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hoga V 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hoga v 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Laul l 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piesen 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("S of S 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hogav 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hoogl 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pisen 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cant 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hoga 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hojs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Kant 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pies 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Sngs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Velp 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Can 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cnt 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Gab 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hld 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Ljl 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PNP 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pis 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pnp 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Sgs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Sng 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SoS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Sol 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Son 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Vlp 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Wim 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Ct 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hl 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pj 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Sg 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("So 1:1").osis()).toEqual("Song.1.1")
		p.include_apocrypha(false)
		expect(p.parse("EL CANTAR DE LOS CANTARES 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTARE DE LOS CANTARES 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTAR DE LOS CANTARES 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTIQUE DES CANTIQUES 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTIQUE DES CANTIQUES 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICOS DOS CANTICOS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SALOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SALOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SOLOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SOLOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ANG AWIT NG MGA AWIT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTAREA LUI SOLOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICO DOS CANTICOS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SALOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SALOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SOLOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SOLOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SALOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SALOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SOLOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SOLOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VELPIESEN SALAMUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ANG AWIT NI SALOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ANG AWIT NI SOLOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTAREA CANTARILOR 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTAREA CANTARILOR 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTARES DE SALOMAO 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICO SUPERLATIVO 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICO DEI CANTICI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICO DEI CANTICI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICO DI SALOMONE 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICUM CANTICORUM 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICUM CANTICORUM 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("KANTIKU I KANTIKEVE 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("MUSTHIKANING KIDUNG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESN NAD PIESNIAMI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PISNJA NAD PISNJAMY 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PJESMA NAD PJESMAMA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SALOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SALOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SOLOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SOLOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICO DE SALOMAO 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("GABAYGII SULAYMAAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOHELIED SALOMONIS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SONGS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOHESLIED SALOMOS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESEN SALAMUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PISEN SALAMOUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SALOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SALOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SOLOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SOLOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SONGS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SONG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("AWIT NG MGA AWIT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("AWIT SA MGA AWIT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("KANTID DE KANTIK 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SALOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SALOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SOLOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SOLOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SALOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SALOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SOLOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SOLOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SONG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("AWIT NI SALOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("AWIT NI SOLOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SALOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SALOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SOLOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SOLOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("WIMBO ULIO BORA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANIAD SOLOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CHANTE SALOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("LAULUJEN LAULU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESN SALOMONA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SONGS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESEN PIESNI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SALAMON ENEKE 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SONGS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SONG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANT. CANTIC 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ENEKEK ENEKE 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("KIDUNG AGUNG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("KORKEA VEISU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SONG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UNNATAPPATTU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANT CANTIC 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PISEN PISNI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("RESHTHAGEET 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOGA VISAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOHES LIED 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("WIMBO BORA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTIQUES 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOHESLIED 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("KANTIKULO 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VELPIESEN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANIADAU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTARES 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICOS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTIQUE 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("GABAYGII 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOHELIED 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOOGLIED 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("GITRATNA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("AW NI S 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTARI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICO 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("KANTIKO 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("LAUL. L 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CHANTE 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOGA V 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOGA V 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("LAUL L 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESEN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("S OF S 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOGAV 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOOGL 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PISEN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOGA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOJS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("KANT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIES 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SNGS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VELP 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CNT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("GAB 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HLD 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("LJL 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PNP 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PNP 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SGS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SNG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SOS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SOL 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VLP 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("WIM 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HL 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PJ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SO 1:1").osis()).toEqual("Song.1.1")
		`
		true
describe "Localized book Prov (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Prov (ascii)", ->
		`
		expect(p.parse("Ksiega Przypowiesci Salomona 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ksiegi Przypowiesci Salomona 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ks. Przypowiesci Salomona 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Przypowiesci Salomonowych 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ks Przypowiesci Salomona 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proverbele lui Solomon 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prislovi Salomounova 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Pildele lui Solomon 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Sananlaskujen kirja 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Liber Proverbiorum 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("hitopadesko pustak 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ordsprogenes Bog 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Salomos Ordsprak 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Salomos Ordsprog 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Kniha prislovi 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Mga Panultihon 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ordspraksboken 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Wulang Bebasan 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Fjalet e urta 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Liv Pwoveb yo 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Maahmaahyadii 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Peldabeszedek 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Sananlaskujen 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Mga Kawikaan 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Mudre izreke 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Sprichworter 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("K. prislovi 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Neetivachan 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Nitimolikal 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ordsprakene 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ordsprogene 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Probverbios 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Sananlaskut 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("hitopadesko 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Diarhebion 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("K prislovi 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Panultihon 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Porverbios 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Preverbios 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proberbios 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proverbele 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proverbios 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prypovisti 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Diarebion 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Poslovice 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Poverbios 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Preverbio 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prislovia 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Probverbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Provebios 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proverbes 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proverbia 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proverbio 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prverbios 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("nitisutre 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Kawikaan 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Oroverbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Porverbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Preverbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prislovi 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proberbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proverbe 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proverbi 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proverbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prverbio 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Spreuken 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Sprueche 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Methali 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Mithali 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Poverbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Preverb 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Provebs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proverb 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prverbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Spruche 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prvbos 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prverb 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Pwoveb 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Sananl 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ordsp 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prvbo 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prvbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Przyp 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Diar 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Maah 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Meth 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Mith 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ords 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Peld 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Pris 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prov 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prvb 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Przy 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Izr 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Kaw 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Mit 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Okv 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Pro 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prv 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prz 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Snl 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Spr 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Pr 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Pv 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Pw 1:1").osis()).toEqual("Prov.1.1")
		p.include_apocrypha(false)
		expect(p.parse("KSIEGA PRZYPOWIESCI SALOMONA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KSIEGI PRZYPOWIESCI SALOMONA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KS. PRZYPOWIESCI SALOMONA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRZYPOWIESCI SALOMONOWYCH 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KS PRZYPOWIESCI SALOMONA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVERBELE LUI SOLOMON 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRISLOVI SALOMOUNOVA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PILDELE LUI SOLOMON 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SANANLASKUJEN KIRJA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("LIBER PROVERBIORUM 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("HITOPADESKO PUSTAK 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ORDSPROGENES BOG 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SALOMOS ORDSPRAK 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SALOMOS ORDSPROG 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KNIHA PRISLOVI 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("MGA PANULTIHON 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ORDSPRAKSBOKEN 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("WULANG BEBASAN 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("FJALET E URTA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("LIV PWOVEB YO 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("MAAHMAAHYADII 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PELDABESZEDEK 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SANANLASKUJEN 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("MGA KAWIKAAN 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("MUDRE IZREKE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SPRICHWORTER 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("K. PRISLOVI 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("NEETIVACHAN 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("NITIMOLIKAL 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ORDSPRAKENE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ORDSPROGENE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROBVERBIOS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SANANLASKUT 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("HITOPADESKO 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("DIARHEBION 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("K PRISLOVI 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PANULTIHON 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PORVERBIOS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PREVERBIOS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROBERBIOS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVERBELE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVERBIOS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRYPOVISTI 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("DIAREBION 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("POSLOVICE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("POVERBIOS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PREVERBIO 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRISLOVIA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROBVERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVEBIOS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVERBES 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVERBIA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVERBIO 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRVERBIOS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("NITISUTRE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KAWIKAAN 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("OROVERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PORVERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PREVERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRISLOVI 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROBERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVERBE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVERBI 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRVERBIO 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SPREUKEN 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SPRUECHE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("METHALI 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("MITHALI 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("POVERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PREVERB 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVEBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVERB 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRVERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SPRUCHE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRVBOS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRVERB 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PWOVEB 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SANANL 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ORDSP 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRVBO 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRVBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRZYP 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("DIAR 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("MAAH 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("METH 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("MITH 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ORDS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PELD 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRIS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROV 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRVB 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRZY 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("IZR 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KAW 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("MIT 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("OKV 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRO 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRV 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRZ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SNL 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SPR 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PR 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PV 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PW 1:1").osis()).toEqual("Prov.1.1")
		`
		true
describe "Localized book Wis (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Wis (ascii)", ->
		`
		expect(p.parse("Cartea intelepciunii lui Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ang Karunungan ni Salomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ang Karunungan ni Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Intelepciunea lui Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("De wijsheid van Salomo 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Het boek der wijsheid 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Karunungan ni Salomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Karunungan ni Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("The Wisdom of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Cartea Intelepciunii 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Moudrost Salomounova 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sabedoria de Salomao 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sapienza di Salomone 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("The Wisom of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Kawicaksanan Salomo 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Salamon bolcsessege 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sapientia Salomonis 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("The Wisd of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wijsheid van Salomo 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Hekima ya Solomoni 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sagesse de Salomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("The Wis of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Doethineb Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wisdom of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Liber Sapientiae 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Madrosc Salomona 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Weisheit Salomos 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wisom of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Kniha Moudrosti 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Kniha moudrosti 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Knjiga Mudrosti 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ksiega Madrosci 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ksiegi Madrosci 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Salomon viisaus 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Viisauden kirja 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wisd of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Salomos Visdom 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Salomos vishet 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Speki Salomons 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Visdommens Bog 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Visdommens bok 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wis of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Vishetens bok 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Kawicaksanan 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ks. Madrosci 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ks Madrosci 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Bolcsesseg 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Karunungan 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sabedoria 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sabiduria 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sapientia 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Visdommen 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Moudrost 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Mudrosti 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sapienza 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Visheten 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Weisheit 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wijsheid 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Mudrost 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sagesse 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Salomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sapient 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Hekima 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wisdom 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Bolcs 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Weish 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Madr 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Mudr 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("SSal 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Viis 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Visd 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Vish 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wisd 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Hek 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Kar 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Mdr 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Mud 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sab 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sap 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wis 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sb 1:1").osis()).toEqual("Wis.1.1")
		`
		true
describe "Localized book Joel (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Joel (ascii)", ->
		`
		expect(p.parse("Proroctwo Ioelowe 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Prophetia Ioel 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joelin kirja 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Ksiega Joela 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Ksiegi Joela 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Liv Jowel la 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joels Bog 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joels bok 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Ks. Joela 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Ks Joela 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Yoo'eel 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Yoo’eel 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Gioele 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joelin 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joela 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joeli 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Jowel 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Yoael 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Yoeli 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Yovel 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Gioe 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Ioel 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Ioil 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joel 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joil 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Yoel 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Yole 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Yool 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("yoel 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joe 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Yoe 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Jl 1:1").osis()).toEqual("Joel.1.1")
		p.include_apocrypha(false)
		expect(p.parse("PROROCTWO IOELOWE 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("PROPHETIA IOEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOELIN KIRJA 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("KSIEGA JOELA 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("KSIEGI JOELA 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("LIV JOWEL LA 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOELS BOG 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOELS BOK 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("KS. JOELA 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("KS JOELA 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YOO'EEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YOO’EEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("GIOELE 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOELIN 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOELA 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOELI 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOWEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YOAEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YOELI 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YOVEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("GIOE 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("IOEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("IOIL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOIL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YOEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YOLE 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YOOL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YOEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOE 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YOE 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JL 1:1").osis()).toEqual("Joel.1.1")
		`
		true
describe "Localized book Jonah (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Jonah (ascii)", ->
		`
		expect(p.parse("Proroctwo Ionaszowe 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Prophetia Ionae 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Ksiega Jonasza 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Ksiegi Jonasza 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Joonan kirja 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Liv Jonas la 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Ks. Jonasza 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jonas' Bog 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jonas’ Bog 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Ks Jonasza 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jonas bok 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jona bok 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jonasza 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Joonan 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Yoonis 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Giona 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Ionas 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jonah 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jonas 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Joona 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Yunus 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Iona 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jona 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Yona 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Yoon 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("yona 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Gio 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jnh 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jns 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jon 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Yon 1:1").osis()).toEqual("Jonah.1.1")
		p.include_apocrypha(false)
		expect(p.parse("PROROCTWO IONASZOWE 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("PROPHETIA IONAE 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("KSIEGA JONASZA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("KSIEGI JONASZA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JOONAN KIRJA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("LIV JONAS LA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("KS. JONASZA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JONAS' BOG 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JONAS’ BOG 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("KS JONASZA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JONAS BOK 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JONA BOK 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JONASZA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JOONAN 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("YOONIS 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("GIONA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("IONAS 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JONAH 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JONAS 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JOONA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("YUNUS 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("IONA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JONA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("YONA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("YOON 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("YONA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("GIO 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JNH 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JNS 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JON 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("YON 1:1").osis()).toEqual("Jonah.1.1")
		`
		true
describe "Localized book Nah (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Nah (ascii)", ->
		`
		expect(p.parse("Proroctwo Nahumowe 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Prophetia Nahum 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Liv Nawoum lan 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Ksiega Nahuma 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Ksiegi Nahuma 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahumin kirja 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Ks. Nahuma 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahums Bog 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahums bok 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Ks Nahuma 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahumin 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Na-hum 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahoom 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahuma 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahumi 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahumu 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nawoum 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nawoun 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Naxuum 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahum 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nakum 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("nahum 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nach 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahu 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Naum 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nah 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Naw 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nax 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Na 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nh 1:1").osis()).toEqual("Nah.1.1")
		p.include_apocrypha(false)
		expect(p.parse("PROROCTWO NAHUMOWE 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("PROPHETIA NAHUM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("LIV NAWOUM LAN 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("KSIEGA NAHUMA 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("KSIEGI NAHUMA 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHUMIN KIRJA 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("KS. NAHUMA 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHUMS BOG 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHUMS BOK 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("KS NAHUMA 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHUMIN 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NA-HUM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHOOM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHUMA 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHUMI 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHUMU 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAWOUM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAWOUN 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAXUUM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHUM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAKUM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHUM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NACH 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHU 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAUM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAH 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAW 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAX 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NA 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NH 1:1").osis()).toEqual("Nah.1.1")
		`
		true
describe "Localized book 1John (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1John (ascii)", ->
		`
		expect(p.parse("Yovan Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Perse poslannja apostola Ivana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ensimmainen Johanneksen kirje 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Waraka wa Kwanza wa Yohane 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Barua ya Kwanza ya Yohane 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prima lettera di Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ensimmainen Johanneksen 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta bref Johannesar 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsza List sw. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsze List sw. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwszy List sw. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prva Ivanova Poslanica 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prva Ivanova poslanica 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yohanacem pahile patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yuhannako pahilo patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Forsta Johannesbrevet 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta Johannesarbref 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsza List sw Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsze List sw Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwszy List sw Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Ivanova Poslanica 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Johanneksen kirje 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Ivanova Poslanica 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Johanneksen kirje 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes forsta brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Ivanova Poslanica 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Johanneksen kirje 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Ivanova Poslanica 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Johanneksen kirje 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Epistula I Ioannis 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Epistula Ioannis I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsza List Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsze List Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwszy List Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Johannesbrevet 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes' 1. Brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes’ 1. Brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Johannesbrevet 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. List sw. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. List sw. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes' 1 Brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes’ 1 Brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prva kniha Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvni list Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 List sw. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Johannesbrev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. List sw Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Eerste Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I List sw. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. List sw Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvy Janov list 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvy list Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yooxanaa Kowaad 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Johannesbrev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 List sw Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Johanneksen 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Erste Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I List sw Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Johanneksen 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Premieres Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prima Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primo Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Johanneksen 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. list Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Johanneksen 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. list Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Kwanza Yohana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Kwanza Yohane 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsza Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsze Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwszy Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Premiere Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Premiers Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primeira Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primeiro Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 list Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. List Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. yuhannako 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1e. Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I list Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. List Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Premier Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prva Ivanova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvni Janova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 List Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 e. Gjonit 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 i. Gjonit 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yohanacem 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yuhannako 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yoohanna 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yooxanaa 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1e Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I List Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Yooxanaa 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvni Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yoohanna 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yooxanaa 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 e Gjonit 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 i Gjonit 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 k. Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Ioannis 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Ivanova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yohanes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yokanan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ere. Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Eerste Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Elso Janos 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Yooxanaa 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Ioannis 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Ivanova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Yohanes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Yokanan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Kwanza Yoh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Premye Jan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prva Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvy Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Unang Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Ioannis 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Ivanova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yohanes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yokanan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 k Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Gjonit 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Janova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yohana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yohane 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1er. Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ere Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1re. Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Ioannis 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Ivanova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Yohanes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Yokanan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Janova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Yohana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Yohane 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ioannis I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvni Jan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Gjonit 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Janova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yohana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yohane 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Gioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Janos 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1a. Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1er Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1re Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Janova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Yohana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Yohane 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Gioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Janos 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Una Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yohane I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Gioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Janos 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yovan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Ioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yoox 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1a Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1e. Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Elso Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Gioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Janos 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Ioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Yoox 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Janos I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvni J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Ioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yoox 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yoh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1e Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Ioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Yoox 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Yoh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yoh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Gi 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. In 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Yoh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Gi 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. In 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Gi 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Gj 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Gv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 In 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Iv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Gi 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I In 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I J 1:1").osis()).toEqual("1John.1.1")
		p.include_apocrypha(false)
		expect(p.parse("YOVAN ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PERSE POSLANNJA APOSTOLA IVANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ENSIMMAINEN JOHANNEKSEN KIRJE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("WARAKA WA KWANZA WA YOHANE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("BARUA YA KWANZA YA YOHANE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMA LETTERA DI GIOVANNI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ENSIMMAINEN JOHANNEKSEN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FYRSTA BREF JOHANNESAR 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZA LIST SW. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZE LIST SW. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZY LIST SW. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVA IVANOVA POSLANICA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVA IVANOVA POSLANICA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YOHANACEM PAHILE PATRA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YUHANNAKO PAHILO PATRA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FORSTA JOHANNESBREVET 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FYRSTA JOHANNESARBREF 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZA LIST SW JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZE LIST SW JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZY LIST SW JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. IVANOVA POSLANICA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOHANNEKSEN KIRJE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. IVANOVA POSLANICA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOHANNEKSEN KIRJE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("JOHANNES FORSTA BREV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 IVANOVA POSLANICA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOHANNEKSEN KIRJE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I IVANOVA POSLANICA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOHANNEKSEN KIRJE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("EPISTULA I IOANNIS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("EPISTULA IOANNIS I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZA LIST JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZE LIST JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZY LIST JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOHANNESBREVET 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("JOHANNES' 1. BREV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("JOHANNES’ 1. BREV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOHANNESBREVET 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. LIST SW. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. LIST SW. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("JOHANNES' 1 BREV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("JOHANNES’ 1 BREV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMERO SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMERO SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMERO SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMERO SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVA KNIHA JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVNI LIST JANUV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 LIST SW. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOHANNESBREV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. LIST SW JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("EERSTE JOHANNES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I LIST SW. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. LIST SW JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMER SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMER SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMER SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMER SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVY JANOV LIST 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVY LIST JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YOOXANAA KOWAAD 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOHANNESBREV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 LIST SW JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOHANNEKSEN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ERSTE JOHANNES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I LIST SW JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOHANNEKSEN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PREMIERES JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMA GIOVANNI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMO GIOVANNI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOHANNEKSEN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. LIST JANUV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O. SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O. SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O. SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O. SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOHANNEKSEN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. LIST JANUV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("KWANZA YOHANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("KWANZA YOHANE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZA JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZE JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZY JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PREMIERE JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PREMIERS JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMEIRA JOAO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMEIRO JOAO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 LIST JANUV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. LIST JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. YUHANNAKO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1E. JOHANNES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O. SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O. SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O. SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O. SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I LIST JANUV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. LIST JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PREMIER JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMERO JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMERO JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMERO JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMERO JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVA IVANOVA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVNI JANOVA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 LIST JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 E. GJONIT 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 I. GJONIT 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOHANACEM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YUHANNAKO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. GIOVANNI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOHANNES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. YOOHANNA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. YOOXANAA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1E JOHANNES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JOPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I LIST JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. GIOVANNI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOHANNES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. YOOXANAA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMER JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMER JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMER JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMER JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVNI JANUV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 GIOVANNI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOHANNES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOOHANNA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOOXANAA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 E GJONIT 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 I GJONIT 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 K. JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. IOANNIS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. IVANOVA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. YOHANES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. YOKANAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ERE. JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JOPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("EERSTE JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ELSO JANOS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JHHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JHON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JOHM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JONH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JOON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I GIOVANNI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOHANNES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I YOOXANAA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. IOANNIS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. IVANOVA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. YOHANES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. YOKANAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("KWANZA YOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PREMYE JAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVA JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVY JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("UNANG JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 IOANNIS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 IVANOVA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOHANES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOKANAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 K JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. GJONIT 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JANOVA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. YOHANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. YOHANE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O. JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O. JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O. JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O. JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ER. JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ERE JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1RE. JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JOPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JHHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JHON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JOHM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JONH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JOON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I IOANNIS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I IVANOVA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I YOHANES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I YOKANAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JANOVA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. YOHANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. YOHANE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("IOANNIS I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVNI JAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 GJONIT 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JANOVA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOHANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOHANE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. GIOAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JANOS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JANUV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1A. JOAO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ER JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O. JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O. JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O. JOAO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O. JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O. JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1RE JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JHHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JHON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JOHM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JONH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JOON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JANOVA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I YOHANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I YOHANE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. GIOAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JANOS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JANUV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("UNA JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YOHANE I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 GIOAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JANOS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JANUV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOVAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. IOAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JHHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JHON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOAO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOHM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JONH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. YOOX 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1A JOAO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1E. JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O JOAO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ELSO JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I GIOAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JANOS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JANUV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. IOAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JHHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JHON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOAO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOHM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JONH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. YOOX 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("JANOS I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVNI J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 IOAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JHHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JHON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOAO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOHM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JONH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOOX 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. YOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1E JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I IOAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JHHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JHON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOAO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOHM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JONH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I YOOX 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. YOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. GI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. IN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I YOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. GI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. IN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 GI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 GJ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 GV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 IN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 IV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I GI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I IN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I J 1:1").osis()).toEqual("1John.1.1")
		`
		true
describe "Localized book 2John (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2John (ascii)", ->
		`
		expect(p.parse("Yovan Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhe poslannja apostola Ivana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Seconda lettera di Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Toinen Johanneksen kirje 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Waraka wa Pili wa Yohane 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Barua ya Pili ya Yohane 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga Ivanova Poslanica 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga Ivanova poslanica 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yuhannako dostro patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Ivanova Poslanica 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Johanneksen kirje 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yohanacem dusre patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Ivanova Poslanica 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Johanneksen kirje 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Andra Johannesbrevet 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Ivanova Poslanica 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Johanneksen kirje 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Johannes' Andet Brev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Johannes’ Andet Brev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Johannes’ andre brev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Ivanova Poslanica 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Johanneksen kirje 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga List sw. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Drugi List sw. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Epistula II Ioannis 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Epistula Ioannis II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Johannes andra brev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Anden Johannesbrev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Andet Johannesbrev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga List sw Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Drugi List sw Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Toinen Johanneksen 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Johannesbrevet 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha kniha Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. List sw. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Johannesbrevet 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. List sw. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha list Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy Janov list 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy list Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy list Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II List sw. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. List sw Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Seconda Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Secondo Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 List sw. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Johannesbrev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. List sw Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga List Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Drugi List Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II List sw Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Johanneksen 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Tweede Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yooxanaa Labaad 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Zweite Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Johannesbrev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 List sw Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Johanneksen 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Anden Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Andre Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Deuxiemes Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Johanneksen 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. list Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ikalawang Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Johanneksen 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. list Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Deuxieme Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga Ivanova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II list Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. List Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Masodik Janos 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 list Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. List Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. yuhannako 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2e. Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha Janova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy Janova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II List Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Yooxanaa 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segunda Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 List Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 e. Gjonit 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 i. Gjonit 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yohanacem 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yuhannako 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yoohanna 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yooxanaa 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2e Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Yooxanaa 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Ioannis 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Ivanova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Yohanes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Yokanan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Pili Yohana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Pili Yohane 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yoohanna 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yooxanaa 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 e Gjonit 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 i Gjonit 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 k. Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Ioannis 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Ivanova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yohanes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yokanan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2eme. Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Dezyem Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Drugi Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Ioannis 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Ivanova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Yohanes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Yokanan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Janova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Yohana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Yohane 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ioannis II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Masodik Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Toinen Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Tweede Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Ioannis 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Ivanova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yohanes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yokanan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 k Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Gjonit 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Janova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yohana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yohane 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2de. Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2eme Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Anden Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Andre Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Janova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Yohana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Yohane 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Gioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Janos 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yohane II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Gjonit 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Janova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yohana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yohane 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Gioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Janos 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2a. Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2d. Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2de Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2e. Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Gioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Janos 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Ioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Yoox 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Janos II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Pili Yoh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Gioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Janos 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yovan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Ioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yoox 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2a Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2d Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2e Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2e. Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Ioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Yoox 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Yoh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Ioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yoox 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yoh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2e Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Yoh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Gi 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. In 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yoh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Gi 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. In 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Gi 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II In 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Gi 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Gj 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Gv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 In 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Iv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 J 1:1").osis()).toEqual("2John.1.1")
		p.include_apocrypha(false)
		expect(p.parse("YOVAN ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHE POSLANNJA APOSTOLA IVANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECONDA LETTERA DI GIOVANNI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("TOINEN JOHANNEKSEN KIRJE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("WARAKA WA PILI WA YOHANE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("BARUA YA PILI YA YOHANE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGA IVANOVA POSLANICA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGA IVANOVA POSLANICA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YUHANNAKO DOSTRO PATRA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. IVANOVA POSLANICA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOHANNEKSEN KIRJE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOHANACEM DUSRE PATRA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. IVANOVA POSLANICA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOHANNEKSEN KIRJE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ANDRA JOHANNESBREVET 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II IVANOVA POSLANICA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOHANNEKSEN KIRJE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("JOHANNES' ANDET BREV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("JOHANNES’ ANDET BREV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("JOHANNES’ ANDRE BREV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 IVANOVA POSLANICA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOHANNEKSEN KIRJE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGA LIST SW. JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGI LIST SW. JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("EPISTULA II IOANNIS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("EPISTULA IOANNIS II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("JOHANNES ANDRA BREV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ANDEN JOHANNESBREV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ANDET JOHANNESBREV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGA LIST SW JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGI LIST SW JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("TOINEN JOHANNEKSEN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOHANNESBREVET 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHA KNIHA JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. LIST SW. JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOHANNESBREVET 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. LIST SW. JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHA LIST JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHY JANOV LIST 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHY LIST JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHY LIST JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II LIST SW. JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. LIST SW JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECONDA GIOVANNI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECONDO GIOVANNI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SEGUNDO SAN JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SEGUNDO SAN JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SEGUNDO SAN JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SEGUNDO SAN JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 LIST SW. JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOHANNESBREV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. LIST SW JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGA LIST JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGI LIST JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II LIST SW JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOHANNEKSEN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("TWEEDE JOHANNES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOOXANAA LABAAD 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ZWEITE JOHANNES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOHANNESBREV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 LIST SW JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOHANNEKSEN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ANDEN JOHANNES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ANDRE JOHANNES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DEUXIEMES JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOHANNEKSEN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. LIST JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("IKALAWANG JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOHANNEKSEN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. LIST JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O. SAN JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O. SAN JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O. SAN JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O. SAN JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DEUXIEME JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGA IVANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II LIST JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. LIST JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("MASODIK JANOS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 LIST JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. LIST JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. YUHANNAKO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O SAN JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O SAN JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O SAN JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O SAN JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2E. JOHANNES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O. SAN JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O. SAN JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O. SAN JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O. SAN JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHA JANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHY JANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II LIST JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. GIOVANNI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOHANNES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. SAN JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. SAN JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. SAN JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. SAN JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. YOOXANAA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JOPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SEGUNDA JOAO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SEGUNDO JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SEGUNDO JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SEGUNDO JOAO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SEGUNDO JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SEGUNDO JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 LIST JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 E. GJONIT 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 I. GJONIT 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOHANACEM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YUHANNAKO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. GIOVANNI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOHANNES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. SAN JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. SAN JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. SAN JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. SAN JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. YOOHANNA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. YOOXANAA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2E JOHANNES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O SAN JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O SAN JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O SAN JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O SAN JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHA JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHA JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHY JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHY JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II GIOVANNI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOHANNES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II SAN JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II SAN JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II SAN JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II SAN JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II YOOXANAA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. IOANNIS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. IVANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. YOHANES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. YOKANAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("PILI YOHANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("PILI YOHANE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JHHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JHON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JOHM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JONH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JOON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 GIOVANNI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOHANNES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 SAN JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 SAN JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 SAN JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 SAN JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOOHANNA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOOXANAA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 E GJONIT 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 I GJONIT 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 K. JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. IOANNIS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. IVANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. YOHANES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. YOKANAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2EME. JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JOPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DEZYEM JAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGA JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGI JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II IOANNIS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II IVANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II YOHANES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II YOKANAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. YOHANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. YOHANE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("IOANNIS II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("MASODIK JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("TOINEN JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("TWEEDE JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 IOANNIS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 IVANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOHANES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOKANAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 K JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. GJONIT 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. YOHANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. YOHANE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O. JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O. JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O. JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O. JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2DE. JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2EME JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JOPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JHHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JHON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JOHM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JONH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JOON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ANDEN JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ANDRE JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHA JAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHY JAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II YOHANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II YOHANE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. GIOAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JANOS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOHANE II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 GJONIT 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOHANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOHANE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. GIOAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JANOS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2A. JOAO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2D. JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2DE JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2E. JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JHHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JHON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JOHM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JONH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JOON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O. JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O. JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O. JOAO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O. JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O. JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II GIOAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JANOS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. IOAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JHHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JHON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOAO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOHM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JONH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. YOOX 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("JANOS II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("PILI YOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 GIOAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JANOS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOVAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. IOAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JHHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JHON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOAO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOHM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JONH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. YOOX 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2A JOAO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2D JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2E JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2E. JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O JOAO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHA J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHY J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II IOAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JHHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JHON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOAO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOHM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JONH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II YOOX 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. YOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 IOAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JHHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JHON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOAO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOHM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JONH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOOX 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. YOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2E JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II YOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. GI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. IN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. GI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. IN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II GI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II IN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 GI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 GJ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 GV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 IN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 IV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 J 1:1").osis()).toEqual("2John.1.1")
		`
		true
describe "Localized book 3John (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 3John (ascii)", ->
		`
		expect(p.parse("Tretje poslannja apostola Ivana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Munravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Terza lettera di Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Kolmas Johanneksen kirje 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Waraka wa Tatu wa Yohane 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Barua ya Tatu ya Yohane 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treca Ivanova Poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treca Ivanova poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Ivanova Poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Johanneksen kirje 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yuhannako testro patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Ivanova Poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Johanneksen kirje 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes' Tredje Brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes’ Tredje Brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes’ tredje brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tredje Johannesbrevet 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzecia List sw. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yohanacem tisre patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Ivanova Poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Johanneksen kirje 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Epistula III Ioannis 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Epistula Ioannis III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes tredje brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzeci List sw. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzecia List sw Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Ivanova Poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Johanneksen kirje 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tredje Johannesbrev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzeci List sw Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e. Johannesbrevet 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. List sw. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Kolmas Johanneksen 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretia kniha Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yooxanaa Saddexaad 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Johannesbrevet 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e Johannesbrevet 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III List sw. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. List sw Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes' 3. Brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes’ 3. Brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzecia List Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Johannesbrevet 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. List sw. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III List sw Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Johanneksen 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes' 3 Brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes’ 3 Brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti Janov list 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti list Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzeci List Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 List sw. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Johannesbrev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. List sw Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Dritte Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Johanneksen 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. list Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tredje Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Troisiemes Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Johannesbrev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 List sw Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Johanneksen 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Derde Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Harmadik Janos 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III list Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. List Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Terza Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Terzo Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Troisieme Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Johanneksen 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. list Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III List Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Yooxanaa 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ikatlong Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Terceira Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Terceiro Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treca Ivanova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 list Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. List Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. yuhannako 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e. Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Yooxanaa 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Ioannis 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Ivanova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Yohanes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Yokanan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti Janova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretia Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzecia Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 List Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 e. Gjonit 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 i. Gjonit 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yohanacem 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yuhannako 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yoohanna 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yooxanaa 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Harmadik Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Ioannis 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Ivanova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Yohanes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Yokanan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Janova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Yohana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Yohane 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ioannis III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tatu Yohana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tatu Yohane 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzeci Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yoohanna 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yooxanaa 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 e Gjonit 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 i Gjonit 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 k. Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Ioannis 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Ivanova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yohanes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yokanan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3eme. Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Janova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Yohana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Yohane 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Gioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Janos 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tredje Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yohane III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Ioannis 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Ivanova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yohanes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yokanan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 k Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Gjonit 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Janova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yohana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yohane 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3eme Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Derde Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Gioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Janos 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Ioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Yoox 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Janos III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti Jan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Gjonit 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Janova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yohana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yohane 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Gioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Janos 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3a. Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e. Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Ioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Yoox 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Yoh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tatu Yoh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Gioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Janos 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yovan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Ioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yoox 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3a Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e. Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Yoh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Gi 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. In 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Ioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yoox 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yoh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Gi 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III In 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yoh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Gi 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. In 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Gi 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Gj 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Gv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 In 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Iv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 J 1:1").osis()).toEqual("3John.1.1")
		p.include_apocrypha(false)
		expect(p.parse("TRETJE POSLANNJA APOSTOLA IVANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN ELUTIYA MUNRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERZA LETTERA DI GIOVANNI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("KOLMAS JOHANNEKSEN KIRJE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("WARAKA WA TATU WA YOHANE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("BARUA YA TATU YA YOHANE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRECA IVANOVA POSLANICA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRECA IVANOVA POSLANICA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. IVANOVA POSLANICA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOHANNEKSEN KIRJE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YUHANNAKO TESTRO PATRA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III IVANOVA POSLANICA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOHANNEKSEN KIRJE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("JOHANNES' TREDJE BREV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("JOHANNES’ TREDJE BREV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("JOHANNES’ TREDJE BREV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TREDJE JOHANNESBREVET 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRZECIA LIST SW. JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOHANACEM TISRE PATRA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. IVANOVA POSLANICA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOHANNEKSEN KIRJE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("EPISTULA III IOANNIS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("EPISTULA IOANNIS III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("JOHANNES TREDJE BREV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRZECI LIST SW. JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRZECIA LIST SW JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 IVANOVA POSLANICA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOHANNEKSEN KIRJE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TREDJE JOHANNESBREV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRZECI LIST SW JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3E. JOHANNESBREVET 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. LIST SW. JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("KOLMAS JOHANNEKSEN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETIA KNIHA JANOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOOXANAA SADDEXAAD 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOHANNESBREVET 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3E JOHANNESBREVET 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III LIST SW. JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. LIST SW JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("JOHANNES' 3. BREV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("JOHANNES’ 3. BREV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRZECIA LIST JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOHANNESBREVET 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. LIST SW. JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III LIST SW JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOHANNEKSEN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("JOHANNES' 3 BREV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("JOHANNES’ 3 BREV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCERO SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCERO SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCERO SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCERO SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETI JANOV LIST 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETI LIST JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRZECI LIST JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 LIST SW. JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOHANNESBREV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. LIST SW JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("DRITTE JOHANNES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOHANNEKSEN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. LIST JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCER SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCER SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCER SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCER SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TREDJE JOHANNES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TROISIEMES JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOHANNESBREV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 LIST SW JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOHANNEKSEN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("DERDE JOHANNES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("HARMADIK JANOS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III LIST JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. LIST JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERZA GIOVANNI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERZO GIOVANNI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TROISIEME JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOHANNEKSEN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. LIST JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O. SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O. SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O. SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O. SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III LIST JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. GIOVANNI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOHANNES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. YOOXANAA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("IKATLONG JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCEIRA JOAO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCEIRO JOAO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRECA IVANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 LIST JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. LIST JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. YUHANNAKO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3E. JOHANNES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O. SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O. SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O. SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O. SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III GIOVANNI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOHANNES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III YOOXANAA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. IOANNIS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. IVANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. YOHANES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. YOKANAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCERO JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCERO JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCERO JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCERO JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETI JANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETIA JANOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRZECIA JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 LIST JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 E. GJONIT 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 I. GJONIT 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOHANACEM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YUHANNAKO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. GIOVANNI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOHANNES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. YOOHANNA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. YOOXANAA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3E JOHANNES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("HARMADIK JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III IOANNIS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III IVANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III YOHANES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III YOKANAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. YOHANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. YOHANE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("IOANNIS III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TATU YOHANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TATU YOHANE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCER JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCER JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCER JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCER JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JOPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETI JANOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETI JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRZECI JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 GIOVANNI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOHANNES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOOHANNA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOOXANAA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 E GJONIT 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 I GJONIT 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 K. JANOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. IOANNIS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. IVANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. YOHANES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. YOKANAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3EME. JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JOPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III YOHANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III YOHANE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. GIOAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JANOS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JANOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JHHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JHON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JOHM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JONH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JOON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TREDJE JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOHANE III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 IOANNIS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 IVANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOHANES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOKANAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 K JANOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. GJONIT 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. YOHANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. YOHANE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O. JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O. JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O. JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O. JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3EME JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JOPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JHHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JHON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JOHM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JONH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JOON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("DERDE JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III GIOAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JANOS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JANOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. IOAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JHHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JHON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOAO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOHM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JONH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. YOOX 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("JANOS III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETI JAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 GJONIT 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOHANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOHANE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. GIOAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JANOS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JANOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3A. JOAO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3E. JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O. JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O. JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O. JOAO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O. JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O. JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JHHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JHON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JOHM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JONH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JOON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III IOAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JHHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JHON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOAO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOHM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JONH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III YOOX 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. YOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TATU YOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 GIOAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JANOS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JANOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOVAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. IOAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JHHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JHON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOAO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOHM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JONH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. YOOX 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3A JOAO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3E JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3E. JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O JOAO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III YOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. GI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. IN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETI J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 IOAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JHHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JHON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOAO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOHM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JONH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOOX 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. YOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3E JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III GI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III IN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. GI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. IN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 GI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 GJ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 GV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 IN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 IV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 J 1:1").osis()).toEqual("3John.1.1")
		`
		true
describe "Localized book John (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: John (ascii)", ->
		`
		expect(p.parse("The Gospel according to Saint Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Mabuting Balita ayon kay San Juan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Evankeliumi Johanneksen mukaan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Mabuting Balita ayon kay Juan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ebanghelyo ayon kay San Juan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Evangelium secundum Ioannem 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Evangelie volgens Johannes 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Evangeliet etter Johannes 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ebanghelyo ayon kay Juan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Johanneksen evankeliumi 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Vangelo di San Giovanni 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ebanghelyo ni San Juan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Evangelium podle Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Evanjelium Podla Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ewangelia wg sw. Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jevanhelije vid Ivana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("El Evangelio de Jaan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("El Evangelio de Jaun 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("El Evangelio de Juan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("El Evangelio de Juun 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ewangelia wg sw Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Johannis evangelium 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Vangelo di Giovanni 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Johannesevangeliet 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Janovo evangelium 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Sulat ni San Juan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ungjilli i Gjonit 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Injili ya Yohana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Injili ya Yohane 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ewangelia Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yovan Narceyti 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Injil Yohanes 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Johanneksen 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yuhannale 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ew. Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Giovanni 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Johannes 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("San Juan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yooxanaa 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yohanane 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ew Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ioannes 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yohanes 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yokanan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yuhanna 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ew Jan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yohana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yohane 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gioan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gjoni 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Janos 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yovan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ioan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ivan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jaan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jaun 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jean 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Joao 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Juan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Juun 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yoox 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gjo 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yoh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gg 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gi 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gv 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jn 1:1").osis()).toEqual("John.1.1")
		p.include_apocrypha(false)
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("MABUTING BALITA AYON KAY SAN JUAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EVANKELIUMI JOHANNEKSEN MUKAAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("MABUTING BALITA AYON KAY JUAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EBANGHELYO AYON KAY SAN JUAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EVANGELIUM SECUNDUM IOANNEM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EVANGELIE VOLGENS JOHANNES 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EVANGELIET ETTER JOHANNES 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EBANGHELYO AYON KAY JUAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOHANNEKSEN EVANKELIUMI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("VANGELO DI SAN GIOVANNI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EBANGHELYO NI SAN JUAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EVANGELIUM PODLE JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EVANJELIUM PODLA JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EWANGELIA WG SW. JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JEVANHELIJE VID IVANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EL EVANGELIO DE JAAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EL EVANGELIO DE JAUN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EL EVANGELIO DE JUAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EL EVANGELIO DE JUUN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EWANGELIA WG SW JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOHANNIS EVANGELIUM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("VANGELO DI GIOVANNI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOHANNESEVANGELIET 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JANOVO EVANGELIUM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SULAT NI SAN JUAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("UNGJILLI I GJONIT 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("INJILI YA YOHANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("INJILI YA YOHANE 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EWANGELIA JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOVAN NARCEYTI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("INJIL YOHANES 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOHANNEKSEN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YUHANNALE 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EW. JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GIOVANNI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOHANNES 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAN JUAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOOXANAA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHANANE 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EW JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("IOANNES 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHANES 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOKANAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YUHANNA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EW JAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHANE 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GIOAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GJONI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JANOS 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOVAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("IOAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("IVAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JAAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JAUN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JEAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOAO 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JUAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JUUN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOOX 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GJO 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GG 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GV 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JN 1:1").osis()).toEqual("John.1.1")
		`
		true
describe "Localized book Josh (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Josh (ascii)", ->
		`
		expect(p.parse("yahosuko pustak 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ksiega Jozuego 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ksiegi Jozuego 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Joosuan kirja 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ks. Jozuego 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Liber Iosue 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Liv Jozye a 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Iosua Navi 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Isus Navyn 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josvabogen 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josvas Bog 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josvas bok 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ks Jozuego 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josuabok 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josvabog 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Yahoshoo 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Yashuuca 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("yahosawa 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("yahosuko 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Joosuan 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josuova 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Joushua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jozuego 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jozuova 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Giosue 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Joshua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josuah 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josvas 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jousua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jozsue 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jozueu 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Yocuva 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Yoshua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Iosua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Iosue 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josue 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josva 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jozua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jozue 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jozye 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Yosua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Yusak 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Gsua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Joos 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josh 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jozs 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Yash 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ios 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jos 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Joz 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jsh 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Yos 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Gs 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Js 1:1").osis()).toEqual("Josh.1.1")
		p.include_apocrypha(false)
		expect(p.parse("YAHOSUKO PUSTAK 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("KSIEGA JOZUEGO 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("KSIEGI JOZUEGO 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOOSUAN KIRJA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("KS. JOZUEGO 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("LIBER IOSUE 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("LIV JOZYE A 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("IOSUA NAVI 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ISUS NAVYN 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSVABOGEN 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSVAS BOG 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSVAS BOK 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("KS JOZUEGO 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSUABOK 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSVABOG 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YAHOSHOO 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YASHUUCA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YAHOSAWA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YAHOSUKO 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOOSUAN 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSUOVA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOUSHUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOZUEGO 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOZUOVA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("GIOSUE 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSHUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSUAH 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSVAS 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOUSUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOZSUE 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOZUEU 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YOCUVA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YOSHUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("IOSUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("IOSUE 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSUE 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSVA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOZUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOZUE 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOZYE 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YOSUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YUSAK 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("GSUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOOS 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSH 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOZS 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YASH 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("IOS 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOS 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOZ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JSH 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YOS 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("GS 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JS 1:1").osis()).toEqual("Josh.1.1")
		`
		true
describe "Localized book Judg (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Judg (ascii)", ->
		`
		expect(p.parse("nyayakarttaharuko pustak 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("nyayakarttaharuko 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Knjiga o Sucima 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Niyayatipatikal 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Tuomarien kirja 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Ksiega Sedziow 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Ksiegi Sedziow 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Mga Maghuhukom 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Dommernes bok 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Liber Iudicum 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Knyha Suddiv 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Domarabokin 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Dommerbogen 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Judecatorii 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Ks. Sedziow 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Liv Chef yo 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Domarboken 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Judecatori 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Ks Sedziow 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Maghuhukom 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Para Hakim 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Xaakinnada 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Domarabok 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Dommernes 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Gjyqtaret 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("K. sudcov 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Mga Hukom 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Richteren 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Tuomarien 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Dommerne 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("K sudcov 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Nyayiyon 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Rechters 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Richtere 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Sudcovia 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Barnwyr 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Giudici 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Iudicum 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Richter 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Sedziow 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Waamuzi 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Dommer 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Judges 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jueces 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Juizes 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Soudcu 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Sudcov 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Birak 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Hukom 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Juges 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Recht 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Richt 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("saste 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Barn 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jdgs 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Judg 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Juec 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Juiz 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Quan 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Sedz 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Suci 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Tuom 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Waam 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Xaak 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Amu 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Bir 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Dom 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Gdc 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Gjy 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Huk 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Iud 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jdg 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jgs 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jij 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jue 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jug 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Sdc 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Sdz 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Sud 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jc 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jg 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jz 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Sd 1:1").osis()).toEqual("Judg.1.1")
		p.include_apocrypha(false)
		expect(p.parse("NYAYAKARTTAHARUKO PUSTAK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NYAYAKARTTAHARUKO 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KNJIGA O SUCIMA 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NIYAYATIPATIKAL 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("TUOMARIEN KIRJA 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KSIEGA SEDZIOW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KSIEGI SEDZIOW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("MGA MAGHUHUKOM 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DOMMERNES BOK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("LIBER IUDICUM 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KNYHA SUDDIV 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DOMARABOKIN 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DOMMERBOGEN 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUDECATORII 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KS. SEDZIOW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("LIV CHEF YO 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DOMARBOKEN 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUDECATORI 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KS SEDZIOW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("MAGHUHUKOM 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("PARA HAKIM 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("XAAKINNADA 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DOMARABOK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DOMMERNES 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("GJYQTARET 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("K. SUDCOV 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("MGA HUKOM 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("RICHTEREN 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("TUOMARIEN 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DOMMERNE 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("K SUDCOV 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NYAYIYON 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("RECHTERS 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("RICHTERE 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SUDCOVIA 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("BARNWYR 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("GIUDICI 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("IUDICUM 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("RICHTER 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SEDZIOW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("WAAMUZI 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DOMMER 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUDGES 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUECES 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUIZES 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SOUDCU 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SUDCOV 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("BIRAK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("HUKOM 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUGES 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("RECHT 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("RICHT 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SASTE 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("BARN 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JDGS 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUDG 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUEC 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUIZ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("QUAN 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SEDZ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SUCI 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("TUOM 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("WAAM 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("XAAK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("AMU 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("BIR 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DOM 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("GDC 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("GJY 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("HUK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("IUD 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JDG 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JGS 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JIJ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUE 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUG 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SDC 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SDZ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SUD 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JC 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JG 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JZ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SD 1:1").osis()).toEqual("Judg.1.1")
		`
		true
describe "Localized book 1Esd (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Esd (ascii)", ->
		`
		expect(p.parse("Kitabu cha Kwanza cha Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsza Ksiega Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsza Ksiegi Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsze Ksiega Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsze Ksiegi Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwszy Ksiega Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwszy Ksiegi Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsza Ks. Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsze Ks. Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwszy Ks. Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsza Ks Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsze Ks Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwszy Ks Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prva kniha Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvy list Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ksiega Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ksiegi Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ksiega Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ksiegi Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ksiega Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ksiegi Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ksiega Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ksiegi Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsza Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsze Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwszy Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prva kniha Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Ensimmainen Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Premieres Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvy list Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Tredje Esdrasbog 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ks. Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ks. Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Premiere Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Premiers Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Primeira Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Primeiro Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ks. Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 k. Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ks Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ks. Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ks Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Liber Esdrae I 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Liber I Esdrae 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Premier Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Primero Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prva Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvy Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ks Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 k Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Eerste Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ks Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Primer Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Esdrasbog 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1ere. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3. Esdrasbog 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Derde Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("First Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prima Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Primo Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvni Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Unang Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Esdrasbog 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 k. Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1.o. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1er. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1ere Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1re. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1st. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3 Esdrasbog 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Eerste Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Elso Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Esdra greco 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Forsta Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("III. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Kwanza Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prima Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Primo Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prva Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvy Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Terza Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Terzo Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Tredje Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 k Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1.o Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1a. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1e. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1er Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1o. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1re Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1st Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3e. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Derde Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Erste Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("First Esdr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("III Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("III. Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("III. Ezdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Una Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Unang Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Esdrae 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1a Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1e Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1o Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1st. Esdr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3e Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("First Esd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Esdrae 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("III Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("III Ezdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("III. Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Esdrae 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ezdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1e. Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1st Esdr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1st. Esd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3 Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3. Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3. Ezdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3e. Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3e. Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Elso Ezd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Ezdras I 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Esdrae 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ezdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("III Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Una Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ezdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Esdr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1e Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1st Esd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3 Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3 Ezdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3. Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3. Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3e Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3e Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ezdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Esdr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Esdr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Esd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Esr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ezd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3 Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3 Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Esdr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Esd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ezd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Esd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Esr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ezd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Es 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Esd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ezd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Es 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1Esd 1:1").osis()).toEqual("1Esd.1.1")
		`
		true
describe "Localized book 2Esd (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Esd (ascii)", ->
		`
		expect(p.parse("Kitabu cha Pili cha Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druga Ksiega Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druga Ksiegi Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Drugi Ksiega Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Drugi Ksiegi Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druha kniha Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhy list Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ksiega Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ksiegi Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ksiega Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ksiegi Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druga Ks. Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Drugi Ks. Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druha kniha Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ksiega Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ksiegi Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ksiega Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ksiegi Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druga Ks Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Drugi Ks Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhy list Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Deuxiemes Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Fjerde Esdrasbog 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ks. Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Ikalawang Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ks. Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Anden Esdrasbog 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Deuxieme Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druha Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhy Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ks. Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ks Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Liber Esdrae II 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Liber II Esdrae 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ks. Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 k. Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ks Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druga Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Drugi Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ks Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Ikalawang Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Masodik Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Seconda Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Secondo Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Segunda Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Segundo Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ks Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 k Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Second Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Seconda Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Secondo Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Tweede Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Vierde Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Esdrasbog 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2eme. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4. Esdrasbog 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Andre Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druha Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhy Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Quarta Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Quarto Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Esdrasbog 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 k. Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2.o. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2de. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2eme Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2nd. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4 Esdrasbog 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Fjarde Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Fjerde Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Masodik Ezd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Second Esdr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Toinen Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Tweede Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Vierde Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Zweite Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 k Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2.o Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2a. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2d. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2de Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2e. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2nd Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2o. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Andra Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Andre Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Esdrae 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("IV. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Second Esd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Esdrae 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2a Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2d Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2e Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2nd. Esdr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2o Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Ezdras II 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Esdrae 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ezdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("IV Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("IV. Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("IV. Ezdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Pili Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Esdrae 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ezdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2e. Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2nd Esdr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2nd. Esd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4 Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4. Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4. Ezdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ezdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Esdr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("IV Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("IV Ezdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("IV. Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ezdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Esdr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2e Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2nd Esd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4 Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4 Ezdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4. Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4. Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Esdr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Esd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ezd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("IV Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Esdr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Esd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Esr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ezd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4 Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4 Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Esd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ezd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Esd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Esr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ezd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Es 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Es 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2Esd 1:1").osis()).toEqual("2Esd.1.1")
		`
		true
describe "Localized book Isa (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Isa (ascii)", ->
		`
		expect(p.parse("Ksiega Izajasza 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ksiegi Izajasza 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Jesajan kirja 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ks. Izajasza 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Liber Isaiae 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Esaias' bok 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Esaias’ bok 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Esajas' Bog 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Esajas’ Bog 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Jesajaboken 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Jesajas bok 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ks Izajasza 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Liv Ezayi a 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Jesajaboka 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("yashaayaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ishacyaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("I-sa-gia 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaaaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaaiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaiaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaiiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiaaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiaiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiiaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiiiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaaaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaaiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaiaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaiiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiaaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiaiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiiaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiiiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Izajasza 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ezsaias 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("I-sai-a 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaaih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaiah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaiih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiaih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiiah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiiih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaisha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaaih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaiah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaiih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiaih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiiah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiiih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Jesajan 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Esaias 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Esajas 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaias 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaish 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Izaias 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Izaija 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Izajas 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Jesaia 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Jesaja 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Yesaya 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("yasaya 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ecaya 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Esaie 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Eseia 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ezayi 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaia 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaie 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaja 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaya 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Issah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Esai 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("I-sa 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isai 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Esa 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ezs 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isa 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ish 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Jes 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ia 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Is 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Iz 1:1").osis()).toEqual("Isa.1.1")
		p.include_apocrypha(false)
		expect(p.parse("KSIEGA IZAJASZA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("KSIEGI IZAJASZA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("JESAJAN KIRJA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("KS. IZAJASZA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("LIBER ISAIAE 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ESAIAS' BOK 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ESAIAS’ BOK 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ESAJAS' BOG 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ESAJAS’ BOG 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("JESAJABOKEN 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("JESAJAS BOK 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("KS IZAJASZA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("LIV EZAYI A 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("JESAJABOKA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("YASHAAYAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISHACYAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("I-SA-GIA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAAAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAAIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAIAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAIIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIAAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIAIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIIAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIIIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAAAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAAIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAIAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAIIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIAAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIAIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIIAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIIIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("IZAJASZA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("EZSAIAS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("I-SAI-A 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAAIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAIAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAIIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIAIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIIAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIIIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAISHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAAIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAIAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAIIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIAIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIIAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIIIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("JESAJAN 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ESAIAS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ESAJAS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIAS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAISH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("IZAIAS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("IZAIJA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("IZAJAS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("JESAIA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("JESAJA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("YESAYA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("YASAYA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ECAYA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ESAIE 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ESEIA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("EZAYI 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIE 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAJA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAYA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISSAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ESAI 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("I-SA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAI 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ESA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("EZS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("JES 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("IA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("IS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("IZ 1:1").osis()).toEqual("Isa.1.1")
		`
		true
describe "Localized book 2Sam (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Sam (ascii)", ->
		`
		expect(p.parse("Kitabu cha Pili cha Samueli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Anden Kongerigernes Bog 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Cartea a doua a Regilor 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Cartea II a lui Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ksiega Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ksiegi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Samuelova knjiga 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga knjiga o Samuelu 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ksiega Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ksiegi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druha kniha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhy kniha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Toinen Samuelin kirja 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Kongerigernes Bog 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Dezyem liv Samyel la 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ksiega Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ksiegi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ksiega Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ksiegi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhy list Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ksiega Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ksiegi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Kongerigernes Bog 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ksiega Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ksiegi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Cartea II a Regilor 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ks. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ks. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ksiega Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ksiegi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. kniha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ksiega Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ksiegi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. kniha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Andra Samuelsboken 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ks Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ks Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II kniha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ksiega Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ksiegi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuelin kirja 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 kniha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ksiega Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ksiegi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelin kirja 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ks. Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ks. Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ksiega Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ksiegi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuelin kirja 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ks. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Liber II Samuelis 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ksiega Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ksiegi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelin kirja 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ks. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Anden Samuelsbog 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Andre Samuelsbok 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Deuxiemes Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ks Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ks Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ks. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ks Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Ikalawang Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Samuu'eel Labaad 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Samuu’eel Labaad 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ks. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ks Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelsboken 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Deuxieme Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhy Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ks Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ks. Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Seconda Samuele 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Secondo Samuele 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Toinen Samuelin 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ks Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelsboken 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 k. Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ks. Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ks. Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ks Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Masodik Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Segunda Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Segunda Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Segundo Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Segundo Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ks. Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 e. Samuelit 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 i. Samuelit 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 k Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ks Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelsbog 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelsbok 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Dezyem Samyel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ks Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuu'eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuu’eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Tweede Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Zweite Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ks Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelsbog 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelsbok 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 e Samuelit 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 i Samuelit 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuu'eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuu’eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Shamooael 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2eme. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Anden Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Andre Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druha Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhy Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuu'eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuu’eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Regnorum 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuelin 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuelis 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Pili Samueli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Pili Samweli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuu'eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuu’eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Shamooael 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Regnorum 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelin 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelis 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelit 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. samuelko 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2.o. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2de. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2eme Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Regnorum 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuelin 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuelis 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Regilor 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuele 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samueli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samweli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Masodik Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Samuelis II 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Regnorum 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelin 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelis 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelit 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 samuelko 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Regilor 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuele 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samueli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samweli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2.o Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2a. Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2a. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2d. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2de Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2e. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2o. Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2o. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Regilor 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuele 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samueli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samweli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samyel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Samueli II 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Tweede Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Camuvel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Regilor 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuele 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samueli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samweli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 samuwel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samyel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2a Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2a Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2d Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2e Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2o Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2o Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Anden Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Andre Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druha Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhy Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samyel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Samuel II 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samyel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Pili Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2e. Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druha S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhy S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2e Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 S 1:1").osis()).toEqual("2Sam.1.1")
		p.include_apocrypha(false)
		expect(p.parse("KITABU CHA PILI CHA SAMUELI 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ANDEN KONGERIGERNES BOG 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("CARTEA A DOUA A REGILOR 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("CARTEA II A LUI SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA KSIEGA SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA KSIEGI SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA SAMUELOVA KNJIGA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA KNJIGA O SAMUELU 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGI KSIEGA SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGI KSIEGI SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHA KNIHA SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHY KNIHA SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("TOINEN SAMUELIN KIRJA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KONGERIGERNES BOG 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DEZYEM LIV SAMYEL LA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA KSIEGA SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA KSIEGI SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGI KSIEGA SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGI KSIEGI SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHY LIST SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KSIEGA SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KSIEGI SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KONGERIGERNES BOG 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KSIEGA SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KSIEGI SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("CARTEA II A REGILOR 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA KS. SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGI KS. SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KSIEGA SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KSIEGI SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KNIHA SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KSIEGA SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KSIEGI SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KNIHA SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ANDRA SAMUELSBOKEN 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA KS SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGI KS SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KNIHA SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KSIEGA SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KSIEGI SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUELIN KIRJA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KNIHA SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KSIEGA SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KSIEGI SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELIN KIRJA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA KS. SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGI KS. SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KSIEGA SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KSIEGI SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUELIN KIRJA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KS. SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("LIBER II SAMUELIS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KSIEGA SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KSIEGI SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELIN KIRJA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KS. SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ANDEN SAMUELSBOG 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ANDRE SAMUELSBOK 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DEUXIEMES SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA KS SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGI KS SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KS. SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KS SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("IKALAWANG SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SAMUU'EEL LABAAD 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SAMUU’EEL LABAAD 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KS. SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KS SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELSBOKEN 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DEUXIEME SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGI SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHA SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHY SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KS SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KS. SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND KINGDOMS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECONDA SAMUELE 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECONDO SAMUELE 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("TOINEN SAMUELIN 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KS SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELSBOKEN 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 K. SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KS. SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KS. SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KS SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("MASODIK SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SAMUALL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SAMUALS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SAMUELL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SAMUELS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SEGUNDA REINOS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SEGUNDA SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SEGUNDO REINOS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SEGUNDO SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KS. SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 E. SAMUELIT 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 I. SAMUELIT 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 K SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KS SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELSBOG 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELSBOK 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. KINGDOMS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DEZYEM SAMYEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KS SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUU'EEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUU’EEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SAMUAL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("TWEEDE SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ZWEITE SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KS SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELSBOG 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELSBOK 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 E SAMUELIT 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 I SAMUELIT 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUU'EEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUU’EEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SHAMOOAEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2EME. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND KINGDOMS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SAMUALL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SAMUALS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SAMUELL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SAMUELS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ANDEN SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ANDRE SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHA SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHY SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUU'EEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUU’EEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KINGDOMS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. REGNORUM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUELIN 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUELIS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("PILI SAMUELI 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("PILI SAMWELI 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUU'EEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUU’EEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SHAMOOAEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KINGDOMS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. REGNORUM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELIN 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELIS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELIT 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELKO 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2.O. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2DE. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2EME SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SAMUALL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SAMUALS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SAMUELL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SAMUELS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SAMUAL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KINGDOMS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II REGNORUM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUELIN 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUELIS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. REGILOR 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUALL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUALS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUELE 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUELI 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUELL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUELS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMWELI 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("MASODIK SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SAMUELIS II 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KINGDOMS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 REGNORUM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELIN 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELIS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELIT 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELKO 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. REGILOR 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUALL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUALS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELE 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELI 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMWELI 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2.O SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2A. REINOS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2A. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2D. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2DE SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2E. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SAMUAL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2O. REINOS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2O. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II REGILOR 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUALL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUALS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUELE 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUELI 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUELL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUELS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMWELI 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. REINOS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUAL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUIL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMYEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SAMUELI II 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SMA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("TWEEDE SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 CAMUVEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 REGILOR 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUALL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUALS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELE 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELI 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMWELI 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUWEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. REINOS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUAL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUIL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMYEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2A REINOS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2A SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2D SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2E SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2O REINOS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2O SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ANDEN SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ANDRE SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHA SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHY SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II REINOS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUAL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUIL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMYEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SAMUEL II 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 REINOS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUAL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUIL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMYEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SMA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("PILI SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2E. SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SMA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHA S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHY S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SMA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SMA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2E SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SMA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SMA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 S 1:1").osis()).toEqual("2Sam.1.1")
		`
		true
describe "Localized book 1Sam (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Sam (ascii)", ->
		`
		expect(p.parse("Kitabu cha Kwanza cha Samueli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Ensimmainen Samuelin kirja 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ksiega Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ksiegi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ksiega Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ksiegi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ksiega Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ksiegi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ksiega Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ksiegi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ksiega Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ksiegi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ksiega Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ksiegi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Cartea intai a Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ks. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ks. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ks. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Cartea I a lui Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ks Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ks Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ks Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prva Samuelova knjiga 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prva knjiga o Samuelu 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvni kniha Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Kongerigernes Bog 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Ensimmainen Samuelin 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ks. Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ks. Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ks. Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premye liv Samyel la 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prva kniha Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Kongerigernes Bog 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ksiega Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ksiegi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Forsta Samuelsboken 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ksiega Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ksiegi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ks Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ks Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ks Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvy list Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ksiega Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ksiegi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. kniha Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Cartea I a Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ksiega Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ksiegi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. kniha Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 kniha Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ksiega Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ksiegi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelin kirja 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I kniha Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ksiega Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ksiegi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuelin kirja 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ksiega Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ksiegi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelin kirja 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ks. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Fyrri Samuelsbok 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ksiega Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ksiegi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuelin kirja 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ks. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Liber I Samuelis 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premieres Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuu'eel Kowaad 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuu’eel Kowaad 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ks. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ks Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelsboken 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ks. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ks Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premiere Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premiers Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Primeira Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Primeira Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Primeiro Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Primeiro Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvni Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("samuelko pustak 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ks Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelsboken 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 k. Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ks. Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ks Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ks. Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Kwanza Samueli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Kwanza Samweli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premier Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Primero Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prva Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvy Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ks. Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 e. Samuelit 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 i. Samuelit 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 k Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ks Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelsbog 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelsbok 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Eerste Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ks. Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ks Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premye Samyel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prima Samuele 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Primer Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Primo Samuele 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ks Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelsbog 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelsbok 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 e Samuelit 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 i Samuelit 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuu'eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuu’eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Shamooael 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ere. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Erste Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ks Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuu'eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuu’eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvni Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Unang Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuu'eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuu’eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Shamooael 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Regnorum 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelin 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelis 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelit 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. samuelko 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1.o. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1er. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ere Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1re. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Elso Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuu'eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuu’eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Regnorum 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuelin 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuelis 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Regnorum 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelin 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelis 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelit 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 samuelko 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuele 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samueli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samweli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1.o Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1a. Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1a. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1e. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1er Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1o. Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1o. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1re Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Eerste Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Regnorum 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuelin 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuelis 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuele 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samueli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samweli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Kwanza Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuelis I 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Una Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Camuvel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuele 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samueli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samweli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 samuwel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samyel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1a Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1a Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1e Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1o Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1o Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuele 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samueli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samweli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samyel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvni Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samueli I 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samyel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Elso Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samyel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuel I 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1e. Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvni S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1e Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I S 1:1").osis()).toEqual("1Sam.1.1")
		p.include_apocrypha(false)
		expect(p.parse("KITABU CHA KWANZA CHA SAMUELI 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ENSIMMAINEN SAMUELIN KIRJA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZA KSIEGA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZA KSIEGI SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZE KSIEGA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZE KSIEGI SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZY KSIEGA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZY KSIEGI SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZA KSIEGA SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZA KSIEGI SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZE KSIEGA SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZE KSIEGI SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZY KSIEGA SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZY KSIEGI SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("CARTEA INTAI A REGILOR 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZA KS. SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZE KS. SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZY KS. SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("CARTEA I A LUI SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZA KS SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZE KS SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZY KS SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVA SAMUELOVA KNJIGA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVA KNJIGA O SAMUELU 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVNI KNIHA SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KONGERIGERNES BOG 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ENSIMMAINEN SAMUELIN 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZA KS. SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZE KS. SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZY KS. SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PREMYE LIV SAMYEL LA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVA KNIHA SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KONGERIGERNES BOG 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KSIEGA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KSIEGI SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FORSTA SAMUELSBOKEN 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KSIEGA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KSIEGI SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZA KS SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZE KS SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZY KS SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVY LIST SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KSIEGA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KSIEGI SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KNIHA SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("CARTEA I A REGILOR 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KSIEGA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KSIEGI SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KNIHA SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZE SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZY SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KNIHA SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KSIEGA SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KSIEGI SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELIN KIRJA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KNIHA SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KSIEGA SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KSIEGI SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUELIN KIRJA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KSIEGA SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KSIEGI SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELIN KIRJA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KS. SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FYRRI SAMUELSBOK 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KSIEGA SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KSIEGI SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUELIN KIRJA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KS. SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("LIBER I SAMUELIS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PREMIERES SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUU'EEL KOWAAD 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUU’EEL KOWAAD 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KS. SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KS SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELSBOKEN 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KS. SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KS SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PREMIERE SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PREMIERS SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRIMEIRA REINOS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRIMEIRA SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRIMEIRO REINOS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRIMEIRO SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVNI SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUELKO PUSTAK 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KS SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELSBOKEN 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 K. SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KS. SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST KINGDOMS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KS SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KS. SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("KWANZA SAMUELI 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("KWANZA SAMWELI 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PREMIER SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRIMERO SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVA SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVY SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KS. SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 E. SAMUELIT 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 I. SAMUELIT 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 K SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KS SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELSBOG 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELSBOK 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. KINGDOMS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("EERSTE SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KS. SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KS SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PREMYE SAMYEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRIMA SAMUELE 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRIMER SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRIMO SAMUELE 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KS SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELSBOG 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELSBOK 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 E SAMUELIT 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 I SAMUELIT 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUU'EEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUU’EEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SHAMOOAEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ERE. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST KINGDOMS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ERSTE SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KS SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUU'EEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUU’EEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVNI SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("UNANG SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUU'EEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUU’EEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SHAMOOAEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KINGDOMS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. REGNORUM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELIN 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELIS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELIT 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELKO 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1.O. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ER. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ERE SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1RE. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ELSO SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUU'EEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUU’EEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KINGDOMS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. REGNORUM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUELIN 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUELIS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KINGDOMS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 REGNORUM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELIN 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELIS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELIT 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELKO 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. REGILOR 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELE 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELI 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMWELI 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1.O SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1A. REINOS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1A. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1E. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ER SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1O. REINOS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1O. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1RE SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("EERSTE SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KINGDOMS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I REGNORUM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUELIN 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUELIS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. REGILOR 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUELE 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUELI 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMWELI 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("KWANZA SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUELIS I 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("UNA SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 CAMUVEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 REGILOR 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELE 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELI 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMWELI 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUWEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. REINOS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUIL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMYEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1A REINOS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1A SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1E SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1O REINOS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1O SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SMA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I REGILOR 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUELE 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUELI 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMWELI 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. REINOS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUIL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMYEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVNI SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUELI I 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 REINOS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUIL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMYEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SMA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ELSO SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I REINOS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUIL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMYEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUEL I 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1E. SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SMA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVNI S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SMA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1E SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SMA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SMA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SMA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I S 1:1").osis()).toEqual("1Sam.1.1")
		`
		true
describe "Localized book 2Chr (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Chr (ascii)", ->
		`
		expect(p.parse("Cartea a doua Paralipomena 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha kniha Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy list Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga knjiga Ljetopisa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Ikalawang Paralipomeno 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Liber II Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Ikalawang Mga Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Ikalawang Mga Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Pili Mambo ya Nyakati 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Deuxiemes Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Dezyem liv Kwonik la 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha kniha Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Mambo ya Nyakati 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Mambo ya Nyakati 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Deuxieme Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga Ksiega Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga Ksiegi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Drugi Ksiega Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Drugi Ksiegi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy list Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Mambo ya Nyakati 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Ikalawang Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Mambo ya Nyakati II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Mambo ya Nyakati 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k. Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Andra Kronikeboken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha kniha Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha kniha kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy kniha kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Ikalawang Kronikel 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Taariikhdii Labaad 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy list Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Ksiega Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Ksiegi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Ikalawang Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Ikalawang Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Ksiega Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Ksiegi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2eme. Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga Ks. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Drugi Ks. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Ksiega Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Ksiegi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Paralipomena 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Paralipomeno 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. kniha kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Paralipomenon II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Seconda Cronache 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Secondo Cronache 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Segunda Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Segundo Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Toinen Aikakirja 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Tweede Kronieken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ksiega Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ksiegi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronikeboken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Paralipomena 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Paralipomeno 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. kniha kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2de. Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2eme Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga Ks Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga Ljetopisa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Drugi Ks Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Paralipomena 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Paralipomeno 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II kniha kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Mga Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Mga Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Taariikhdii 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Masodik Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronikeboken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Paralipomena 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Paralipomeno 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 e. Kronikave 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 i. Kronikave 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 kniha kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Mga Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Mga Cronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Mga Kronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Mga Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Taariikhdii 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2d. Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2de Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2e. Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha Letopisu 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy Letopisu 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Mga Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Mga Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Taariikhdii 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronicilor 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Ks. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Zweite Chronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Mga Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Mga Cronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Mga Kronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Mga Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Taariikhdii 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 e Kronikave 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 i Kronikave 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k. Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronicilor 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Ks. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.o. Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2d Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2e Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2e. Kronieken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Dezyem Kwonik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronicilor 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Ks. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Aikakirja 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kronieken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Ks Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Ljetopisa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronicilor 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ks. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 e. Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 i. Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Aikakirja 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronieken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronikave 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Ks Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Ljetopisa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.o Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2a. Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2e Kronieken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2o. Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Dezyem Istwa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Drugi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Aikakirja 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kronieken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Ks Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Ljetopisa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronache 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kronikel 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Letopisu 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Masodik Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Aikakirja 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronieken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronikave 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ks Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ljetopisa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Nalakamam 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 e Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 i Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronache 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronikel 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Letopisu 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. itihasko 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2a Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2o Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronache 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kronikel 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Letopisu 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronici 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronicl 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Kronikak II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Tweede Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronache 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronikel 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Letopisu 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 itihasko 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronici 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronicl 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Anden Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronici 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronicl 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kwonik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronici 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronicl 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Itihas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kwonik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kwonik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Babad 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Istwa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Itihas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kwonik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 itihas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Babad 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Istwa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2e. Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha Pa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy Pa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Babad 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Istwa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Taar 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Pili Nya 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Aikak 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Babad 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Istwa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Taar 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2e Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Taar 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Nya 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Par 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ljet 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Taar 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Nya 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Par 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Nya 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Par 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Pa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Aik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ist 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Krn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Nya 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Par 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Pa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Pa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ch 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Pa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2Chr 1:1").osis()).toEqual("2Chr.1.1")
		p.include_apocrypha(false)
		expect(p.parse("CARTEA A DOUA PARALIPOMENA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA KNIHA PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY LIST PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGA KNJIGA LJETOPISA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("IKALAWANG PARALIPOMENO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("LIBER II PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("IKALAWANG MGA CRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("IKALAWANG MGA KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("PILI MAMBO YA NYAKATI 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DEUXIEMES CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DEZYEM LIV KWONIK LA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA KNIHA KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. MAMBO YA NYAKATI 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. MAMBO YA NYAKATI 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DEUXIEME CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGA KSIEGA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGA KSIEGI KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGI KSIEGA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGI KSIEGI KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY LIST KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II MAMBO YA NYAKATI 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("IKALAWANG CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("MAMBO YA NYAKATI II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 MAMBO YA NYAKATI 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 K. PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ANDRA KRONIKEBOKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA KNIHA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA KNIHA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY KNIHA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("IKALAWANG KRONIKEL 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("TAARIIKHDII LABAAD 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 K PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY LIST KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KSIEGA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KSIEGI KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("IKALAWANG CRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("IKALAWANG KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRONICALS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KSIEGA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KSIEGI KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2EME. CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGA KS. KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGI KS. KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KSIEGA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KSIEGI KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. PARALIPOMENA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. PARALIPOMENO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KNIHA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("PARALIPOMENON II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECONDA CRONACHE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECONDO CRONACHE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SEGUNDA CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SEGUNDO CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("TOINEN AIKAKIRJA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("TWEEDE KRONIEKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KSIEGA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KSIEGI KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRONIKEBOKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. PARALIPOMENA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. PARALIPOMENO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KNIHA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2DE. CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2EME CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRONICALS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGA KS KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGA LJETOPISA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGI KS KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II PARALIPOMENA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II PARALIPOMENO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KNIHA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. MGA CRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. MGA KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. TAARIIKHDII 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("MASODIK KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRONIKEBOKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 PARALIPOMENA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 PARALIPOMENO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 E. KRONIKAVE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 I. KRONIKAVE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KNIHA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. MGA CRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. MGA CRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. MGA KRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. MGA KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. TAARIIKHDII 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2D. CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2DE CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2E. CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRONICALS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA LETOPISU 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY LETOPISU 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II MGA CRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II MGA KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II TAARIIKHDII 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRONICALS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONICILOR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KS. KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ZWEITE CHRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 MGA CRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 MGA CRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 MGA KRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 MGA KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 TAARIIKHDII 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 E KRONIKAVE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 I KRONIKAVE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 K. KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRONICALS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONICILOR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KS. KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.O. CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2D CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2E CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2E. KRONIEKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DEZYEM KWONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRONICALS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONICILOR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KS. KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. AIKAKIRJA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KRONIEKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KS KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. LJETOPISA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRONICALS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONICILOR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KS. KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 E. KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 I. KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 K KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. AIKAKIRJA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRONIEKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRONIKAVE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KS KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. LJETOPISA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.O CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2A. CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2E KRONIEKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2O. CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DEZYEM ISTWA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGI KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II AIKAKIRJA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KRONIEKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KS KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II LJETOPISA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONACHE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KRONIKEL 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. LETOPISU 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("MASODIK KRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 AIKAKIRJA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRONIEKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRONIKAVE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KS KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 LJETOPISA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 NALAKAMAM 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 E KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 I KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 K. KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONACHE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRONIKEL 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. LETOPISU 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ITIHASKO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2A CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2O CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONACHE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KRONIKEL 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II LETOPISU 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONICI 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONICL 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. HRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("KRONIKAK II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("TWEEDE KRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONACHE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRONIKEL 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 LETOPISU 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ITIHASKO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 K KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONICI 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONICL 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. HRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ANDEN KRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONICI 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONICL 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II HRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KWONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONICI 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONICL 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 HRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ITIHAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KWONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KWONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. BABAD 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. ISTWA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ITIHAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KWONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ITIHAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. BABAD 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ISTWA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2E. KRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA PA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY PA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II BABAD 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II ISTWA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. TAAR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("PILI NYA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 AIKAK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 BABAD 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ISTWA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. TAAR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2E KRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II TAAR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. NYA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. PAR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 LJET 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 TAAR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. NYA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. PAR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II NYA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II PAR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. PA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 AIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 IST 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 NYA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 PAR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. PA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II PA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CH 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 PA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2CHR 1:1").osis()).toEqual("2Chr.1.1")
		`
		true
describe "Localized book 1Chr (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Chr (ascii)", ->
		`
		expect(p.parse("Cartea intai Paralipomena 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva kniha Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Kwanza Mambo ya Nyakati 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy list Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsza Ksiega Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsza Ksiegi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsze Ksiega Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsze Ksiegi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwszy Ksiega Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwszy Ksiegi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Ensimmainen Aikakirja 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Liber I Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva knjiga Ljetopisa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premieres Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premye liv Kwonik la 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Mambo ya Nyakati 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Forsta Kronikeboken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Mambo ya Nyakati 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsza Ks. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsze Ks. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwszy Ks. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premiere Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premiers Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva kniha Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvni Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Mambo ya Nyakati 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k. Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Mambo ya Nyakati 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Mambo ya Nyakati I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsza Ks Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsze Ks Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwszy Ks Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premier Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvni kniha kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy list Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Taariikhdii Kowaad 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Unang Paralipomeno 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primeira Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primeiro Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva kniha Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Unang Mga Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Unang Mga Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Ksiega Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Ksiegi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ere. Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Eerste Kronieken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Fyrri Kronikubok 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Ksiega Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Ksiegi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primero Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy list Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Una Paralipomeno 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ksiega Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ksiegi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronikeboken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Paralipomena 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Paralipomeno 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. kniha kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1er. Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ere Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1re. Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Ksiega Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Ksiegi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Paralipomena 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Paralipomeno 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. kniha kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Paralipomenon I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsza Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsze Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwszy Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primer Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Una Mga Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Una Mga Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Unang Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("itihasko pustak 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronikeboken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Paralipomena 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Paralipomeno 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 e. Kronikave 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 i. Kronikave 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 kniha kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Mga Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Mga Cronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Mga Kronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Mga Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Taariikhdii 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1er Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1re Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Paralipomena 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Paralipomeno 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I kniha kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Mga Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Mga Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Taariikhdii 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prima Cronache 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primo Cronache 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva Ljetopisa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvni Letopisu 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Unang Kronikel 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Mga Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Mga Cronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Mga Kronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Mga Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Taariikhdii 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 e Kronikave 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 i Kronikave 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k. Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronicilor 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Ks. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.o. Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1e. Kronieken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Erste Chronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Mga Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Mga Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Taariikhdii 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronicilor 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Ks. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premye Kwonik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Una Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Unang Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Unang Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronicilor 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ks. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 e. Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 i. Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Aikakirja 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronieken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronikave 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Ks Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Ljetopisa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.o Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1a. Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1e Kronieken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1o. Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Elso Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronicilor 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Ks. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Aikakirja 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kronieken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Ks Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Ljetopisa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premye Istwa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvni Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Una Kronikel 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Aikakirja 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronieken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronikave 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ks Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ljetopisa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Nalakamam 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 e Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 i Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronache 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronikel 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Letopisu 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. itihasko 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1a Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1o Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Eerste Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Aikakirja 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kronieken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Ks Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Ljetopisa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronache 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kronikel 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Letopisu 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Una Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Una Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronache 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronikel 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Letopisu 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 itihasko 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronici 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronicl 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Choronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronache 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kronikel 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Letopisu 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronici 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronicl 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Kronikak I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Kwanza Nya 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronici 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronicl 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Itihas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kwonik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Elso Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronici 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronicl 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kwonik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Itihas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kwonik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 itihas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Babad 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Istwa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1e. Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kwonik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Babad 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Istwa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvni Pa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Aikak 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Babad 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Istwa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Taar 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1e Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Babad 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Istwa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Taar 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ljet 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Taar 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Nya 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Par 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Taar 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Nya 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Par 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Aik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ist 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Krn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Nya 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Par 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Pa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Nya 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Par 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Pa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ch 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Pa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Pa 1:1").osis()).toEqual("1Chr.1.1")
		p.include_apocrypha(false)
		expect(p.parse("CARTEA INTAI PARALIPOMENA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVA KNIHA PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("KWANZA MAMBO YA NYAKATI 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVY LIST PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZA KSIEGA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZA KSIEGI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZE KSIEGA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZE KSIEGI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZY KSIEGA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZY KSIEGI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ENSIMMAINEN AIKAKIRJA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("LIBER I PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVA KNJIGA LJETOPISA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PREMIERES CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PREMYE LIV KWONIK LA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. MAMBO YA NYAKATI 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FORSTA KRONIKEBOKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. MAMBO YA NYAKATI 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZA KS. KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZE KS. KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZY KS. KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PREMIERE CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PREMIERS CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVA KNIHA KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVNI PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 MAMBO YA NYAKATI 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 K. PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I MAMBO YA NYAKATI 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("MAMBO YA NYAKATI I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZA KS KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZE KS KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZY KS KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PREMIER CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVA PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVNI KNIHA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVY PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVY LIST KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("TAARIIKHDII KOWAAD 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNANG PARALIPOMENO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 K PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRIMEIRA CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRIMEIRO CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVA KNIHA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNANG MGA CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNANG MGA KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KSIEGA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KSIEGI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ERE. CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("EERSTE KRONIEKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FYRRI KRONIKUBOK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KSIEGA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KSIEGI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRIMERO CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVY LIST KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNA PARALIPOMENO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KSIEGA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KSIEGI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRONIKEBOKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. PARALIPOMENA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. PARALIPOMENO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KNIHA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ER. CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ERE CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1RE. CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KSIEGA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KSIEGI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. PARALIPOMENA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. PARALIPOMENO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KNIHA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PARALIPOMENON I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZE KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZY KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRIMER CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNA MGA CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNA MGA KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNANG CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ITIHASKO PUSTAK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRONIKEBOKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 PARALIPOMENA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 PARALIPOMENO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 E. KRONIKAVE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 I. KRONIKAVE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KNIHA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. MGA CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. MGA CRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. MGA KRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. MGA KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. TAARIIKHDII 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ER CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1RE CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I PARALIPOMENA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I PARALIPOMENO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KNIHA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. MGA CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. MGA KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. TAARIIKHDII 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRIMA CRONACHE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRIMO CRONACHE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVA LJETOPISA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVNI LETOPISU 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNANG KRONIKEL 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 MGA CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 MGA CRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 MGA KRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 MGA KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 TAARIIKHDII 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 E KRONIKAVE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 I KRONIKAVE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 K. KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONICILOR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KS. KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.O. CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1E. KRONIEKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ERSTE CHRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I MGA CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I MGA KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I TAARIIKHDII 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONICILOR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KS. KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PREMYE KWONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVA KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVY KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNA CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNANG CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNANG KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONICILOR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KS. KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 E. KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 I. KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 K KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. AIKAKIRJA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRONIEKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRONIKAVE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KS KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. LJETOPISA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.O CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1A. CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1E KRONIEKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1O. CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ELSO KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONICILOR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KS. KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. AIKAKIRJA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KRONIEKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KS KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. LJETOPISA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PREMYE ISTWA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVNI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNA KRONIKEL 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 AIKAKIRJA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRONIEKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRONIKAVE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KS KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 LJETOPISA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 NALAKAMAM 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 E KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 I KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 K. KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONACHE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRONIKEL 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. LETOPISU 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ITIHASKO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1A CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1O CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("EERSTE KRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I AIKAKIRJA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KRONIEKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KS KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I LJETOPISA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONACHE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KRONIKEL 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. LETOPISU 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVY KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNA CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNA KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONACHE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRONIKEL 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 LETOPISU 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ITIHASKO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 K KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONICI 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONICL 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. HRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONACHE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KRONIKEL 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I LETOPISU 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONICI 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONICL 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. HRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("KRONIKAK I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("KWANZA NYA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONICI 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONICL 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 HRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ITIHAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KWONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ELSO KRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONICI 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONICL 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I HRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KWONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ITIHAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KWONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ITIHAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. BABAD 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ISTWA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1E. KRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KWONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. BABAD 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. ISTWA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVNI PA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 AIKAK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 BABAD 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ISTWA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. TAAR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1E KRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I BABAD 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I ISTWA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. TAAR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 LJET 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 TAAR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. NYA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. PAR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I TAAR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. NYA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. PAR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 AIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 IST 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 NYA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 PAR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. PA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I NYA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I PAR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. PA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CH 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 PA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I PA 1:1").osis()).toEqual("1Chr.1.1")
		`
		true
describe "Localized book Ezra (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Ezra (ascii)", ->
		`
		expect(p.parse("Ksiega Ezdrasza 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ksiegi Ezdrasza 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Knjiga Ezrina 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Liv Esdras la 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ks. Ezdrasza 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Liber Esdrae 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esran kirja 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ks Ezdrasza 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esras bok 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezras Bog 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezdrasza 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esrabok 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezsdras 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Cesraa 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esdrae 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esdras 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezdras 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Aejra 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esdra 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esran 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esras 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezdra 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("edzra 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Cesr 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esdr 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esra 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezdr 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezra 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezsd 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ces 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esd 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esr 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezd 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezr 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ed 1:1").osis()).toEqual("Ezra.1.1")
		p.include_apocrypha(false)
		expect(p.parse("KSIEGA EZDRASZA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("KSIEGI EZDRASZA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("KNJIGA EZRINA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("LIV ESDRAS LA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("KS. EZDRASZA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("LIBER ESDRAE 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESRAN KIRJA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("KS EZDRASZA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESRAS BOK 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZRAS BOG 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZDRASZA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESRABOK 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZSDRAS 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("CESRAA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESDRAE 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESDRAS 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZDRAS 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("AEJRA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESDRA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESRAN 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESRAS 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZDRA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EDZRA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("CESR 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESDR 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESRA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZDR 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZRA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZSD 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("CES 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESD 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESR 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZD 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZR 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ED 1:1").osis()).toEqual("Ezra.1.1")
		`
		true
describe "Localized book Ruth (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Ruth (ascii)", ->
		`
		expect(p.parse("Kitabu cha Ruthi 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Kitabu cha Ruthu 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Knjiga o Ruti 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ksiega Ruthy 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ksiegi Ruthy 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ruutin kirja 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ksiega Rut 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ksiegi Rut 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Liber Ruth 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Liv Rit la 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ks. Ruthy 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ruths Bog 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ks Ruthy 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Rutarbok 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ruts bok 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ks. Rut 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ks Rut 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ruutin 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ruthi 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ruthu 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Root 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ruta 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Rute 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ruth 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ruts 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ruud 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ruut 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Rit 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Rth 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Rut 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Rt 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ru 1:1").osis()).toEqual("Ruth.1.1")
		p.include_apocrypha(false)
		expect(p.parse("KITABU CHA RUTHI 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KITABU CHA RUTHU 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KNJIGA O RUTI 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KSIEGA RUTHY 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KSIEGI RUTHY 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUUTIN KIRJA 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KSIEGA RUT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KSIEGI RUT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("LIBER RUTH 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("LIV RIT LA 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KS. RUTHY 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUTHS BOG 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KS RUTHY 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUTARBOK 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUTS BOK 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KS. RUT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KS RUT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUUTIN 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUTHI 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUTHU 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("ROOT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUTA 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUTE 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUTH 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUTS 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUUD 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUUT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RIT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RTH 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RU 1:1").osis()).toEqual("Ruth.1.1")
		`
		true
describe "Localized book Neh (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Neh (ascii)", ->
		`
		expect(p.parse("Knjiga Nehemijina 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Ksiega Nehemiasza 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Ksiegi Nehemiasza 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("nahemyahko pustak 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Ks. Nehemiasza 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Liber Nehemiae 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemian kirja 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Ks Nehemiasza 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Liv Neyemi an 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemias’ Bog 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemjas bok 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiabok 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiasza 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("nahemyahko 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemaaah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemaaih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemaiah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemaiih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiaah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiaih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiiah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiiih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimaaah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimaaih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimaiah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimaiih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimiaah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimiaih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimiiah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimiiih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nexemyaah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nahemyah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehamiah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemaah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemaih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemeia 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiae 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemian 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemias 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemija 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemjas 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimaah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimaih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimiah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimiih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nekemiya 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Neemias 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Neemija 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehamia 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemia 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemie 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemja 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemya 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimia 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("nahemya 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Neemia 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Neyemi 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Neemi 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Neem 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Neh 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nex 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Ne 1:1").osis()).toEqual("Neh.1.1")
		p.include_apocrypha(false)
		expect(p.parse("KNJIGA NEHEMIJINA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("KSIEGA NEHEMIASZA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("KSIEGI NEHEMIASZA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NAHEMYAHKO PUSTAK 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("KS. NEHEMIASZA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("LIBER NEHEMIAE 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIAN KIRJA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("KS NEHEMIASZA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("LIV NEYEMI AN 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIAS’ BOG 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMJAS BOK 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIABOK 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIASZA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NAHEMYAHKO 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMAAAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMAAIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMAIAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMAIIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIAAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIAIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIIAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIIIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMAAAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMAAIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMAIAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMAIIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIAAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIAIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIIAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIIIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEXEMYAAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NAHEMYAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHAMIAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMAAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMAIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMEIA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIAE 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIAN 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIAS 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIJA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMJAS 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMAAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMAIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEKEMIYA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEEMIAS 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEEMIJA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHAMIA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIE 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMJA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMYA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NAHEMYA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEEMIA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEYEMI 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEEMI 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEEM 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEX 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NE 1:1").osis()).toEqual("Neh.1.1")
		`
		true
describe "Localized book GkEsth (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: GkEsth (ascii)", ->
		`
		expect(p.parse("Ester enligt den grekiska texten 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter konyvenek kiegeszitese 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Kreikkalainen Esterin kirja 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester \(versione greca\) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Grecke casti knihy Ester 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Den greske Ester-boken 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Den greske Ester-boka 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esterarbok hin griska 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Kreikkalainen Esterin 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester \(Griechisch\) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester recke dodatky 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester (Griechisch) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester recke casti 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester \(Grieks\) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester (Griyego) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester \(greco\) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester (Griego) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester (Grieks) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester (Gryego) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester (griego) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esther (Greek) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester (Grega) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester (Grego) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester (grega) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester Griyego 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esther (Grec) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esther (grec) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esther graeca 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Graeca Esther 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester Griego 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester Gryego 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester griego 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Greek Esther 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester Grega 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester Grego 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester greco 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester grega 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esther Grec 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esther grec 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Est \(Gr\) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester (Gr) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Greek Esth 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester Gr. 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esther Gr 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esther gr 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Greek Est 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Est (Gr) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester Gr 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester gr 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esth Gr 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esth gr 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Gk Esth 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Gr Esth 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Kr. Est 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Est Gr 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Est gr 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Gk Est 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("GkEsth 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Gr Est 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Kr Est 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("GrEst 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Estg 1:1").osis()).toEqual("GkEsth.1.1")
		`
		true
describe "Localized book Esth (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Esth (ascii)", ->
		`
		expect(p.parse("estarko pustak 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esterin kirja 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Ksiega Estery 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Ksiegi Estery 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Liber Esther 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esterarbok 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esters Bog 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esters bok 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Ks. Estery 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Liv Este a 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Ks Estery 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esterei 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esterin 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("estarko 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Aester 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esteer 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Estera 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esters 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Estery 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esther 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Eszter 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Estar 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Ester 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esthr 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("astar 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ester 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esta 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Este 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esth 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Eszt 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Est 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Es 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Et 1:1").osis()).toEqual("Esth.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ESTARKO PUSTAK 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTERIN KIRJA 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("KSIEGA ESTERY 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("KSIEGI ESTERY 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("LIBER ESTHER 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTERARBOK 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTERS BOG 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTERS BOK 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("KS. ESTERY 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("LIV ESTE A 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("KS ESTERY 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTEREI 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTERIN 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTARKO 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("AESTER 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTEER 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTERA 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTERS 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTERY 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTHER 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESZTER 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTAR 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTER 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTHR 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ASTAR 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTER 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTA 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTE 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTH 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESZT 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("EST 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ES 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ET 1:1").osis()).toEqual("Esth.1.1")
		`
		true
describe "Localized book Job (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Job (ascii)", ->
		`
		expect(p.parse("Kitabu cha Ayubu 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Kitabu cha Yobu 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ayyubko pustak 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Knjiga o Jobu 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Kniha Jobova 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ksiega Hioba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ksiega Ijoba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ksiegi Hioba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ksiegi Ijoba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jobin kirja 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ksiega Joba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ksiegi Joba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Liv Job la 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("K. Jobova 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ks. Hioba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ks. Ijoba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Liber Iob 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jobs Bog 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jobs bok 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("K Jobova 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ks Hioba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ks Ijoba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ks. Joba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jobsbok 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ks Joba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ayyubko 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ayyoob 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Giobbe 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ayubu 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ayuub 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Hioba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Hiobi 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jobin 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ayub 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Hiob 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ijob 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Joba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jobi 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jobs 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Yobu 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Yopu 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("iyob 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ayu 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Iob 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Iov 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Job 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jov 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Yob 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Gb 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Hi 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jb 1:1").osis()).toEqual("Job.1.1")
		p.include_apocrypha(false)
		expect(p.parse("KITABU CHA AYUBU 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KITABU CHA YOBU 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("AYYUBKO PUSTAK 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KNJIGA O JOBU 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KNIHA JOBOVA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KSIEGA HIOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KSIEGA IJOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KSIEGI HIOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KSIEGI IJOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JOBIN KIRJA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KSIEGA JOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KSIEGI JOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("LIV JOB LA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("K. JOBOVA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KS. HIOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KS. IJOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("LIBER IOB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JOBS BOG 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JOBS BOK 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("K JOBOVA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KS HIOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KS IJOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KS. JOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JOBSBOK 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KS JOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("AYYUBKO 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("AYYOOB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("GIOBBE 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("AYUBU 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("AYUUB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("HIOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("HIOBI 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JOBIN 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("AYUB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("HIOB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("IJOB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JOBI 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JOBS 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("YOBU 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("YOPU 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("IYOB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("AYU 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("IOB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("IOV 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JOB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JOV 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("YOB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("GB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("HI 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JB 1:1").osis()).toEqual("Job.1.1")
		`
		true
describe "Localized book Mal (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Mal (ascii)", ->
		`
		expect(p.parse("Proroctwo Malachyaszowe 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Prophetia Malachiae 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Ksiega Malachiasza 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Ksiegi Malachiasza 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Ks. Malachiasza 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Ks Malachiasza 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malakian kirja 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Liv Malachi a 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malakias’ Bog 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malachiasza 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malakis bok 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Ma-la-chi 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malachias 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malaquias 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Ma-la-ki 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malaakii 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malachia 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malachie 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malahija 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malakian 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malakias 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Maleachi 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Maleakhi 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malachi 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malakee 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malakia 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Maleahi 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malichi 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malkiya 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malach 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malaci 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malaki 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malaqu 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("malaki 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malac 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malch 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Mala 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malc 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Mal 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Ml 1:1").osis()).toEqual("Mal.1.1")
		p.include_apocrypha(false)
		expect(p.parse("PROROCTWO MALACHYASZOWE 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("PROPHETIA MALACHIAE 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("KSIEGA MALACHIASZA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("KSIEGI MALACHIASZA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("KS. MALACHIASZA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("KS MALACHIASZA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKIAN KIRJA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("LIV MALACHI A 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKIAS’ BOG 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALACHIASZA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKIS BOK 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MA-LA-CHI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALACHIAS 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAQUIAS 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MA-LA-KI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAAKII 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALACHIA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALACHIE 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAHIJA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKIAN 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKIAS 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALEACHI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALEAKHI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALACHI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKEE 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKIA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALEAHI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALICHI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALKIYA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALACH 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALACI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAQU 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAC 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALCH 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALC 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MAL 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("ML 1:1").osis()).toEqual("Mal.1.1")
		`
		true
describe "Localized book Matt (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Matt (ascii)", ->
		`
		expect(p.parse("The Gospel according to Saint Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mabuting Balita ayon kay San Mateo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mabuting Balita ayon kay Mateo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evangelium secundum Matthaeum 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evankeliumi Matteuksen mukaan 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ebanghelyo ayon kay Mateo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evangelie volgens Matteus 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ewangelia wg sw. Mateusza 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evangeliet etter Matteus 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evangelium podle Matouse 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ewangelia wg sw Mateusza 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ebanghelyo ni San Mateo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evanjelium Podla Matusa 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Jevanhelije vid Matvija 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matteuksen evankeliumi 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("El Evangelio de Mateo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Vangelo di San Matteo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matousovo evangelium 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ebanghelyo ni Mateo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evangelio de Mateo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ewangelia Mateusza 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Sulat ni San Mateo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Injili ya Mathayo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattei evangelium 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matteusevangeliet 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ungjilli i Mateut 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Vangelo di Matteo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matteyu Narceyti 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ew. Mateusza 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Injil Matius 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ew Mateusza 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matteuksen 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthaeus 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("San Mateo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattayane 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthaus 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattheus 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthieu 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matayos 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mateusz 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathayo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matteus 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matteyu 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattile 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ew Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matayo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mateus 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matius 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matous 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattee 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matteo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matusa 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matei 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matej 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mateo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mateu 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matth 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matus 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matye 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mate 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Math 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mth 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mtt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mt 1:1").osis()).toEqual("Matt.1.1")
		p.include_apocrypha(false)
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MABUTING BALITA AYON KAY SAN MATEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MABUTING BALITA AYON KAY MATEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANGELIUM SECUNDUM MATTHAEUM 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANKELIUMI MATTEUKSEN MUKAAN 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EBANGHELYO AYON KAY MATEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANGELIE VOLGENS MATTEUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EWANGELIA WG SW. MATEUSZA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANGELIET ETTER MATTEUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANGELIUM PODLE MATOUSE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EWANGELIA WG SW MATEUSZA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EBANGHELYO NI SAN MATEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANJELIUM PODLA MATUSA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("JEVANHELIJE VID MATVIJA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEUKSEN EVANKELIUMI 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EL EVANGELIO DE MATEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("VANGELO DI SAN MATTEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATOUSOVO EVANGELIUM 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EBANGHELYO NI MATEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANGELIO DE MATEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EWANGELIA MATEUSZA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SULAT NI SAN MATEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("INJILI YA MATHAYO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEI EVANGELIUM 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEUSEVANGELIET 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("UNGJILLI I MATEUT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("VANGELO DI MATTEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEYU NARCEYTI 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EW. MATEUSZA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("INJIL MATIUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EW MATEUSZA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEUKSEN 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHAEUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAN MATEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTAYANE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHAUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHEUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHIEU 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATAYOS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATEUSZ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHAYO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEYU 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTILE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EW MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATAYO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATEUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATIUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATOUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATUSA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATEI 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATEJ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATEU 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTH 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATYE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATH 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MTH 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MTT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MT 1:1").osis()).toEqual("Matt.1.1")
		`
		true
describe "Localized book Ps (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Ps (ascii)", ->
		`
		expect(p.parse("Cartea Psalmilor 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Libri i Psalmeve 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Liber Psalmorum 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ksiega Psalmow 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ksiegi Psalmow 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmien kirja 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salmernes Bog 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("stotrasamhita 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Kniha zalmov 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salmenes bok 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Kniha zalmu 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ks. Psalmow 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Sabuurradii 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ks Psalmow 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Liv Som yo 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("K. zalmov 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Mga Salmo 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psaltaren 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salmarnir 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Zsoltarok 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Cankitam 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("K zalmov 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Mga Awit 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmien 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salmenes 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salmerne 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plasmas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plsssss 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psaalms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalams 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psallms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmau 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmen 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmet 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmii 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmit 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmls 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmul 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmus 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psamlms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psaumes 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslalms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psmalms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salmene 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Masmur 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Palsms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Paslms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pasmls 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plamas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plasma 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plasms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plsams 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plssss 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psaalm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psaams 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalam 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psallm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalma 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalme 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmi 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalml 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmy 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psamas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psamla 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psamlm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psamls 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psamms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psaume 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslalm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslams 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslmas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psmalm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psmals 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Sabuur 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salmau 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salmos 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Zaburi 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Zaltar 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Bhjan 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Jabur 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Palls 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Palms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Palsm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pamls 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pamss 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Paslm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pasms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Passs 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plaas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plams 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plasm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plass 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plsam 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plsms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plsss 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psaaa 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psala 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psals 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psaml 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psamm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psams 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslam 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslmm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psmal 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psmls 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salme 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salmi 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salmo 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Zabur 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Zalmy 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Zsolt 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Awit 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plaa 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plam 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plsa 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plsm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plss 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psal 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psam 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psau 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psla 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psma 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psml 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psmm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pssm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Zalm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psa 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pss 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Sal 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Slm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Som 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Thi 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Zab 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ps 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Sl 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Z 1:1").osis()).toEqual("Ps.1.1")
		p.include_apocrypha(false)
		expect(p.parse("CARTEA PSALMILOR 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("LIBRI I PSALMEVE 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("LIBER PSALMORUM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KSIEGA PSALMOW 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KSIEGI PSALMOW 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMIEN KIRJA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMERNES BOG 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("STOTRASAMHITA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KNIHA ZALMOV 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMENES BOK 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KNIHA ZALMU 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KS. PSALMOW 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SABUURRADII 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KS PSALMOW 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("LIV SOM YO 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("K. ZALMOV 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("MGA SALMO 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALTAREN 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMARNIR 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ZSOLTAROK 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("CANKITAM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("K ZALMOV 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("MGA AWIT 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMIEN 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMENES 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMERNE 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLASMAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSSSSS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAALMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALAMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALLMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMAU 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMEN 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMET 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMII 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMIT 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMLS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMUL 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMUS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMLMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAUMES 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLALMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSMALMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMENE 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("MASMUR 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PALSMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PASLMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PASMLS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLAMAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLASMA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLASMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSAMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSSSS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAALM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAAMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALAM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALLM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALME 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMI 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALML 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMY 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMLA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMLM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMLS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAUME 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLALM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLAMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLMAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSMALM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSMALS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SABUUR 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMAU 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMOS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ZABURI 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ZALTAR 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("BHJAN 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("JABUR 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PALLS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PALMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PALSM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PAMLS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PAMSS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PASLM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PASMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PASSS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLAAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLAMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLASM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLASS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSAM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSSS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAAA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAML 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLAM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLMM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSMAL 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSMLS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALME 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMI 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMO 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ZABUR 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ZALMY 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ZSOLT 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("AWIT 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLAA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLAM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAL 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAU 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSMA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSML 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSMM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSSM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ZALM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SAL 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SLM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SOM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("THI 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ZAB 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SL 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Z 1:1").osis()).toEqual("Ps.1.1")
		`
		true
describe "Localized book Eccl (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Eccl (ascii)", ->
		`
		expect(p.parse("Ksiega Kaznodziei Salomona 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ksiegi Kaznodziei Salomona 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eklezyas - Liv Filozof la 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Kaznodziei Salomonowego 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ks. Kaznodziei Salomona 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ks Kaznodziei Salomona 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ksiega Eklezjastesa 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ksiegi Eklezjastesa 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Liber Ecclesiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Kohelet — Kazatel 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("upadesakko pustak 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Forkynnerens bok 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Kniha kazatelova 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ks. Eklezjastesa 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Predikantens bok 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Saarnaajan kirja 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ang Mangangaral 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ks Eklezjastesa 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ksiega Koheleta 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ksiegi Koheleta 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Predikarens bok 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiaiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiastices 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Liv Filozof la 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiaastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiaistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiasties 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiaiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiastices 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("K. kazatelova 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Predikarboken 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Sabhopadeshak 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiaates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiastul 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaaste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaiste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaites 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiaste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiiste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiites 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiasties 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ekklesiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("K kazatelova 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ks. Koheleta 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Liber Qoelet 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Propovjednik 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaaste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaiste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaites 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiaste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiiste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiites 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaate 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaite 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiate 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiite 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiastul 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaaste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaiste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaites 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiaste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiiste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiites 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesyastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecleziastul 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclisiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclisyastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ekklezijast 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eklesiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eklesyastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ekleziastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eklisiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eklisyastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Forkynneren 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Juru Kotbah 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ks Koheleta 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Mangangaral 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Predikarinn 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Predikerens 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaate 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaite 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiast 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiate 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiite 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesites 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaaste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaiste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaites 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiaste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiiste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiites 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaate 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaite 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiate 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiite 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Predikaren 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Predikator 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Predikeren 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Predikuesi 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Saarnaajan 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Wacdiyahii 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("upadesakko 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaate 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaite 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiate 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiite 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecleziast 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Magwawali 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Piracanki 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Pregethwr 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Saarnaaja 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Wacdiyaha 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eklezyas 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Koheleth 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Prediger 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Prediker 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Qoheleth 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("upadesak 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Filozof 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Kazatel 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Kohelet 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Mhubiri 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Qohelet 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Coelet 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eccles 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Kaalam 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Qoelet 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecles 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Manga 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Saarn 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eccl 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Fork 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Kazn 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Prad 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Pred 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Preg 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Prop 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Saar 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecc 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecl 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ekl 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Kaz 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Koh 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Mhu 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Qoh 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Wac 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ec 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Qo 1:1").osis()).toEqual("Eccl.1.1")
		p.include_apocrypha(false)
		expect(p.parse("KSIEGA KAZNODZIEI SALOMONA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KSIEGI KAZNODZIEI SALOMONA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKLEZYAS - LIV FILOZOF LA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KAZNODZIEI SALOMONOWEGO 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KS. KAZNODZIEI SALOMONA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KS KAZNODZIEI SALOMONA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KSIEGA EKLEZJASTESA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KSIEGI EKLEZJASTESA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("LIBER ECCLESIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KOHELET — KAZATEL 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("UPADESAKKO PUSTAK 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("FORKYNNERENS BOK 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KNIHA KAZATELOVA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KS. EKLEZJASTESA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIKANTENS BOK 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("SAARNAAJAN KIRJA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ANG MANGANGARAL 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KS EKLEZJASTESA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KSIEGA KOHELETA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KSIEGI KOHELETA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIKARENS BOK 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIAIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIASTICES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("LIV FILOZOF LA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIAASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIAISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIASTIES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIAIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIASTICES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("K. KAZATELOVA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIKARBOKEN 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("SABHOPADESHAK 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIAATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIASTUL 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAASTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAISTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAITES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIASTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIISTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIITES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIASTIES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKKLESIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("K KAZATELOVA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KS. KOHELETA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("LIBER QOELET 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PROPOVJEDNIK 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAASTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAISTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAITES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIASTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIISTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIITES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAATE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAITE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIATE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIITE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIASTUL 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAASTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAISTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAITES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIASTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIISTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIITES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESYASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLEZIASTUL 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLISIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLISYASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKKLEZIJAST 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKLESIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKLESYASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKLEZIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKLISIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKLISYASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("FORKYNNEREN 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("JURU KOTBAH 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KS KOHELETA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("MANGANGARAL 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIKARINN 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIKERENS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAATE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAITE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIAST 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIATE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIITE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESITES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAASTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAISTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAITES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIASTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIISTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIITES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAATE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAITE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIATE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIITE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIKAREN 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIKATOR 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIKEREN 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIKUESI 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("SAARNAAJAN 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("WACDIYAHII 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("UPADESAKKO 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAATE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAITE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIATE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIITE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLEZIAST 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("MAGWAWALI 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PIRACANKI 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREGETHWR 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("SAARNAAJA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("WACDIYAHA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKLEZYAS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KOHELETH 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIGER 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIKER 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("QOHELETH 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("UPADESAK 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("FILOZOF 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KAZATEL 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KOHELET 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("MHUBIRI 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("QOHELET 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("COELET 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KAALAM 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("QOELET 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("MANGA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("SAARN 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCL 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("FORK 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KAZN 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PRAD 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PRED 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREG 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PROP 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("SAAR 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECC 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECL 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKL 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KAZ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KOH 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("MHU 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("QOH 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("WAC 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EC 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("QO 1:1").osis()).toEqual("Eccl.1.1")
		`
		true
describe "Localized book Ezek (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Ezek (ascii)", ->
		`
		expect(p.parse("Prophetia Ezechielis 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Hesekielin kirja 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ksiega Ezechiela 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ksiegi Ezechiela 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Liv Ezekyel la 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezekiels’ Bog 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Hesekiels bok 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ks. Ezechiela 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Esekiels bok 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezekiels Bog 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ks Ezechiela 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Hesekielin 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ecekkiyel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezechiela 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezechiele 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeequiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeiquiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziequiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziiquiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Hezechiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Iezechiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Jezekiil' 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Jezekiil’ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Yahejakel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Yeheskiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Yehezkiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Yexesqeel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("yahedzkel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exeekiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exeikiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exiekiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exiikiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezechiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeekiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeequel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeikiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeiquel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezekieli 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezequial 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezequiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziekiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziequel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziikiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziiquel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziquiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Hesekiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eseciel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Esekiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Esekyel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exeekel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exeikel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exekiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exiekel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exiikel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exikiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeciel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeekel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeikel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezekial 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezekiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezekyel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezequel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziekel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziikel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezikiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziquel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exekel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exikel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezekel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezikel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezech 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezequ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Esec 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Esek 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezec 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezek 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeq 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Esk 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eze 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezk 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezq 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Hes 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Yex 1:1").osis()).toEqual("Ezek.1.1")
		p.include_apocrypha(false)
		expect(p.parse("PROPHETIA EZECHIELIS 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("HESEKIELIN KIRJA 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("KSIEGA EZECHIELA 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("KSIEGI EZECHIELA 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("LIV EZEKYEL LA 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEKIELS’ BOG 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("HESEKIELS BOK 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("KS. EZECHIELA 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ESEKIELS BOK 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEKIELS BOG 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("KS EZECHIELA 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("HESEKIELIN 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ECEKKIYEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZECHIELA 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZECHIELE 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEEQUIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEIQUIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIEQUIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIIQUIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("HEZECHIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("IEZECHIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("JEZEKIIL' 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("JEZEKIIL’ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("YAHEJAKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("YEHESKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("YEHEZKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("YEXESQEEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("YAHEDZKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXEEKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXEIKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXIEKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXIIKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZECHIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEEKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEEQUEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEIKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEIQUEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEKIELI 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEQUIAL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEQUIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIEKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIEQUEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIIKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIIQUEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIQUIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("HESEKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ESECIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ESEKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ESEKYEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXEEKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXEIKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXEKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXIEKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXIIKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXIKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZECIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEEKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEIKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEKIAL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEKYEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEQUEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIEKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIIKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIQUEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXEKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXIKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZECH 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEQU 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ESEC 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ESEK 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEC 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEK 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEQ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ESK 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZE 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZK 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZQ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("HES 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("YEX 1:1").osis()).toEqual("Ezek.1.1")
		`
		true
describe "Localized book Hos (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Hos (ascii)", ->
		`
		expect(p.parse("Ksiega Ozeasza 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ksiegi Ozeasza 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Prophetia Osee 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hoosean kirja 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hoseas’ Bog 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ks. Ozeasza 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hoseas bok 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ks Ozeasza 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hoosheeca 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Liv Oze a 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hoosean 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hoseias 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ozeasza 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hoseas 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hoseia 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hozeas 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Oseiah 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Oseias 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hoosh 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hosea 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hosho 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ociya 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Oseah 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Oseas 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Oseia 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Osija 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ozeas 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("hosey 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hoos 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Osea 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Osee 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("hose 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hos 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Oze 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ho 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hs 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Os 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Oz 1:1").osis()).toEqual("Hos.1.1")
		p.include_apocrypha(false)
		expect(p.parse("KSIEGA OZEASZA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("KSIEGI OZEASZA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("PROPHETIA OSEE 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOOSEAN KIRJA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOSEAS’ BOG 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("KS. OZEASZA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOSEAS BOK 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("KS OZEASZA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOOSHEECA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("LIV OZE A 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOOSEAN 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOSEIAS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OZEASZA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOSEAS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOSEIA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOZEAS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OSEIAH 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OSEIAS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOOSH 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOSEA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOSHO 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OCIYA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OSEAH 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OSEAS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OSEIA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OSIJA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OZEAS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOSEY 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOOS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OSEA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OSEE 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOSE 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OZE 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HO 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OZ 1:1").osis()).toEqual("Hos.1.1")
		`
		true
describe "Localized book Obad (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Obad (ascii)", ->
		`
		expect(p.parse("Proroctwo Abdyaszowe 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Prophetia Abdiae 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Ksiega Abdiasza 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Ksiegi Abdiasza 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Liv Abdyas la 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadjan kirja 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Ks. Abdiasza 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadias' Bog 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadias’ Bog 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Ks Abdiasza 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadjas bok 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Cobadyaah 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Abdiasza 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Abdijas 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadeia 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadhah 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadiah 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadias 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadija 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadjan 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadjas 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obedias 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Opatiya 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("obadiya 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Abdias 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Abdyas 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadia 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadja 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obidah 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Ovadia 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Abdia 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Avdie 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Cobad 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadj 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obaja 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Ovdij 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obad 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Abd 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Cob 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Oba 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obd 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Ab 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Ob 1:1").osis()).toEqual("Obad.1.1")
		p.include_apocrypha(false)
		expect(p.parse("PROROCTWO ABDYASZOWE 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("PROPHETIA ABDIAE 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("KSIEGA ABDIASZA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("KSIEGI ABDIASZA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("LIV ABDYAS LA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADJAN KIRJA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("KS. ABDIASZA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADIAS' BOG 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADIAS’ BOG 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("KS ABDIASZA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADJAS BOK 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("COBADYAAH 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ABDIASZA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ABDIJAS 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADEIA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADHAH 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADIAH 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADIAS 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADIJA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADJAN 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADJAS 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBEDIAS 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OPATIYA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADIYA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ABDIAS 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ABDYAS 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADIA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADJA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBIDAH 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OVADIA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ABDIA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("AVDIE 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("COBAD 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADJ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBAJA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OVDIJ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBAD 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ABD 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("COB 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBD 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("AB 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OB 1:1").osis()).toEqual("Obad.1.1")
		`
		true
describe "Localized book Hag (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Hag (ascii)", ->
		`
		expect(p.parse("Proroctwo Aggieuszowe 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Prophetia Aggaei 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ksiega Aggeusza 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ksiegi Aggeusza 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggain kirja 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ks. Aggeusza 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggais bok 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggajs Bog 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ks Aggeusza 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Liv Aje a 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Aggeusza 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Aggaeus 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggaai 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggain 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggeus 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggiah 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggiai 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Aggaus 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Aggeus 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ha-gai 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggai 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggaj 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggeo 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Xaggay 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("haggay 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("A-gai 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ageus 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Aggee 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Aggeo 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Agheu 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Hagai 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Hagaj 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Hagej 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Hageo 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Agai 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Agej 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ageo 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ageu 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Akay 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Hagg 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ohij 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Xagg 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Agg 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Aje 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Hag 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Hgg 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Xag 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ag 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Hg 1:1").osis()).toEqual("Hag.1.1")
		p.include_apocrypha(false)
		expect(p.parse("PROROCTWO AGGIEUSZOWE 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("PROPHETIA AGGAEI 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("KSIEGA AGGEUSZA 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("KSIEGI AGGEUSZA 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGAIN KIRJA 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("KS. AGGEUSZA 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGAIS BOK 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGAJS BOG 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("KS AGGEUSZA 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("LIV AJE A 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGGEUSZA 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGGAEUS 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGAAI 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGAIN 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGEUS 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGIAH 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGIAI 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGGAUS 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGGEUS 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HA-GAI 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGAI 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGAJ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGEO 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("XAGGAY 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGAY 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("A-GAI 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGEUS 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGGEE 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGGEO 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGHEU 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGAI 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGAJ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGEJ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGEO 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGAI 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGEJ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGEO 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGEU 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AKAY 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGG 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("OHIJ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("XAGG 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGG 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AJE 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAG 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HGG 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("XAG 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AG 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HG 1:1").osis()).toEqual("Hag.1.1")
		`
		true
describe "Localized book Hab (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Hab (ascii)", ->
		`
		expect(p.parse("Proroctwo Abakukowe 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Prophetia Habacuc 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakukin kirja 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Ksiega Habakuka 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Ksiegi Habakuka 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakkuks Bog 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakkuks bok 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Liv Abakik la 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Ks. Habakuka 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Ks Habakuka 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakkakk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakkukk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habacuque 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakkakk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakkook 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakkukk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakukin 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakakk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakkak 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakkuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakukk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habaccuc 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habackuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakakk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakkak 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakkuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakuka 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakuki 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakukk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakuku 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbacac 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbacuc 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakak 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Xabaquuq 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("habakkuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Abakouk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Abakuka 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habacac 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habacuc 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakak 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("habakuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Abacuc 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Abakik 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Abakuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Apakuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Avacum 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Avakum 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habac 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habak 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Abak 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habc 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Abk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Hab 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Xab 1:1").osis()).toEqual("Hab.1.1")
		p.include_apocrypha(false)
		expect(p.parse("PROROCTWO ABAKUKOWE 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("PROPHETIA HABACUC 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKUKIN KIRJA 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("KSIEGA HABAKUKA 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("KSIEGI HABAKUKA 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKKUKS BOG 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKKUKS BOK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("LIV ABAKIK LA 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("KS. HABAKUKA 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("KS HABAKUKA 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKKAKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKKUKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABACUQUE 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKKAKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKKOOK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKKUKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKUKIN 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKAKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKKAK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKUKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABACCUC 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABACKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKAKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKKAK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKUKA 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKUKI 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKUKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKUKU 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBACAC 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBACUC 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKAK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("XABAQUUQ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ABAKOUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ABAKUKA 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABACAC 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABACUC 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKAK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ABACUC 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ABAKIK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ABAKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("APAKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("AVACUM 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("AVAKUM 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAC 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ABAK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABC 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ABK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HAB 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("XAB 1:1").osis()).toEqual("Hab.1.1")
		`
		true
describe "Localized book Mic (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Mic (ascii)", ->
		`
		expect(p.parse("Prophetia Michaeae 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Ksiega Micheasza 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Ksiegi Micheasza 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Ks. Micheasza 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Ks Micheasza 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Miikan kirja 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Liv Miche a 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Micheasza 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mikas Bog 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mikas bok 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Michaeas 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Miqueias 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Michaas 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Micheas 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Miikaah 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mikeyas 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mikieas 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Miqueas 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Michah 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Michea 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Michee 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Miheia 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Miikan 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mikeas 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Meeka 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mi-ca 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Micah 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Micha 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Miche 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mihej 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Miika 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mikah 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mikas 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mikea 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mikha 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Myhej 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mica 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mich 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Miik 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mika 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("mika 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mic 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mih 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mik 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Miq 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mq 1:1").osis()).toEqual("Mic.1.1")
		p.include_apocrypha(false)
		expect(p.parse("PROPHETIA MICHAEAE 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("KSIEGA MICHEASZA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("KSIEGI MICHEASZA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("KS. MICHEASZA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("KS MICHEASZA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIIKAN KIRJA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("LIV MICHE A 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHEASZA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKAS BOG 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKAS BOK 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHAEAS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIQUEIAS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHAAS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHEAS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIIKAAH 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKEYAS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKIEAS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIQUEAS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHAH 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHEA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHEE 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIHEIA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIIKAN 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKEAS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MEEKA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MI-CA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICAH 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHE 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIHEJ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIIKA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKAH 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKAS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKEA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKHA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MYHEJ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICH 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIIK 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIC 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIH 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIK 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIQ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MQ 1:1").osis()).toEqual("Mic.1.1")
		`
		true
describe "Localized book Zech (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Zech (ascii)", ->
		`
		expect(p.parse("Prophetia Zachariae 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Ksiega Zachariasza 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Ksiegi Zachariasza 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Ks. Zachariasza 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Ks Zachariasza 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sakarjan kirja 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zakarias' Bog 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zakarias’ Bog 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Liv Zakari a 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sakarjaboken 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sakarjas bok 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Xa-cha-ri-a 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zachariasza 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sechareia 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sekaryaah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Xa-cha-ri 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zaccharie 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharaah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharaih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zachariah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharias 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zachariih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharjas 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacheraah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacheraih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacheriah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacheriih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecharaah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecharaih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zechariah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zechariih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecheraah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecheraih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecheriah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecheriih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Cakariya 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Jakaryah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sacarias 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sacharja 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sakarias 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sakarjan 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacarias 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zaccaria 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharia 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharie 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacherah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacheria 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacherih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zaharija 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zakariah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zakarias 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zakharia 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecharah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecharia 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecharih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecherah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecheria 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecherih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zekariah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("jakariya 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sakaria 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sakarja 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zaharia 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zaharij 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zakaria 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zekaria 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zakari 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacar 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacch 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sach 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sech 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacc 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zach 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zech 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sak 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sek 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zac 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zak 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zch 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zec 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zek 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Xa 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Za 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zc 1:1").osis()).toEqual("Zech.1.1")
		p.include_apocrypha(false)
		expect(p.parse("PROPHETIA ZACHARIAE 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("KSIEGA ZACHARIASZA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("KSIEGI ZACHARIASZA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("KS. ZACHARIASZA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("KS ZACHARIASZA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SAKARJAN KIRJA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAKARIAS' BOG 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAKARIAS’ BOG 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("LIV ZAKARI A 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SAKARJABOKEN 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SAKARJAS BOK 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("XA-CHA-RI-A 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARIASZA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SECHAREIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SEKARYAAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("XA-CHA-RI 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACCHARIE 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARAAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARAIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARIAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARIAS 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARIIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARJAS 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHERAAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHERAIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHERIAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHERIIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHARAAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHARAIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHARIAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHARIIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHERAAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHERAIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHERIAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHERIIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("CAKARIYA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("JAKARYAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SACARIAS 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SACHARJA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SAKARIAS 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SAKARJAN 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACARIAS 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACCARIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARIE 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHERAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHERIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHERIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAHARIJA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAKARIAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAKARIAS 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAKHARIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHARAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHARIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHARIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHERAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHERIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHERIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZEKARIAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("JAKARIYA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SAKARIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SAKARJA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAHARIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAHARIJ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAKARIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZEKARIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAKARI 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACAR 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACCH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SACH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SECH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACC 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SAK 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SEK 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAC 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAK 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZCH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZEC 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZEK 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("XA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZC 1:1").osis()).toEqual("Zech.1.1")
		`
		true
describe "Localized book Zeph (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Zeph (ascii)", ->
		`
		expect(p.parse("Proroctwo Sofoniaszowe 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Prophetia Sophoniae 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Ksiega Sofoniasza 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Ksiegi Sofoniasza 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Ks. Sofoniasza 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sefanjan kirja 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Ks Sofoniasza 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Liv Sofoni an 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sefanias' Bog 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sefanias’ Bog 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sefanjas bok 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofoniasza 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zephanaiah 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Ceppaniya 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sefanyaah 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Seffaneia 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sophonias 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Szefanias 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Szofonias 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zaphaniah 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zephanaia 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zephaniah 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zephanias 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sapanyah 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sefanias 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sefanija 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sefanjan 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sepanias 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofonias 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofonija 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofonije 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofonjas 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sophonie 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zafaniah 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zaphania 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zefaniah 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zefanias 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zepanias 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zephania 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zephanja 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zofonias 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("sapanyah 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sefania 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sefanja 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sepania 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofonia 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofonie 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Tefania 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zafania 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zefania 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zefanja 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zefanya 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofoni 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zephan 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Seff 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Seph 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Soph 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Szof 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zeph 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sef 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sof 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Tef 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zef 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zep 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zph 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sf 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zp 1:1").osis()).toEqual("Zeph.1.1")
		p.include_apocrypha(false)
		expect(p.parse("PROROCTWO SOFONIASZOWE 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("PROPHETIA SOPHONIAE 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("KSIEGA SOFONIASZA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("KSIEGI SOFONIASZA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("KS. SOFONIASZA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFANJAN KIRJA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("KS SOFONIASZA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("LIV SOFONI AN 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFANIAS' BOG 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFANIAS’ BOG 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFANJAS BOK 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONIASZA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEPHANAIAH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("CEPPANIYA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFANYAAH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFFANEIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOPHONIAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SZEFANIAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SZOFONIAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZAPHANIAH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEPHANAIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEPHANIAH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEPHANIAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SAPANYAH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFANIAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFANIJA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFANJAN 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEPANIAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONIAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONIJA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONIJE 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONJAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOPHONIE 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZAFANIAH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZAPHANIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEFANIAH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEFANIAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEPANIAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEPHANIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEPHANJA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZOFONIAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SAPANYAH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFANIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFANJA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEPANIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONIE 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("TEFANIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZAFANIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEFANIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEFANJA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEFANYA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONI 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEPHAN 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFF 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEPH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOPH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SZOF 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEPH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEF 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOF 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("TEF 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEF 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEP 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZPH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SF 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZP 1:1").osis()).toEqual("Zeph.1.1")
		`
		true
describe "Localized book Luke (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Luke (ascii)", ->
		`
		expect(p.parse("Mabuting Balita ayon kay San Lucas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Mabuting Balita ayon kay San Lukas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Saint Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Saint Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Saint Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Saint Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St. Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St. Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Saint Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Mabuting Balita ayon kay Lucas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Mabuting Balita ayon kay Lukas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St. Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St. Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ebanghelyo ayon kay San Lucas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ebanghelyo ayon kay San Lukas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Saint Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Saint Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Saint Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St. Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evankeliumi Luukkaan mukaan 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St. Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St. Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St. Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ebanghelyo ayon kay Lucas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ebanghelyo ayon kay Lukas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evangelium secundum Lucam 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Saint Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ebanghelyo ni San Lucas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ebanghelyo ni San Lukas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evangelie volgens Lucas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evangelie volgens Lukas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evangelium podle Lukase 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evanjelium Podla Lukasa 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Saint Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evangeliet etter Lukas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Saint Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Saint Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St. Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("El Evangelio de Lucas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St. Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Saint Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Jevanhelije vid Luky 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Luukkaan evankeliumi 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St. Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St. Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Saint Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukasovo evangelium 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Vangelo di San Luca 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evangelio de Lucas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Saint Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Saint Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St. Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Sulat ni San Lucas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St. Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St. Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St. Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukas evangelium 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ungjilli i Lukes 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukasevangeliet 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Vangelo di Luca 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Injili ya Luka 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukka Narceyti 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Injil Lukas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Saint Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Saint Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("San Lucas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Luukkaan 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Saint Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Saint Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St. Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St. Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukacs 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukasa 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Luukos 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St. Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St. Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lukale 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lukane 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lluka 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Looka 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lu-ca 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lucas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukka 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Luca 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Luka 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Luuk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lik 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Llu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Luc 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lc 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("L 1:1").osis()).toEqual("Luke.1.1")
		p.include_apocrypha(false)
		expect(p.parse("MABUTING BALITA AYON KAY SAN LUCAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("MABUTING BALITA AYON KAY SAN LUKAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("MABUTING BALITA AYON KAY LUCAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("MABUTING BALITA AYON KAY LUKAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EBANGHELYO AYON KAY SAN LUCAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EBANGHELYO AYON KAY SAN LUKAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANKELIUMI LUUKKAAN MUKAAN 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EBANGHELYO AYON KAY LUCAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EBANGHELYO AYON KAY LUKAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANGELIUM SECUNDUM LUCAM 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF SAINT LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EBANGHELYO NI SAN LUCAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EBANGHELYO NI SAN LUKAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANGELIE VOLGENS LUCAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANGELIE VOLGENS LUKAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANGELIUM PODLE LUKASE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANJELIUM PODLA LUKASA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF SAINT LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANGELIET ETTER LUKAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF SAINT LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF SAINT LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST. LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EL EVANGELIO DE LUCAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST. LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF SAINT LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("JEVANHELIJE VID LUKY 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUUKKAAN EVANKELIUMI 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST. LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST. LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF SAINT LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKASOVO EVANGELIUM 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("VANGELO DI SAN LUCA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANGELIO DE LUCAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF SAINT LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF SAINT LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST. LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("SULAT NI SAN LUCAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST. LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST. LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST. LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKAS EVANGELIUM 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("UNGJILLI I LUKES 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKASEVANGELIET 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("VANGELO DI LUCA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("INJILI YA LUKA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKKA NARCEYTI 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("INJIL LUKAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("SAINT LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("SAINT LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("SAN LUCAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUUKKAAN 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("SAINT LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("SAINT LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST. LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST. LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKACS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKASA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUUKOS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST. LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST. LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKALE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKANE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LLUKA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LOOKA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LU-CA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUCAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKKA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUCA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LIK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LLU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUC 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LC 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("L 1:1").osis()).toEqual("Luke.1.1")
		`
		true
describe "Localized book Jer (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Jer (ascii)", ->
		`
		expect(p.parse("Aklat ni Jeremiah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Aklat ni Jeremias 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Ksiega Jeremiasza 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Ksiegi Jeremiasza 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Sulat ni Jeremias 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("yarmiyako pustak 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremian kirja 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Ks. Jeremiasza 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Liber Ieremiae 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremias' Bog 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremias’ Bog 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Ks Jeremiasza 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Liv Jeremi an 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremias bok 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremiasza 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremaiah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Yeremyaah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("yarmiyako 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Heremias 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Heremyas 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Herimias 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Herimyas 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Hiremias 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Hiremyas 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Hirimias 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Hirimyas 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Ieremias 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeramaih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeramiah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeramiha 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeramiih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremaih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremeia 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremiah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremian 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremias 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremiha 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremiih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremija 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremjas 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jerimiah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jerimiih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Yirmayah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Eremiya 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Geremia 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Ieremia 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeraiah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeramah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeramia 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeramih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremia 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremie 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jerimah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jerimih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jermiah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jermmah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Yeremia 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("yirmaya 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremi 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jerem 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jere 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Ger 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Ier 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jer 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Yer 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Gr 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Je 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jr 1:1").osis()).toEqual("Jer.1.1")
		p.include_apocrypha(false)
		expect(p.parse("AKLAT NI JEREMIAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("AKLAT NI JEREMIAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("KSIEGA JEREMIASZA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("KSIEGI JEREMIASZA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("SULAT NI JEREMIAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("YARMIYAKO PUSTAK 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIAN KIRJA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("KS. JEREMIASZA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("LIBER IEREMIAE 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIAS' BOG 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIAS’ BOG 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("KS JEREMIASZA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("LIV JEREMI AN 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIAS BOK 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIASZA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMAIAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("YEREMYAAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("YARMIYAKO 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("HEREMIAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("HEREMYAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("HERIMIAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("HERIMYAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("HIREMIAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("HIREMYAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("HIRIMIAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("HIRIMYAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("IEREMIAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAMAIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAMIAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAMIHA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAMIIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMAIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMEIA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIAN 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIHA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIJA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMJAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERIMIAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERIMIIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("YIRMAYAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("EREMIYA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("GEREMIA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("IEREMIA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAIAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAMAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAMIA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAMIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIE 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERIMAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERIMIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERMIAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERMMAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("YEREMIA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("YIRMAYA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMI 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREM 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERE 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("GER 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("IER 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JER 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("YER 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("GR 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JE 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JR 1:1").osis()).toEqual("Jer.1.1")
		`
		true
describe "Localized book 2Cor (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Cor (ascii)", ->
		`
		expect(p.parse("Druhe poslannja apostola Pavla do korynfjan 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Pavlova druga poslanica Korincanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Paulus' Andet Brev til Korintherne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Paulus’ Andet Brev til Korintherne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Paulus’ andre brev til korinterne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Toinen Kirje korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Waraka wa Pili kwa Wakorintho 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Barua ya Pili kwa Wakorintho 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ika- 2 Sulat sa mga Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND Sulat sa mga Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Waraka wa Pili kwa Wakorinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga Korincanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga poslanica Korincanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ika 2 Sulat sa mga Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ika- 2 Sulat sa mga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ikalawang Mga Taga- Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND Sulat sa mga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Kirje korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ika 2 Sulat sa mga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ikalawang Mga Taga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Seconda lettera ai Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Kirje korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Epistula II ad Corinthios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Epistula ad Corinthios II 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Kirje korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korincanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Kirje korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korincanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korincanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Toinen Korinttolaiskirje 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korincanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga list do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Drugi list do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Masodik Korinthusiakhoz 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Toinen Korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andra Korinthierbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha kniha Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha kniha Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andra Korintherbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andra Korintierbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Deuxiemes Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha list Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy list Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy list Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinttolaiskirje 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Mga Taga- Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. list do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinttolaiskirje 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Mga Taga- Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. list do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andra Korinterbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Deuxieme Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha list Korinskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy list Korinskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinttolaiskirje 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Mga Taga- Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II list do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Mga Taga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinttolaiskirje 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Mga Taga- Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 list do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinthierbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Mga Taga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Mga Taga-Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Anden Korintherbrev 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andet Korintherbrev 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Mga Taga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinthusiakhoz 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. list Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinthierbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Mga Taga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Mga Taga-Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintherbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinthusiakhoz 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintierbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. list Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andre korinterbrev 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinthusiakhoz 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II list Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. list Korinskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ikalawang Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ikalawang Korintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintherbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinthusiakhoz 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintierbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 list Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinterbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. list Korinskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2eme. Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andre Korintierne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga Korincanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II list Korinskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ikalawang Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ikalawang Korinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Masodik Korinthus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Masodik Korintusi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Segunda Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Segundo Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinterbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintiyarukku 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 list Korinskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintherbrev 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2de. Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2eme Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Anden Korinterne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Dezyem Korentyen 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Zweite Korinther 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ad Corinthios II 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintherbrev 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 e. Korintasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 i. Korintasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 k. Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 k. Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Kurinthiayon 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Taga-Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korinterbrev 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2d. Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2de Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Drugi Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiaid 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korincanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintos Labaad 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Pili Wakorintho 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Seconda Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Secondo Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Kurinthiayon 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Taga-Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 e Korintasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 e. Koritasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 i Korintasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 i. Koritasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 k Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 k Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korinterbrev 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiaid 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korincanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintierne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2.o. Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2d Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andre Korinter 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga Koryntow 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Drugi Koryntow 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiaid 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korincanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintieni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Wakorintho 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Pili Wakorinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiaid 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korincanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintierne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 e Koritasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 i Koritasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintieni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinterne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Wakorintho 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2.o Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2a. Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2o. Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Corinthios II 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Dezyem Korint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintieni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Wakorintho 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinteni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korentyen 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinthus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintusi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Wakorinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Wakorintho II 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintieni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinterne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Wakorintho 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinteni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korentyen 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinther 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinthus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintusi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Koritasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Wakorinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2a Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2o Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinteni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korentyen 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinthus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintusi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Wakorinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Koryntow 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinteni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korentyen 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinther 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinthus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintusi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Koritasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Wakorinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinter 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Koryntow 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Koryntow 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinta 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Masodik Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinter 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Koryntow 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinta 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinta 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinti 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinta 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Anden Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andre Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corini 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Pili Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha K 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy K 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DruhaK 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DruhyK 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2Kor 1:1").osis()).toEqual("2Cor.1.1")
		p.include_apocrypha(false)
		expect(p.parse("DRUHE POSLANNJA APOSTOLA PAVLA DO KORYNFJAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTIYARUKKU ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("PAVLOVA DRUGA POSLANICA KORINCANIMA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("PAULUS' ANDET BREV TIL KORINTHERNE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("PAULUS’ ANDET BREV TIL KORINTHERNE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("PAULUS’ ANDRE BREV TIL KORINTERNE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TOINEN KIRJE KORINTTILAISILLE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("WARAKA WA PILI KWA WAKORINTHO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("BARUA YA PILI KWA WAKORINTHO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("IKA- 2 SULAT SA MGA CORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND SULAT SA MGA CORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("WARAKA WA PILI KWA WAKORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGA KORINCANIMA POSLANICA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGA POSLANICA KORINCANIMA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("IKA 2 SULAT SA MGA CORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("IKA- 2 SULAT SA MGA CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("IKALAWANG MGA TAGA- CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND SULAT SA MGA CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KIRJE KORINTTILAISILLE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("IKA 2 SULAT SA MGA CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("IKALAWANG MGA TAGA CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECONDA LETTERA AI CORINZI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KIRJE KORINTTILAISILLE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("EPISTULA II AD CORINTHIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("EPISTULA AD CORINTHIOS II 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KIRJE KORINTTILAISILLE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINCANIMA POSLANICA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KIRJE KORINTTILAISILLE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINCANIMA POSLANICA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINCANIMA POSLANICA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TOINEN KORINTTOLAISKIRJE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINCANIMA POSLANICA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGA LIST DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGI LIST DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("MASODIK KORINTHUSIAKHOZ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TOINEN KORINTTILAISILLE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDRA KORINTHIERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHA KNIHA KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHA KNIHA KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDRA KORINTHERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDRA KORINTIERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DEUXIEMES CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHA LIST KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHY LIST KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHY LIST KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTTOLAISKIRJE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. MGA TAGA- CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. LIST DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTTOLAISKIRJE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. MGA TAGA- CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. LIST DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDRA KORINTERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DEUXIEME CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHA LIST KORINSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHY LIST KORINSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTTOLAISKIRJE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II MGA TAGA- CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II LIST DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTTILAISILLE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. MGA TAGA CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORIINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTTOLAISKIRJE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 MGA TAGA- CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 LIST DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTHIERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTTILAISILLE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. MGA TAGA CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. MGA TAGA-CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDEN KORINTHERBREV 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDET KORINTHERBREV 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTTILAISILLE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II MGA TAGA CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTHUSIAKHOZ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. LIST KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CHORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CHORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CHORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORIINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINATHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINITHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIAANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIANAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIANOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHOIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNITHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORRINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORRINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTHIERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTTILAISILLE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 MGA TAGA CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 MGA TAGA-CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTHERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTHUSIAKHOZ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTIERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. LIST KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORIINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDRE KORINTERBREV 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTHUSIAKHOZ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II LIST KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. LIST KORINSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("IKALAWANG CORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("IKALAWANG KORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CHORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CHORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CHORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORITHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORRITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORRITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE CORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE KORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTHERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTHUSIAKHOZ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTIERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 LIST KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. LIST KORINSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2EME. CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORIINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CHORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CHORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CHORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORIINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINATHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINITHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIAANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIANAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIANOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHOIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNITHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORRINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORRINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDRE KORINTIERNE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGA KORINCANIMA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II LIST KORINSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORIINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("IKALAWANG CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("IKALAWANG KORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("MASODIK KORINTHUS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("MASODIK KORINTUSI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORITHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SEGUNDA CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SEGUNDO CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE CORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE CORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE KORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE KORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTIYARUKKU 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 LIST KORINSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORIINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTHERBREV 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2DE. CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2EME CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CHORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CHORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CHORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORIINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINATHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINITHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIAANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIANAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIANOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHOIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNITHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORRINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORRINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CHORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CHORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CHORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORITHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORRITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORRITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDEN KORINTERNE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DEZYEM KORENTYEN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHA KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHA KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHY KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHY KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORIINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CHORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CHORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CHORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORIINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINATHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINITHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIAANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIANAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIANOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHOIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNITHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORRINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORRINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORITHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE CORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE KORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ZWEITE KORINTHER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("AD CORINTHIOS II 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORIINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTHERBREV 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 E. KORINTASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 I. KORINTASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 K. KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 K. KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CHORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CHORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CHORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORIINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINATHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINITHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIAANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIANAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIANOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHOIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNITHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORRINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORRINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KURINTHIAYON 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. TAGA-CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTERBREV 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2D. CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2DE CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. CORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. KORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CHORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CHORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CHORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORITHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORRITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORRITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORITHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGA KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGI KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CHORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CHORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CHORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORIINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINATHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINITHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIAANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIANAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIANOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHOIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNITHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORRINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORRINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CHORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CHORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CHORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIAID 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORITHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORRITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORRITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINCANIMA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTOS LABAAD 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("PILI WAKORINTHO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECONDA CORINZI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECONDO CORINZI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE CORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE KORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CHORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CHORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CHORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORIINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINATHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINITHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIAANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIANAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIANOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHOIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNITHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORRINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORRINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KURINTHIAYON 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 TAGA-CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 E KORINTASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 E. KORITASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 I KORINTASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 I. KORITASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 K KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 K KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTERBREV 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CHORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CHORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CHORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIAID 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORITHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORRITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORRITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINCANIMA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTIERNE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2.O. CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2D CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E CORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E KORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. CORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. CORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. KORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. KORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORITHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORITHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDRE KORINTER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGA KORYNTOW 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGI KORYNTOW 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CHORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CHORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CHORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIAID 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORITHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORRITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORRITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINCANIMA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTIENI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORITHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. WAKORINTHO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("PILI WAKORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CHORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CHORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CHORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIAID 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORITHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORRITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORRITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINCANIMA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTIERNE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 E KORITASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 I KORITASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTIENI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORITHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTERNE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. WAKORINTHO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2.O CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2A. CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E CORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E CORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E KORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E KORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. CORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. KORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORITHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2O. CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("CORINTHIOS II 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DEZYEM KORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTIENI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORITHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II WAKORINTHO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTENI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORITHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORENTYEN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTHUS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTUSI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. WAKORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("WAKORINTHO II 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTIENI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORITHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTERNE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 WAKORINTHO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTENI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORITHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORENTYEN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTHER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTHUS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTUSI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORITASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. WAKORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2A CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E CORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E KORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. CORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. KORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2O CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTENI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORITHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORENTYEN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTHUS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTUSI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II WAKORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTUS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORYNTOW 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORIN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTENI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORITHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORENTYEN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTHER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTHUS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTUSI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORITASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 WAKORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTUS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORYNTOW 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E CORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E KORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTUS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORYNTOW 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINZI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("MASODIK KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTUS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORYNTOW 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINZI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORIN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINZI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINZI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORIN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDEN KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDRE KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORIN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORIN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORIN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("PILI KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORIN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHA K 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHY K 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHAK 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHYK 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2KOR 1:1").osis()).toEqual("2Cor.1.1")
		`
		true
describe "Localized book 1Cor (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Cor (ascii)", ->
		`
		expect(p.parse("Perse poslannja apostola Pavla do korynfjan 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Korintiyarukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ensimmainen Kirje korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pavlova prva poslanica Korincanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra bref Pals til Korintumanna 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Paulus' 1. Brev til Korintherne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Paulus’ 1. Brev til Korintherne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Waraka wa Kwanza kwa Wakorintho 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Barua ya Kwanza kwa Wakorintho 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Paulus' 1 Brev til Korintherne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Paulus’ 1 Brev til Korintherne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Waraka wa Kwanza kwa Wakorinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ensimmainen Korinttolaiskirje 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ensimmainen Korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ika- 1 Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ika 1 Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ika- 1 Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ika 1 Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsza list do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsze list do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwszy list do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva Korincanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva poslanica Korincanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Kirje korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra bref Pals til Korin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Kirje korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Kirje korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korincanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Epistula I ad Corinthios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Epistula ad Corinthios I 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Kirje korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korincanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prima lettera ai Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korincanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Forsta Korinthierbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korincanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Mga Taga- Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Forsta Korintherbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Forsta Korintierbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Mga Taga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Forsta Korinterbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Premieres Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva kniha Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva kniha Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvni list Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Mga Taga- Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinttolaiskirje 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Mga Taga- Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. list do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Elso Korinthusiakhoz 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinttolaiskirje 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Mga Taga- Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. list do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Premiere Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Premiers Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvni list Korinskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvy list Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvy list Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Mga Taga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinttolaiskirje 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Mga Taga- Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 list do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinthierbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Mga Taga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Mga Taga-Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinttolaiskirje 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Mga Taga- Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I list do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Mga Taga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Premier Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinthierbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Mga Taga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Mga Taga-Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintherbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinthusiakhoz 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintierbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. list Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Mga Taga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinthusiakhoz 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. list Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsza Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsze Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwszy Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Primeira Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Primeiro Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintherbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinthusiakhoz 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintierbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 list Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinterbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. list Korinskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ere. Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra Korintubref 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinthusiakhoz 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I list Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. list Korinskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Kwanza Wakorintho 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsza Koryntow 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsze Koryntow 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwszy Koryntow 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Primero Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinterbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintiyarukku 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 list Korinskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintherbrev 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1er. Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ere Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1re. Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I list Korinskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Kwanza Wakorinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Premye Korentyen 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Primer Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva Korincanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvni Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintherbrev 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 e. Korintasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 i. Korintasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 k. Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 k. Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Kurinthiayon 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Taga-Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korinterbrev 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1er Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1re Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Erste Korinther 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Korintos Kowaad 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvy Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvy Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ad Corinthios I 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Kurinthiayon 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Taga-Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 e Korintasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 e. Koritasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 i Korintasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 i. Koritasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 k Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 k Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korinterbrev 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiaid 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korincanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintierne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1.o. Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Elso Korinthus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Elso Korintusi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiaid 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korincanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Korintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiaid 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korincanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintierne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 e Koritasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 i Koritasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintieni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinterne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Wakorintho 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1.o Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1a. Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1o. Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiaid 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korincanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintieni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Wakorintho 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Premye Korint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prima Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Primo Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Korinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintieni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinterne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Wakorintho 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinteni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korentyen 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinther 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinthus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintusi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Koritasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Wakorinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1a Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1o Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthios I 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintieni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Wakorintho 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinteni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korentyen 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinthus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintusi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Wakorinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Korintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Wakorintho I 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinteni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korentyen 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinther 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinthus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintusi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Koritasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Wakorinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinter 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Koryntow 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinteni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korentyen 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinthus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintusi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Wakorinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Koryntow 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Korinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinter 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Koryntow 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinta 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Koryntow 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinta 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Kwanza Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinti 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinta 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinta 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvni Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corini 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Elso Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvni K 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PrvniK 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Co 1:1").osis()).toEqual("1Cor.1.1")
		p.include_apocrypha(false)
		expect(p.parse("PERSE POSLANNJA APOSTOLA PAVLA DO KORYNFJAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTIYARUKKU ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ENSIMMAINEN KIRJE KORINTTILAISILLE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PAVLOVA PRVA POSLANICA KORINCANIMA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FYRRA BREF PALS TIL KORINTUMANNA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PAULUS' 1. BREV TIL KORINTHERNE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PAULUS’ 1. BREV TIL KORINTHERNE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("WARAKA WA KWANZA KWA WAKORINTHO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("BARUA YA KWANZA KWA WAKORINTHO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PAULUS' 1 BREV TIL KORINTHERNE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PAULUS’ 1 BREV TIL KORINTHERNE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("WARAKA WA KWANZA KWA WAKORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ENSIMMAINEN KORINTTOLAISKIRJE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ENSIMMAINEN KORINTTILAISILLE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("IKA- 1 SULAT SA MGA CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("IKA 1 SULAT SA MGA CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("IKA- 1 SULAT SA MGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNANG SULAT SA MGA CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("IKA 1 SULAT SA MGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZA LIST DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZE LIST DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZY LIST DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVA KORINCANIMA POSLANICA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVA POSLANICA KORINCANIMA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNANG SULAT SA MGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KIRJE KORINTTILAISILLE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FYRRA BREF PALS TIL KORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KIRJE KORINTTILAISILLE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNA SULAT SA MGA CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KIRJE KORINTTILAISILLE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINCANIMA POSLANICA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. SULAT SA MGA CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EPISTULA I AD CORINTHIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EPISTULA AD CORINTHIOS I 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KIRJE KORINTTILAISILLE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINCANIMA POSLANICA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. SULAT SA MGA CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRIMA LETTERA AI CORINZI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNA SULAT SA MGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINCANIMA POSLANICA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 SULAT SA MGA CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. SULAT SA MGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FORSTA KORINTHIERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINCANIMA POSLANICA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I SULAT SA MGA CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. SULAT SA MGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNANG MGA TAGA- CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 SULAT SA MGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FORSTA KORINTHERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FORSTA KORINTIERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I SULAT SA MGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNANG MGA TAGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FORSTA KORINTERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PREMIERES CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVA KNIHA KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVA KNIHA KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNI LIST KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNA MGA TAGA- CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTTOLAISKIRJE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. MGA TAGA- CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. LIST DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ELSO KORINTHUSIAKHOZ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTTOLAISKIRJE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. MGA TAGA- CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. LIST DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PREMIERE CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PREMIERS CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNI LIST KORINSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVY LIST KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVY LIST KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNA MGA TAGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTTOLAISKIRJE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 MGA TAGA- CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 LIST DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTHIERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTTILAISILLE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. MGA TAGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. MGA TAGA-CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTTOLAISKIRJE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I MGA TAGA- CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I LIST DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTTILAISILLE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. MGA TAGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PREMIER CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTHIERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTTILAISILLE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 MGA TAGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 MGA TAGA-CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTHERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTHUSIAKHOZ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTIERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. LIST KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE CORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE KORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTTILAISILLE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I MGA TAGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTHUSIAKHOZ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. LIST KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZA KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZE KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZY KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRIMEIRA CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRIMEIRO CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTHERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTHUSIAKHOZ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTIERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 LIST KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. LIST KORINSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ERE. CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE CORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE CORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE KORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE KORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FYRRA KORINTUBREF 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTHUSIAKHOZ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I LIST KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. LIST KORINSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KWANZA WAKORINTHO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZA KORYNTOW 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZE KORYNTOW 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZY KORYNTOW 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRIMERO CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTIYARUKKU 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 LIST KORINSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTHERBREV 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ER. CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ERE CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1RE. CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE CORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE KORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I LIST KORINSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KWANZA WAKORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PREMYE KORENTYEN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRIMER CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVA KORINCANIMA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNI KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTHERBREV 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 E. KORINTASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 I. KORINTASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 K. KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 K. KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KURINTHIAYON 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. TAGA-CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTERBREV 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. CORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. KORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ER CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1RE CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE CORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE KORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ERSTE KORINTHER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTOS KOWAAD 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVA KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVA KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVY KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVY KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("AD CORINTHIOS I 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KURINTHIAYON 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 TAGA-CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 E KORINTASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 E. KORITASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 I KORINTASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 I. KORITASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 K KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 K KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTERBREV 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIAID 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINCANIMA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTIERNE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1.O. CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E CORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E KORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. CORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. CORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. KORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. KORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ELSO KORINTHUS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ELSO KORINTUSI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIAID 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINCANIMA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNANG CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNANG KORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIAID 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINCANIMA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTIERNE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 E KORITASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 I KORITASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTIENI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTERNE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. WAKORINTHO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1.O CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1A. CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E CORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E CORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E KORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E KORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. CORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. KORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1O. CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIAID 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINCANIMA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTIENI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. WAKORINTHO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PREMYE KORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRIMA CORINZI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRIMO CORINZI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNANG CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNANG KORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTIENI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTERNE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 WAKORINTHO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTENI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORENTYEN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTHER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTHUS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTUSI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORITASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. WAKORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1A CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E CORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E KORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. CORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. KORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1O CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIOS I 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTIENI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I WAKORINTHO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTENI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORENTYEN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTHUS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTUSI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. WAKORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNA CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNA KORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("WAKORINTHO I 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTENI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORENTYEN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTHER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTHUS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTUSI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORITASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 WAKORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTUS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORYNTOW 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E CORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E KORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTENI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORENTYEN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTHUS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTUSI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I WAKORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTUS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORYNTOW 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNA KORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTUS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORYNTOW 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINZI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTUS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORYNTOW 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINZI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KWANZA KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINZI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINZI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNI KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ELSO KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNI K 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNIK 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CO 1:1").osis()).toEqual("1Cor.1.1")
		`
		true
describe "Localized book Gal (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Gal (ascii)", ->
		`
		expect(p.parse("Poslannja apostola Pavla do halativ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Kalattiyarukku Elutiya Nirupam 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Pavlova poslanica Galacanima 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Paulus' Brev til Galaterne 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Paulus’ Brev til Galaterne 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Paulus’ brev til galaterne 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Bref Pals til Galatamanna 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Sulat sa mga taga Galacia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Layang Paulus Galatia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Brevet til Galaterne 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Kirje galatalaisille 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Poslanica Galacanima 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Sulat sa mga Galacia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Barua kwa Wagalatia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Epistula ad Galatas 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatiharulai patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatikarams patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Lettera ai Galati 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Mga Taga- Galacia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Mga Taga- Galasya 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("List do Galacjan 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Mga Taga Galacia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Mga Taga Galasya 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Mga Taga-Galacia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("List do Galatow 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatalaisille 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatalaiskirj 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galaterbrefvet 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Kalattiyarukku 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("List Galatanom 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("List Galatskym 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galaterbrevet 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Taga- Galacia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatiharulai 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatenbrief 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Taga Galacia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Taga-Galacia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatikarams 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galacanima 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galataians 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galataions 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatakhoz 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatiaans 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatiains 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatianas 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatianis 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatiians 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatiions 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatinans 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatioans 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galationas 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galationns 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gallatians 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gallations 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ad Galatas 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galasyano 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galataans 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatains 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatanom 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galataons 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatasve 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galaterne 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatiaid 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatians 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatiins 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatinas 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galations 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatiyon 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatoans 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatskym 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gallatins 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Wagalatia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Ga-la-ti 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galacjan 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galasyen 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatans 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galateni 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatian 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatias 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatins 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatios 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatiya 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatons 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galacia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galasia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatas 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galaten 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galater 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galates 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatns 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatow 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galasi 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galata 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galati 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galat 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gala 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gal 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Ga 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gl 1:1").osis()).toEqual("Gal.1.1")
		p.include_apocrypha(false)
		expect(p.parse("POSLANNJA APOSTOLA PAVLA DO HALATIV 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("KALATTIYARUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("PAVLOVA POSLANICA GALACANIMA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("PAULUS' BREV TIL GALATERNE 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("PAULUS’ BREV TIL GALATERNE 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("PAULUS’ BREV TIL GALATERNE 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("BREF PALS TIL GALATAMANNA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("SULAT SA MGA TAGA GALACIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("LAYANG PAULUS GALATIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("BREVET TIL GALATERNE 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("KIRJE GALATALAISILLE 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("POSLANICA GALACANIMA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("SULAT SA MGA GALACIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("BARUA KWA WAGALATIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("EPISTULA AD GALATAS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIHARULAI PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIKARAMS PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("LETTERA AI GALATI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("MGA TAGA- GALACIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("MGA TAGA- GALASYA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("LIST DO GALACJAN 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("MGA TAGA GALACIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("MGA TAGA GALASYA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("MGA TAGA-GALACIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("LIST DO GALATOW 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATALAISILLE 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATALAISKIRJ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATERBREFVET 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("KALATTIYARUKKU 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("LIST GALATANOM 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("LIST GALATSKYM 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATERBREVET 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("TAGA- GALACIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIHARULAI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATENBRIEF 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("TAGA GALACIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("TAGA-GALACIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIKARAMS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALACANIMA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATAIANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATAIONS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATAKHOZ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIAANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIAINS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIANAS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIANIS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIIANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIIONS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATINANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIOANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIONAS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIONNS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALLATIANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALLATIONS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("AD GALATAS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALASYANO 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATAANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATAINS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATANOM 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATAONS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATASVE 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATERNE 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIAID 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIINS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATINAS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIONS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIYON 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATOANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATSKYM 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALLATINS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("WAGALATIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GA-LA-TI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALACJAN 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALASYEN 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATENI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIAN 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIAS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATINS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIOS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIYA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATONS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALACIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALASIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATAS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATEN 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATER 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATES 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATNS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATOW 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALASI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALAT 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GAL 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GL 1:1").osis()).toEqual("Gal.1.1")
		`
		true
describe "Localized book Eph (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Eph (ascii)", ->
		`
		expect(p.parse("Poslannja apostola Pavla do efesjan 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Epeciyarukku Elutiya Nirupam 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Pavlova poslanica Efezanima 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Bref Pals til Efesusmanna 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Paulus' Brev til Efeserne 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Paulus’ Brev til Efeserne 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Paulus’ brev til efeserne 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Epistula ad Ephesios 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Layang Paulus Efesus 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Lettera agli Efesini 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Kirje efesolaisille 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Poslanica Efezanima 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Sulat sa mga Efesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Sulat sa mga Epesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Sulat sa mga Efeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Sulat sa mga Epeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Waraka kwa Waefeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Barua kwa Waefeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Taga- Efesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Taga- Epesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Epheszosziakhoz 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List do Efezjan 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Taga Efesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Taga Epesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Taga- Efeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Taga- Epeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efesolaiskirje 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Taga Efeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Taga Epeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Taga-Efeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efesierbrevet 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efesolaisille 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List Efezanom 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List Efezanum 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List Efezskym 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efeserbrevet 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efezusiakhoz 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Epeciyarukku 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Taga- Efesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Taga- Epesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Taga Efesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Taga Epesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Taga- Efeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Taga- Epeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ad Ephesios 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efesianeve 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Epehesians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Esphesians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Efesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Epesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Taga Efeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Taga Epeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Taga-Efeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efezanima 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Effesiaid 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ehpesians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ehpisians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesains 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesiaid 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesiand 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesiens 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesions 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephisians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Iafisiyon 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Efeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Epeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efeserne 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efezanom 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efeziers 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efezskym 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Epesians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesain 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesian 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesios 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephisian 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephsians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efeseni 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efesini 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efesios 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efeskym 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efezjan 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efezyen 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Epheser 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephsian 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Waefeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efesos 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efesus 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efezow 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efezus 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efese 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephes 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efes 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efez 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephe 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephs 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efe 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Eff 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ehp 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Eph 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ef 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ep 1:1").osis()).toEqual("Eph.1.1")
		p.include_apocrypha(false)
		expect(p.parse("POSLANNJA APOSTOLA PAVLA DO EFESJAN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPECIYARUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("PAVLOVA POSLANICA EFEZANIMA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("BREF PALS TIL EFESUSMANNA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("PAULUS' BREV TIL EFESERNE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("PAULUS’ BREV TIL EFESERNE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("PAULUS’ BREV TIL EFESERNE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPISTULA AD EPHESIOS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LAYANG PAULUS EFESUS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LETTERA AGLI EFESINI 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("KIRJE EFESOLAISILLE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("POSLANICA EFEZANIMA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("SULAT SA MGA EFESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("SULAT SA MGA EPESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("SULAT SA MGA EFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("SULAT SA MGA EPESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("WARAKA KWA WAEFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("BARUA KWA WAEFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA TAGA- EFESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA TAGA- EPESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESZOSZIAKHOZ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST DO EFEZJAN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA TAGA EFESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA TAGA EPESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA TAGA- EFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA TAGA- EPESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESOLAISKIRJE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA TAGA EFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA TAGA EPESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA TAGA-EFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESIERBREVET 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESOLAISILLE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST EFEZANOM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST EFEZANUM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST EFEZSKYM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESERBREVET 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZUSIAKHOZ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPECIYARUKKU 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("TAGA- EFESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("TAGA- EPESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("TAGA EFESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("TAGA EPESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("TAGA- EFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("TAGA- EPESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("AD EPHESIOS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESIANEVE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPEHESIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ESPHESIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA EFESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA EPESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("TAGA EFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("TAGA EPESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("TAGA-EFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZANIMA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFFESIAID 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EHPESIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EHPISIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESAINS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESIAID 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESIAND 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESIENS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESIONS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHISIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("IAFISIYON 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA EFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA EPESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESERNE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZANOM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZIERS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZSKYM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPESIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESAIN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESIAN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESIOS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHISIAN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHSIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESENI 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESINI 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESIOS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESKYM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZJAN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZYEN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESER 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHSIAN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("WAEFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESOS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESUS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZOW 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZUS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHES 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFES 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFF 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EHP 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPH 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EF 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EP 1:1").osis()).toEqual("Eph.1.1")
		`
		true
describe "Localized book Col (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Col (ascii)", ->
		`
		expect(p.parse("Poslannja apostola Pavla do kolosjan 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Paulus' Brev til Kolossenserne 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Paulus’ Brev til Kolossenserne 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Koloceyarukku Elutiya Nirupam 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Pavlova poslanica Kolosanima 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Paulus’ brev til kolosserne 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Bref Pals til Kolossumanna 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Bref Pals til Kolossumann 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Epistula ad Colossenses 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Sulat sa mga Colonsense 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Sulat sa mga Kolonsense 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Sulat sa mga Colosense 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Sulat sa mga Kolosense 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kirje kolossalaisille 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Layang Paulus Kolose 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Lettera ai Colossesi 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Poslanica Kolosanima 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Waraka kwa Wakolosai 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassaikarams patra 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassiharulai patra 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Barua kwa Wakolosai 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolossenserbrevet 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosszebeliekhez 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Mga Taga- Colosas 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Mga Taga- Kolosas 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolossalaiskirje 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Mga Taga Colosas 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Mga Taga Kolosas 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Mga Taga-Colosas 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolossalaisille 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("List do Kolosan 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosserbrevet 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosszeieknek 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("List Kolosanom 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("List Kolosanum 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Mga Colonsense 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Mga Kolonsense 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ad Colossenses 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassaikarams 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassiharulai 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Koloceyarukku 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosseiakhoz 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolossenserne 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("List Koloskym 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Mga Colosense 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Mga Kolosense 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Taga- Colosas 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolossensern 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolossenskym 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Taga Colosas 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Taga-Colosas 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Callossians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colossenses 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colossenzen 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosenskym 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosianeve 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolossenzen 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kulussaiyon 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calassians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calassions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Callasians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Callasions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Callosians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Callosions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calossians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calossions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colassians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colassions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Collasians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Collasions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Collosians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Collosions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colosenses 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colossiaid 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colossians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colossiens 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colossions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosanima 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosensow 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosserne 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calasians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calasions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calosians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calosions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colasians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colasions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colosiaid 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colosians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colosions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colossans 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colossesi 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colossian 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosanom 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosanum 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Wakolosai 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Coloseni 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Koloskym 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosser 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosyen 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colosas 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosan 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosay 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosse 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Coloss 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolose 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colos 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolos 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Col 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kol 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Cl 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Co 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Ko 1:1").osis()).toEqual("Col.1.1")
		p.include_apocrypha(false)
		expect(p.parse("POSLANNJA APOSTOLA PAVLA DO KOLOSJAN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("PAULUS' BREV TIL KOLOSSENSERNE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("PAULUS’ BREV TIL KOLOSSENSERNE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOCEYARUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("PAVLOVA POSLANICA KOLOSANIMA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("PAULUS’ BREV TIL KOLOSSERNE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("BREF PALS TIL KOLOSSUMANNA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("BREF PALS TIL KOLOSSUMANN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("EPISTULA AD COLOSSENSES 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("SULAT SA MGA COLONSENSE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("SULAT SA MGA KOLONSENSE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("SULAT SA MGA COLOSENSE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("SULAT SA MGA KOLOSENSE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KIRJE KOLOSSALAISILLE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("LAYANG PAULUS KOLOSE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("LETTERA AI COLOSSESI 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("POSLANICA KOLOSANIMA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("WARAKA KWA WAKOLOSAI 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSAIKARAMS PATRA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSIHARULAI PATRA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("BARUA KWA WAKOLOSAI 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSENSERBREVET 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSZEBELIEKHEZ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("MGA TAGA- COLOSAS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("MGA TAGA- KOLOSAS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSALAISKIRJE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("MGA TAGA COLOSAS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("MGA TAGA KOLOSAS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("MGA TAGA-COLOSAS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSALAISILLE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("LIST DO KOLOSAN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSERBREVET 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSZEIEKNEK 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("LIST KOLOSANOM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("LIST KOLOSANUM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("MGA COLONSENSE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("MGA KOLONSENSE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("AD COLOSSENSES 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSAIKARAMS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSIHARULAI 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOCEYARUKKU 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSEIAKHOZ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSENSERNE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("LIST KOLOSKYM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("MGA COLOSENSE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("MGA KOLOSENSE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("TAGA- COLOSAS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSENSERN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSENSKYM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("TAGA COLOSAS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("TAGA-COLOSAS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALLOSSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSSENSES 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSSENZEN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSENSKYM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSIANEVE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSENZEN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KULUSSAIYON 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALASSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALASSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALLASIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALLASIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALLOSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALLOSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALOSSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALOSSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLASSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLASSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLLASIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLLASIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLLOSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLLOSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSENSES 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSSIAID 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSSIENS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSANIMA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSENSOW 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSERNE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALASIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALASIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALOSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALOSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLASIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLASIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSIAID 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSSANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSSESI 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSSIAN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSANOM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSANUM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("WAKOLOSAI 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSENI 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSKYM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSER 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSYEN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSAS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSAN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSAY 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COL 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOL 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CL 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CO 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KO 1:1").osis()).toEqual("Col.1.1")
		`
		true
describe "Localized book 2Tim (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Tim (ascii)", ->
		`
		expect(p.parse("Druhe poslannja apostola Pavla do Tymofija 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Paulus' Andet Brev til Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Paulus’ Andet Brev til Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Pavlova druga poslanica Timoteju 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Paulus’ andre brev til Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Waraka wa Pili kwa Timotheo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Barua ya Pili kwa Timotheo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Toinen Kirje Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Seconda lettera a Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga List do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga Timoteju Poslanica 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga poslanica Timoteju 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Drugi List do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Epistula II ad Timotheum 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Epistula ad Timotheum II 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Kirje Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Kirje Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha kniha Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Kirje Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. List do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteju Poslanica 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Kirje Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. List do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteju Poslanica 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Andra Timotheosbrevet 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha kniha Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy list Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II List do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteju Poslanica 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Ikalawang Kay Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 List do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteju Poslanica 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Andra Timoteusbrevet 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha list Timeteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha list Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy list Timeteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy list Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Toinen Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Toinen Timoteuskirje 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Anden Timotheusbrev 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Andet Timotheusbrev 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Timoteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Timoteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotheosbrevet 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Andre Timoteusbrev 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Deuxiemes Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. list Timeteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. list Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Timotheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotheosbrevet 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteusbrevet 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. list Timeteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. list Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Deuxieme Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II list Timeteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II list Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteuskirje 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Ikalawang Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteusbrevet 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotteyuvukku 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 list Timeteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 list Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Teemuathaiyus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteuskirje 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotheusbrev 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Drugi Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteuskirje 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timoteyos Labaad 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tweede Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Zweite Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Teemuathaiyus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteuskirje 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotheusbrev 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 k. Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Kang Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteusbrev 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Kay Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Seconda Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Secondo Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Segunda Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Segundo Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tweede Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ad Timotheum II 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Kang Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteusbrev 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 k Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 k. Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Kay Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2eme. Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Anden Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Andre Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga Timoteju 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Kay Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Kay Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 e. Timoteut 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 i. Timoteut 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 k Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2de. Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e. Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2eme Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Dezyem Timote 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteyos 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotheum 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Pili Timotheo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 e Timoteut 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 i Timoteut 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteyos 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotheum 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2.o. Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2d. Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2de Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e. Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e. Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteyos 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotheum 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteju 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotheo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotius 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotheum II 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteyos 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotheum 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteju 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteut 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotheo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotius 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2.o Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2a. Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2d Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2o. Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteju 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotheo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotius 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotei 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotheo II 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteju 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteut 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotheo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotius 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotei 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2a Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2o Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotei 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timote 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tweede Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotei 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timote 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Anden Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Andre Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timote 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timote 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Pili Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e. Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tym 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2Tim 1:1").osis()).toEqual("2Tim.1.1")
		p.include_apocrypha(false)
		expect(p.parse("DRUHE POSLANNJA APOSTOLA PAVLA DO TYMOFIJA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTEYUVUKKU ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("PAULUS' ANDET BREV TIL TIMOTHEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("PAULUS’ ANDET BREV TIL TIMOTHEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("PAVLOVA DRUGA POSLANICA TIMOTEJU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("PAULUS’ ANDRE BREV TIL TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("WARAKA WA PILI KWA TIMOTHEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("BARUA YA PILI KWA TIMOTHEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TOINEN KIRJE TIMOTEUKSELLE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECONDA LETTERA A TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUGA LIST DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUGA TIMOTEJU POSLANICA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUGA POSLANICA TIMOTEJU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUGI LIST DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("EPISTULA II AD TIMOTHEUM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("EPISTULA AD TIMOTHEUM II 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. KIRJE TIMOTEUKSELLE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. KIRJE TIMOTEUKSELLE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHA KNIHA TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II KIRJE TIMOTEUKSELLE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. LIST DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEJU POSLANICA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 KIRJE TIMOTEUKSELLE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. LIST DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEJU POSLANICA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ANDRA TIMOTHEOSBREVET 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHA KNIHA TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHY LIST TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II LIST DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEJU POSLANICA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("IKALAWANG KAY TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 LIST DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEJU POSLANICA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ANDRA TIMOTEUSBREVET 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHA LIST TIMETEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHA LIST TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHY LIST TIMETEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHY LIST TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TOINEN TIMOTEUKSELLE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TOINEN TIMOTEUSKIRJE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ANDEN TIMOTHEUSBREV 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ANDET TIMOTHEUSBREV 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MASODIK TIMOTEUSHOZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MASODIK TIMOTEUSNAK 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTHEOSBREVET 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ANDRE TIMOTEUSBREV 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DEUXIEMES TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. LIST TIMETEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. LIST TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MASODIK TIMOTHEOSZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTHEOSBREVET 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEUSBREVET 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. LIST TIMETEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. LIST TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DEUXIEME TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II LIST TIMETEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II LIST TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEUKSELLE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEUSKIRJE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("IKALAWANG TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEUSBREVET 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTTEYUVUKKU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 LIST TIMETEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 LIST TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TEEMUATHAIYUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEUKSELLE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEUSKIRJE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTHEUSBREV 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUGA TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUGI TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHA TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHY TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEUKSELLE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEUSKIRJE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MASODIK TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTEYOS LABAAD 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TWEEDE TIMOTHEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ZWEITE TIMOTHEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TEEMUATHAIYUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEUKSELLE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEUSKIRJE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTHEUSBREV 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 K. TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. KANG TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEUSBREV 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHA TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHY TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. KAY TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEUSHOZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEUSNAK 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND THIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECONDA TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECONDO TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SEGUNDA TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SEGUNDO TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TWEEDE TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("AD TIMOTHEUM II 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 KANG TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEUSBREV 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 K TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 K. TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. KAY TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEUSHOZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEUSNAK 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2EME. TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ANDEN TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ANDRE TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUGA TIMOTEJU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHA TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHY TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II KAY TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEUSHOZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEUSNAK 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTHEOSZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND THIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND TIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND TOMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 KAY TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEUSHOZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEUSNAK 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 E. TIMOTEUT 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 I. TIMOTEUT 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 K TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTHEOSZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2DE. TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2E. TIMOTHEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2EME TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. THIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DEZYEM TIMOTE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTHEOSZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEYOS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTHEUM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTHEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("PILI TIMOTHEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND TIMOTH 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND TIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTHEOSZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 E TIMOTEUT 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 I TIMOTEUT 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEYOS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTHEUM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTHEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2.O. TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2D. TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2DE TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2E TIMOTHEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2E. TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2E. TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND THIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. THIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. TIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. TOMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEYOS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTHEUM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTHEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. THIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEJU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTHEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTIUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTHEUM II 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEYOS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTHEUM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTHEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. THIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEJU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEUT 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTHEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTIUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2.O TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2A. TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2D TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2E TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2E TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND THIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND TIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND TOMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. TIMOTH 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. TIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2O. TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II THIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEJU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTHEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTIUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. THIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TOMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MASODIK TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTHEO II 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 THIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEJU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEUT 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTHEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTIUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. THIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TOMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2A TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND TIMOTH 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND TIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2O TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II THIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TOMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTH 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TWEEDE TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 THIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TOMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTH 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ANDEN TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ANDRE TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHA TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHY TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTH 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND TI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTH 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHA TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHY TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("PILI TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2E. TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. TI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2E TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND TI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TYM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2TIM 1:1").osis()).toEqual("2Tim.1.1")
		`
		true
describe "Localized book 1Tim (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Tim (ascii)", ->
		`
		expect(p.parse("Perse poslannja apostola Pavla do Tymofija 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timotteyuvukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Ensimmainen Kirje Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pavlova prva poslanica Timoteju 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Pals til Timoteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Paulus' 1. Brev til Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Paulus’ 1. Brev til Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Waraka wa Kwanza kwa Timotheo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Barua ya Kwanza kwa Timotheo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Paulus' 1 Brev til Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Paulus’ 1 Brev til Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsza List do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsze List do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwszy List do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Ensimmainen Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Ensimmainen Timoteuskirje 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Pals til Timot 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Epistula I ad Timotheum 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Epistula ad Timotheum I 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prima lettera a Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prva Timoteju Poslanica 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prva poslanica Timoteju 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Kirje Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Forsta Timotheosbrevet 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Kirje Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Kirje Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. List do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteju Poslanica 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Forsta Timoteusbrevet 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Kirje Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. List do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteju Poslanica 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prva kniha Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 List do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteju Poslanica 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra Timoteusarbref 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I List do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteju Poslanica 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prva kniha Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvni list Timeteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvni list Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvy list Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsza Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsze Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwszy Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvy list Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotheosbrevet 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premieres Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotheosbrevet 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteusbrevet 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. list Timeteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. list Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. list Timeteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. list Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premiere Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premiers Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Unang Kay Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteusbrevet 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotteyuvukku 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 list Timeteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 list Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Teemuathaiyus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteuskirje 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotheusbrev 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Eerste Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Timoteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Timoteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I list Timeteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I list Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteuskirje 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premier Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Primeira Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Primeiro Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timoteyos Kowaad 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Teemuathaiyus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteuskirje 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotheusbrev 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 k. Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Kang Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteusbrev 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Eerste Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Timotheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Erste Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteuskirje 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Kwanza Timotheo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Primero Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prva Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvni Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvy Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Una Kay Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Kang Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteusbrev 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 k Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 k. Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Kay Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ere. Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Kay Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Primer Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prva Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvni Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvy Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ad Timotheum I 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Kay Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 e. Timoteut 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 i. Timoteut 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 k Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e. Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1er. Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ere Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1re. Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Kay Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premye Timote 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prima Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Primo Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prva Timoteju 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Unang Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 e Timoteut 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 i Timoteut 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteyos 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotheum 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1.o. Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e. Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1er Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1re Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteyos 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotheum 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsza Tym 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsze Tym 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwszy Tym 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteyos 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotheum 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteju 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteut 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotheo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotius 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1.o Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1a. Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1o. Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteyos 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotheum 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteju 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotheo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotius 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timotheum I 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Una Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteju 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteut 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotheo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotius 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotei 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1a Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1o Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Eerste Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteju 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotheo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotius 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotei 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Kwanza Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timotheo I 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotei 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timote 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotei 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timote 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvni Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timote 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timote 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvni Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e. Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Tym 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Tym 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tym 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Tym 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Tm 1:1").osis()).toEqual("1Tim.1.1")
		p.include_apocrypha(false)
		expect(p.parse("PERSE POSLANNJA APOSTOLA PAVLA DO TYMOFIJA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTTEYUVUKKU ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ENSIMMAINEN KIRJE TIMOTEUKSELLE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PAVLOVA PRVA POSLANICA TIMOTEJU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BREF PALS TIL TIMOTEUSAR 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PAULUS' 1. BREV TIL TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PAULUS’ 1. BREV TIL TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("WARAKA WA KWANZA KWA TIMOTHEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("BARUA YA KWANZA KWA TIMOTHEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PAULUS' 1 BREV TIL TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PAULUS’ 1 BREV TIL TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZA LIST DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZE LIST DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZY LIST DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ENSIMMAINEN TIMOTEUKSELLE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ENSIMMAINEN TIMOTEUSKIRJE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BREF PALS TIL TIMOT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("EPISTULA I AD TIMOTHEUM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("EPISTULA AD TIMOTHEUM I 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRIMA LETTERA A TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVA TIMOTEJU POSLANICA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVA POSLANICA TIMOTEJU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. KIRJE TIMOTEUKSELLE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FORSTA TIMOTHEOSBREVET 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. KIRJE TIMOTEUKSELLE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 KIRJE TIMOTEUKSELLE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. LIST DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEJU POSLANICA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FORSTA TIMOTEUSBREVET 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I KIRJE TIMOTEUKSELLE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. LIST DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEJU POSLANICA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVA KNIHA TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 LIST DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEJU POSLANICA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA TIMOTEUSARBREF 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I LIST DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEJU POSLANICA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVA KNIHA TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVNI LIST TIMETEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVNI LIST TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVY LIST TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZA TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZE TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZY TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVY LIST TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTHEOSBREVET 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PREMIERES TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTHEOSBREVET 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEUSBREVET 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. LIST TIMETEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. LIST TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. LIST TIMETEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. LIST TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PREMIERE TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PREMIERS TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("UNANG KAY TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEUSBREVET 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTTEYUVUKKU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 LIST TIMETEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 LIST TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TEEMUATHAIYUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEUKSELLE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEUSKIRJE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTHEUSBREV 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("EERSTE TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSO TIMOTEUSHOZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSO TIMOTEUSNAK 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I LIST TIMETEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I LIST TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEUKSELLE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEUSKIRJE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PREMIER TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRIMEIRA TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRIMEIRO TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTEYOS KOWAAD 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TEEMUATHAIYUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEUKSELLE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEUSKIRJE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTHEUSBREV 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 K. TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. KANG TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEUSBREV 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("EERSTE TIMOTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSO TIMOTHEOSZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ERSTE TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEUKSELLE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEUSKIRJE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("KWANZA TIMOTHEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRIMERO TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVA TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVNI TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVY TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("UNA KAY TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 KANG TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEUSBREV 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 K TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 K. TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. KAY TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEUSHOZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEUSNAK 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ERE. TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST THIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. KAY TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEUSHOZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEUSNAK 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRIMER TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVA TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVNI TIMOTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVY TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("AD TIMOTHEUM I 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 KAY TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEUSHOZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEUSNAK 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 E. TIMOTEUT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 I. TIMOTEUT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 K TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTHEOSZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1E. TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ER. TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ERE TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1RE. TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. THIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSO TIMOTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST THIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST TOMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I KAY TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEUSHOZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEUSNAK 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTHEOSZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PREMYE TIMOTE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRIMA TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRIMO TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVA TIMOTEJU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("UNANG TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTHEOSZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 E TIMOTEUT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 I TIMOTEUT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEYOS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTHEUM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1.O. TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1E TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1E. TIMOTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ER TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1RE TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST THIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. THIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. TOMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST TIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTHEOSZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEYOS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTHEUM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZA TYM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZE TYM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZY TYM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEYOS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTHEUM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. THIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEJU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEUT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTHEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTIUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1.O TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1A. TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1E TIMOTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1O. TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST THIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST TOMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. TIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEYOS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTHEUM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. THIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEJU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTHEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTIUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTHEUM I 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("UNA TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 THIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEJU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEUT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTHEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTIUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. THIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TOMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1A TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1O TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST TIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("EERSTE TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I THIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEJU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTHEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTIUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. THIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TOMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("KWANZA TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTHEO I 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 THIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TOMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I THIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TOMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVNI TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSO TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST TI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST TM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVNI TM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1E. TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. TI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. TM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TYM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1E TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST TI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST TM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TYM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TYM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TYM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TM 1:1").osis()).toEqual("1Tim.1.1")
		`
		true
describe "Localized book Deut (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Deut (ascii)", ->
		`
		expect(p.parse("Ksiega Powtorzonego Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ksiegi Powtorzonego Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Kitabu cha Tano cha Musa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Ksiega Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Ksiegi Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Sharciga Kunoqoshadiisa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ks. Powtorzonego Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Viides Mooseksen kirja 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ks Powtorzonego Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata kniha Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Ksiega Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Ksiegi Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Kumbukumbu la Sheria 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Kumbukumbu la Torati 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Masodik torvenykonyv 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pata kniha Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Ks. Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Ksiega Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Ksiegi Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Ksiega Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Ksiegi Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Mozes otodik konyve 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pangandharing Toret 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Ks Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Ksiega Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Ksiegi Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mooseksen kirja 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. kniha Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Dezyem liv Lalwa a 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Liber Deuteronomii 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Povtorennja Zakonu 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mooseksen kirja 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. kniha Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mooseksen kirja 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 kniha Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Ks. Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Andharaning Toret 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ksiega Powt Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ksiegi Powt Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ligji i Perterire 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mooseksen kirja 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V kniha Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Ks. Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Vyavasthaavivaran 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Ks. Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Ks Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Funfte Buch Mose 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ponovljeni zakon 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Ks. Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Ks Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Viides Mooseksen 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Ks Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Femte Moseboken 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Fimmta bok Mose 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Ks Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 k. Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Fimmta Mosebok 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ks. Powt Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pata Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 k Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronomium 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronomiya 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronomiyo 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deyuteronomyo 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Diyuteronomyo 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Femte Mosebog 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Femte Mosebok 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ks Powt Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Buch Mose 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mooseksen 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Moseboken 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronomia 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronomio 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronomul 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronomya 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deutoronomio 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Dueteronomio 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Dyuteronomyo 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mooseksen 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Vijfde Mozes 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Buch Mose 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mooseksen 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Moseboken 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deeteronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deetoronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronmio 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronoma 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronome 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronomi 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deutoronmio 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deutoronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deutronomio 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Dueteronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duetoronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duuteronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duutoronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Funfte Mose 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mooseksen 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mosebog 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mosebok 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deeteronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deetoronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deetronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronom 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deutoronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deutronmio 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deutronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Dueteronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duetoronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duetronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duuteronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duutoronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duutronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Kumbukumbu 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Mojz 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mosebok 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mosebog 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mosebok 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deetronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deteronom 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Detewonom 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deutronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duetronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duutronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Femte Mos 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mosebok 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mozes 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Dewariem 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Upakamam 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mozes 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mozes 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mojz 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mose 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Mozes V 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mozes 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mojz 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mojz 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Moos 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mose 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mos 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Sharci 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mojz 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mos 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("anuwad 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Moj 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mos 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Moz 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mo 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MTorv 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Moj 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mos 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mo 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mz 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deut 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duet 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Kumb 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 M 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Det 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deu 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Dtn 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Kum 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("LiP 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pnz 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pwt 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("De 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Dt 1:1").osis()).toEqual("Deut.1.1")
		p.include_apocrypha(false)
		expect(p.parse("KSIEGA POWTORZONEGO PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KSIEGI POWTORZONEGO PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KITABU CHA TANO CHA MUSA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("SHARCIGA KUNOQOSHADIISA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KS. POWTORZONEGO PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("VIIDES MOOSEKSEN KIRJA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KS POWTORZONEGO PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA KNIHA MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KUMBUKUMBU LA SHERIA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KUMBUKUMBU LA TORATI 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MASODIK TORVENYKONYV 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATA KNIHA MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA KS. MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MOZES OTODIK KONYVE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PANGANDHARING TORET 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA KS MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOOSEKSEN KIRJA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KNIHA MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEZYEM LIV LALWA A 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("LIBER DEUTERONOMII 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("POVTORENNJA ZAKONU 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOOSEKSEN KIRJA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KNIHA MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOOSEKSEN KIRJA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KNIHA MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KS. MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ANDHARANING TORET 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KSIEGA POWT PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KSIEGI POWT PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("LIGJI I PERTERIRE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOOSEKSEN KIRJA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KNIHA MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KS. MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("VYAVASTHAAVIVARAN 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KS. MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KS MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FUNFTE BUCH MOSE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PONOVLJENI ZAKON 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KS. MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KS MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("VIIDES MOOSEKSEN 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KS MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FEMTE MOSEBOKEN 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FIMMTA BOK MOSE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KS MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 K. MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FIMMTA MOSEBOK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KS. POWT PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATA MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 K MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOMIUM 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOMIYA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOMIYO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEYUTERONOMYO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DIYUTERONOMYO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FEMTE MOSEBOG 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FEMTE MOSEBOK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KS POWT PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. BUCH MOSE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOOSEKSEN 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOSEBOKEN 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOMIA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOMIO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOMUL 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOMYA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTORONOMIO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUETERONOMIO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DYUTERONOMYO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOOSEKSEN 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("VIJFDE MOZES 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 BUCH MOSE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOOSEKSEN 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOSEBOKEN 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEETERONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEETORONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONMIO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOMA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOME 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOMI 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTORONMIO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTORONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTRONOMIO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUETERONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUETORONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUUTERONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUUTORONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FUNFTE MOSE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOOSEKSEN 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOSEBOG 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOSEBOK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEETERONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEETORONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEETRONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOM 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTORONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTRONMIO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTRONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUETERONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUETORONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUETRONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUUTERONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUUTORONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUUTRONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KUMBUKUMBU 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA MOJZ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOSEBOK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOSEBOG 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOSEBOK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEETRONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DETERONOM 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DETEWONOM 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTRONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUETRONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUUTRONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FEMTE MOS 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOSEBOK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOZES 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEWARIEM 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("UPAKAMAM 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOZES 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOZES 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOJZ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOSE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MOZES V 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOZES 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOJZ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOJZ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOOS 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOSE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOS 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("SHARCI 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOJZ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOS 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ANUWAD 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOJ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOS 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOZ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MTORV 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOJ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOS 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MZ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUT 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUET 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KUMB 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 M 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DET 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEU 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DTN 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KUM 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("LIP 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PNZ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PWT 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DT 1:1").osis()).toEqual("Deut.1.1")
		`
		true
describe "Localized book Titus (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Titus (ascii)", ->
		`
		expect(p.parse("Poslannja apostola Pavla do Tyta 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tittuvukku Elutiya Nirupam 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Paulus' Brev til Titus 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Paulus’ Brev til Titus 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Paulus’ brev til Titus 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Pavlova poslanica Titu 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Bref Pals til Titusar 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Brevet till Titus 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Epistula ad Titum 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Brevet til Titus 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Kirje Titukselle 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Waraka kwa Tito 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Barua kwa Tito 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Lettera a Tito 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("List do Tytusa 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Poslanica Titu 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("titaslai patra 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("titala patra 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("List Titovi 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titusarbref 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titusbrevet 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tittuvukku 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titukselle 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Kang Tito 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tituszhoz 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Kay Tito 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titushoz 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ad Titum 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("titaslai 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Teetus 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tiitos 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titovi 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titusz 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tytusa 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("titala 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titit 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titum 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titus 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tiit 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tite 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titi 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tito 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titu 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tit 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tyt 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Ti 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tt 1:1").osis()).toEqual("Titus.1.1")
		p.include_apocrypha(false)
		expect(p.parse("POSLANNJA APOSTOLA PAVLA DO TYTA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITTUVUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("PAULUS' BREV TIL TITUS 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("PAULUS’ BREV TIL TITUS 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("PAULUS’ BREV TIL TITUS 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("PAVLOVA POSLANICA TITU 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("BREF PALS TIL TITUSAR 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("BREVET TILL TITUS 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("EPISTULA AD TITUM 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("BREVET TIL TITUS 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("KIRJE TITUKSELLE 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("WARAKA KWA TITO 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("BARUA KWA TITO 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("LETTERA A TITO 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("LIST DO TYTUSA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("POSLANICA TITU 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITASLAI PATRA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITALA PATRA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("LIST TITOVI 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITUSARBREF 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITUSBREVET 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITTUVUKKU 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITUKSELLE 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("KANG TITO 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITUSZHOZ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("KAY TITO 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITUSHOZ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("AD TITUM 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITASLAI 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TEETUS 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TIITOS 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITOVI 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITUSZ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TYTUSA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITALA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITIT 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITUM 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITUS 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TIIT 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITE 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITI 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITO 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITU 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TIT 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TYT 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TI 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TT 1:1").osis()).toEqual("Titus.1.1")
		`
		true
describe "Localized book Heb (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Heb (ascii)", ->
		`
		expect(p.parse("Epireyarukku Elutiya Nirupam 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Pavlova poslanica Hebrejima 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("hibruharuko nimti patra 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Brevet til hebreerne 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Epistula ad Hebraeos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Kirje hebrealaisille 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Kirje heprealaisille 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("List do Hebrajczykow 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Poslannja do jevreiv 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Waraka kwa Waebrania 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Barua kwa Waebrania 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Poslanica Hebrejima 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zsidokhoz irt level 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Lettera agli Ebrei 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("hibruharuko nimti 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ibri lokams patra 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heprealaiskirje 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heprealaisille 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Mga Hebrohanon 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebreerbrevet 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Layang Ibrani 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("List Hebrejom 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("List Hebrejum 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("List do Zydow 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Cibraaniyada 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Epireyarukku 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrajczykow 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heber level 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebreohanon 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Ibraaaniyon 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ad Hebraeos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ibri lokams 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("List Zidum 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Mga Hebreo 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebreerne 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrejima 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrenjve 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heebrewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hewbrewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hwebrewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hwwbrewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Mga Ebreo 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Waebrania 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zsidokhoz 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebraeer 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebraeos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebreaid 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebreeen 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrejom 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrejum 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heebrews 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hewbrews 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hwbrewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hwebrews 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hwwbrews 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hbrewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebeees 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebeeos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebeers 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebeoes 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebeoos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebeors 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heberes 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heberos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heberrs 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heberws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebewes 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebewrs 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heboees 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heboeos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heboers 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebooes 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebooos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heboors 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebores 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heboros 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heborrs 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebraer 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrees 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebreos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrers 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebreus 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebreux 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrews 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebroes 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebroos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrors 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrres 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrros 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrrrs 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrrws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrwes 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebwers 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebwres 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hwbrews 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hbrews 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebees 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebeos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebers 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heboes 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heboos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebors 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebreo 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebres 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrew 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebros 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrrs 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Ibrani 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zsidok 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Ebrei 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Evrei 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebes 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrs 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zidom 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zidum 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zydow 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Ebre 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebr 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hepr 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zsid 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Cib 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Ebr 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Evr 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hbr 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heb 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zid 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zyd 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Eb 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("He 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zd 1:1").osis()).toEqual("Heb.1.1")
		p.include_apocrypha(false)
		expect(p.parse("EPIREYARUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("PAVLOVA POSLANICA HEBREJIMA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HIBRUHARUKO NIMTI PATRA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("BREVET TIL HEBREERNE 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("EPISTULA AD HEBRAEOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("KIRJE HEBREALAISILLE 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("KIRJE HEPREALAISILLE 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("LIST DO HEBRAJCZYKOW 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("POSLANNJA DO JEVREIV 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("WARAKA KWA WAEBRANIA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("BARUA KWA WAEBRANIA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("POSLANICA HEBREJIMA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZSIDOKHOZ IRT LEVEL 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("LETTERA AGLI EBREI 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HIBRUHARUKO NIMTI 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRI LOKAMS PATRA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEPREALAISKIRJE 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEPREALAISILLE 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("MGA HEBROHANON 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREERBREVET 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("LAYANG IBRANI 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("LIST HEBREJOM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("LIST HEBREJUM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("LIST DO ZYDOW 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("CIBRAANIYADA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("EPIREYARUKKU 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRAJCZYKOW 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBER LEVEL 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREOHANON 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRAAANIYON 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("AD HEBRAEOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRI LOKAMS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("LIST ZIDUM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("MGA HEBREO 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREERNE 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREJIMA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRENJVE 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEEBREWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEWBREWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HWEBREWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HWWBREWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("MGA EBREO 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("WAEBRANIA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZSIDOKHOZ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRAEER 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRAEOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREAID 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREEEN 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREJOM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREJUM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEEBREWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEWBREWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HWBREWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HWEBREWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HWWBREWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HBREWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEEES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEEOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEERS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEOES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEOOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEORS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBERES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEROS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBERRS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBERWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEWES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEWRS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBOEES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBOEOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBOERS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBOOES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBOOOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBOORS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBORES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBOROS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBORRS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRAER 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRERS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREUS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREUX 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBROES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBROOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRORS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRRES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRROS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRRRS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRRWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRWES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBWERS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBWRES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HWBREWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HBREWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBERS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBOES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBOOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBORS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREO 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREW 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBROS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRRS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRANI 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZSIDOK 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("EBREI 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("EVREI 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZIDOM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZIDUM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZYDOW 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("EBRE 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBR 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEPR 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZSID 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("CIB 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("EBR 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("EVR 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HBR 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEB 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZID 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZYD 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("EB 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HE 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZD 1:1").osis()).toEqual("Heb.1.1")
		`
		true
describe "Localized book Phil (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Phil (ascii)", ->
		`
		expect(p.parse("Poslannja apostola Pavla do fylyp'jan 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Poslannja apostola Pavla do fylyp’jan 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Pavlova poslanica Filipljanima 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Pilippiyarukku Elutiya Nirupam 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Paulus' Brev til Filipperne 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Paulus’ Brev til Filipperne 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Paulus’ brev til filipperne 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Bref Pals til Filippimanna 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Bref Pals til Filippimann 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Epistula ad Philippenses 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Poslanica Filipljanima 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Sulat sa mga Filipense 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Sulat sa mga Pilipense 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Sulat sa mga Pilipyano 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Kirje filippilaisille 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Layang Paulus Filipi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Lettera ai Filippesi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Waraka kwa Wafilipi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Barua kwa Wafilipi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Mga Taga- Filipos 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Mga Taga- Pilipos 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippibeliekhez 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filippilaiskirje 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("List do Filipian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Mga Taga Filipos 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Mga Taga Pilipos 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Mga Taga-Filipos 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filippilaisille 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ad Philippenses 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipperbrevet 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("List Filipanom 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("List Filipskym 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Pilippiyarukku 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filippenserne 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Mga Filipense 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Mga Pilipense 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Mga Pilipyano 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippiains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippieans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippiians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipppians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philllipiians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philllippians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Taga- Filipos 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Taga- Pilipos 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipljanima 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filippiekhez 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippaians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippenses 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippiaans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippiains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippiians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipppians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipaians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipiaans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipiains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipieans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipiians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippeans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philllipians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philllppians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Taga Filipos 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Taga Pilipos 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Taga-Filipos 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipenskym 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipianeve 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filippaiyon 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filippenzen 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Flippiekhez 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipaians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipiians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippeans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippiens 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipppian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipeans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipiens 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippean 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippins 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philllipian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philllpians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillppians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philppiians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpppians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipenses 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipensow 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipperne 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipeans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipiaid 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipiens 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippean 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippins 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipain 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipean 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipins 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillpians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillpiens 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillppian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philppians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phlippians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipanom 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filippesi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipskym 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipain 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipens 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipins 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippan 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipper 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippin 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipan 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillpans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillpian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpeans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philppian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phlipians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipeni 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipyen 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipan 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpins 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Wafilipi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filiboy 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipos 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filippi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipp 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillip 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpan 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philip 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philli 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpp 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phlipp 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filip 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phili 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philp 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phlip 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phlpp 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Fili 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phil 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phlp 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Fil 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Flp 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Php 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Fl 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Fp 1:1").osis()).toEqual("Phil.1.1")
		p.include_apocrypha(false)
		expect(p.parse("POSLANNJA APOSTOLA PAVLA DO FYLYP'JAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("POSLANNJA APOSTOLA PAVLA DO FYLYP’JAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PAVLOVA POSLANICA FILIPLJANIMA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PILIPPIYARUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PAULUS' BREV TIL FILIPPERNE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PAULUS’ BREV TIL FILIPPERNE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PAULUS’ BREV TIL FILIPPERNE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("BREF PALS TIL FILIPPIMANNA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("BREF PALS TIL FILIPPIMANN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("EPISTULA AD PHILIPPENSES 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("POSLANICA FILIPLJANIMA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("SULAT SA MGA FILIPENSE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("SULAT SA MGA PILIPENSE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("SULAT SA MGA PILIPYANO 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("KIRJE FILIPPILAISILLE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("LAYANG PAULUS FILIPI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("LETTERA AI FILIPPESI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("WARAKA KWA WAFILIPI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("BARUA KWA WAFILIPI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("MGA TAGA- FILIPOS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("MGA TAGA- PILIPOS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIBELIEKHEZ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPILAISKIRJE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("LIST DO FILIPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("MGA TAGA FILIPOS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("MGA TAGA PILIPOS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("MGA TAGA-FILIPOS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPILAISILLE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("AD PHILIPPENSES 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPERBREVET 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("LIST FILIPANOM 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("LIST FILIPSKYM 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PILIPPIYARUKKU 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPENSERNE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("MGA FILIPENSE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("MGA PILIPENSE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("MGA PILIPYANO 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPIAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPIEANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPIIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLLIPIIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLLIPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("TAGA- FILIPOS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("TAGA- PILIPOS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPLJANIMA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPIEKHEZ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPAIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPENSES 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIAANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPAIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPIAANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPIAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPIEANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPIIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPEANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLLIPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLLPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("TAGA FILIPOS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("TAGA PILIPOS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("TAGA-FILIPOS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPENSKYM 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPIANEVE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPAIYON 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPENZEN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FLIPPIEKHEZ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPAIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPIIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPEANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIENS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPEANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPIENS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPEAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLLIPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLLPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPPIIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPENSES 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPENSOW 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPERNE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPEANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPIAID 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPIENS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPEAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPAIN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPEAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLPIENS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLPPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHLIPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPANOM 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPESI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPSKYM 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPAIN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPENS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPER 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLPANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPEANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHLIPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPENI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPYEN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("WAFILIPI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIBOY 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPOS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHLIPP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHLIP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHLPP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHIL 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHLP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FIL 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FLP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FL 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FP 1:1").osis()).toEqual("Phil.1.1")
		`
		true
describe "Localized book Dan (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Dan (ascii)", ->
		`
		expect(p.parse("Prophetia Danielis 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("daniyalko pustak 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Danielin kirja 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Ksiega Daniela 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Ksiegi Daniela 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Liv Danyel la 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Daniels Bog 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Daniels bok 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Ks. Daniela 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Ks Daniela 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Daaniyyel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("daniyalko 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Daanyeel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Danielin 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Daniela 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Daniele 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Danieli 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Dhaniel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Taniyel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Danial 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Daniel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Danyel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Danyil 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("daniel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Daan 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Dan 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Da 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Dl 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Dn 1:1").osis()).toEqual("Dan.1.1")
		p.include_apocrypha(false)
		expect(p.parse("PROPHETIA DANIELIS 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIYALKO PUSTAK 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIELIN KIRJA 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("KSIEGA DANIELA 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("KSIEGI DANIELA 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("LIV DANYEL LA 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIELS BOG 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIELS BOK 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("KS. DANIELA 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("KS DANIELA 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DAANIYYEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIYALKO 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DAANYEEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIELIN 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIELA 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIELE 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIELI 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DHANIEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("TANIYEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIAL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANYEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANYIL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DAAN 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DAN 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DA 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DN 1:1").osis()).toEqual("Dan.1.1")
		`
		true
describe "Localized book Jude (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Jude (ascii)", ->
		`
		expect(p.parse("Poslanica Jude apostola 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Poslannja apostola Judy 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yuta Elutiya Nirupam 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judina poslanica 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Lettera di Giuda 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Juudaksen kirje 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahudacem patra 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Epistula Iudae 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahudako patra 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Barua ya Yuda 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judas epistel 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("List sw. Judy 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Layang Yudas 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("List sw Judy 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judas' Brev 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judasarbref 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judasbrevet 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judas’ Brev 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judas’ brev 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judas brev 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judov List 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("List Juduv 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Juudaksen 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("List Judy 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("San Judas 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahudacem 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahudako 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yahooda 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judina 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judova 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yuudas 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Giuda 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Hudas 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Iudae 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judas 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judov 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Jwdas 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yudas 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Iuda 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Jdas 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Juda 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Jude 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judy 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Juud 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yuda 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yuta 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yuud 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Jde 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Jid 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Jwd 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yud 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Gd 1:1").osis()).toEqual("Jude.1.1")
		p.include_apocrypha(false)
		expect(p.parse("POSLANICA JUDE APOSTOLA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("POSLANNJA APOSTOLA JUDY 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YUTA ELUTIYA NIRUPAM 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDINA POSLANICA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("LETTERA DI GIUDA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUUDAKSEN KIRJE 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHUDACEM PATRA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("EPISTULA IUDAE 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHUDAKO PATRA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("BARUA YA YUDA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDAS EPISTEL 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("LIST SW. JUDY 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("LAYANG YUDAS 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("LIST SW JUDY 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDAS' BREV 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDASARBREF 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDASBREVET 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDAS’ BREV 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDAS’ BREV 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDAS BREV 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDOV LIST 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("LIST JUDUV 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUUDAKSEN 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("LIST JUDY 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("SAN JUDAS 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHUDACEM 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHUDAKO 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHOODA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDINA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDOVA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YUUDAS 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("GIUDA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("HUDAS 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("IUDAE 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDAS 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDOV 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JWDAS 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YUDAS 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("IUDA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JDAS 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDE 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDY 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUUD 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YUDA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YUTA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YUUD 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JDE 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JID 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JWD 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YUD 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("GD 1:1").osis()).toEqual("Jude.1.1")
		`
		true
describe "Localized book 2Macc (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Macc (ascii)", ->
		`
		expect(p.parse("Druga knjiga o Makabejcima 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Secondo libro dei Maccabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druga Ksiega Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druga Ksiegi Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Drugi Ksiega Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Drugi Ksiegi Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Kitabu cha Wamakabayo II 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druha kniha Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Toinen makkabilaiskirja 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druha kniha Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhy list Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Ksiega Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Ksiegi Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Ksiega Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Ksiegi Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druga Ks. Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Drugi Ks. Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhy list Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Ksiega Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Ksiegi Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Ikalawang Mga Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Liber II Maccabaeorum 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Liber Maccabaeorum II 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Ksiega Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Ksiegi Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Andra Mackabeerboken 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druga Ks Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Drugi Ks Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. makkabilaiskirja 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. makkabilaiskirja 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Deuxiemes Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II makkabilaiskirja 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Ks. Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Masodik Makkabeusok 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Maccabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 makkabilaiskirja 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Ks. Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Andre Makkabeerbok 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Deuxieme Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Ks. Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Ks Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Ikalawang Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Macabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Maccabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Maccabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Maccabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Ks. Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Ks Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Mackabeerboken 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druha Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhy Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Ks Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Ikalawang Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Onnur Makkabeabok 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Macabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Macabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Macabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Maccabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Maccabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Maccabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Tweede Makkabeeen 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Ks Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Mackabeerboken 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 k. Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Maccabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druha Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druha Makabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhy Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhy Makabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Machabaeorum 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Seconda Maccabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Secondo Maccabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segunda Macabeus 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Macabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Macabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Macabeus 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Maccabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Zweite Makkabaer 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 k Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 k. Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Machabaeorum 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Makkabeerbok 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Maccabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Macabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Maccabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Maccabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Maccabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2eme. Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Maccabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Machabaeorum 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabaeorum 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Makkabeusok 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Mga Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Machabaeorum II 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Pili Wamakabayo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Machabaeorum 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Makkabeerbok 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 k Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabaeorum 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Makkabeusok 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Mga Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Macabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Maccabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Maccabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Maccabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Macabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Macabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Macabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Maccabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Maccabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Maccabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2de. Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2e. Makkabeeen 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2eme Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Maccabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Macabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Maccabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Maccabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Maccabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabaeorum 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Makkabeusok 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Mga Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Makabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Makkabeeen 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Wamakabayo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Makkabeusok II 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabaeorum 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Makkabeusok 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Mga Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Makabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Makkabeeen 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Wamakabayo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Macabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Macabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Macabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Maccabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Maccabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Maccabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Macabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Macabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Maccabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2d. Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2de Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2e Makkabeeen 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2e. Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Macabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Maccabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Maccabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Maccabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Macabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Macabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Macabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Maccabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Maccabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Maccabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Makabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Makkabeeen 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Wamakabayo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabeaid 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Wamakabayo II 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Makabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Makkabeeen 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Wamakabayo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabeaid 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Makkabaer 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Macabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Macabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Maccabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2a. Macabeus 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2d Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2e Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Macabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Macabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Macabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Maccabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Maccabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Maccabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Macabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Macabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Macabeus 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Maccabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabeaid 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabeus 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabeaid 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Makkabaer 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabeus 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2a Macabeus 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Macabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Macabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Macabeus 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Maccabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabeus 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Masodik Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabeus 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Anden Makk 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Andre Makk 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Makabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Mac 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Tweede Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Makabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druha Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhy Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Makabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Makabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Mac 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Makk 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Pili Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Makk 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2e. Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Mac 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Makk 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Mac 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Mach 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Mack 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Makk 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 makk 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Mac 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2e Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Mac 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Mac 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Mcb 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Mch 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Ma 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Mc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 M 1:1").osis()).toEqual("2Macc.1.1")
		`
		true
describe "Localized book 3Macc (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 3Macc (ascii)", ->
		`
		expect(p.parse("Treca knjiga o Makabejcima 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Trzecia Ksiega Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Trzecia Ksiegi Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Kitabu cha Wamakabayo III 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Trzeci Ksiega Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Trzeci Ksiegi Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Terzo libro dei Maccabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tretia kniha Machabejcov 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Ksiega Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Ksiegi Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Kolmas makkabilaiskirja 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Trzecia Ks. Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Ksiega Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Ksiegi Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Liber III Maccabaeorum 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Liber Maccabaeorum III 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Trzeci Ks. Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Trzecia Ks Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Ksiega Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Ksiegi Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. makkabilaiskirja 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tredje Mackabeerboken 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Trzeci Ks Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Ksiega Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Ksiegi Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Harmadik Makkabeusok 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III makkabilaiskirja 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Ks. Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Ikatlong Mga Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Troisiemes Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. makkabilaiskirja 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Ks. Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Ks Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tredje Makkabeerbok 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Troisieme Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 makkabilaiskirja 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Ks. Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3e. Mackabeerboken 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Ks Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tretia Machabejcov 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Ks. Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Ks Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Mackabeerboken 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3e Mackabeerboken 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Machabaeorum 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Ikatlong Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Terceira Macabeus 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Terceiro Macabeus 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Treti Machabejcov 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Ks Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Mackabeerboken 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 k. Machabejcov 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Derde Makkabeeen 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Dritte Makkabaer 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Machabaeorum 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabaeorum 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Machabejcov 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Makkabeusok 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Mga Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Ikatlong Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Machabaeorum III 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Treti Makabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 k Machabejcov 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Machabaeorum 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Makkabeerbok 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3eme. Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabaeorum 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Machabejcov 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Makkabeusok 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Mga Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Makabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Makkabeeen 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Wamakabayo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Makkabeusok III 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tatu Wamakabayo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Machabaeorum 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Makkabeerbok 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabaeorum 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Machabejcov 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Makkabeusok 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Mga Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3e. Makkabeeen 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3eme Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Makabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Makkabeeen 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Wamakabayo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabeaid 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Terza Maccabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Terzo Maccabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Wamakabayo III 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabaeorum 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Machabejcov 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Makkabeusok 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Mga Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Makabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Makkabeeen 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Wamakabayo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3e Makkabeeen 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3e. Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabeaid 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabeus 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Makabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Makkabeeen 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Wamakabayo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabeaid 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Makkabaer 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3a. Macabeus 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3e Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Macabeus 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Harmadik Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabeus 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabeaid 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Makkabaer 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabeus 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3a Macabeus 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Macabeus 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Makabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tredje Makk 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabeus 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Makabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Makabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Derde Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Makk 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Mac 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Treti Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Makabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Mac 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Makk 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Mac 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tatu Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Makk 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3e. Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Mac 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Mac 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Mach 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Mack 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Makk 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 makk 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Mac 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3e Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Mac 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Mcb 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Mch 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Mc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 M 1:1").osis()).toEqual("3Macc.1.1")
		`
		true
describe "Localized book 4Macc (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 4Macc (ascii)", ->
		`
		expect(p.parse("Czwarta Ksiega Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Czwarta Ksiegi Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Quarto libro dei Maccabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Kitabu cha Wamakabayo IV 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Stvrta kniha Machabejcov 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Czwarta Ks. Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Neljas makkabilaiskirja 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Czwarta Ks Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Ksiega Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Ksiegi Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Ksiega Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Ksiegi Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fjarde Mackabeerboken 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Ksiega Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Ksiegi Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Liber IV Maccabaeorum 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Liber Maccabaeorum IV 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Ksiega Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Ksiegi Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. makkabilaiskirja 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Quatriemes Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. makkabilaiskirja 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fjerde Makkabeerbok 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV makkabilaiskirja 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Ks. Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Ikaapat Mga Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Quatrieme Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 makkabilaiskirja 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Ks. Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Maccabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Ks. Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Ks Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Stvrta Machabejcov 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Ks. Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Ks Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Mackabeerboken 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Ctvrta Makabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Macabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Maccabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Maccabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Maccabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Ks Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Vierde Makkabeeen 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Ks Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Mackabeerboken 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 k. Machabejcov 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Maccabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Macabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Macabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Macabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Maccabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Maccabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Maccabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Machabaeorum 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Ikaapat Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Vierte Makkabaer 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 k Machabejcov 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Machabaeorum 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Makkabeerbok 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Maccabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Macabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Maccabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Maccabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Maccabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4eme. Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Maccabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Macabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Macabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Maccabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Machabaeorum 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabaeorum 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Machabejcov 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Makkabeusok 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Mga Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Ikaapat Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Machabaeorum IV 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Quarta Macabeus 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Quarta Maccabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Quarto Macabeus 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Quarto Maccabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Machabaeorum 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Makkabeerbok 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabaeorum 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Machabejcov 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Makkabeusok 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Mga Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Macabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Maccabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Maccabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Maccabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Macabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Macabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Macabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Maccabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Maccabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Maccabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4eme Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Maccabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Macabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Maccabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Maccabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Maccabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabaeorum 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Machabejcov 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Makkabeusok 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Mga Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Makabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Makkabeeen 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Wamakabayo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Makkabeusok IV 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Nne Wamakabayo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabaeorum 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Machabejcov 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Makkabeusok 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Mga Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Makabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Makkabeeen 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Wamakabayo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Macabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Macabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Macabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Maccabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Maccabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Maccabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Macabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Macabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Maccabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4e. Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Macabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Maccabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Maccabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Maccabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Macabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Macabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Macabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Maccabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Maccabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Maccabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Makabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Makkabeeen 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Wamakabayo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabeaid 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Wamakabayo IV 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Makabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Makkabeeen 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Wamakabayo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabeaid 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Makkabaer 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Macabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Macabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Maccabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4a. Macabeus 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4e Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Macabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Macabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Macabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Maccabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Maccabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Maccabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Macabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Macabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Macabeus 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Maccabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabeaid 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabeus 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabeaid 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Makkabaer 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabeus 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4a Macabeus 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Macabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Macabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Macabeus 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Maccabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fjerde Makk 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabeus 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabeus 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Ctvrta Mak 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Mac 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Makabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Vierde Mak 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Makabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Makabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Makabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Mac 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Makk 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Makk 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Mac 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Makk 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Mac 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Mak 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Nne Mak 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Mach 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Mack 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Makk 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 makk 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Mac 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Mak 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Mac 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Mak 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Mac 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Mak 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Mcb 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Mch 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Mc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 M 1:1").osis()).toEqual("4Macc.1.1")
		`
		true
describe "Localized book 1Macc (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Macc (ascii)", ->
		`
		expect(p.parse("Ensimmainen makkabilaiskirja 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwsza Ksiega Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwsza Ksiegi Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwsze Ksiega Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwsze Ksiegi Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwszy Ksiega Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwszy Ksiegi Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prva knjiga o Makabejcima 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwsza Ks. Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwsze Ks. Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwszy Ks. Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primo libro dei Maccabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Kitabu cha Wamakabayo I 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwsza Ks Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwsze Ks Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwszy Ks Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prva kniha Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Ksiega Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Ksiegi Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Forsta Mackabeerboken 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Ksiega Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Ksiegi Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prvy list Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Ksiega Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Ksiegi Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Ksiega Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Ksiegi Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Liber I Maccabaeorum 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Liber Maccabaeorum I 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. makkabilaiskirja 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. makkabilaiskirja 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Premieres Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 makkabilaiskirja 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Ks. Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Fyrsta Makkabeabok 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I makkabilaiskirja 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Ks. Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Premiere Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Premiers Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Ks. Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Ks Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Mackabeerboken 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Eerste Makkabeeen 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Ks. Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Ks Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Kwanza Wamakabayo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Premier Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primeira Macabeus 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primeiro Macabeus 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Unang Mga Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Ks Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Mackabeerboken 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 k. Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Elso Makkabeusok 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Ks Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prva Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prvni Makabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prvy Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 k Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Machabaeorum 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Makkabeerbok 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1ere. Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Erste Makkabaer 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Machabaeorum 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prva Makabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Una Mga Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Machabaeorum 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Makkabeerbok 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabaeorum 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Makkabeusok 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Mga Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1e. Makkabeeen 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1er. Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1ere Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1re. Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Machabaeorum 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabaeorum 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Makkabeusok 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Mga Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Machabaeorum I 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prima Maccabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primo Maccabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Unang Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabaeorum 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Makkabeusok 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Mga Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Makabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Makkabeeen 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Wamakabayo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1e Makkabeeen 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1er Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1re Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabaeorum 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Makkabeusok 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Mga Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Makabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Makkabeeen 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Wamakabayo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Makkabeusok I 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Unang Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Makabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Makkabeeen 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Wamakabayo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabeaid 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Makkabaer 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1a. Macabeus 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Macabeus 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Makabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Makkabeeen 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Wamakabayo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabeaid 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Una Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Wamakabayo I 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabeaid 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Makkabaer 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabeus 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1a Macabeus 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Macabeus 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabeaid 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabeus 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Una Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabeus 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Eerste Mak 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabeus 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Kwanza Mak 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Makabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Mac 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Makabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prvni Mak 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Makabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Mac 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Elso Mak 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Makabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Makk 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1e. Mak 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Mac 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Makk 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Mach 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Mack 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Makk 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 makk 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Mac 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Mak 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1e Mak 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Makk 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Mac 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Mak 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Mac 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Mak 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Mcb 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Mch 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Mac 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Mak 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Ma 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Mc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 M 1:1").osis()).toEqual("1Macc.1.1")
		`
		true
describe "Localized book Mark (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Mark (ascii)", ->
		`
		expect(p.parse("Mabuting Balita ayon kay San Marcos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mabuting Balita ayon kay San Markos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Saint Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Saint Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Saint Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Saint Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Saint Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St. Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mabuting Balita ayon kay Marcos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mabuting Balita ayon kay Markos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St. Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St. Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Saint Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St. Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St. Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Saint Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Saint Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Evankeliumi Markuksen mukaan 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Saint Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Saint Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St. Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St. Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St. Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ebanghelyo ayon kay Marcos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Evangelium secundum Marcum 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St. Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St. Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ebanghelyo ni San Marcos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ebanghelyo ni San Markos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Evangelie volgens Marcus 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Evangelie volgens Markus 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Saint Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Evangeliet etter Markus 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Saint Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Saint Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("El Evangelio de Marcos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Evangelium podle Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Evanjelium Podla Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ewangelia wg sw. Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Saint Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Saint Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St. Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ewangelia wg sw Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Jevanhelije vid Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Markuksen evankeliumi 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St. Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St. Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ebanghelyo ni Marcos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ebanghelyo ni Markos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Saint Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St. Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St. Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Vangelo di San Marco 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Evangelio de Marcos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Saint Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Saint Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Sulat ni San Marcos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Saint Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Saint Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St. Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Markovo evangelium 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St. Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St. Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Markus evangelium 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ungjilli i Markut 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St. Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St. Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Markusevangeliet 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Vangelo di Marco 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ewangelia Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Injili ya Marko 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marku Narceyti 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Injil Markus 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Saint Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("San Marcos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ew. Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Markuksen 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Saint Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Saint Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ew Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Saint Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Saint Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St. Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markusle 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marakus 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St. Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St. Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markane 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ew Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marcos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marcus 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Markos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Markus 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St. Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St. Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markus 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marco 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marcu 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marek 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marko 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marku 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mrcos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marc 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mrc 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mc 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mr 1:1").osis()).toEqual("Mark.1.1")
		p.include_apocrypha(false)
		expect(p.parse("MABUTING BALITA AYON KAY SAN MARCOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MABUTING BALITA AYON KAY SAN MARKOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MABUTING BALITA AYON KAY MARCOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MABUTING BALITA AYON KAY MARKOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EVANKELIUMI MARKUKSEN MUKAAN 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EBANGHELYO AYON KAY MARCOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EVANGELIUM SECUNDUM MARCUM 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EBANGHELYO NI SAN MARCOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EBANGHELYO NI SAN MARKOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EVANGELIE VOLGENS MARCUS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EVANGELIE VOLGENS MARKUS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EVANGELIET ETTER MARKUS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EL EVANGELIO DE MARCOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EVANGELIUM PODLE MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EVANJELIUM PODLA MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EWANGELIA WG SW. MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST. MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EWANGELIA WG SW MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("JEVANHELIJE VID MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKUKSEN EVANKELIUMI 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST. MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST. MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EBANGHELYO NI MARCOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EBANGHELYO NI MARKOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF SAINT MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST. MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST. MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("VANGELO DI SAN MARCO 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EVANGELIO DE MARCOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF SAINT MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF SAINT MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("SULAT NI SAN MARCOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF SAINT MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF SAINT MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST. MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKOVO EVANGELIUM 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST. MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST. MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKUS EVANGELIUM 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("UNGJILLI I MARKUT 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST. MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST. MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKUSEVANGELIET 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("VANGELO DI MARCO 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EWANGELIA MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("INJILI YA MARKO 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKU NARCEYTI 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("INJIL MARKUS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("SAINT MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("SAN MARCOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EW. MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKUKSEN 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("SAINT MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("SAINT MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EW MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("SAINT MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("SAINT MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST. MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKUSLE 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARAKUS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST. MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST. MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKANE 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EW MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARCOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARCUS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKUS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST. MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST. MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKUS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARCO 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARCU 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MAREK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKO 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKU 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MRCOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARC 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MRC 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MC 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MR 1:1").osis()).toEqual("Mark.1.1")
		`
		true
describe "Localized book Jas (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Jas (ascii)", ->
		`
		expect(p.parse("Poslannja apostola Jakova 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yakkopu Elutiya Nirupam 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakovljeva poslanica 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Lettera di Giacomo 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Waraka wa Yakobo 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Barua ya Yakobo 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Epistula Iacobi 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("List sw. Jakuba 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yakobacem patra 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jaakobin kirje 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakobs epistel 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Layang Yakobus 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("List sw Jakuba 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yakubko patra 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakobsbrevet 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakobusbrief 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakubov List 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("List Jakubuv 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakobs Brev 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakobs brev 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("List Jakuba 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakovljeva 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yakobacem 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jaakobin 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Santiago 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Giacomo 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jacques 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakobit 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakobus 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakubov 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yacquub 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yakkopu 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yakobus 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yakubko 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Iacobi 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jacobo 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakobi 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakobs 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakuba 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jaques 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yakobo 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yakoob 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Iacob 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Iacov 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakab 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakob 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakub 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("James 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Tiago 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Iago 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jaak 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jacq 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jame 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Sant 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yacq 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Iac 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Iag 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jac 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jak 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jam 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jas 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jms 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("San 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Stg 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yac 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yak 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Gc 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Gm 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Ja 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jk 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jm 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("St 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Tg 1:1").osis()).toEqual("Jas.1.1")
		p.include_apocrypha(false)
		expect(p.parse("POSLANNJA APOSTOLA JAKOVA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKKOPU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOVLJEVA POSLANICA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("LETTERA DI GIACOMO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("WARAKA WA YAKOBO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("BARUA YA YAKOBO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("EPISTULA IACOBI 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("LIST SW. JAKUBA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKOBACEM PATRA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAAKOBIN KIRJE 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOBS EPISTEL 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("LAYANG YAKOBUS 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("LIST SW JAKUBA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKUBKO PATRA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOBSBREVET 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOBUSBRIEF 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKUBOV LIST 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("LIST JAKUBUV 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOBS BREV 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOBS BREV 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("LIST JAKUBA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOVLJEVA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKOBACEM 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAAKOBIN 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("SANTIAGO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("GIACOMO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JACQUES 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOBIT 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOBUS 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKUBOV 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YACQUUB 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKKOPU 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKOBUS 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKUBKO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("IACOBI 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JACOBO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOBI 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOBS 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKUBA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAQUES 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKOBO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKOOB 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("IACOB 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("IACOV 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKAB 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOB 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKUB 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAMES 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("TIAGO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("IAGO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAAK 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JACQ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAME 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("SANT 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YACQ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("IAC 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("IAG 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAC 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAK 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAM 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAS 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JMS 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("SAN 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("STG 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAC 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAK 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("GC 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("GM 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JK 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JM 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ST 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("TG 1:1").osis()).toEqual("Jas.1.1")
		`
		true
describe "Localized book Amos (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Amos (ascii)", ->
		`
		expect(p.parse("Aamoksen kirja 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Prophetia Amos 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Ksiega Amosa 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Ksiegi Amosa 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Liv Amos la 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amos' Bog 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amos' bok 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amos’ Bog 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amos’ bok 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Ks. Amosa 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Aamoksen 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Ks Amosa 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Caamoos 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amosa 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amosi 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amosz 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amos 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Caam 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("amos 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Aam 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amo 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Ams 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Am 1:1").osis()).toEqual("Amos.1.1")
		p.include_apocrypha(false)
		expect(p.parse("AAMOKSEN KIRJA 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("PROPHETIA AMOS 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("KSIEGA AMOSA 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("KSIEGI AMOSA 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("LIV AMOS LA 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMOS' BOG 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMOS' BOK 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMOS’ BOG 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMOS’ BOK 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("KS. AMOSA 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AAMOKSEN 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("KS AMOSA 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("CAAMOOS 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMOSA 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMOSI 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMOSZ 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMOS 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("CAAM 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMOS 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AAM 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMO 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMS 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AM 1:1").osis()).toEqual("Amos.1.1")
		`
		true
describe "Localized book Tob (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Tob (ascii)", ->
		`
		expect(p.parse("Cartea lui Tobit 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Ksiega Tobiasza 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Ksiegi Tobiasza 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Ksiega Tobita 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Ksiegi Tobita 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobiaan kirja 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobitin kirja 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Ks. Tobiasza 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Liber Thobis 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Liber Tobiae 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobian kirja 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Ks Tobiasza 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobias' bok 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobias’ bok 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Ks. Tobita 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobits Bog 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobits bok 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Ks Tobita 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobitsbok 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobiaan 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobijas 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobiolo 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobitin 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobiae 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobian 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobias 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobija 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobiti 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobia 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobie 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobit 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobi 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobt 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tho 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tob 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tb 1:1").osis()).toEqual("Tob.1.1")
		`
		true
describe "Localized book Jdt (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Jdt (ascii)", ->
		`
		expect(p.parse("Kniha Juditina 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Juditin kirja 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Ksiega Judyty 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Ksiegi Judyty 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Liber Iudith 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("K. Juditina 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Kitab Yudit 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Juditarbok 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judits Bog 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judits bok 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("K Juditina 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Ks. Judyty 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Ks Judyty 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Giuditta 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Juditin 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Yudithi 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Iudita 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Iudith 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judita 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judite 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judith 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judyty 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Yudith 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Yuditi 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Jdith 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judit 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judth 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Yudit 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Jdit 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Jdth 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judt 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Yudt 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Gdt 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Idt 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Jdt 1:1").osis()).toEqual("Jdt.1.1")
		`
		true
describe "Localized book Bar (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Bar (ascii)", ->
		`
		expect(p.parse("Proroctvo Baruchovo 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Kniha Baruchova 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baarukin kirja 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Kniha Barukova 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Ksiega Barucha 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Ksiegi Barucha 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Barukin kirja 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Kitab Barukh 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Liber Baruch 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Ks. Barucha 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baruks Bog 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baruks bok 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Ks Barucha 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baruksbok 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baarukin 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Barucha 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Barukin 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baruque 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baruch 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Barukh 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baruku 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baruc 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baruh 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baruk 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Bar 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Ba 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Br 1:1").osis()).toEqual("Bar.1.1")
		`
		true
describe "Localized book 1Kgs, (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Kgs, (ascii)", ->
		`
		expect(p.parse("1. Ks 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Re 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Re 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks 1:1").osis()).toEqual("1Kgs.1.1")
		p.include_apocrypha(false)
		expect(p.parse("1. KS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. RE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KS 1:1").osis()).toEqual("1Kgs.1.1")
		`
		true
describe "Localized book 2Kgs, (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Kgs, (ascii)", ->
		`
		expect(p.parse("II. Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Re 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Re 1:1").osis()).toEqual("2Kgs.1.1")
		p.include_apocrypha(false)
		expect(p.parse("II. KS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. RE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RE 1:1").osis()).toEqual("2Kgs.1.1")
		`
		true
describe "Localized book Ezek,Ezra (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Ezek,Ezra (ascii)", ->
		`
		expect(p.parse("Ez 1:1").osis()).toEqual("Ezek.1.1")
		p.include_apocrypha(false)
		expect(p.parse("EZ 1:1").osis()).toEqual("Ezek.1.1")
		`
		true
describe "Localized book Hab,Hag (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Hab,Hag (ascii)", ->
		`
		expect(p.parse("Ha 1:1").osis()).toEqual("Hab.1.1")
		p.include_apocrypha(false)
		expect(p.parse("HA 1:1").osis()).toEqual("Hab.1.1")
		`
		true
describe "Localized book Heb,Hab (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Heb,Hab (ascii)", ->
		`
		expect(p.parse("Hb 1:1").osis()).toEqual("Heb.1.1")
		p.include_apocrypha(false)
		expect(p.parse("HB 1:1").osis()).toEqual("Heb.1.1")
		`
		true
describe "Localized book John, (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: John, (ascii)", ->
		`
		expect(p.parse("Jan 1:1").osis()).toEqual("John.1.1")
		p.include_apocrypha(false)
		expect(p.parse("JAN 1:1").osis()).toEqual("John.1.1")
		`
		true
describe "Localized book John,Jonah (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: John,Jonah (ascii)", ->
		`
		expect(p.parse("Yn 1:1").osis()).toEqual("John.1.1")
		p.include_apocrypha(false)
		expect(p.parse("YN 1:1").osis()).toEqual("John.1.1")
		`
		true
describe "Localized book John,Jonah,Job,Josh,Joel (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: John,Jonah,Job,Josh,Joel (ascii)", ->
		`
		expect(p.parse("Jo 1:1").osis()).toEqual("John.1.1")
		p.include_apocrypha(false)
		expect(p.parse("JO 1:1").osis()).toEqual("John.1.1")
		`
		true
describe "Localized book Jonah,Joel (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Jonah,Joel (ascii)", ->
		`
		expect(p.parse("Yoo 1:1").osis()).toEqual("Jonah.1.1")
		p.include_apocrypha(false)
		expect(p.parse("YOO 1:1").osis()).toEqual("Jonah.1.1")
		`
		true
describe "Localized book Jude,Judg (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Jude,Judg (ascii)", ->
		`
		expect(p.parse("Jud 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Jd 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Ju 1:1").osis()).toEqual("Jude.1.1")
		p.include_apocrypha(false)
		expect(p.parse("JUD 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JD 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JU 1:1").osis()).toEqual("Jude.1.1")
		`
		true
describe "Localized book Lam, (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Lam, (ascii)", ->
		`
		expect(p.parse("La 1:1").osis()).toEqual("Lam.1.1")
		p.include_apocrypha(false)
		expect(p.parse("LA 1:1").osis()).toEqual("Lam.1.1")
		`
		true
describe "Localized book Matt,Mark,Mal (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Matt,Mark,Mal (ascii)", ->
		`
		expect(p.parse("Ma 1:1").osis()).toEqual("Matt.1.1")
		p.include_apocrypha(false)
		expect(p.parse("MA 1:1").osis()).toEqual("Matt.1.1")
		`
		true
describe "Localized book Mic, (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Mic, (ascii)", ->
		`
		expect(p.parse("Mi 1:1").osis()).toEqual("Mic.1.1")
		p.include_apocrypha(false)
		expect(p.parse("MI 1:1").osis()).toEqual("Mic.1.1")
		`
		true
describe "Localized book Phil,Phlm (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Phil,Phlm (ascii)", ->
		`
		expect(p.parse("Phl 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Ph 1:1").osis()).toEqual("Phil.1.1")
		p.include_apocrypha(false)
		expect(p.parse("PHL 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PH 1:1").osis()).toEqual("Phil.1.1")
		`
		true
describe "Localized book Rev, (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Rev, (ascii)", ->
		`
		expect(p.parse("Re 1:1").osis()).toEqual("Rev.1.1")
		p.include_apocrypha(false)
		expect(p.parse("RE 1:1").osis()).toEqual("Rev.1.1")
		`
		true
describe "Localized book Song, (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Song, (ascii)", ->
		`
		expect(p.parse("Songs 1:1").osis()).toEqual("Song.1.1")
		p.include_apocrypha(false)
		expect(p.parse("SONGS 1:1").osis()).toEqual("Song.1.1")
		`
		true
describe "Localized book Zeph,Zech (ascii)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Zeph,Zech (ascii)", ->
		`
		expect(p.parse("Ze 1:1").osis()).toEqual("Zeph.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ZE 1:1").osis()).toEqual("Zeph.1.1")
		`
		true

describe "Miscellaneous tests", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore", book_sequence_strategy: "ignore", osis_compaction_strategy: "bc", captive_end_digits_strategy: "delete"
		p.include_apocrypha true

	it "should handle ranges (ascii)", ->
		expect(p.parse("Titus 1:1 through 2").osis()).toEqual "Titus.1.1-Titus.1.2"
		expect(p.parse("Matt 1through2").osis()).toEqual "Matt.1-Matt.2"
		expect(p.parse("Phlm 2 THROUGH 3").osis()).toEqual "Phlm.1.2-Phlm.1.3"
		expect(p.parse("Titus 1:1 thru 2").osis()).toEqual "Titus.1.1-Titus.1.2"
		expect(p.parse("Matt 1thru2").osis()).toEqual "Matt.1-Matt.2"
		expect(p.parse("Phlm 2 THRU 3").osis()).toEqual "Phlm.1.2-Phlm.1.3"
		expect(p.parse("Titus 1:1 to 2").osis()).toEqual "Titus.1.1-Titus.1.2"
		expect(p.parse("Matt 1to2").osis()).toEqual "Matt.1-Matt.2"
		expect(p.parse("Phlm 2 TO 3").osis()).toEqual "Phlm.1.2-Phlm.1.3"
	it "should handle chapters (ascii)", ->
		expect(p.parse("Titus 1:1, chapters 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPTERS 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chapter 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPTER 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chapts. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPTS. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chapts 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPTS 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chpts. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHPTS. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chpts 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHPTS 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chapt. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPT. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chapt 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPT 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chaps. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPS. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chaps 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPS 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chap. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAP. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chap 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAP 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chp. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHP. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chp 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHP 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chs. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHS. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chs 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHS 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, cha. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHA. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, cha 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHA 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, ch. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CH. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, ch 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CH 6").osis()).toEqual "Matt.3.4,Matt.6"
	it "should handle verses (ascii)", ->
		expect(p.parse("Exod 1:1 verses 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VERSES 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 verse 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VERSE 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 ver. 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VER. 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 ver 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VER 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 vss. 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VSS. 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 vss 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VSS 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 vs. 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VS. 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 vs 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VS 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 vv. 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VV. 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 vv 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VV 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 v. 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm V. 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 v 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm V 6").osis()).toEqual "Phlm.1.6"
	it "should handle 'and' (ascii)", ->
		expect(p.parse("Exod 1:1 and 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm 2 AND 6").osis()).toEqual "Phlm.1.2,Phlm.1.6"
		expect(p.parse("Exod 1:1 compare 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm 2 COMPARE 6").osis()).toEqual "Phlm.1.2,Phlm.1.6"
		expect(p.parse("Exod 1:1 cf. 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm 2 CF. 6").osis()).toEqual "Phlm.1.2,Phlm.1.6"
		expect(p.parse("Exod 1:1 cf 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm 2 CF 6").osis()).toEqual "Phlm.1.2,Phlm.1.6"
		expect(p.parse("Exod 1:1 see also 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm 2 SEE ALSO 6").osis()).toEqual "Phlm.1.2,Phlm.1.6"
		expect(p.parse("Exod 1:1 also 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm 2 ALSO 6").osis()).toEqual "Phlm.1.2,Phlm.1.6"
		expect(p.parse("Exod 1:1 see 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm 2 SEE 6").osis()).toEqual "Phlm.1.2,Phlm.1.6"
	it "should handle titles (ascii)", ->
		expect(p.parse("Ps 3 title, 4:2, 5:title").osis()).toEqual "Ps.3.1,Ps.4.2,Ps.5.1"
		expect(p.parse("PS 3 TITLE, 4:2, 5:TITLE").osis()).toEqual "Ps.3.1,Ps.4.2,Ps.5.1"
	it "should handle 'ff' (ascii)", ->
		expect(p.parse("Rev 3ff, 4:2ff").osis()).toEqual "Rev.3-Rev.22,Rev.4.2-Rev.4.11"
		expect(p.parse("REV 3 FF, 4:2 FF").osis()).toEqual "Rev.3-Rev.22,Rev.4.2-Rev.4.11"
		expect(p.parse("Rev 3f, 4:2f").osis()).toEqual "Rev.3-Rev.22,Rev.4.2-Rev.4.11"
		expect(p.parse("REV 3 F, 4:2 F").osis()).toEqual "Rev.3-Rev.22,Rev.4.2-Rev.4.11"
	it "should handle translations (ascii)", ->
		expect(p.parse("Lev 1 (AMP)").osis_and_translations()).toEqual [["Lev.1", "AMP"]]
		expect(p.parse("lev 1 amp").osis_and_translations()).toEqual [["Lev.1", "AMP"]]
		expect(p.parse("Lev 1 (ASV)").osis_and_translations()).toEqual [["Lev.1", "ASV"]]
		expect(p.parse("lev 1 asv").osis_and_translations()).toEqual [["Lev.1", "ASV"]]
		expect(p.parse("Lev 1 (CEB)").osis_and_translations()).toEqual [["Lev.1", "CEB"]]
		expect(p.parse("lev 1 ceb").osis_and_translations()).toEqual [["Lev.1", "CEB"]]
		expect(p.parse("Lev 1 (CEV)").osis_and_translations()).toEqual [["Lev.1", "CEV"]]
		expect(p.parse("lev 1 cev").osis_and_translations()).toEqual [["Lev.1", "CEV"]]
		expect(p.parse("Lev 1 (ERV)").osis_and_translations()).toEqual [["Lev.1", "ERV"]]
		expect(p.parse("lev 1 erv").osis_and_translations()).toEqual [["Lev.1", "ERV"]]
		expect(p.parse("Lev 1 (ESV)").osis_and_translations()).toEqual [["Lev.1", "ESV"]]
		expect(p.parse("lev 1 esv").osis_and_translations()).toEqual [["Lev.1", "ESV"]]
		expect(p.parse("Lev 1 (HCSB)").osis_and_translations()).toEqual [["Lev.1", "HCSB"]]
		expect(p.parse("lev 1 hcsb").osis_and_translations()).toEqual [["Lev.1", "HCSB"]]
		expect(p.parse("Lev 1 (KJV)").osis_and_translations()).toEqual [["Lev.1", "KJV"]]
		expect(p.parse("lev 1 kjv").osis_and_translations()).toEqual [["Lev.1", "KJV"]]
		expect(p.parse("Lev 1 (MSG)").osis_and_translations()).toEqual [["Lev.1", "MSG"]]
		expect(p.parse("lev 1 msg").osis_and_translations()).toEqual [["Lev.1", "MSG"]]
		expect(p.parse("Lev 1 (NAB)").osis_and_translations()).toEqual [["Lev.1", "NAB"]]
		expect(p.parse("lev 1 nab").osis_and_translations()).toEqual [["Lev.1", "NAB"]]
		expect(p.parse("Lev 1 (NABRE)").osis_and_translations()).toEqual [["Lev.1", "NABRE"]]
		expect(p.parse("lev 1 nabre").osis_and_translations()).toEqual [["Lev.1", "NABRE"]]
		expect(p.parse("Lev 1 (NAS)").osis_and_translations()).toEqual [["Lev.1", "NASB"]]
		expect(p.parse("lev 1 nas").osis_and_translations()).toEqual [["Lev.1", "NASB"]]
		expect(p.parse("Lev 1 (NASB)").osis_and_translations()).toEqual [["Lev.1", "NASB"]]
		expect(p.parse("lev 1 nasb").osis_and_translations()).toEqual [["Lev.1", "NASB"]]
		expect(p.parse("Lev 1 (NIRV)").osis_and_translations()).toEqual [["Lev.1", "NIRV"]]
		expect(p.parse("lev 1 nirv").osis_and_translations()).toEqual [["Lev.1", "NIRV"]]
		expect(p.parse("Lev 1 (NIV)").osis_and_translations()).toEqual [["Lev.1", "NIV"]]
		expect(p.parse("lev 1 niv").osis_and_translations()).toEqual [["Lev.1", "NIV"]]
		expect(p.parse("Lev 1 (NKJV)").osis_and_translations()).toEqual [["Lev.1", "NKJV"]]
		expect(p.parse("lev 1 nkjv").osis_and_translations()).toEqual [["Lev.1", "NKJV"]]
		expect(p.parse("Lev 1 (NLT)").osis_and_translations()).toEqual [["Lev.1", "NLT"]]
		expect(p.parse("lev 1 nlt").osis_and_translations()).toEqual [["Lev.1", "NLT"]]
		expect(p.parse("Lev 1 (NRSV)").osis_and_translations()).toEqual [["Lev.1", "NRSV"]]
		expect(p.parse("lev 1 nrsv").osis_and_translations()).toEqual [["Lev.1", "NRSV"]]
		expect(p.parse("Lev 1 (RSV)").osis_and_translations()).toEqual [["Lev.1", "RSV"]]
		expect(p.parse("lev 1 rsv").osis_and_translations()).toEqual [["Lev.1", "RSV"]]
		expect(p.parse("Lev 1 (TNIV)").osis_and_translations()).toEqual [["Lev.1", "TNIV"]]
		expect(p.parse("lev 1 tniv").osis_and_translations()).toEqual [["Lev.1", "TNIV"]]
	it "should handle boundaries (ascii)", ->
		p.set_options {book_alone_strategy: "full"}
		expect(p.parse("\u2014Matt\u2014").osis()).toEqual "Matt.1-Matt.28"
		expect(p.parse("\u201cMatt 1:1\u201d").osis()).toEqual "Matt.1.1"
