bcv_parser = require("../../js/en_bcv_parser.js").bcv_parser

describe "Parsing", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.options.osis_compaction_strategy = "b"
		p.options.sequence_combination_strategy = "combine"

	it "should round-trip OSIS references", ->
		p.set_options osis_compaction_strategy: "bc"
		books = ["Gen","Exod","Lev","Num","Deut","Josh","Judg","Ruth","1Sam","2Sam","1Kgs","2Kgs","1Chr","2Chr","Ezra","Neh","Esth","Job","Ps","Prov","Eccl","Song","Isa","Jer","Lam","Ezek","Dan","Hos","Joel","Amos","Obad","Jonah","Mic","Nah","Hab","Zeph","Hag","Zech","Mal","Matt","Mark","Luke","John","Acts","Rom","1Cor","2Cor","Gal","Eph","Phil","Col","1Thess","2Thess","1Tim","2Tim","Titus","Phlm","Heb","Jas","1Pet","2Pet","1John","2John","3John","Jude","Rev"]
		for book in books
			bc = book + ".1"
			bcv = bc + ".1"
			bcv_range = bcv + "-" + bc + ".2"
			expect(p.parse(bc).osis()).toEqual bc
			expect(p.parse(bcv).osis()).toEqual bcv
			expect(p.parse(bcv_range).osis()).toEqual bcv_range

	it "should round-trip OSIS Apocrypha references", ->
		p.set_options osis_compaction_strategy: "bc", ps151_strategy: "b"
		p.include_apocrypha true
		books = ["Tob","Jdt","GkEsth","Wis","Sir","Bar","PrAzar","Sus","Bel","SgThree","EpJer","1Macc","2Macc","3Macc","4Macc","1Esd","2Esd","PrMan","Ps151"]
		for book in books
			bc = book + ".1"
			bcv = bc + ".1"
			bcv_range = bcv + "-" + bc + ".2"
			expect(p.parse(bc).osis()).toEqual bc
			expect(p.parse(bcv).osis()).toEqual bcv
			expect(p.parse(bcv_range).osis()).toEqual bcv_range
		p.set_options ps151_strategy: "bc"
		expect(p.parse("Ps151.1").osis()).toEqual "Ps.151"
		expect(p.parse("Ps151.1.1").osis()).toEqual "Ps.151.1"
		expect(p.parse("Ps151.1-Ps151.2").osis()).toEqual "Ps.151.1-Ps.151.2"
		p.include_apocrypha false
		for book in books
			bc = book + ".1"
			expect(p.parse(bc).osis()).toEqual ""

	it "should handle a preceding character", ->
		expect(p.parse(" Gen 1").osis()).toEqual "Gen.1"
		expect(p.parse("Matt5John3").osis()).toEqual "Matt.5,John.3"
		expect(p.parse("1Ps 1").osis()).toEqual ""
		expect(p.parse("11Sam 1").osis()).toEqual ""

describe "Localized book Gen (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Gen (en)", ->
		`
		expect(p.parse("Genneeses 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneesus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneises 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneisis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneisus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gennieses 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genniesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genniesus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genniises 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genniisis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genniisus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneeses 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneesus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneises 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneisis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneisus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genieses 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geniesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geniesus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geniises 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geniisis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geniisus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneses 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gennesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gennesus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gennises 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gennisis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gennisus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneses 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genesus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genises 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genisis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genisus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gennsis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genese 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genesi 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gensis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gen 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Ge 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gn 1:1").osis()).toEqual("Gen.1.1")
		p.include_apocrypha(false)
		expect(p.parse("GENNEESES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNEESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNEESUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNEISES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNEISIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNEISUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNIESES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNIESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNIESUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNIISES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNIISIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNIISUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEESES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEESUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEISES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEISIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEISUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENIESES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENIESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENIESUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENIISES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENIISIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENIISUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNESES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNESUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNISES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNISIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNISUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENESES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENESUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENISES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENISIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENISUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNEIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNSIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENESE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENESI 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENSIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GN 1:1").osis()).toEqual("Gen.1.1")
		`
		true
describe "Localized book Exod (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Exod (en)", ->
		`
		expect(p.parse("Exodis 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exodus 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exode 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exods 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exod 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exd 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exo 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Ex 1:1").osis()).toEqual("Exod.1.1")
		p.include_apocrypha(false)
		expect(p.parse("EXODIS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXODUS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXODE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXODS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXOD 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXD 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXO 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EX 1:1").osis()).toEqual("Exod.1.1")
		`
		true
describe "Localized book Bel (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Bel (en)", ->
		`
		expect(p.parse("Bel and the Serpent 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel and the Dragon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel & the Serpent 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel and the Snake 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel & the Dragon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel & the Snake 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel and Serpent 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel and Dragon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel & Serpent 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel and Snake 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel & Dragon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel & Snake 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel 1:1").osis()).toEqual("Bel.1.1")
		`
		true
describe "Localized book Lev (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Lev (en)", ->
		`
		expect(p.parse("Levetecus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Leveticus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitecus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Leviticus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Livetecus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Liveticus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Livitecus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Liviticus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levetcus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitcus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Livetcus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Livitcus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levi 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lev 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Le 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lv 1:1").osis()).toEqual("Lev.1.1")
		p.include_apocrypha(false)
		expect(p.parse("LEVETECUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVETICUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITECUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITICUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LIVETECUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LIVETICUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LIVITECUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LIVITICUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVETCUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITCUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LIVETCUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LIVITCUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVI 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEV 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LV 1:1").osis()).toEqual("Lev.1.1")
		`
		true
describe "Localized book Num (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Num (en)", ->
		`
		expect(p.parse("Numbers 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Number 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Numb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Num 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Nm 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Nu 1:1").osis()).toEqual("Num.1.1")
		p.include_apocrypha(false)
		expect(p.parse("NUMBERS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUMBER 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUMB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUM 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NM 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NU 1:1").osis()).toEqual("Num.1.1")
		`
		true
describe "Localized book Sir (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Sir (en)", ->
		`
		expect(p.parse("The Wisdom of Jesus, Son of Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("The Wisdom of Jesus Son of Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("The Wisdom of Jesus ben Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Wisdom of Jesus, Son of Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Wisdom of Jesus Son of Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Wisdom of Jesus ben Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ecclesiasticus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ecclusiasticus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ben Sira 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ecclus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Eccs 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sir 1:1").osis()).toEqual("Sir.1.1")
		`
		true
describe "Localized book Wis (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Wis (en)", ->
		`
		expect(p.parse("The Wisdom of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("The Wisom of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("The Wisd of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("The Wis of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wisdom of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wisom of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wisd of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wis of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wisdom 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wisd 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wis 1:1").osis()).toEqual("Wis.1.1")
		`
		true
describe "Localized book Lam (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Lam (en)", ->
		`
		expect(p.parse("Lamentations 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamintations 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentation 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamintation 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lam 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("La 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lm 1:1").osis()).toEqual("Lam.1.1")
		p.include_apocrypha(false)
		expect(p.parse("LAMENTATIONS 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMINTATIONS 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTATION 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMINTATION 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAM 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LA 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LM 1:1").osis()).toEqual("Lam.1.1")
		`
		true
describe "Localized book EpJer (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: EpJer (en)", ->
		`
		expect(p.parse("The Epistle of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("The Letter of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("The Let. of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Epistle of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("The Ep. of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("The Let of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Letter of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("The Ep of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Epistle of Jeremy 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Let. of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep. of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Let of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep Jer 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("EpJer 1:1").osis()).toEqual("EpJer.1.1")
		`
		true
describe "Localized book Rev (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Rev (en)", ->
		`
		expect(p.parse("Revalations 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revelations 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revolations 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revalation 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revelation 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revlations 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revolation 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revlation 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revel 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Rev 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Re 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Rv 1:1").osis()).toEqual("Rev.1.1")
		p.include_apocrypha(false)
		expect(p.parse("REVALATIONS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVELATIONS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVOLATIONS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVALATION 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVELATION 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVLATIONS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVOLATION 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVLATION 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVEL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REV 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("RE 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("RV 1:1").osis()).toEqual("Rev.1.1")
		`
		true
describe "Localized book PrMan (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: PrMan (en)", ->
		`
		expect(p.parse("The Prayers of Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("The Prayer of Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("The Prayers Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Prayers of Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("The Prayer Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Prayer of Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("The Pr of Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Prayers Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Prayer Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("The Pr Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Pr of Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Pr Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Pr Man 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("PrMan 1:1").osis()).toEqual("PrMan.1.1")
		`
		true
describe "Localized book Deut (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Deut (en)", ->
		`
		expect(p.parse("Deeteronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deetoronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deutoronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Dueteronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duetoronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duuteronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duutoronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deeteronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deetoronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deetronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deutoronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deutronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Dueteronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duetoronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duetronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duuteronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duutoronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duutronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deetronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deutronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duetronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duutronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deut 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duet 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deu 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Dt 1:1").osis()).toEqual("Deut.1.1")
		p.include_apocrypha(false)
		expect(p.parse("DEETERONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEETORONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTORONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUETERONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUETORONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUUTERONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUUTORONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEETERONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEETORONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEETRONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTORONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTRONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUETERONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUETORONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUETRONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUUTERONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUUTORONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUUTRONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEETRONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTRONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUETRONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUUTRONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUT 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUET 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEU 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DT 1:1").osis()).toEqual("Deut.1.1")
		`
		true
describe "Localized book Josh (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Josh (en)", ->
		`
		expect(p.parse("Joushua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Joshua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jousua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josh 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jos 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jsh 1:1").osis()).toEqual("Josh.1.1")
		p.include_apocrypha(false)
		expect(p.parse("JOUSHUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSHUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOUSUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSH 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOS 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JSH 1:1").osis()).toEqual("Josh.1.1")
		`
		true
describe "Localized book Judg (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Judg (en)", ->
		`
		expect(p.parse("Judges 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jdgs 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Judg 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jdg 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jgs 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jg 1:1").osis()).toEqual("Judg.1.1")
		p.include_apocrypha(false)
		expect(p.parse("JUDGES 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JDGS 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUDG 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JDG 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JGS 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JG 1:1").osis()).toEqual("Judg.1.1")
		`
		true
describe "Localized book Ruth (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Ruth (en)", ->
		`
		expect(p.parse("Ruth 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Rth 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Rut 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Rt 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ru 1:1").osis()).toEqual("Ruth.1.1")
		p.include_apocrypha(false)
		expect(p.parse("RUTH 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RTH 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RU 1:1").osis()).toEqual("Ruth.1.1")
		`
		true
describe "Localized book 1Esd (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Esd (en)", ->
		`
		expect(p.parse("First Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1st. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1st Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("First Esdr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1st. Esdr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("First Esd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1st Esdr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1st. Esd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Esdr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1st Esd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Esdr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Esdr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Esd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Esdr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Esd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Esd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Esd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1Esd 1:1").osis()).toEqual("1Esd.1.1")
		`
		true
describe "Localized book 2Esd (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Esd (en)", ->
		`
		expect(p.parse("Second Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2nd. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Second Esdr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2nd Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Second Esd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2nd. Esdr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2nd Esdr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2nd. Esd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Esdr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Esdr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2nd Esd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Esdr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Esd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Esdr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Esd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Esd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Esd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2Esd 1:1").osis()).toEqual("2Esd.1.1")
		`
		true
describe "Localized book Isa (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Isa (en)", ->
		`
		expect(p.parse("Isaaaaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaaiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaiaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaiiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiaaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiaiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiiaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiiiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaaaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaaiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaiaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaiiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiaaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiaiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiiaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiiiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaaih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaiah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaiih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiaih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiiah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiiih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaisha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaaih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaiah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaiih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiaih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiiah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiiih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaish 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Issah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isai 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isa 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ia 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Is 1:1").osis()).toEqual("Isa.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ISAAAAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAAIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAIAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAIIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIAAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIAIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIIAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIIIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAAAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAAIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAIAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAIIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIAAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIAIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIIAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIIIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAAIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAIAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAIIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIAIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIIAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIIIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAISHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAAIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAIAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAIIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIAIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIIAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIIIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAISH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISSAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAI 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("IA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("IS 1:1").osis()).toEqual("Isa.1.1")
		`
		true
describe "Localized book 2Sam (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Sam (en)", ->
		`
		expect(p.parse("Second Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 S 1:1").osis()).toEqual("2Sam.1.1")
		p.include_apocrypha(false)
		expect(p.parse("SECOND KINGDOMS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SAMUALL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SAMUALS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SAMUELL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SAMUELS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. KINGDOMS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SAMUAL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND KINGDOMS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SAMUALL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SAMUALS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SAMUELL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SAMUELS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KINGDOMS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KINGDOMS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SAMUALL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SAMUALS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SAMUELL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SAMUELS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SAMUAL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KINGDOMS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUALL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUALS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUELL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUELS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KINGDOMS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUALL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUALS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SAMUAL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUALL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUALS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUELL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUELS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUAL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SMA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUALL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUALS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUAL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUAL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUAL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SMA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SMA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SMA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SMA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SMA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SMA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 S 1:1").osis()).toEqual("2Sam.1.1")
		`
		true
describe "Localized book 1Sam (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Sam (en)", ->
		`
		expect(p.parse("First Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 S 1:1").osis()).toEqual("1Sam.1.1")
		p.include_apocrypha(false)
		expect(p.parse("FIRST KINGDOMS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. KINGDOMS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST KINGDOMS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KINGDOMS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KINGDOMS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KINGDOMS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KINGDOMS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SMA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SMA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SMA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SMA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SMA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SMA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SMA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 S 1:1").osis()).toEqual("1Sam.1.1")
		`
		true
describe "Localized book 2Kgs (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Kgs (en)", ->
		`
		expect(p.parse("Fourth Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4th. Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4th Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 K 1:1").osis()).toEqual("2Kgs.1.1")
		p.include_apocrypha(false)
		expect(p.parse("FOURTH KINGDOMS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4TH. KINGDOMS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4TH KINGDOMS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KINGDOMS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KINGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KINGDOMS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KINGDOMS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KIGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KING 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KINS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KNGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KINGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KINGDOMS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KIG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KIN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KNS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KINGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KIGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KING 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KINS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KNGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KINGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KINGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KIGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KING 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KINS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KNGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KIG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KIN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KNS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KINGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KIGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KING 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KINS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KNGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KINGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KIGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KING 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KINS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KNGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KIG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KIN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KNS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KIGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KING 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KINS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KNGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KIG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KIN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KNS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KIGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KING 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KINS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KNGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KIG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KIN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KNS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KIG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KIN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KNS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KIG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KIN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KNS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 K 1:1").osis()).toEqual("2Kgs.1.1")
		`
		true
describe "Localized book 1Kgs (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Kgs (en)", ->
		`
		expect(p.parse("Third Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3rd. Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3rd Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Ks 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Ks 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Ks 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kin 1:1").osis()).toEqual("1Kgs.1.1")
		p.include_apocrypha(false)
		expect(p.parse("THIRD KINGDOMS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3RD. KINGDOMS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KINGDOMS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3RD KINGDOMS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KINGDOMS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KINGDOMS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KINGDOMS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KIGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KING 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KINS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KIGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KING 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KINS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KIG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KIN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KNS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KIGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KING 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KINS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KIG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KIN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KNS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KIGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KING 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KINS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KIG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KIN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KNS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KIGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KING 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KINS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KIGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KING 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KINS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KIG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KIN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KNS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KIGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KING 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KINS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KIG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KIN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KNS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KIG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KIN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KNS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KIG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KIN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KNS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("KIN 1:1").osis()).toEqual("1Kgs.1.1")
		`
		true
describe "Localized book 2Chr (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Chr (en)", ->
		`
		expect(p.parse("Second Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ch 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2Chr 1:1").osis()).toEqual("2Chr.1.1")
		p.include_apocrypha(false)
		expect(p.parse("SECOND PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRONICALS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRONICALS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRONICALS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRONICALS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRONICALS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRONICALS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRONICALS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CH 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2CHR 1:1").osis()).toEqual("2Chr.1.1")
		`
		true
describe "Localized book 1Chr (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Chr (en)", ->
		`
		expect(p.parse("First Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Choronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ch 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1Chr 1:1").osis()).toEqual("1Chr.1.1")
		p.include_apocrypha(false)
		expect(p.parse("FIRST PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CH 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1CHR 1:1").osis()).toEqual("1Chr.1.1")
		`
		true
describe "Localized book Ezra (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Ezra (en)", ->
		`
		expect(p.parse("Esra 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezra 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezr 1:1").osis()).toEqual("Ezra.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ESRA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZRA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZR 1:1").osis()).toEqual("Ezra.1.1")
		`
		true
describe "Localized book Neh (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Neh (en)", ->
		`
		expect(p.parse("Nehemaaah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemaaih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemaiah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemaiih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiaah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiaih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiiah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiiih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimaaah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimaaih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimaiah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimaiih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimiaah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimiaih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimiiah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimiiih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehamiah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemaah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemaih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimaah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimaih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimiah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimiih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehamia 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemia 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimia 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Neh 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Ne 1:1").osis()).toEqual("Neh.1.1")
		p.include_apocrypha(false)
		expect(p.parse("NEHEMAAAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMAAIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMAIAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMAIIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIAAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIAIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIIAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIIIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMAAAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMAAIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMAIAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMAIIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIAAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIAIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIIAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIIIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHAMIAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMAAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMAIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMAAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMAIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHAMIA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NE 1:1").osis()).toEqual("Neh.1.1")
		`
		true
describe "Localized book GkEsth (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: GkEsth (en)", ->
		`
		expect(p.parse("Esther (Greek) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Greek Esther 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Greek Esth 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Greek Est 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Gk Esth 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Gr Esth 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Gk Est 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("GkEsth 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Gr Est 1:1").osis()).toEqual("GkEsth.1.1")
		`
		true
describe "Localized book Esth (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Esth (en)", ->
		`
		expect(p.parse("Esther 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Ester 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esthr 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esth 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Est 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Es 1:1").osis()).toEqual("Esth.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ESTHER 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTER 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTHR 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTH 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("EST 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ES 1:1").osis()).toEqual("Esth.1.1")
		`
		true
describe "Localized book Job (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Job (en)", ->
		`
		expect(p.parse("Job 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jb 1:1").osis()).toEqual("Job.1.1")
		p.include_apocrypha(false)
		expect(p.parse("JOB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JB 1:1").osis()).toEqual("Job.1.1")
		`
		true
describe "Localized book Ps (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Ps (en)", ->
		`
		expect(p.parse("Plasmas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plsssss 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psaalms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalams 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psallms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmls 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psamlms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslalms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psmalms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Palsms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Paslms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pasmls 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plamas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plasma 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plasms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plsams 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plssss 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psaalm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psaams 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalam 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psallm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalma 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalml 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psamas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psamla 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psamlm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psamls 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psamms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslalm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslams 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslmas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psmalm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psmals 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Palls 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Palms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Palsm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pamls 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pamss 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Paslm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pasms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Passs 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plaas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plams 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plasm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plass 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plsam 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plsms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plsss 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psaaa 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psala 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psals 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psaml 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psamm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psams 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslam 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslmm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psmal 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psmls 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plaa 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plam 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plsa 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plsm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plss 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psal 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psam 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psla 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psma 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psml 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psmm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pssm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psa 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pss 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ps 1:1").osis()).toEqual("Ps.1.1")
		p.include_apocrypha(false)
		expect(p.parse("PLASMAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSSSSS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAALMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALAMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALLMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMLS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMLMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLALMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSMALMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PALSMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PASLMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PASMLS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLAMAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLASMA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLASMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSAMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSSSS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAALM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAAMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALAM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALLM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALML 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMLA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMLM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMLS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLALM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLAMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLMAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSMALM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSMALS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PALLS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PALMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PALSM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PAMLS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PAMSS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PASLM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PASMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PASSS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLAAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLAMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLASM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLASS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSAM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSSS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAAA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAML 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLAM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLMM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSMAL 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSMLS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLAA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLAM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAL 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSMA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSML 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSMM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSSM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PS 1:1").osis()).toEqual("Ps.1.1")
		`
		true
describe "Localized book PrAzar (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: PrAzar (en)", ->
		`
		expect(p.parse("The Prayers of Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("The Prayer of Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("The Prayers of Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("The Prayer of Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Prayers of Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Prayer of Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Prayers of Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("The Pr of Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Prayer of Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("The Pr of Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Pr of Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Pr of Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Pr Azar 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("PrAzar 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("PrAzr 1:1").osis()).toEqual("PrAzar.1.1")
		`
		true
describe "Localized book Prov (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Prov (en)", ->
		`
		expect(p.parse("Probverbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Oroverbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Porverbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Preverbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proberbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proverbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Poverbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Preverb 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Provebs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proverb 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prverbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prverb 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prvbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prov 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prvb 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Pro 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prv 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Pr 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Pv 1:1").osis()).toEqual("Prov.1.1")
		p.include_apocrypha(false)
		expect(p.parse("PROBVERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("OROVERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PORVERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PREVERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROBERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("POVERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PREVERB 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVEBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVERB 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRVERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRVERB 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRVBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROV 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRVB 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRO 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRV 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PR 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PV 1:1").osis()).toEqual("Prov.1.1")
		`
		true
describe "Localized book Eccl (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Eccl (en)", ->
		`
		expect(p.parse("Ecclesiaiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiaastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiaistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiasties 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiaiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiaates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaites 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiaste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiast 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiate 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesites 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiaste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Qoheleth 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eccles 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eccl 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecc 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecl 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Qoh 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ec 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Qo 1:1").osis()).toEqual("Eccl.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ECCLESIAIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIAASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIAISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIASTIES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIAIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIAATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAITES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIASTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIAST 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIATE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESITES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIASTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("QOHELETH 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCL 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECC 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECL 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("QOH 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EC 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("QO 1:1").osis()).toEqual("Eccl.1.1")
		`
		true
describe "Localized book SgThree (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: SgThree (en)", ->
		`
		expect(p.parse("The Song of the Three Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the Three Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of Three Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the 3 Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the Three Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the Three Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of Three Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the 3 Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the Three Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of 3 Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of Three Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the 3 Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the Three Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the Three Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of Three Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the 3 Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of 3 Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of Three Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the 3 Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of 3 Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the Three Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of Three Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the 3 Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of Three Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the 3 Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of 3 Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of 3 Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of Three Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the 3 Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of 3 Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of 3 Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Three. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Three. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Three Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Three. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of 3 Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Three Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Three. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Three Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Three Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Three. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Th. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Three. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Th. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Three Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Three. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of 3. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Th Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Th. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Three Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Three. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of 3. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Th Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Th. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Three Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of 3 Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of 3. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Th Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song Three 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Three Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of 3 Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of 3. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Th Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Th. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of 3 Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Sng Three 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Th. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of 3 Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. 3. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Th Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Th. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Sg Three 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S 3. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Th Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Th. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. 3 Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. 3. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Th Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("SgThree 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S 3 Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S 3. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Th Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. 3 Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Sg Thr 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S 3 Y 1:1").osis()).toEqual("SgThree.1.1")
		`
		true
describe "Localized book Song (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Song (en)", ->
		`
		expect(p.parse("The Songs of Salomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Salomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Solomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Solomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Salomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Salomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Solomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Solomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Saloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Salomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Soloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Solomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Saloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Salomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Soloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Solomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Songs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Salomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Salomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Solomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Solomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Songs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Song 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Salomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Salomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Solomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Solomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Saloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Salomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Soloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Solomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Song 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Saloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Salomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Soloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Solomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Songs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Songs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Song 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Song 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("S of S 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Sngs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Sgs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Sng 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SoS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Sol 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Son 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Sg 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("So 1:1").osis()).toEqual("Song.1.1")
		p.include_apocrypha(false)
		expect(p.parse("THE SONGS OF SALOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SALOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SOLOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SOLOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SALOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SALOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SOLOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SOLOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SALOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SALOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SOLOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SOLOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SALOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SALOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SOLOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SOLOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SONGS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SALOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SALOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SOLOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SOLOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SONGS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SONG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SALOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SALOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SOLOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SOLOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SALOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SALOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SOLOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SOLOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SONG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SALOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SALOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SOLOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SOLOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SONGS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SONGS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SONG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SONG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("S OF S 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SNGS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SGS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SNG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SOS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SOL 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SO 1:1").osis()).toEqual("Song.1.1")
		`
		true
describe "Localized book Jer (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Jer (en)", ->
		`
		expect(p.parse("Jeremaiah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeramaih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeramiah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeramiha 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeramiih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremaih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremiah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremiha 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremiih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jerimiah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jerimiih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeraiah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeramah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeramia 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeramih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremia 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremie 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jerimah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jerimih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jermiah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jermmah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremi 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jere 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jer 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Je 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jr 1:1").osis()).toEqual("Jer.1.1")
		p.include_apocrypha(false)
		expect(p.parse("JEREMAIAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAMAIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAMIAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAMIHA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAMIIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMAIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIHA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERIMIAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERIMIIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAIAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAMAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAMIA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAMIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIE 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERIMAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERIMIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERMIAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERMMAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMI 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERE 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JER 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JE 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JR 1:1").osis()).toEqual("Jer.1.1")
		`
		true
describe "Localized book Ezek (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Ezek (en)", ->
		`
		expect(p.parse("Exeekiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exeikiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exiekiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exiikiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeekiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeikiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziekiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziikiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exeekel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exeikel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exekiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exiekel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exiikel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exikiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeekel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeikel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezekial 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezekiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziekel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziikel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezikiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exekel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exikel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezekel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezikel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezek 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eze 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezk 1:1").osis()).toEqual("Ezek.1.1")
		p.include_apocrypha(false)
		expect(p.parse("EXEEKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXEIKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXIEKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXIIKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEEKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEIKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIEKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIIKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXEEKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXEIKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXEKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXIEKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXIIKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXIKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEEKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEIKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEKIAL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIEKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIIKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXEKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXIKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEK 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZE 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZK 1:1").osis()).toEqual("Ezek.1.1")
		`
		true
describe "Localized book Dan (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Dan (en)", ->
		`
		expect(p.parse("Danial 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Daniel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Dan 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Da 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Dl 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Dn 1:1").osis()).toEqual("Dan.1.1")
		p.include_apocrypha(false)
		expect(p.parse("DANIAL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DAN 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DA 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DN 1:1").osis()).toEqual("Dan.1.1")
		`
		true
describe "Localized book Hos (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Hos (en)", ->
		`
		expect(p.parse("Hosea 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hos 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ho 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hs 1:1").osis()).toEqual("Hos.1.1")
		p.include_apocrypha(false)
		expect(p.parse("HOSEA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HO 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HS 1:1").osis()).toEqual("Hos.1.1")
		`
		true
describe "Localized book Joel (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Joel (en)", ->
		`
		expect(p.parse("Joel 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joe 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Jl 1:1").osis()).toEqual("Joel.1.1")
		p.include_apocrypha(false)
		expect(p.parse("JOEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOE 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JL 1:1").osis()).toEqual("Joel.1.1")
		`
		true
describe "Localized book Amos (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Amos (en)", ->
		`
		expect(p.parse("Amos 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amo 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Ams 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Am 1:1").osis()).toEqual("Amos.1.1")
		p.include_apocrypha(false)
		expect(p.parse("AMOS 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMO 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMS 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AM 1:1").osis()).toEqual("Amos.1.1")
		`
		true
describe "Localized book Obad (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Obad (en)", ->
		`
		expect(p.parse("Obadiah 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadia 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obidah 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obad 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Oba 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obd 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Ob 1:1").osis()).toEqual("Obad.1.1")
		p.include_apocrypha(false)
		expect(p.parse("OBADIAH 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADIA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBIDAH 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBAD 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBD 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OB 1:1").osis()).toEqual("Obad.1.1")
		`
		true
describe "Localized book Jonah (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Jonah (en)", ->
		`
		expect(p.parse("Jonah 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jnh 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jon 1:1").osis()).toEqual("Jonah.1.1")
		p.include_apocrypha(false)
		expect(p.parse("JONAH 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JNH 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JON 1:1").osis()).toEqual("Jonah.1.1")
		`
		true
describe "Localized book Mic (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Mic (en)", ->
		`
		expect(p.parse("Michah 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Micah 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Micha 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mica 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mic 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mi 1:1").osis()).toEqual("Mic.1.1")
		p.include_apocrypha(false)
		expect(p.parse("MICHAH 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICAH 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIC 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MI 1:1").osis()).toEqual("Mic.1.1")
		`
		true
describe "Localized book Nah (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Nah (en)", ->
		`
		expect(p.parse("Nahum 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahu 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nah 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Na 1:1").osis()).toEqual("Nah.1.1")
		p.include_apocrypha(false)
		expect(p.parse("NAHUM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHU 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAH 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NA 1:1").osis()).toEqual("Nah.1.1")
		`
		true
describe "Localized book Hab (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Hab (en)", ->
		`
		expect(p.parse("Habbakkakk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakkukk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakkakk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakkukk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakakk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakkak 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakkuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakukk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakakk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakkak 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakkuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakukk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakak 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakak 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Hab 1:1").osis()).toEqual("Hab.1.1")
		p.include_apocrypha(false)
		expect(p.parse("HABBAKKAKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKKUKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKKAKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKKUKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKAKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKKAK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKUKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKAKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKKAK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKUKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKAK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKAK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HAB 1:1").osis()).toEqual("Hab.1.1")
		`
		true
describe "Localized book Zeph (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Zeph (en)", ->
		`
		expect(p.parse("Zephanaiah 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zaphaniah 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zephanaia 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zephaniah 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zafaniah 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zaphania 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zefaniah 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zephania 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zafania 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zefania 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zeph 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zep 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zph 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zp 1:1").osis()).toEqual("Zeph.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ZEPHANAIAH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZAPHANIAH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEPHANAIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEPHANIAH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZAFANIAH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZAPHANIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEFANIAH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEPHANIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZAFANIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEFANIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEPH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEP 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZPH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZP 1:1").osis()).toEqual("Zeph.1.1")
		`
		true
describe "Localized book Hag (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Hag (en)", ->
		`
		expect(p.parse("Haggiah 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggiai 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggai 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Hagai 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Hagg 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Hag 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Hgg 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Hg 1:1").osis()).toEqual("Hag.1.1")
		p.include_apocrypha(false)
		expect(p.parse("HAGGIAH 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGIAI 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGAI 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGAI 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGG 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAG 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HGG 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HG 1:1").osis()).toEqual("Hag.1.1")
		`
		true
describe "Localized book Zech (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Zech (en)", ->
		`
		expect(p.parse("Zacharaah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharaih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zachariah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zachariih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacheraah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacheraih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacheriah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacheriih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecharaah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecharaih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zechariah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zechariih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecheraah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecheraih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecheriah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecheriih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharia 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacherah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacheria 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacherih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zakariah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecharah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecharia 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecharih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecherah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecheria 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecherih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zekariah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zekaria 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zach 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zech 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zac 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zch 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zec 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zc 1:1").osis()).toEqual("Zech.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ZACHARAAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARAIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARIAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARIIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHERAAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHERAIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHERIAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHERIIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHARAAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHARAIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHARIAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHARIIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHERAAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHERAIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHERIAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHERIIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHERAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHERIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHERIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAKARIAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHARAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHARIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHARIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHERAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHERIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHERIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZEKARIAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZEKARIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAC 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZCH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZEC 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZC 1:1").osis()).toEqual("Zech.1.1")
		`
		true
describe "Localized book Mal (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Mal (en)", ->
		`
		expect(p.parse("Malachi 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malichi 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malach 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malaci 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Mal 1:1").osis()).toEqual("Mal.1.1")
		p.include_apocrypha(false)
		expect(p.parse("MALACHI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALICHI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALACH 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALACI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MAL 1:1").osis()).toEqual("Mal.1.1")
		`
		true
describe "Localized book Matt (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Matt (en)", ->
		`
		expect(p.parse("The Gospel according to Saint Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mtt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mt 1:1").osis()).toEqual("Matt.1.1")
		p.include_apocrypha(false)
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MTT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MT 1:1").osis()).toEqual("Matt.1.1")
		`
		true
describe "Localized book Mark (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Mark (en)", ->
		`
		expect(p.parse("The Gospel according to Saint Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Saint Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Saint Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Saint Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Saint Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St. Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St. Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St. Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Saint Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St. Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St. Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Saint Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Saint Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Saint Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Saint Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St. Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St. Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St. Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St. Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St. Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Saint Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Saint Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Saint Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Saint Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Saint Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St. Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St. Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St. Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Saint Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St. Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St. Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Saint Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Saint Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Saint Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Saint Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St. Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St. Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St. Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St. Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St. Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Saint Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Saint Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Saint Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Saint Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Saint Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St. Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St. Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St. Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St. Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St. Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mr 1:1").osis()).toEqual("Mark.1.1")
		p.include_apocrypha(false)
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST. MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST. MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST. MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF SAINT MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST. MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST. MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF SAINT MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF SAINT MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF SAINT MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF SAINT MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST. MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST. MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST. MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST. MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST. MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("SAINT MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("SAINT MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("SAINT MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("SAINT MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("SAINT MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST. MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST. MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST. MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST. MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST. MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MR 1:1").osis()).toEqual("Mark.1.1")
		`
		true
describe "Localized book Luke (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Luke (en)", ->
		`
		expect(p.parse("The Gospel according to Saint Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Saint Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Saint Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Saint Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St. Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St. Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Saint Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St. Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St. Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Saint Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Saint Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Saint Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St. Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St. Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St. Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St. Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Saint Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Saint Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Saint Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Saint Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St. Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St. Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Saint Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St. Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St. Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Saint Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Saint Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Saint Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St. Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St. Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St. Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St. Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Saint Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Saint Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Saint Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Saint Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St. Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St. Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St. Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St. Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lu 1:1").osis()).toEqual("Luke.1.1")
		p.include_apocrypha(false)
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF SAINT LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF SAINT LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF SAINT LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF SAINT LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST. LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST. LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF SAINT LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST. LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST. LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF SAINT LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF SAINT LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF SAINT LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST. LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST. LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST. LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST. LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("SAINT LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("SAINT LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("SAINT LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("SAINT LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST. LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST. LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST. LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST. LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LU 1:1").osis()).toEqual("Luke.1.1")
		`
		true
describe "Localized book 1John (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1John (en)", ->
		`
		expect(p.parse("First Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jo 1:1").osis()).toEqual("1John.1.1")
		p.include_apocrypha(false)
		expect(p.parse("FIRST JOPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JOPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JHHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JHON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JOHM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JONH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JOON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JOPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JHHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JHON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JOHM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JONH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JOON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JHHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JHON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JOHM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JONH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JOON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JHHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JHON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOHM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JONH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JHHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JHON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOHM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JONH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JHHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JHON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOHM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JONH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JHHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JHON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOHM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JONH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JO 1:1").osis()).toEqual("1John.1.1")
		`
		true
describe "Localized book 2John (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2John (en)", ->
		`
		expect(p.parse("Second Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jo 1:1").osis()).toEqual("2John.1.1")
		p.include_apocrypha(false)
		expect(p.parse("SECOND JOPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JHHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JHON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JOHM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JONH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JOON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JOPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JOPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JHHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JHON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JOHM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JONH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JOON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JHHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JHON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JOHM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JONH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JOON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JHHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JHON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOHM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JONH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JHHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JHON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOHM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JONH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JHHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JHON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOHM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JONH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JHHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JHON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOHM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JONH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JO 1:1").osis()).toEqual("2John.1.1")
		`
		true
describe "Localized book 3John (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 3John (en)", ->
		`
		expect(p.parse("Third Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jo 1:1").osis()).toEqual("3John.1.1")
		p.include_apocrypha(false)
		expect(p.parse("THIRD JOPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JOPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JHHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JHON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JOHM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JONH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JOON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JOPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JHHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JHON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JOHM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JONH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JOON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JHHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JHON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOHM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JONH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JHHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JHON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JOHM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JONH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JOON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JHHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JHON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOHM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JONH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JHHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JHON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOHM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JONH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JHHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JHON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOHM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JONH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JO 1:1").osis()).toEqual("3John.1.1")
		`
		true
describe "Localized book John (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: John (en)", ->
		`
		expect(p.parse("The Gospel according to Saint Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jn 1:1").osis()).toEqual("John.1.1")
		p.include_apocrypha(false)
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JN 1:1").osis()).toEqual("John.1.1")
		`
		true
describe "Localized book Acts (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Acts (en)", ->
		`
		expect(p.parse("The Acts of the Apostles 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Acts of the Apostles 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Actsss 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Actss 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Acts 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Act 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Ac 1:1").osis()).toEqual("Acts.1.1")
		p.include_apocrypha(false)
		expect(p.parse("THE ACTS OF THE APOSTLES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTS OF THE APOSTLES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTSSS 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTSS 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTS 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACT 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AC 1:1").osis()).toEqual("Acts.1.1")
		`
		true
describe "Localized book Rom (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Rom (en)", ->
		`
		expect(p.parse("Romands 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Roamns 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romans 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romasn 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rpmans 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Roman 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rmns 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Roms 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rmn 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rms 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rom 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Ros 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rm 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Ro 1:1").osis()).toEqual("Rom.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ROMANDS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROAMNS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMANS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMASN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RPMANS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMAN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RMNS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RMN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RMS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RO 1:1").osis()).toEqual("Rom.1.1")
		`
		true
describe "Localized book 2Cor (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Cor (en)", ->
		`
		expect(p.parse("Second Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2Cor 1:1").osis()).toEqual("2Cor.1.1")
		p.include_apocrypha(false)
		expect(p.parse("SECOND CORIINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CHORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CHORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CHORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORIINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINATHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINITHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIAANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIANAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIANOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHOIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNITHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORRINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORRINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORIINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CHORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CHORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CHORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORITHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORRITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORRITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORIINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CHORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CHORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CHORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORIINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINATHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINITHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIAANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIANAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIANOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHOIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNITHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORRINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORRINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORIINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORITHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORIINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CHORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CHORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CHORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORIINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINATHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINITHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIAANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIANAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIANOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHOIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNITHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORRINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORRINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CHORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CHORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CHORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORITHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORRITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORRITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORIINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CHORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CHORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CHORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORIINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINATHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINITHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIAANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIANAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIANOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHOIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNITHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORRINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORRINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORITHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORIINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CHORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CHORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CHORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORIINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINATHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINITHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIAANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIANAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIANOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHOIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNITHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORRINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORRINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CHORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CHORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CHORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORITHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORRITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORRITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORITHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CHORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CHORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CHORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORIINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINATHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINITHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIAANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIANAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIANOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHOIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNITHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORRINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORRINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CHORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CHORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CHORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORITHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORRITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORRITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CHORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CHORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CHORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORIINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINATHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINITHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIAANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIANAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIANOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHOIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNITHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORRINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORRINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CHORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CHORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CHORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORITHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORRITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORRITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORITHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORITHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CHORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CHORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CHORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORITHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORRITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORRITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORITHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CHORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CHORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CHORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORITHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORRITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORRITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORITHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORITHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORITHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORITHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORITHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORITHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORITHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORIN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORITHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORIN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORIN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORIN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORIN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORIN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORIN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2COR 1:1").osis()).toEqual("2Cor.1.1")
		`
		true
describe "Localized book 1Cor (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Cor (en)", ->
		`
		expect(p.parse("First Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Co 1:1").osis()).toEqual("1Cor.1.1")
		p.include_apocrypha(false)
		expect(p.parse("FIRST CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CO 1:1").osis()).toEqual("1Cor.1.1")
		`
		true
describe "Localized book Gal (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Gal (en)", ->
		`
		expect(p.parse("Galataians 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galataions 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatiaans 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatiains 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatianas 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatianis 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatiians 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatiions 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatinans 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatioans 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galationas 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galationns 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gallatians 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gallations 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galataans 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatains 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galataons 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatians 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatiins 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatinas 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galations 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatoans 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gallatins 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatans 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatian 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatias 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatins 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatios 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatons 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatas 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatns 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galat 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gala 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gal 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Ga 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gl 1:1").osis()).toEqual("Gal.1.1")
		p.include_apocrypha(false)
		expect(p.parse("GALATAIANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATAIONS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIAANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIAINS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIANAS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIANIS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIIANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIIONS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATINANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIOANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIONAS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIONNS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALLATIANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALLATIONS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATAANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATAINS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATAONS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIINS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATINAS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIONS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATOANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALLATINS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIAN 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIAS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATINS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIOS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATONS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATAS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATNS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALAT 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GAL 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GL 1:1").osis()).toEqual("Gal.1.1")
		`
		true
describe "Localized book Eph (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Eph (en)", ->
		`
		expect(p.parse("Epehesians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Esphesians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ehpesians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ehpisians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesains 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesiand 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesions 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephisians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Epesians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesain 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesian 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephisian 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephsians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephsian 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephes 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephe 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephs 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ehp 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Eph 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ep 1:1").osis()).toEqual("Eph.1.1")
		p.include_apocrypha(false)
		expect(p.parse("EPEHESIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ESPHESIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EHPESIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EHPISIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESAINS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESIAND 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESIONS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHISIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPESIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESAIN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESIAN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHISIAN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHSIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHSIAN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHES 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EHP 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPH 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EP 1:1").osis()).toEqual("Eph.1.1")
		`
		true
describe "Localized book Phil (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Phil (en)", ->
		`
		expect(p.parse("Phillippiains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippieans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippiians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipppians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philllipiians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philllippians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippaians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippiaans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippiains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippiians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipppians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipaians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipiaans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipiains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipieans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipiians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippeans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philllipians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philllppians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipaians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipiians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippeans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippiens 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipppian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipeans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipiens 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippean 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippins 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philllipian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philllpians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillppians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philppiians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpppians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipeans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipiens 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippean 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippins 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipain 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipean 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipins 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillpians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillpiens 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillppian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philppians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phlippians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipain 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipens 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipins 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippan 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippin 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipan 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillpans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillpian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpeans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philppian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phlipians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipan 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpins 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipp 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillip 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpan 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philip 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philli 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpp 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phlipp 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phili 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philp 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phlip 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phlpp 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phil 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phlp 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Php 1:1").osis()).toEqual("Phil.1.1")
		p.include_apocrypha(false)
		expect(p.parse("PHILLIPPIAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPIEANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPIIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLLIPIIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLLIPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPAIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIAANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPAIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPIAANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPIAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPIEANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPIIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPEANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLLIPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLLPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPAIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPIIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPEANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIENS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPEANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPIENS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPEAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLLIPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLLPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPPIIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPEANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPIENS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPEAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPAIN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPEAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLPIENS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLPPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHLIPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPAIN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPENS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLPANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPEANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHLIPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHLIPP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHLIP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHLPP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHIL 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHLP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHP 1:1").osis()).toEqual("Phil.1.1")
		`
		true
describe "Localized book Col (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Col (en)", ->
		`
		expect(p.parse("Callossians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calassians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calassions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Callasians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Callasions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Callosians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Callosions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calossians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calossions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colassians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colassions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Collasians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Collasions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Collosians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Collosions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colossians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colossions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calasians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calasions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calosians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calosions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colasians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colasions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colosians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colosions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colossans 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colossian 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Coloss 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Col 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Co 1:1").osis()).toEqual("Col.1.1")
		p.include_apocrypha(false)
		expect(p.parse("CALLOSSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALASSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALASSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALLASIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALLASIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALLOSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALLOSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALOSSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALOSSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLASSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLASSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLLASIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLLASIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLLOSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLLOSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALASIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALASIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALOSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALOSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLASIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLASIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSSANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSSIAN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COL 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CO 1:1").osis()).toEqual("Col.1.1")
		`
		true
describe "Localized book 2Thess (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Thess (en)", ->
		`
		expect(p.parse("Second Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Th 1:1").osis()).toEqual("2Thess.1.1")
		p.include_apocrypha(false)
		expect(p.parse("SECOND THESSALONICIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONAIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONCIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONIAANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONIIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONIOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONOIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONICIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESALONIIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONEANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONICIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONAIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONCIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONIAANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONIIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONIOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONOIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONICIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONAIN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONION 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSOLONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONICIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONAIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONCIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONIAANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONIIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONIOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONOIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESALONIIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONEANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONICIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONAIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONCIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIAANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONOIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONICIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONAIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONCIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIAANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONOIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESALONIIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONEANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONAIN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONION 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSOLONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONAIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONCIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIAANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONOIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALONIIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONEANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONAIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONCIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIAANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONOIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONIIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONEANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONAIN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONION 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSOLONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALONIIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONEANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONAIN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONION 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSOLONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONIIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONEANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONAIN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONION 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSOLONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONAIN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONION 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSOLONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONAIN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONION 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSOLONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THSSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THSSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THSSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THSSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND TH 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THSSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THSSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THSSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. TH 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND TH 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TH 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TH 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TH 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TH 1:1").osis()).toEqual("2Thess.1.1")
		`
		true
describe "Localized book 1Thess (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Thess (en)", ->
		`
		expect(p.parse("First Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Th 1:1").osis()).toEqual("1Thess.1.1")
		p.include_apocrypha(false)
		expect(p.parse("FIRST THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THSSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THSSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THSSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THSSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST TH 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THSSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THSSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. TH 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THSSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST TH 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TH 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TH 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TH 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TH 1:1").osis()).toEqual("1Thess.1.1")
		`
		true
describe "Localized book 2Tim (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Tim (en)", ->
		`
		expect(p.parse("Second Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2Tim 1:1").osis()).toEqual("2Tim.1.1")
		p.include_apocrypha(false)
		expect(p.parse("SECOND THIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND THIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND TIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND TOMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. THIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND TIMOTH 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND TIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND THIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. THIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. TIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. TOMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. THIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. THIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND THIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND TIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND TOMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. TIMOTH 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. TIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II THIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. THIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TOMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 THIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. THIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TOMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND TIMOTH 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND TIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II THIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TOMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTH 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 THIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TOMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTH 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTH 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND TI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTH 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. TI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND TI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2TIM 1:1").osis()).toEqual("2Tim.1.1")
		`
		true
describe "Localized book 1Tim (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Tim (en)", ->
		`
		expect(p.parse("First Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Tm 1:1").osis()).toEqual("1Tim.1.1")
		p.include_apocrypha(false)
		expect(p.parse("FIRST THIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. THIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST THIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST TOMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST THIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. THIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. TOMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST TIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. THIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST THIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST TOMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. TIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. THIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 THIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. THIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TOMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST TIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I THIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. THIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TOMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 THIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TOMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I THIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TOMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST TI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST TM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. TI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. TM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST TI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST TM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TM 1:1").osis()).toEqual("1Tim.1.1")
		`
		true
describe "Localized book Titus (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Titus (en)", ->
		`
		expect(p.parse("Titus 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tit 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Ti 1:1").osis()).toEqual("Titus.1.1")
		p.include_apocrypha(false)
		expect(p.parse("TITUS 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TIT 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TI 1:1").osis()).toEqual("Titus.1.1")
		`
		true
describe "Localized book Phlm (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Phlm (en)", ->
		`
		expect(p.parse("Philemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phlemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phlimon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Philem 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phile 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phlmn 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phlm 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phmn 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phm 1:1").osis()).toEqual("Phlm.1.1")
		p.include_apocrypha(false)
		expect(p.parse("PHILEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHLEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHLIMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHILEM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHILE 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHLMN 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHLM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHMN 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHM 1:1").osis()).toEqual("Phlm.1.1")
		`
		true
describe "Localized book Heb (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Heb (en)", ->
		`
		expect(p.parse("Heebrewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hewbrewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hwebrewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hwwbrewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heebrews 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hewbrews 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hwbrewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hwebrews 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hwwbrews 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hbrewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heberws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebewes 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebewrs 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrews 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrrws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrwes 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebwers 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebwres 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hwbrews 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hbrews 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebres 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrew 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrs 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heb 1:1").osis()).toEqual("Heb.1.1")
		p.include_apocrypha(false)
		expect(p.parse("HEEBREWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEWBREWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HWEBREWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HWWBREWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEEBREWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEWBREWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HWBREWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HWEBREWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HWWBREWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HBREWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBERWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEWES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEWRS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRRWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRWES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBWERS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBWRES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HWBREWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HBREWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREW 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEB 1:1").osis()).toEqual("Heb.1.1")
		`
		true
describe "Localized book Jas (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Jas (en)", ->
		`
		expect(p.parse("James 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jame 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jam 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jas 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jms 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Ja 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jm 1:1").osis()).toEqual("Jas.1.1")
		p.include_apocrypha(false)
		expect(p.parse("JAMES 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAME 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAM 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAS 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JMS 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JM 1:1").osis()).toEqual("Jas.1.1")
		`
		true
describe "Localized book 2Pet (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Pet (en)", ->
		`
		expect(p.parse("Second Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 P 1:1").osis()).toEqual("2Pet.1.1")
		p.include_apocrypha(false)
		expect(p.parse("SECOND PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PETE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PETE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PETE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 P 1:1").osis()).toEqual("2Pet.1.1")
		`
		true
describe "Localized book 1Pet (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Pet (en)", ->
		`
		expect(p.parse("First Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I P 1:1").osis()).toEqual("1Pet.1.1")
		p.include_apocrypha(false)
		expect(p.parse("FIRST PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PETE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PETE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PETE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I P 1:1").osis()).toEqual("1Pet.1.1")
		`
		true
describe "Localized book Jude (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Jude (en)", ->
		`
		expect(p.parse("Jude 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Jde 1:1").osis()).toEqual("Jude.1.1")
		p.include_apocrypha(false)
		expect(p.parse("JUDE 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JDE 1:1").osis()).toEqual("Jude.1.1")
		`
		true
describe "Localized book Tob (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Tob (en)", ->
		`
		expect(p.parse("Tobias 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobit 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobi 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobt 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tob 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tb 1:1").osis()).toEqual("Tob.1.1")
		`
		true
describe "Localized book Jdt (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Jdt (en)", ->
		`
		expect(p.parse("Judith 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Jdith 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judit 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judth 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Jdit 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Jdth 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judt 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Jdt 1:1").osis()).toEqual("Jdt.1.1")
		`
		true
describe "Localized book Bar (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Bar (en)", ->
		`
		expect(p.parse("Baruch 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Bar 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Br 1:1").osis()).toEqual("Bar.1.1")
		`
		true
describe "Localized book Sus (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Sus (en)", ->
		`
		expect(p.parse("Shoshana 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susannah 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susanna 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Sus 1:1").osis()).toEqual("Sus.1.1")
		`
		true
describe "Localized book 2Macc (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Macc (en)", ->
		`
		expect(p.parse("Second Macabbbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Mac 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Mac 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Mac 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Mac 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Mac 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Mac 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Mac 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Ma 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Mc 1:1").osis()).toEqual("2Macc.1.1")
		`
		true
describe "Localized book 3Macc (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 3Macc (en)", ->
		`
		expect(p.parse("Third Macabbbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Mac 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Mac 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Mac 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Mac 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Mac 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Mac 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Mac 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Mc 1:1").osis()).toEqual("3Macc.1.1")
		`
		true
describe "Localized book 4Macc (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 4Macc (en)", ->
		`
		expect(p.parse("Fourth Macabbbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Mac 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Mac 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Mac 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Mac 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Mac 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Mac 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Mac 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Mc 1:1").osis()).toEqual("4Macc.1.1")
		`
		true
describe "Localized book 1Macc (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Macc (en)", ->
		`
		expect(p.parse("First Macabbbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Mac 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Mac 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Mac 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Mac 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Mac 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Mac 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Mac 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Ma 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Mc 1:1").osis()).toEqual("1Macc.1.1")
		`
		true
describe "Localized book Ezek,Ezra (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Ezek,Ezra (en)", ->
		`
		expect(p.parse("Ez 1:1").osis()).toEqual("Ezek.1.1")
		p.include_apocrypha(false)
		expect(p.parse("EZ 1:1").osis()).toEqual("Ezek.1.1")
		`
		true
describe "Localized book Hab,Hag (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Hab,Hag (en)", ->
		`
		expect(p.parse("Ha 1:1").osis()).toEqual("Hab.1.1")
		p.include_apocrypha(false)
		expect(p.parse("HA 1:1").osis()).toEqual("Hab.1.1")
		`
		true
describe "Localized book Heb,Hab (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Heb,Hab (en)", ->
		`
		expect(p.parse("Hb 1:1").osis()).toEqual("Heb.1.1")
		p.include_apocrypha(false)
		expect(p.parse("HB 1:1").osis()).toEqual("Heb.1.1")
		`
		true
describe "Localized book John,Jonah,Job,Josh,Joel (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: John,Jonah,Job,Josh,Joel (en)", ->
		`
		expect(p.parse("Jo 1:1").osis()).toEqual("John.1.1")
		p.include_apocrypha(false)
		expect(p.parse("JO 1:1").osis()).toEqual("John.1.1")
		`
		true
describe "Localized book Jude,Judg (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Jude,Judg (en)", ->
		`
		expect(p.parse("Jud 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Jd 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Ju 1:1").osis()).toEqual("Jude.1.1")
		p.include_apocrypha(false)
		expect(p.parse("JUD 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JD 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JU 1:1").osis()).toEqual("Jude.1.1")
		`
		true
describe "Localized book Matt,Mark,Mal (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Matt,Mark,Mal (en)", ->
		`
		expect(p.parse("Ma 1:1").osis()).toEqual("Matt.1.1")
		p.include_apocrypha(false)
		expect(p.parse("MA 1:1").osis()).toEqual("Matt.1.1")
		`
		true
describe "Localized book Phil,Phlm (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Phil,Phlm (en)", ->
		`
		expect(p.parse("Ph 1:1").osis()).toEqual("Phil.1.1")
		p.include_apocrypha(false)
		expect(p.parse("PH 1:1").osis()).toEqual("Phil.1.1")
		`
		true
describe "Localized book Zeph,Zech (en)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Zeph,Zech (en)", ->
		`
		expect(p.parse("Ze 1:1").osis()).toEqual("Zeph.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ZE 1:1").osis()).toEqual("Zeph.1.1")
		`
		true

describe "Miscellaneous tests", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore", book_sequence_strategy: "ignore", osis_compaction_strategy: "bc", captive_end_digits_strategy: "delete"
		p.include_apocrypha true

	it "should handle ranges (en)", ->
		expect(p.parse("Titus 1:1 through 2").osis()).toEqual "Titus.1.1-Titus.1.2"
		expect(p.parse("Matt 1through2").osis()).toEqual "Matt.1-Matt.2"
		expect(p.parse("Phlm 2 THROUGH 3").osis()).toEqual "Phlm.1.2-Phlm.1.3"
		expect(p.parse("Titus 1:1 thru 2").osis()).toEqual "Titus.1.1-Titus.1.2"
		expect(p.parse("Matt 1thru2").osis()).toEqual "Matt.1-Matt.2"
		expect(p.parse("Phlm 2 THRU 3").osis()).toEqual "Phlm.1.2-Phlm.1.3"
		expect(p.parse("Titus 1:1 to 2").osis()).toEqual "Titus.1.1-Titus.1.2"
		expect(p.parse("Matt 1to2").osis()).toEqual "Matt.1-Matt.2"
		expect(p.parse("Phlm 2 TO 3").osis()).toEqual "Phlm.1.2-Phlm.1.3"
	it "should handle chapters (en)", ->
		expect(p.parse("Titus 1:1, chapters 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPTERS 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chapter 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPTER 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chapts. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPTS. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chapts 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPTS 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chpts. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHPTS. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chpts 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHPTS 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chapt. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPT. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chapt 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPT 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chaps. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPS. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chaps 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPS 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chap. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAP. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chap 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAP 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chp. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHP. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chp 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHP 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chs. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHS. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chs 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHS 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, cha. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHA. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, cha 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHA 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, ch. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CH. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, ch 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CH 6").osis()).toEqual "Matt.3.4,Matt.6"
	it "should handle verses (en)", ->
		expect(p.parse("Exod 1:1 verses 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VERSES 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 verse 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VERSE 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 ver. 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VER. 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 ver 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VER 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 vss. 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VSS. 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 vss 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VSS 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 vs. 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VS. 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 vs 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VS 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 vv. 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VV. 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 vv 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VV 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 v. 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm V. 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 v 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm V 6").osis()).toEqual "Phlm.1.6"
	it "should handle 'and' (en)", ->
		expect(p.parse("Exod 1:1 and 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm 2 AND 6").osis()).toEqual "Phlm.1.2,Phlm.1.6"
		expect(p.parse("Exod 1:1 compare 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm 2 COMPARE 6").osis()).toEqual "Phlm.1.2,Phlm.1.6"
		expect(p.parse("Exod 1:1 cf. 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm 2 CF. 6").osis()).toEqual "Phlm.1.2,Phlm.1.6"
		expect(p.parse("Exod 1:1 cf 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm 2 CF 6").osis()).toEqual "Phlm.1.2,Phlm.1.6"
		expect(p.parse("Exod 1:1 see also 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm 2 SEE ALSO 6").osis()).toEqual "Phlm.1.2,Phlm.1.6"
		expect(p.parse("Exod 1:1 also 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm 2 ALSO 6").osis()).toEqual "Phlm.1.2,Phlm.1.6"
		expect(p.parse("Exod 1:1 see 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm 2 SEE 6").osis()).toEqual "Phlm.1.2,Phlm.1.6"
	it "should handle titles (en)", ->
		expect(p.parse("Ps 3 title, 4:2, 5:title").osis()).toEqual "Ps.3.1,Ps.4.2,Ps.5.1"
		expect(p.parse("PS 3 TITLE, 4:2, 5:TITLE").osis()).toEqual "Ps.3.1,Ps.4.2,Ps.5.1"
	it "should handle 'ff' (en)", ->
		expect(p.parse("Rev 3ff, 4:2ff").osis()).toEqual "Rev.3-Rev.22,Rev.4.2-Rev.4.11"
		expect(p.parse("REV 3 FF, 4:2 FF").osis()).toEqual "Rev.3-Rev.22,Rev.4.2-Rev.4.11"
		expect(p.parse("Rev 3f, 4:2f").osis()).toEqual "Rev.3-Rev.22,Rev.4.2-Rev.4.11"
		expect(p.parse("REV 3 F, 4:2 F").osis()).toEqual "Rev.3-Rev.22,Rev.4.2-Rev.4.11"
	it "should handle translations (en)", ->
		expect(p.parse("Lev 1 (AMP)").osis_and_translations()).toEqual [["Lev.1", "AMP"]]
		expect(p.parse("lev 1 amp").osis_and_translations()).toEqual [["Lev.1", "AMP"]]
		expect(p.parse("Lev 1 (ASV)").osis_and_translations()).toEqual [["Lev.1", "ASV"]]
		expect(p.parse("lev 1 asv").osis_and_translations()).toEqual [["Lev.1", "ASV"]]
		expect(p.parse("Lev 1 (CEB)").osis_and_translations()).toEqual [["Lev.1", "CEB"]]
		expect(p.parse("lev 1 ceb").osis_and_translations()).toEqual [["Lev.1", "CEB"]]
		expect(p.parse("Lev 1 (CEV)").osis_and_translations()).toEqual [["Lev.1", "CEV"]]
		expect(p.parse("lev 1 cev").osis_and_translations()).toEqual [["Lev.1", "CEV"]]
		expect(p.parse("Lev 1 (ERV)").osis_and_translations()).toEqual [["Lev.1", "ERV"]]
		expect(p.parse("lev 1 erv").osis_and_translations()).toEqual [["Lev.1", "ERV"]]
		expect(p.parse("Lev 1 (ESV)").osis_and_translations()).toEqual [["Lev.1", "ESV"]]
		expect(p.parse("lev 1 esv").osis_and_translations()).toEqual [["Lev.1", "ESV"]]
		expect(p.parse("Lev 1 (HCSB)").osis_and_translations()).toEqual [["Lev.1", "HCSB"]]
		expect(p.parse("lev 1 hcsb").osis_and_translations()).toEqual [["Lev.1", "HCSB"]]
		expect(p.parse("Lev 1 (KJV)").osis_and_translations()).toEqual [["Lev.1", "KJV"]]
		expect(p.parse("lev 1 kjv").osis_and_translations()).toEqual [["Lev.1", "KJV"]]
		expect(p.parse("Lev 1 (MSG)").osis_and_translations()).toEqual [["Lev.1", "MSG"]]
		expect(p.parse("lev 1 msg").osis_and_translations()).toEqual [["Lev.1", "MSG"]]
		expect(p.parse("Lev 1 (NAB)").osis_and_translations()).toEqual [["Lev.1", "NAB"]]
		expect(p.parse("lev 1 nab").osis_and_translations()).toEqual [["Lev.1", "NAB"]]
		expect(p.parse("Lev 1 (NABRE)").osis_and_translations()).toEqual [["Lev.1", "NABRE"]]
		expect(p.parse("lev 1 nabre").osis_and_translations()).toEqual [["Lev.1", "NABRE"]]
		expect(p.parse("Lev 1 (NAS)").osis_and_translations()).toEqual [["Lev.1", "NASB"]]
		expect(p.parse("lev 1 nas").osis_and_translations()).toEqual [["Lev.1", "NASB"]]
		expect(p.parse("Lev 1 (NASB)").osis_and_translations()).toEqual [["Lev.1", "NASB"]]
		expect(p.parse("lev 1 nasb").osis_and_translations()).toEqual [["Lev.1", "NASB"]]
		expect(p.parse("Lev 1 (NIRV)").osis_and_translations()).toEqual [["Lev.1", "NIRV"]]
		expect(p.parse("lev 1 nirv").osis_and_translations()).toEqual [["Lev.1", "NIRV"]]
		expect(p.parse("Lev 1 (NIV)").osis_and_translations()).toEqual [["Lev.1", "NIV"]]
		expect(p.parse("lev 1 niv").osis_and_translations()).toEqual [["Lev.1", "NIV"]]
		expect(p.parse("Lev 1 (NKJV)").osis_and_translations()).toEqual [["Lev.1", "NKJV"]]
		expect(p.parse("lev 1 nkjv").osis_and_translations()).toEqual [["Lev.1", "NKJV"]]
		expect(p.parse("Lev 1 (NLT)").osis_and_translations()).toEqual [["Lev.1", "NLT"]]
		expect(p.parse("lev 1 nlt").osis_and_translations()).toEqual [["Lev.1", "NLT"]]
		expect(p.parse("Lev 1 (NRSV)").osis_and_translations()).toEqual [["Lev.1", "NRSV"]]
		expect(p.parse("lev 1 nrsv").osis_and_translations()).toEqual [["Lev.1", "NRSV"]]
		expect(p.parse("Lev 1 (RSV)").osis_and_translations()).toEqual [["Lev.1", "RSV"]]
		expect(p.parse("lev 1 rsv").osis_and_translations()).toEqual [["Lev.1", "RSV"]]
		expect(p.parse("Lev 1 (TNIV)").osis_and_translations()).toEqual [["Lev.1", "TNIV"]]
		expect(p.parse("lev 1 tniv").osis_and_translations()).toEqual [["Lev.1", "TNIV"]]
	it "should handle book ranges (en)", ->
		p.set_options {book_alone_strategy: "full", book_range_strategy: "include"}
		expect(p.parse("1st through 3rd  Jophn").osis()).toEqual "1John.1-3John.1"
		expect(p.parse("1st thru 3rd  Jophn").osis()).toEqual "1John.1-3John.1"
		expect(p.parse("1st to 3rd  Jophn").osis()).toEqual "1John.1-3John.1"
		expect(p.parse("1st through 3rd  Jphn").osis()).toEqual "1John.1-3John.1"
		expect(p.parse("1st thru 3rd  Jphn").osis()).toEqual "1John.1-3John.1"
		expect(p.parse("1st to 3rd  Jphn").osis()).toEqual "1John.1-3John.1"
	it "should handle boundaries (en)", ->
		p.set_options {book_alone_strategy: "full"}
		expect(p.parse("\u2014Matt\u2014").osis()).toEqual "Matt.1-Matt.28"
		expect(p.parse("\u201cMatt 1:1\u201d").osis()).toEqual "Matt.1.1"
