bcv_parser = require("../../js/full_bcv_parser.js").bcv_parser

describe "Parsing", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.options.osis_compaction_strategy = "b"
		p.options.sequence_combination_strategy = "combine"

	it "should round-trip OSIS references", ->
		p.set_options osis_compaction_strategy: "bc"
		books = ["Gen","Exod","Lev","Num","Deut","Josh","Judg","Ruth","1Sam","2Sam","1Kgs","2Kgs","1Chr","2Chr","Ezra","Neh","Esth","Job","Ps","Prov","Eccl","Song","Isa","Jer","Lam","Ezek","Dan","Hos","Joel","Amos","Obad","Jonah","Mic","Nah","Hab","Zeph","Hag","Zech","Mal","Matt","Mark","Luke","John","Acts","Rom","1Cor","2Cor","Gal","Eph","Phil","Col","1Thess","2Thess","1Tim","2Tim","Titus","Phlm","Heb","Jas","1Pet","2Pet","1John","2John","3John","Jude","Rev"]
		for book in books
			bc = book + ".1"
			bcv = bc + ".1"
			bcv_range = bcv + "-" + bc + ".2"
			expect(p.parse(bc).osis()).toEqual bc
			expect(p.parse(bcv).osis()).toEqual bcv
			expect(p.parse(bcv_range).osis()).toEqual bcv_range

	it "should round-trip OSIS Apocrypha references", ->
		p.set_options osis_compaction_strategy: "bc", ps151_strategy: "b"
		p.include_apocrypha true
		books = ["Tob","Jdt","GkEsth","Wis","Sir","Bar","PrAzar","Sus","Bel","SgThree","EpJer","1Macc","2Macc","3Macc","4Macc","1Esd","2Esd","PrMan","Ps151"]
		for book in books
			bc = book + ".1"
			bcv = bc + ".1"
			bcv_range = bcv + "-" + bc + ".2"
			expect(p.parse(bc).osis()).toEqual bc
			expect(p.parse(bcv).osis()).toEqual bcv
			expect(p.parse(bcv_range).osis()).toEqual bcv_range
		p.set_options ps151_strategy: "bc"
		expect(p.parse("Ps151.1").osis()).toEqual "Ps.151"
		expect(p.parse("Ps151.1.1").osis()).toEqual "Ps.151.1"
		expect(p.parse("Ps151.1-Ps151.2").osis()).toEqual "Ps.151.1-Ps.151.2"
		p.include_apocrypha false
		for book in books
			bc = book + ".1"
			expect(p.parse(bc).osis()).toEqual ""

	it "should handle a preceding character", ->
		expect(p.parse(" Gen 1").osis()).toEqual "Gen.1"
		expect(p.parse("Matt5John3").osis()).toEqual "Matt.5,John.3"
		expect(p.parse("1Ps 1").osis()).toEqual ""
		expect(p.parse("11Sam 1").osis()).toEqual ""

describe "Localized book Gen (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Gen (full)", ->
		`
		expect(p.parse("Ensimmainen Mooseksen kirja 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Ensimmäinen Mooseksen kirja 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Kitabu cha Kwanza cha Musa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ksiega Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ksiega Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ksiega Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ksiega Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ksiegi Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ksiegi Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ksiegi Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ksiegi Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Księga Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Księga Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Księga Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Księga Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Księgi Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Księgi Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Księgi Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Księgi Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ksiega Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ksiega Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ksiega Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ksiega Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ksiegi Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ksiegi Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ksiegi Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ksiegi Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Księga Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Księga Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Księga Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Księga Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Księgi Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Księgi Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Księgi Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Księgi Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ksiega Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ksiega Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ksiega Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ksiega Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ksiegi Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ksiegi Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ksiegi Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ksiegi Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Księga Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Księga Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Księga Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Księga Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Księgi Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Księgi Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Księgi Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Księgi Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ks. Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ks. Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ks. Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ks. Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ks. Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ks. Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ks. Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ks. Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ks. Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ks. Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ks. Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ks. Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ks Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ks Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ks Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Ks Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ks Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ks Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ks Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Ks Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ks Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ks Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ks Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Ks Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Ensimmainen Mooseksen 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Ensimmäinen Mooseksen 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvni kniha Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvni kniha Mojzišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvni kniha Mojzísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvni kniha Mojzíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvni kniha Mojžisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvni kniha Mojžišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvni kniha Mojžísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvni kniha Mojžíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("První kniha Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("První kniha Mojzišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("První kniha Mojzísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("První kniha Mojzíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("První kniha Mojžisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("První kniha Mojžišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("První kniha Mojžísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("První kniha Mojžíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-ше. книга Моисеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-ше. книга Мойсеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ksiega Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ksiega Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ksiega Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ksiega Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ksiegi Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ksiegi Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ksiegi Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ksiegi Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Księga Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Księga Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Księga Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Księga Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Księgi Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Księgi Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Księgi Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Księgi Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ksiega Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ksiega Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ksiega Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ksiega Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ksiegi Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ksiegi Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ksiegi Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ksiegi Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Księga Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Księga Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Księga Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Księga Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Księgi Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Księgi Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Księgi Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Księgi Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prva kniha Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prva kniha Mojzišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prva kniha Mojžisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prva kniha Mojžišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvá kniha Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvá kniha Mojzišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvá kniha Mojžisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvá kniha Mojžišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Перша книга Моисеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Перша книга Мойсеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Перше книга Моисеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Перше книга Мойсеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Първа книга Моисеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ksiega Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ksiega Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ksiega Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ksiega Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ksiegi Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ksiegi Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ksiegi Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ksiegi Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Księga Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Księga Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Księga Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Księga Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Księgi Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Księgi Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Księgi Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Księgi Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-а. книга Моисеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-а. книга Мойсеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-е. книга Моисеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-е. книга Мойсеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-ше книга Моисеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-ше книга Мойсеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ksiega Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ksiega Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ksiega Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ksiega Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ksiegi Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ksiegi Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ksiegi Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ksiegi Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Księga Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Księga Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Księga Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Księga Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Księgi Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Księgi Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Księgi Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Księgi Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvy list Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvy list Mojzišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvy list Mojžisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvy list Mojžišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvý list Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvý list Mojzišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvý list Mojžisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvý list Mojžišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Прва книга Мојсеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Прво книга Мојсеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-а книга Моисеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-а книга Мойсеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-е книга Моисеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-е книга Мойсеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mooseksen kirja 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. kniha Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. kniha Mojzišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. kniha Mojzísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. kniha Mojzíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. kniha Mojžisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. kniha Mojžišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. kniha Mojžísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. kniha Mojžíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mooseksen kirja 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. kniha Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. kniha Mojzišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. kniha Mojzísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. kniha Mojzíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. kniha Mojžisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. kniha Mojžišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. kniha Mojžísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. kniha Mojžíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mooseksen kirja 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 kniha Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 kniha Mojzišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 kniha Mojzísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 kniha Mojzíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 kniha Mojžisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 kniha Mojžišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 kniha Mojžísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 kniha Mojžíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ks. Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ks. Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ks. Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ks. Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. книга Моисеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. книга Мойсеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. книга Мојсеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mooseksen kirja 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I kniha Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I kniha Mojzišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I kniha Mojzísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I kniha Mojzíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I kniha Mojžisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I kniha Mojžišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I kniha Mojžísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I kniha Mojžíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ks. Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ks. Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ks. Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ks. Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. книга Моисеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. книга Мойсеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. книга Мојсеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("liv Konmansman an 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("उत्पत्तिको पुस्तक 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ks. Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ks. Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ks. Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ks. Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 книга Моисеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 книга Мойсеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 книга Мојсеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ks Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ks Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ks Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Ks Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Forsta Moseboken 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Första Moseboken 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ks. Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ks. Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ks. Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ks. Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I книга Моисеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I книга Мойсеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I книга Мојсеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ks Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ks Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ks Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Ks Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Purwaning Dumadi 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("utpattiko pustak 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ks Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ks Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ks Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Ks Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Erste Buch Mose 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Fyrsta bok Mose 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Fyrsta bok Móse 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Fyrsta bók Mose 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Fyrsta bók Móse 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ks Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ks Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ks Moyzeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Ks Moyżeszowe 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Kniha stvorenia 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Knjiga Postanka 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvni Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvni Mojzišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvni Mojzísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvni Mojzíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvni Mojžisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvni Mojžišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvni Mojžísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvni Mojžíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("První Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("První Mojzišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("První Mojzísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("První Mojzíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("První Mojžisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("První Mojžišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("První Mojžísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("První Mojžíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 k. Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 k. Mojzišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 k. Mojžisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 k. Mojžišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Forsta Mosebok 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Fyrsta Mosebok 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Fyrsta Mosebók 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Fyrsta Mósebok 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Fyrsta Mósebók 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Första Mosebok 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Første Mosebog 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Første Mosebok 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Ksiega Rodzaju 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Ksiegi Rodzaju 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Księga Rodzaju 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Księgi Rodzaju 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prva Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prva Mojzišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prva Mojžisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prva Mojžišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvy Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvy Mojzišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvy Mojžisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvy Mojžišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvá Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvá Mojzišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvá Mojžisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvá Mojžišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvý Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvý Mojzišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvý Mojžisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Prvý Mojžišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Прва Мојсијева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Първа Моисеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 k Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 k Mojzišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 k Mojžisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 k Mojžišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Liber Genesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Mojz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsza Mojż 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Mojz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwsze Mojż 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Mojz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Pierwszy Mojż 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Buch Mose 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mojzišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mojzísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mojzíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mojžisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mojžišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mojžísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mojžíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mooseksen 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Moseboken 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Мојсијева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Eerste Mozes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mojzeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mojżeszowa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mojzišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mojzísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mojzíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mojžisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mojžišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mojžísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mojžíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mooseksen 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Мојсијева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("K. stvorenia 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Kniha povodu 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Kniha pôvodu 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Buch Mose 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mojzišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mojzísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mojzíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mojžisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mojžišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mojžísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mojžíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mooseksen 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Moseboken 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Мојсијева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Моисеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mojzisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mojzišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mojzísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mojzíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mojžisova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mojžišova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mojžísova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mojžíšova 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mooseksen 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Мојсијева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Моисеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("K stvorenia 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Ks. Rodzaju 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Sáng thế ký 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Книга Бытия 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Настанување 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("سفر التكوين 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("தொடக்க நூல் 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Моисеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mosebog 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mosebok 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mosebók 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mósebok 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mósebók 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Atiyakamam 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Atiyākamam 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Elso Mozes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Elso Mózes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Első Mozes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Első Mózes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Erste Mose 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Første Mos 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Моисеева 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mosebok 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mosebók 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mósebok 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mósebók 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Konmansman 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Ks Rodzaju 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Ātiyakamam 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Ātiyākamam 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("उत्पत्तिको 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mosebog 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mosebok 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mosebók 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mósebok 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mósebók 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1e. Mozes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Beresjiet 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneeses 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneesus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneises 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneisis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneisus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gennieses 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genniesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genniesus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genniises 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genniisis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genniisus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mosebok 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mosebók 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mósebok 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mósebók 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("K. povodu 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("K. pôvodu 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Zanafilla 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("utpattiko 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Прва Мојс 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ଆଦିପୁସ୍ତକ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ஆதியாகமம் 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mozes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mózes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1e Mozes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Bilowgii 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneeses 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneesus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneises 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneisis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneisus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genieses 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geniesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geniesus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geniises 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geniisis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geniisus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneses 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gennesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gennesus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gennises 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gennisis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gennisus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mozes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mózes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("K povodu 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("K pôvodu 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Postanak 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Sáng Thế 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Teremtes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Teremtés 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("उत्पत्ति 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mozes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mózes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mojz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mojż 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mose 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Мојс 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Facerea 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneses 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genesus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genezis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genises 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genisis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genisus 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genneis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gennsis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Génesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gênesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Henesis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mozes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mózes 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mojz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mojż 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Мојс 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Mozes I 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Mózes I 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Utpaati 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("pīdāyiš 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("utpatti 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Γένεσις 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Γενεσις 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Постање 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("التكوين 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("پَیدایش 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("उत्पाति 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mojz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mojż 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Moos 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mose 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Мојс 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mos 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mós 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Buttja 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genesa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genese 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genesi 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Geneza 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gensis 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Genèse 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mojz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mojż 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Мојс 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mos 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. Mós 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Mwanzo 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Γένεση 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Γενεση 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Начало 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("בראשית 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("پيدائش 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("پیدائش 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("پیدایش 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("उत्पति 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ปฐมกาล 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Moj 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mos 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Moz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mós 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Móz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. Mo 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Moj 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mos 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I Mós 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Jenez 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Jenèz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("utpat 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Битие 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Буття 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Бытие 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("בריאה 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("《创世记》 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("《創世紀》 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("《創世記》 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ﺗﻜﻮﻳﻦ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mo 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 Mz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1Mós 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Post 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Rodz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Sáng 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Пост 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ਉਤਪਤ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("தொநூ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("《创世记 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("《創世紀 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("《創世記 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("创世记》 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("創世紀》 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("創世記》 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 М 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gen 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gén 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gên 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Jen 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Mwa 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Rdz 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Ter 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Zan 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Γέν 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Γεν 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Бит 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Буг 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Бут 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Быт 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Нач 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ଆଦି 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ஆதி 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ปฐก 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("《创》 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("《創》 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("创世记 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("創世紀 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("創世記 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("창세기 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Ge 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gn 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Gé 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("Γε 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("تك 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("《创 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("《創 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("创》 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("創》 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("창세 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("创 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("創 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("창 1:1").osis()).toEqual("Gen.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ENSIMMAINEN MOOSEKSEN KIRJA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ENSIMMÄINEN MOOSEKSEN KIRJA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("KITABU CHA KWANZA CHA MUSA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KSIEGA MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KSIEGA MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KSIEGI MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KSIEGI MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KSIĘGA MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KSIĘGA MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KSIĘGI MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KSIĘGI MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KSIEGA MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KSIEGA MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KSIEGI MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KSIEGI MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KSIĘGA MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KSIĘGA MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KSIĘGI MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KSIĘGI MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KSIEGA MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KSIEGA MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KSIEGI MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KSIEGI MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KSIĘGA MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KSIĘGA MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KSIĘGI MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KSIĘGI MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KS. MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KS. MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KS. MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KS. MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KS. MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KS. MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KS. MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KS. MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KS. MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KS. MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KS. MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KS. MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KS MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KS MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KS MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA KS MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KS MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KS MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KS MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE KS MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KS MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KS MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KS MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY KS MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ENSIMMAINEN MOOSEKSEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ENSIMMÄINEN MOOSEKSEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNI KNIHA MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNI KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNI KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNI KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNI KNIHA MOJŽISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNI KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNI KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNI KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNÍ KNIHA MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNÍ KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNÍ KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNÍ KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNÍ KNIHA MOJŽISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNÍ KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNÍ KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNÍ KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-ШЕ. КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-ШЕ. КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KSIEGA MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KSIEGA MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KSIEGI MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KSIEGI MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KSIĘGA MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KSIĘGA MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KSIĘGI MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KSIĘGI MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KSIEGA MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KSIEGA MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KSIEGI MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KSIEGI MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KSIĘGA MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KSIĘGA MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KSIĘGI MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KSIĘGI MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVA KNIHA MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVA KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVA KNIHA MOJŽISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVA KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVÁ KNIHA MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVÁ KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVÁ KNIHA MOJŽISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVÁ KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ПЕРША КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ПЕРША КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ПЕРШЕ КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ПЕРШЕ КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ПЪРВА КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KSIEGA MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KSIEGA MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KSIEGI MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KSIEGI MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KSIĘGA MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KSIĘGA MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KSIĘGI MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KSIĘGI MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-А. КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-А. КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-Е. КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-Е. КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-ШЕ КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-ШЕ КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KSIEGA MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KSIEGA MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KSIEGI MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KSIEGI MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KSIĘGA MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KSIĘGA MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KSIĘGI MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KSIĘGI MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVY LIST MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVY LIST MOJZIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVY LIST MOJŽISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVY LIST MOJŽIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVÝ LIST MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVÝ LIST MOJZIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVÝ LIST MOJŽISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVÝ LIST MOJŽIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ПРВА КНИГА МОЈСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ПРВО КНИГА МОЈСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-А КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-А КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-Е КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1-Е КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOOSEKSEN KIRJA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KNIHA MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KNIHA MOJŽISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOOSEKSEN KIRJA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KNIHA MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KNIHA MOJŽISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOOSEKSEN KIRJA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KNIHA MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KNIHA MOJŽISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KS. MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KS. MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KS. MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KS. MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. КНИГА МОЈСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOOSEKSEN KIRJA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KNIHA MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KNIHA MOJŽISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KS. MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KS. MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KS. MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KS. MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. КНИГА МОЈСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("LIV KONMANSMAN AN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("उत्पत्तिको पुस्तक 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KS. MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KS. MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KS. MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KS. MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 КНИГА МОЈСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KS MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KS MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KS MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. KS MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("FORSTA MOSEBOKEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("FÖRSTA MOSEBOKEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KS. MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KS. MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KS. MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KS. MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I КНИГА МОЈСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KS MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KS MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KS MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. KS MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PURWANING DUMADI 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("UTPATTIKO PUSTAK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KS MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KS MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KS MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 KS MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ERSTE BUCH MOSE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("FYRSTA BOK MOSE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("FYRSTA BOK MÓSE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("FYRSTA BÓK MOSE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("FYRSTA BÓK MÓSE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KS MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KS MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KS MOYZESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I KS MOYŻESZOWE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("KNIHA STVORENIA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("KNJIGA POSTANKA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNI MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNI MOJZIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNI MOJZÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNI MOJZÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNI MOJŽISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNI MOJŽIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNI MOJŽÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNI MOJŽÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNÍ MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNÍ MOJZIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNÍ MOJZÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNÍ MOJZÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNÍ MOJŽISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNÍ MOJŽIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNÍ MOJŽÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVNÍ MOJŽÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 K. MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 K. MOJZIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 K. MOJŽISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 K. MOJŽIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("FORSTA MOSEBOK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("FYRSTA MOSEBOK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("FYRSTA MOSEBÓK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("FYRSTA MÓSEBOK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("FYRSTA MÓSEBÓK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("FÖRSTA MOSEBOK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("FØRSTE MOSEBOG 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("FØRSTE MOSEBOK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("KSIEGA RODZAJU 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("KSIEGI RODZAJU 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("KSIĘGA RODZAJU 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("KSIĘGI RODZAJU 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVA MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVA MOJZIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVA MOJŽISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVA MOJŽIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVY MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVY MOJZIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVY MOJŽISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVY MOJŽIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVÁ MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVÁ MOJZIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVÁ MOJŽISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVÁ MOJŽIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVÝ MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVÝ MOJZIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVÝ MOJŽISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PRVÝ MOJŽIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ПРВА МОЈСИЈЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ПЪРВА МОИСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 K MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 K MOJZIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 K MOJŽISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 K MOJŽIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("LIBER GENESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA MOJZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZA MOJŻ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE MOJZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZE MOJŻ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY MOJZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PIERWSZY MOJŻ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. BUCH MOSE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOJZIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOJZÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOJZÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOJŽISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOJŽIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOJŽÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOJŽÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOOSEKSEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOSEBOKEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. МОЈСИЈЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("EERSTE MOZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOJZESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOJŻESZOWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOJZIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOJZÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOJZÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOJŽISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOJŽIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOJŽÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOJŽÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOOSEKSEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. МОЈСИЈЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("K. STVORENIA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("KNIHA POVODU 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("KNIHA PÔVODU 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 BUCH MOSE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOJZIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOJZÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOJZÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOJŽISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOJŽIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOJŽÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOJŽÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOOSEKSEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOSEBOKEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 МОЈСИЈЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. МОИСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOJZISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOJZIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOJZÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOJZÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOJŽISOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOJŽIŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOJŽÍSOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOJŽÍŠOVA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOOSEKSEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I МОЈСИЈЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. МОИСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("K STVORENIA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("KS. RODZAJU 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("SÁNG THẾ KÝ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("КНИГА БЫТИЯ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("НАСТАНУВАЊЕ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("سفر التكوين 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("தொடக்க நூல் 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 МОИСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOSEBOG 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOSEBOK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOSEBÓK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MÓSEBOK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MÓSEBÓK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ATIYAKAMAM 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ATIYĀKAMAM 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ELSO MOZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ELSO MÓZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ELSŐ MOZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ELSŐ MÓZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ERSTE MOSE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("FØRSTE MOS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I МОИСЕЕВА 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOSEBOK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOSEBÓK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MÓSEBOK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MÓSEBÓK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("KONMANSMAN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("KS RODZAJU 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ĀTIYAKAMAM 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ĀTIYĀKAMAM 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("उत्पत्तिको 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOSEBOG 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOSEBOK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOSEBÓK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MÓSEBOK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MÓSEBÓK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1E. MOZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("BERESJIET 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNEESES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNEESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNEESUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNEISES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNEISIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNEISUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNIESES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNIESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNIESUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNIISES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNIISIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNIISUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOSEBOK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOSEBÓK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MÓSEBOK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MÓSEBÓK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("K. POVODU 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("K. PÔVODU 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ZANAFILLA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("UTPATTIKO 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ПРВА МОЈС 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ଆଦିପୁସ୍ତକ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ஆதியாகமம் 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MÓZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1E MOZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("BILOWGII 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEESES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEESUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEISES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEISIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEISUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENIESES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENIESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENIESUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENIISES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENIISIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENIISUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNESES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNESUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNISES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNISIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNISUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MÓZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("K POVODU 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("K PÔVODU 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("POSTANAK 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("SÁNG THẾ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("TEREMTES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("TEREMTÉS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("उत्पत्ति 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MÓZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOJZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOJŻ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOSE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. МОЈС 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("FACEREA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENESES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENESUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEZIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENISES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENISIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENISUS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNEIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENNSIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GÉNESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GÊNESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("HENESIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MÓZES 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOJZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOJŻ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. МОЈС 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("MOZES I 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("MÓZES I 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("UTPAATI 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("PĪDĀYIŠ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("UTPATTI 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ΓΈΝΕΣΙΣ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ΓΕΝΕΣΙΣ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ПОСТАЊЕ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("التكوين 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("پَیدایش 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("उत्पाति 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOJZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOJŻ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOOS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOSE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 МОЈС 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MOS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MÓS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("BUTTJA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENESA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENESE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENESI 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENEZA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENSIS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GENÈSE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOJZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOJŻ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I МОЈС 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MOS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I. MÓS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("MWANZO 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ΓΈΝΕΣΗ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ΓΕΝΕΣΗ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("НАЧАЛО 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("בראשית 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("پيدائش 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("پیدائش 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("پیدایش 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("उत्पति 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ปฐมกาล 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOJ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MOZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MÓS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MÓZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1. MO 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOJ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MOS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("I MÓS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("JENEZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("JENÈZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("UTPAT 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("БИТИЕ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("БУТТЯ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("БЫТИЕ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("בריאה 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("《创世记》 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("《創世紀》 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("《創世記》 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ﺗﻜﻮﻳﻦ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MO 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 MZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1MÓS 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("POST 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("RODZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("SÁNG 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ПОСТ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ਉਤਪਤ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("தொநூ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("《创世记 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("《創世紀 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("《創世記 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("创世记》 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("創世紀》 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("創世記》 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("1 М 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GÉN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GÊN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("JEN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("MWA 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("RDZ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("TER 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ZAN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ΓΈΝ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ΓΕΝ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("БИТ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("БУГ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("БУТ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("БЫТ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("НАЧ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ଆଦି 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ஆதி 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ปฐก 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("《创》 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("《創》 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("创世记 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("創世紀 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("創世記 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("창세기 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GE 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GN 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("GÉ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("ΓΕ 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("تك 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("《创 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("《創 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("创》 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("創》 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("창세 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("创 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("創 1:1").osis()).toEqual("Gen.1.1")
		expect(p.parse("창 1:1").osis()).toEqual("Gen.1.1")
		`
		true
describe "Localized book Exod (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Exod (full)", ->
		`
		expect(p.parse("Kitabu cha Pili cha Musa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druga Ksiega Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druga Ksiega Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druga Ksiegi Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druga Ksiegi Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druga Księga Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druga Księga Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druga Księgi Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druga Księgi Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Drugi Ksiega Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Drugi Ksiega Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Drugi Ksiegi Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Drugi Ksiegi Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Drugi Księga Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Drugi Księga Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Drugi Księgi Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Drugi Księgi Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Toinen Mooseksen kirja 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druha kniha Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druha kniha Mojzišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druha kniha Mojzísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druha kniha Mojzíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druha kniha Mojžisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druha kniha Mojžišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druha kniha Mojžísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druha kniha Mojžíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy kniha Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy kniha Mojzišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy kniha Mojzísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy kniha Mojzíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy kniha Mojžisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy kniha Mojžišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy kniha Mojžísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy kniha Mojžíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhá kniha Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhá kniha Mojzišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhá kniha Mojzísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhá kniha Mojzíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhá kniha Mojžisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhá kniha Mojžišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhá kniha Mojžísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhá kniha Mojžíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhý kniha Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhý kniha Mojzišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhý kniha Mojzísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhý kniha Mojzíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhý kniha Mojžisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhý kniha Mojžišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhý kniha Mojžísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhý kniha Mojžíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Ksiega Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Ksiega Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Ksiegi Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Ksiegi Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Księga Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Księga Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Księgi Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Księgi Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-ге. книга Моисеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-ге. книга Мойсеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Ksiega Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Ksiega Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Ksiegi Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Ksiegi Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Księga Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Księga Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Księgi Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Księgi Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druga Ks. Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druga Ks. Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Drugi Ks. Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Drugi Ks. Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy list Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy list Mojzišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy list Mojžisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy list Mojžišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhý list Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhý list Mojzišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhý list Mojžisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhý list Mojžišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Ksiega Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Ksiega Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Ksiegi Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Ksiegi Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Księga Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Księga Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Księgi Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Księgi Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Втора книга Моисеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Втора книга Мојсеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Второ книга Мојсеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Друга книга Моисеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Друга книга Мойсеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Друге книга Моисеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Друге книга Мойсеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Ksiega Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Ksiega Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Ksiegi Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Ksiegi Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Księga Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Księga Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Księgi Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Księgi Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-а. книга Моисеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-а. книга Мойсеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-ге книга Моисеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-ге книга Мойсеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-е. книга Моисеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-е. книга Мойсеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druga Ks Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druga Ks Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Drugi Ks Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Drugi Ks Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mooseksen kirja 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. kniha Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. kniha Mojzišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. kniha Mojzísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. kniha Mojzíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. kniha Mojžisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. kniha Mojžišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. kniha Mojžísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. kniha Mojžíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-а книга Моисеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-а книга Мойсеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-е книга Моисеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-е книга Мойсеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mooseksen kirja 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. kniha Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. kniha Mojzišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. kniha Mojzísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. kniha Mojzíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. kniha Mojžisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. kniha Mojžišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. kniha Mojžísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. kniha Mojžíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mooseksen kirja 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II kniha Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II kniha Mojzišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II kniha Mojzísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II kniha Mojzíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II kniha Mojžisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II kniha Mojžišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II kniha Mojžísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II kniha Mojžíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Ks. Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Ks. Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. книга Моисеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. книга Мойсеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. книга Мојсеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mooseksen kirja 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 kniha Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 kniha Mojzišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 kniha Mojzísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 kniha Mojzíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 kniha Mojžisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 kniha Mojžišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 kniha Mojžísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 kniha Mojžíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Ks. Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Ks. Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. книга Моисеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. книга Мойсеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. книга Мојсеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Ks. Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Ks. Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II книга Моисеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II книга Мойсеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II книга Мојсеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Ks Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Ks Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("liv delivrans lan 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("prastʰanko pustak 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("prastʰānko pustak 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("प्रस्थानको पुस्तक 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Ks. Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Ks. Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 книга Моисеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 книга Мойсеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 книга Мојсеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Ks Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Ks Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druga Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druga Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Drugi Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Drugi Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Ks Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Ks Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Toinen Mooseksen 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Xuất Ê-díp-tô ký 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Zweite Buch Mose 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Ks Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Ks Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Andra Moseboken 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druha Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druha Mojzišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druha Mojzísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druha Mojzíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druha Mojžisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druha Mojžišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druha Mojžísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druha Mojžíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy Mojzišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy Mojzísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy Mojzíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy Mojžisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy Mojžišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy Mojžísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhy Mojžíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhá Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhá Mojzišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhá Mojzísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhá Mojzíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhá Mojžisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhá Mojžišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhá Mojžísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhá Mojžíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhý Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhý Mojzišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhý Mojzísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhý Mojzíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhý Mojžisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhý Mojžišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhý Mojžísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druhý Mojžíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Друга Мојсијева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("விடுதலைப் பயணம் 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 k. Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 k. Mojzišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 k. Mojžisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 k. Mojžišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Knjiga Izlaska 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Ksiega Wyjscia 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Ksiega Wyjścia 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Ksiegi Wyjscia 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Ksiegi Wyjścia 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Księga Wyjscia 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Księga Wyjścia 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Księgi Wyjscia 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Księgi Wyjścia 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Onnur bok Mose 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Onnur bok Móse 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Onnur bók Mose 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Onnur bók Móse 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Xuất Ai Cập Ký 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Önnur bok Mose 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Önnur bok Móse 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Önnur bók Mose 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Önnur bók Móse 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Втора Моисеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 k Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 k Mojzišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 k Mojžisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 k Mojžišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Anden Mosebog 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Andra Mosebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Andre Mosebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Annen Mosebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mojzišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mojzísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mojzíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mojžisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mojžišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mojžísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mojžíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mooseksen 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Мојсијева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Masodik Mozes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Masodik Mózes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Második Mozes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Második Mózes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Onnur Mosebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Onnur Mosebók 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Onnur Mósebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Onnur Mósebók 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Önnur Mosebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Önnur Mosebók 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Önnur Mósebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Önnur Mósebók 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ଯାତ୍ରା ପୁସ୍ତକ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mojzeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mojżeszowa 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Buch Mose 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mojzišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mojzísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mojzíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mojžisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mojžišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mojžísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mojžíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mooseksen 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Moseboken 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Мојсијева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mojzišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mojzísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mojzíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mojžisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mojžišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mojžísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mojžíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mooseksen 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Мојсијева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Моисеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Liber Exodus 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Tweede Mozes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Yattirakamam 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Yattirākamam 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Yāttirakamam 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Yāttirākamam 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ଯାତ୍ରାପୁସ୍ତକ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("யாத்திராகமம் 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Buch Mose 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mojzisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mojzišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mojzísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mojzíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mojžisova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mojžišova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mojžísova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mojžíšova 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mooseksen 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Moseboken 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Мојсијева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Моисеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Моисеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mosebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mosebók 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mósebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mósebók 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Ks. Wyjscia 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Ks. Wyjścia 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Pangentasan 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Xuất Ai-cập 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Zweite Mose 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Книга Исход 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("יציאת מצרים 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Моисеева 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mosebog 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mosebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mosebók 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mósebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mósebók 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Baxniintii 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druga Mojz 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Druga Mojż 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Drugi Mojz 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Drugi Mojż 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mosebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mosebók 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mósebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mósebók 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Ks Wyjscia 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Ks Wyjścia 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("prastʰanko 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("prastʰānko 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Друга Мојс 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("سفر الخروج 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("प्रस्थानको 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mosebog 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mosebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mosebók 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mósebok 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mósebók 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2e. Mozes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Anden Mos 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Andre Mos 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Delivrans 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mozes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mózes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Kivonulas 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Kivonulás 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Xuất Hành 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mozes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mózes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2e Mozes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mozes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mózes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mojz 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mojż 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Мојс 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Mozes II 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Mózes II 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Nirgaman 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("प्रस्थान 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mozes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mózes 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mojz 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mojż 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mose 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Мојс 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Ecsodus 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Egzodus 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mojz 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mojż 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Мојс 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mos 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. Mós 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Iesirea 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Ieşirea 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Ieșirea 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Izlazak 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Егзодус 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Излазак 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("निर्गमन 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mojz 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mojż 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Moos 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mose 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Мојс 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mos 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mós 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Eksodi 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Eksodo 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exodis 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exodul 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exodus 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Moj 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mos 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II Mós 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Kutoka 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Sjemot 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("nirgam 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Έξοδος 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Εξοδος 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("الخروج 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("خُرُوج 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("निर्गम 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ଯାତ୍ରା 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("《出埃及記》 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("《出埃及记》 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出エシフト記 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出エシプト記 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出エジフト記 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出エジプト記 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Moj 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mos 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Moz 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mós 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Móz 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. Mo 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Dalja 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Egzod 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Egzòd 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Esodo 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exode 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exodo 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exods 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Vyhid 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Vyȟid 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Éxodo 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Êxodo 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Вихід 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Излез 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Изход 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Исход 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("יציאה 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ḫurūj 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("《出埃及》 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("《出埃及記 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("《出埃及记 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("《出谷紀》 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出埃及記》 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出埃及记》 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mo 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 Mz 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2Mós 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exod 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Xuất 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Éxod 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Êxod 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("שמות 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("خروج 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("யாத் 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("อพยพ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("《出埃及 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("《出谷紀 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出埃及》 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出埃及記 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出埃及记 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出谷紀》 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("출애굽기 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 М 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Bax 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Dal 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Ecs 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Egz 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Eks 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exd 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Exo 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Izl 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Kiv 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Kut 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Wyj 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("kūč 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Éxd 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Éxo 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Êxd 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Êxo 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Вих 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Изл 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Изх 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Исх 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ਕੂਚ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("விப 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("อพย 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("《出》 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出埃及 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出谷紀 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("탈출기 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Ex 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Wj 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Éx 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Êx 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Εξ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("خر 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("Ἔξ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("《出 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出》 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("탈출 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("출 1:1").osis()).toEqual("Exod.1.1")
		p.include_apocrypha(false)
		expect(p.parse("KITABU CHA PILI CHA MUSA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGA KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGA KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGA KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGA KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGA KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGA KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGA KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGA KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGI KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGI KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGI KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGI KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGI KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGI KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGI KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGI KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("TOINEN MOOSEKSEN KIRJA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHA KNIHA MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHA KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHA KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHA KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHA KNIHA MOJŽISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHA KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHA KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHA KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY KNIHA MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY KNIHA MOJŽISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÁ KNIHA MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÁ KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÁ KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÁ KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÁ KNIHA MOJŽISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÁ KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÁ KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÁ KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÝ KNIHA MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÝ KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÝ KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÝ KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÝ KNIHA MOJŽISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÝ KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÝ KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÝ KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-ГЕ. КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-ГЕ. КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGA KS. MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGA KS. MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGI KS. MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGI KS. MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY LIST MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY LIST MOJZIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY LIST MOJŽISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY LIST MOJŽIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÝ LIST MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÝ LIST MOJZIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÝ LIST MOJŽISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÝ LIST MOJŽIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ВТОРА КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ВТОРА КНИГА МОЈСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ВТОРО КНИГА МОЈСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ДРУГА КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ДРУГА КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ДРУГЕ КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ДРУГЕ КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-А. КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-А. КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-ГЕ КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-ГЕ КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-Е. КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-Е. КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGA KS MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGA KS MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGI KS MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGI KS MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOOSEKSEN KIRJA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KNIHA MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KNIHA MOJŽISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-А КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-А КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-Е КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2-Е КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOOSEKSEN KIRJA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KNIHA MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KNIHA MOJŽISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOOSEKSEN KIRJA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KNIHA MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KNIHA MOJŽISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KS. MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KS. MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. КНИГА МОЈСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOOSEKSEN KIRJA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KNIHA MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KNIHA MOJŽISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KS. MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KS. MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. КНИГА МОЈСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KS. MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KS. MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II КНИГА МОЈСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KS MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. KS MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("LIV DELIVRANS LAN 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("PRASTʰANKO PUSTAK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("PRASTʰĀNKO PUSTAK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("प्रस्थानको पुस्तक 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KS. MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KS. MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 КНИГА МОЈСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KS MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. KS MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGA MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGA MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGI MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGI MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KS MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II KS MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("TOINEN MOOSEKSEN 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("XUẤT Ê-DÍP-TÔ KÝ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ZWEITE BUCH MOSE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KS MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 KS MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ANDRA MOSEBOKEN 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHA MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHA MOJZIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHA MOJZÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHA MOJZÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHA MOJŽISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHA MOJŽIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHA MOJŽÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHA MOJŽÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY MOJZIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY MOJZÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY MOJZÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY MOJŽISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY MOJŽIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY MOJŽÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHY MOJŽÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÁ MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÁ MOJZIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÁ MOJZÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÁ MOJZÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÁ MOJŽISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÁ MOJŽIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÁ MOJŽÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÁ MOJŽÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÝ MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÝ MOJZIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÝ MOJZÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÝ MOJZÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÝ MOJŽISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÝ MOJŽIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÝ MOJŽÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUHÝ MOJŽÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ДРУГА МОЈСИЈЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("விடுதலைப் பயணம் 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 K. MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 K. MOJZIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 K. MOJŽISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 K. MOJŽIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KNJIGA IZLASKA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KSIEGA WYJSCIA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KSIEGA WYJŚCIA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KSIEGI WYJSCIA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KSIEGI WYJŚCIA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KSIĘGA WYJSCIA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KSIĘGA WYJŚCIA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KSIĘGI WYJSCIA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KSIĘGI WYJŚCIA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ONNUR BOK MOSE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ONNUR BOK MÓSE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ONNUR BÓK MOSE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ONNUR BÓK MÓSE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("XUẤT AI CẬP KÝ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ÖNNUR BOK MOSE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ÖNNUR BOK MÓSE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ÖNNUR BÓK MOSE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ÖNNUR BÓK MÓSE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ВТОРА МОИСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 K MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 K MOJZIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 K MOJŽISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 K MOJŽIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ANDEN MOSEBOG 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ANDRA MOSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ANDRE MOSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ANNEN MOSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOJZIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOJZÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOJZÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOJŽISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOJŽIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOJŽÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOJŽÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOOSEKSEN 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. МОЈСИЈЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("MASODIK MOZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("MASODIK MÓZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("MÁSODIK MOZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("MÁSODIK MÓZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ONNUR MOSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ONNUR MOSEBÓK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ONNUR MÓSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ONNUR MÓSEBÓK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ÖNNUR MOSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ÖNNUR MOSEBÓK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ÖNNUR MÓSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ÖNNUR MÓSEBÓK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ଯାତ୍ରା ପୁସ୍ତକ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOJZESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOJŻESZOWA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. BUCH MOSE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOJZIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOJZÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOJZÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOJŽISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOJŽIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOJŽÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOJŽÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOOSEKSEN 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOSEBOKEN 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. МОЈСИЈЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOJZIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOJZÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOJZÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOJŽISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOJŽIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOJŽÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOJŽÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOOSEKSEN 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II МОЈСИЈЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. МОИСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("LIBER EXODUS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("TWEEDE MOZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("YATTIRAKAMAM 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("YATTIRĀKAMAM 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("YĀTTIRAKAMAM 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("YĀTTIRĀKAMAM 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ଯାତ୍ରାପୁସ୍ତକ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("யாத்திராகமம் 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 BUCH MOSE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOJZISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOJZIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOJZÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOJZÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOJŽISOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOJŽIŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOJŽÍSOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOJŽÍŠOVA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOOSEKSEN 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOSEBOKEN 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 МОЈСИЈЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. МОИСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II МОИСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOSEBÓK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MÓSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MÓSEBÓK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KS. WYJSCIA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KS. WYJŚCIA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("PANGENTASAN 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("XUẤT AI-CẬP 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ZWEITE MOSE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("КНИГА ИСХОД 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("יציאת מצרים 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 МОИСЕЕВА 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOSEBOG 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOSEBÓK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MÓSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MÓSEBÓK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("BAXNIINTII 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGA MOJZ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGA MOJŻ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGI MOJZ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DRUGI MOJŻ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOSEBÓK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MÓSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MÓSEBÓK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KS WYJSCIA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KS WYJŚCIA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("PRASTʰANKO 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("PRASTʰĀNKO 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ДРУГА МОЈС 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("سفر الخروج 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("प्रस्थानको 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOSEBOG 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOSEBÓK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MÓSEBOK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MÓSEBÓK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2E. MOZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ANDEN MOS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ANDRE MOS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DELIVRANS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MÓZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KIVONULAS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KIVONULÁS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("XUẤT HÀNH 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MÓZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2E MOZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MÓZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOJZ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOJŻ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. МОЈС 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("MOZES II 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("MÓZES II 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("NIRGAMAN 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("प्रस्थान 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MÓZES 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOJZ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOJŻ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOSE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. МОЈС 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ECSODUS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EGZODUS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOJZ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOJŻ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II МОЈС 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MOS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II. MÓS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("IESIREA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("IEŞIREA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("IEȘIREA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("IZLAZAK 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ЕГЗОДУС 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ИЗЛАЗАК 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("निर्गमन 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOJZ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOJŻ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOOS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOSE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 МОЈС 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MOS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MÓS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EKSODI 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EKSODO 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXODIS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXODUL 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXODUS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOJ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MOS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("II MÓS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KUTOKA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("SJEMOT 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("NIRGAM 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ΈΞΟΔΟΣ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ΕΞΟΔΟΣ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("الخروج 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("خُرُوج 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("निर्गम 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ଯାତ୍ରା 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("《出埃及記》 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("《出埃及记》 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出エシフト記 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出エシプト記 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出エジフト記 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出エジプト記 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOJ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MOZ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MÓS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MÓZ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2. MO 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DALJA 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EGZOD 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EGZÒD 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ESODO 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXODE 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXODO 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXODS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("VYHID 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("VYȞID 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ÉXODO 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ÊXODO 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ВИХІД 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ИЗЛЕЗ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ИЗХОД 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ИСХОД 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("יציאה 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ḪURŪJ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("《出埃及》 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("《出埃及記 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("《出埃及记 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("《出谷紀》 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出埃及記》 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出埃及记》 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MO 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 MZ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2MÓS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXOD 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("XUẤT 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ÉXOD 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ÊXOD 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("שמות 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("خروج 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("யாத் 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("อพยพ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("《出埃及 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("《出谷紀 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出埃及》 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出埃及記 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出埃及记 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出谷紀》 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("출애굽기 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("2 М 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("BAX 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("DAL 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ECS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EGZ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EKS 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXD 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EXO 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("IZL 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KIV 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KUT 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("WYJ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("KŪČ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ÉXD 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ÉXO 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ÊXD 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ÊXO 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ВИХ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ИЗЛ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ИЗХ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ИСХ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ਕੂਚ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("விப 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("อพย 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("《出》 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出埃及 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出谷紀 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("탈출기 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("EX 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("WJ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ÉX 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ÊX 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ΕΞ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("خر 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("ἜΞ 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("《出 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出》 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("탈출 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("出 1:1").osis()).toEqual("Exod.1.1")
		expect(p.parse("출 1:1").osis()).toEqual("Exod.1.1")
		`
		true
describe "Localized book Bel (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Bel (full)", ->
		`
		expect(p.parse("Istoria omorarii balaurului si a sfaramarii lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorarii balaurului si a sfaramării lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorarii balaurului si a sfarâmarii lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorarii balaurului si a sfarâmării lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorarii balaurului si a sfăramarii lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorarii balaurului si a sfăramării lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorarii balaurului si a sfărâmarii lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorarii balaurului si a sfărâmării lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorarii balaurului şi a sfaramarii lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorarii balaurului şi a sfaramării lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorarii balaurului şi a sfarâmarii lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorarii balaurului şi a sfarâmării lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorarii balaurului şi a sfăramarii lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorarii balaurului şi a sfăramării lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorarii balaurului şi a sfărâmarii lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorarii balaurului şi a sfărâmării lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorârii balaurului si a sfaramarii lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorârii balaurului si a sfaramării lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorârii balaurului si a sfarâmarii lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorârii balaurului si a sfarâmării lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorârii balaurului si a sfăramarii lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorârii balaurului si a sfăramării lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorârii balaurului si a sfărâmarii lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorârii balaurului si a sfărâmării lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorârii balaurului şi a sfaramarii lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorârii balaurului şi a sfaramării lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorârii balaurului şi a sfarâmarii lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorârii balaurului şi a sfarâmării lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorârii balaurului şi a sfăramarii lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorârii balaurului şi a sfăramării lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorârii balaurului şi a sfărâmarii lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria omorârii balaurului şi a sfărâmării lui Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("பேல் தெய்வமும் அரக்கப்பாம்பும் என்பவையாகும் 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("பேல் தெய்வமும் அரக்கப்பாம்பும் 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Danieli na Makuhani wa Beli 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Opowiadaniem o Belu i wezu 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Opowiadaniem o Belu i weżu 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Opowiadaniem o Belu i węzu 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Opowiadaniem o Belu i wężu 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Histoia Beli et draconis 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel og dragen i Babylon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Si Bel at ang Dragon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel and the Serpent 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel und Vom Drachen 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel and the Dragon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel y el Serpiente 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Istoria Balaurului 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Baal es a sarkany 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Baal es a sarkány 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Baal es a sárkany 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Baal es a sárkány 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Baal és a sarkany 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Baal és a sarkány 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Baal és a sárkany 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Baal és a sárkány 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Baál es a sarkany 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Baál es a sarkány 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Baál es a sárkany 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Baál es a sárkány 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Baál és a sarkany 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Baál és a sarkány 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Baál és a sárkany 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Baál és a sárkány 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel & the Serpent 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel and the Snake 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel at ang Dragon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel et le Serpent 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel et le serpent 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel ja lohikaarme 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel ja lohikaärme 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel ja lohikäarme 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel ja lohikäärme 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel & the Dragon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel es a sarkany 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel es a sarkány 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel es a sárkany 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel es a sárkány 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel et le Dragon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel et le dragon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel och Ormguden 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel és a sarkany 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel és a sarkány 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel és a sárkany 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel és a sárkány 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bél es a sarkany 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bél es a sarkány 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bél es a sárkany 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bél es a sárkány 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bél és a sarkany 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bél és a sarkány 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bél és a sárkany 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bél és a sárkány 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel & the Snake 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel and Serpent 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel en de draak 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel et draconis 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel si dragonul 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel y el Dragon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel y el Dragón 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel și dragonul 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel a'r Ddraig 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel and Dragon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel a’r Ddraig 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel e il Drago 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel e o Dragao 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel e o Dragão 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel e o dragao 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel e o dragão 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel og drekinn 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Βηλ και Δράκων 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Βηλ και Δρακων 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Виле и драконе 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel & Serpent 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel and Snake 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel og Dragen 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel og draken 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel & Dragon 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Бел и Дракон 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Бел і дракон 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel & Snake 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bela i weza 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bela i weża 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bela i węza 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bela i węża 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel a drak 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bél a drak 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("בל והדרקון 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("התנין בבבל 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("بل والتنين 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("《Bel》 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel》 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Беле 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("பேல் 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("《Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("ヘルと竜 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("ヘルと龍 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("ベルと竜 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("ベルと龍 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("벨과 뱀 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("벨과 용 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bel 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Bél 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Βηλ 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Βὴλ 1:1").osis()).toEqual("Bel.1.1")
		expect(p.parse("Бел 1:1").osis()).toEqual("Bel.1.1")
		`
		true
describe "Localized book Phlm (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Phlm (full)", ->
		`
		expect(p.parse("Послання св. апостола Павла до Филимона 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Послання св апостола Павла до Филимона 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Послание на св. ап. Павла до Филимона 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Poslannja apostola Pavla do Fylymona 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Послание на св ап. Павла до Филимона 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Послание на св. ап Павла до Филимона 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Послание на св ап Павла до Филимона 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Послання апостола Павла до Филимона 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Писмо од апостол Павле до Филемон 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("فلیمون کے نام پولس رسُول کا خط 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("رسالة بولس الرسول إلى فليمون 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("பிலமோனுக்கு எழுதிய திருமுகம் 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilemonukku Elutiya Nirupam 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilemonukku Eḻutiya Nirupam 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilemoṉukku Elutiya Nirupam 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilemoṉukku Eḻutiya Nirupam 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilemōnukku Elutiya Nirupam 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilemōnukku Eḻutiya Nirupam 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilemōṉukku Elutiya Nirupam 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilemōṉukku Eḻutiya Nirupam 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilēmonukku Elutiya Nirupam 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilēmonukku Eḻutiya Nirupam 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilēmoṉukku Elutiya Nirupam 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilēmoṉukku Eḻutiya Nirupam 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilēmōnukku Elutiya Nirupam 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilēmōnukku Eḻutiya Nirupam 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilēmōṉukku Elutiya Nirupam 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilēmōṉukku Eḻutiya Nirupam 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("பிலேமோனுக்கு எழுதிய நிருபம் 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("List sw. Pawła do Filemona 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("List św. Pawła do Filemona 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pavlova poslanica Filemonu 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("பிலேமோனுக்கு எழுதிய கடிதம் 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("List sw Pawła do Filemona 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("List św Pawła do Filemona 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Paulus' Brev til Filemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Paulus’ Brev til Filemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Paulus’ brev til Filemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Epistulam ad Philemonem 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Bref Pals til Filemons 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Bref Pals til Fílemons 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Bref Páls til Filemons 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Bref Páls til Fílemons 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Bréf Pals til Filemons 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Bréf Pals til Fílemons 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Bréf Páls til Filemons 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Bréf Páls til Fílemons 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Epistula ad Philemonem 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Послання до Филипіиців 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Послання до Филипійців 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("पौलाचे फिलेमोनाला पत्र 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("फिलेमोनलाई पावलको पत्र 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("filēmōn ke nām kā ḫaṭ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("אגרת פולוס אל-פילימון 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ଫିଲୀମୋନଙ୍କ ପ୍ରତି ପତ୍ର 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Послание към Филимон 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Послання до Филимона 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("فِلیمون کے نام کا خط 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Brevet till Filemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Waraka kwa Filemoni 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("pʰilemon nū̃ pattrī 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Послание к Филимону 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("فلیمون کے نام کا خط 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ਫ਼ਿਲੇਮੋਨ ਨੂੰ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Barua kwa Filemoni 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Brevet til Filemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Lettera a Filemone 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Poslanica Filemonu 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Посланица Филимону 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("الرسالة إلى فليمون 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ਫਿਲੇਮੋਨ ਨੂੰ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Kirje Filemonille 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("pʰilemonala patra 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("pʰilemonalā patra 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("pʰilemonlai patra 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("pʰilemonlaī patra 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("pʰilemonlāi patra 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("pʰilemonlāī patra 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("pʰilemonāla patra 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("pʰilemonālā patra 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("האיגרת אל פילימון 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("List do Filemona 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("List Filemonovi 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("List Filemónovi 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("फिलेमोनलाई पत्र 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("फिलेमोनाला पत्र 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemonsbrefið 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemonsbréfið 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Fílemonsbrefið 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Fílemonsbréfið 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemonbrevet 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ad Philemonem 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Προς Φιλήμονα 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Προς Φιλημονα 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Kang Filemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Kang Filemón 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ਫ਼ਿਲੇਮੋਨ ਨੂੰ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemonille 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Kay Filemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Philemonhoz 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilemonukku 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilemoṉukku 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilemōnukku 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilemōṉukku 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilēmonukku 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilēmoṉukku 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilēmōnukku 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Pilēmōṉukku 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("pʰilemonala 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("pʰilemonalā 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("pʰilemonlai 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("pʰilemonlaī 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("pʰilemonlāi 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("pʰilemonlāī 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("pʰilemonāla 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("pʰilemonālā 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("До Филимона 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("필레몬에게 보낸 서간 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemonhoz 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemonovi 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phi-lê-môn 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Philemonem 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("К Филимону 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("אל פילימון 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("फिलेमोनलाई 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("फिलेमोनाला 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ଫିଲୀମୋନଙ୍କ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemonit 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("フィレモンへの手紙 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemona 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemone 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemoni 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemonu 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filèmone 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Philemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Philémon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Philêmon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("pʰilemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Φιλήμονα 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Φιλημονα 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Филимона 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Филимону 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("फिलेमोना 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("பிலேமோன் 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ヒレモンへの手紙 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ヒレモンヘの手紙 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ピレモンへの手紙 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ピレモンヘの手紙 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemom 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filemón 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filimon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filémon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phlemon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phlimon 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Филемон 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Филимон 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("فِلیمون 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("फिलेमोन 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("பிலமோன் 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ฟีเลโมน 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ヒレモンへの書 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ピレモンへの書 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phi-lê 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Philem 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("فليمون 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("فلیمون 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《腓利門書》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《腓利门书》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《費肋孟書》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("フィレモン書 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filem 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Filim 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phile 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phlmn 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Филим 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《肥利孟》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《腓利門書 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《腓利门书 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《費肋孟書 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ヒレモン書 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ピレモン書 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("フィレモン 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("腓利門書》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("腓利门书》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("費肋孟書》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Film 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Flmn 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Fílm 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phlm 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phmn 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("பிலே 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《肥利孟 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("肥利孟》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("腓利門書 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("腓利门书 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("費肋孟書 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("빌레몬서 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("필레몬서 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Flm 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Fmn 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Phm 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Φλμ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Флм 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("فيل 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("फले 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("பில 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《門》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《门》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("肥利孟 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Fi 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("Fm 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ฟม 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《門 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《门 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("門》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("门》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("필레 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ف 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("門 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("门 1:1").osis()).toEqual("Phlm.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ФИЛИМОНА 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ФИЛИМОНА 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ. АП. ПАВЛА ДО ФИЛИМОНА 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("POSLANNJA APOSTOLA PAVLA DO FYLYMONA 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ АП. ПАВЛА ДО ФИЛИМОНА 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ. АП ПАВЛА ДО ФИЛИМОНА 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ АП ПАВЛА ДО ФИЛИМОНА 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ФИЛИМОНА 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ФИЛЕМОН 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("فلیمون کے نام پولس رسُول کا خط 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("رسالة بولس الرسول إلى فليمون 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("பிலமோனுக்கு எழுதிய திருமுகம் 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILEMONUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILEMONUKKU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILEMOṈUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILEMOṈUKKU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILEMŌNUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILEMŌNUKKU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILEMŌṈUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILEMŌṈUKKU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILĒMONUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILĒMONUKKU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILĒMOṈUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILĒMOṈUKKU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILĒMŌNUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILĒMŌNUKKU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILĒMŌṈUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILĒMŌṈUKKU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("பிலேமோனுக்கு எழுதிய நிருபம் 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("LIST SW. PAWŁA DO FILEMONA 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("LIST ŚW. PAWŁA DO FILEMONA 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PAVLOVA POSLANICA FILEMONU 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("பிலேமோனுக்கு எழுதிய கடிதம் 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("LIST SW PAWŁA DO FILEMONA 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("LIST ŚW PAWŁA DO FILEMONA 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PAULUS' BREV TIL FILEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PAULUS’ BREV TIL FILEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PAULUS’ BREV TIL FILEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("EPISTULAM AD PHILEMONEM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("BREF PALS TIL FILEMONS 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("BREF PALS TIL FÍLEMONS 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("BREF PÁLS TIL FILEMONS 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("BREF PÁLS TIL FÍLEMONS 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("BRÉF PALS TIL FILEMONS 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("BRÉF PALS TIL FÍLEMONS 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("BRÉF PÁLS TIL FILEMONS 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("BRÉF PÁLS TIL FÍLEMONS 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("EPISTULA AD PHILEMONEM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ПОСЛАННЯ ДО ФИЛИПІИЦІВ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ПОСЛАННЯ ДО ФИЛИПІЙЦІВ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("पौलाचे फिलेमोनाला पत्र 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("फिलेमोनलाई पावलको पत्र 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILĒMŌN KE NĀM KĀ ḪAṬ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("אגרת פולוס אל-פילימון 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ଫିଲୀମୋନଙ୍କ ପ୍ରତି ପତ୍ର 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ПОСЛАНИЕ КЪМ ФИЛИМОН 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ПОСЛАННЯ ДО ФИЛИМОНА 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("فِلیمون کے نام کا خط 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("BREVET TILL FILEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("WARAKA KWA FILEMONI 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PʰILEMON NŪ̃ PATTRĪ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ПОСЛАНИЕ К ФИЛИМОНУ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("فلیمون کے نام کا خط 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ਫ਼ਿਲੇਮੋਨ ਨੂੰ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("BARUA KWA FILEMONI 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("BREVET TIL FILEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("LETTERA A FILEMONE 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("POSLANICA FILEMONU 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ПОСЛАНИЦА ФИЛИМОНУ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("الرسالة إلى فليمون 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ਫਿਲੇਮੋਨ ਨੂੰ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("KIRJE FILEMONILLE 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PʰILEMONALA PATRA 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PʰILEMONALĀ PATRA 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PʰILEMONLAI PATRA 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PʰILEMONLAĪ PATRA 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PʰILEMONLĀI PATRA 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PʰILEMONLĀĪ PATRA 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PʰILEMONĀLA PATRA 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PʰILEMONĀLĀ PATRA 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("האיגרת אל פילימון 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("LIST DO FILEMONA 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("LIST FILEMONOVI 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("LIST FILEMÓNOVI 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("फिलेमोनलाई पत्र 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("फिलेमोनाला पत्र 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMONSBREFIÐ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMONSBRÉFIÐ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FÍLEMONSBREFIÐ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FÍLEMONSBRÉFIÐ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMONBREVET 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("AD PHILEMONEM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ΠΡΟΣ ΦΙΛΉΜΟΝΑ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ΠΡΟΣ ΦΙΛΗΜΟΝΑ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("KANG FILEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("KANG FILEMÓN 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ਫ਼ਿਲੇਮੋਨ ਨੂੰ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMONILLE 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("KAY FILEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHILEMONHOZ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILEMONUKKU 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILEMOṈUKKU 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILEMŌNUKKU 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILEMŌṈUKKU 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILĒMONUKKU 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILĒMOṈUKKU 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILĒMŌNUKKU 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PILĒMŌṈUKKU 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PʰILEMONALA 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PʰILEMONALĀ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PʰILEMONLAI 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PʰILEMONLAĪ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PʰILEMONLĀI 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PʰILEMONLĀĪ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PʰILEMONĀLA 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PʰILEMONĀLĀ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ДО ФИЛИМОНА 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("필레몬에게 보낸 서간 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMONHOZ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMONOVI 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHI-LÊ-MÔN 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHILEMONEM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("К ФИЛИМОНУ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("אל פילימון 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("फिलेमोनलाई 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("फिलेमोनाला 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ଫିଲୀମୋନଙ୍କ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMONIT 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("フィレモンへの手紙 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMONA 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMONE 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMONI 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMONU 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILÈMONE 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHILEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHILÉMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHILÊMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PʰILEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ΦΙΛΉΜΟΝΑ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ΦΙΛΗΜΟΝΑ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ФИЛИМОНА 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ФИЛИМОНУ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("फिलेमोना 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("பிலேமோன் 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ヒレモンへの手紙 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ヒレモンヘの手紙 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ピレモンへの手紙 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ピレモンヘの手紙 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMOM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEMÓN 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILIMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILÉMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHLEMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHLIMON 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ФИЛЕМОН 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ФИЛИМОН 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("فِلیمون 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("फिलेमोन 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("பிலமோன் 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ฟีเลโมน 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ヒレモンへの書 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ピレモンへの書 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHI-LÊ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHILEM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("فليمون 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("فلیمون 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《腓利門書》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《腓利门书》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《費肋孟書》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("フィレモン書 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILEM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILIM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHILE 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHLMN 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ФИЛИМ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《肥利孟》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《腓利門書 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《腓利门书 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《費肋孟書 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ヒレモン書 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ピレモン書 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("フィレモン 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("腓利門書》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("腓利门书》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("費肋孟書》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FILM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FLMN 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FÍLM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHLM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHMN 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("பிலே 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《肥利孟 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("肥利孟》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("腓利門書 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("腓利门书 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("費肋孟書 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("빌레몬서 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("필레몬서 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FLM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FMN 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("PHM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ΦΛΜ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ФЛМ 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("فيل 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("फले 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("பில 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《門》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《门》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("肥利孟 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FI 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("FM 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ฟม 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《門 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("《门 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("門》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("门》 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("필레 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("ف 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("門 1:1").osis()).toEqual("Phlm.1.1")
		expect(p.parse("门 1:1").osis()).toEqual("Phlm.1.1")
		`
		true
describe "Localized book Lev (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Lev (full)", ->
		`
		expect(p.parse("liv Prensip lavi nan Bondye 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzecia Ksiega Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzecia Ksiega Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzecia Ksiegi Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzecia Ksiegi Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzecia Księga Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzecia Księga Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzecia Księgi Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzecia Księgi Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Kitabu cha Tatu cha Musa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzeci Ksiega Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzeci Ksiega Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzeci Ksiegi Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzeci Ksiegi Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzeci Księga Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzeci Księga Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzeci Księgi Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzeci Księgi Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Ksiega Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Ksiega Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Ksiegi Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Ksiegi Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Księga Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Księga Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Księgi Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Księgi Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Kolmas Mooseksen kirja 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretia kniha Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretia kniha Mojzišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretia kniha Mojžisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretia kniha Mojžišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzecia Ks. Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzecia Ks. Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Ksiega Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Ksiega Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Ksiegi Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Ksiegi Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Księga Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Księga Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Księgi Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Księgi Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Treti kniha Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Treti kniha Mojzišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Treti kniha Mojzísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Treti kniha Mojzíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Treti kniha Mojžisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Treti kniha Mojžišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Treti kniha Mojžísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Treti kniha Mojžíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretí kniha Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretí kniha Mojzišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretí kniha Mojzísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretí kniha Mojzíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretí kniha Mojžisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretí kniha Mojžišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretí kniha Mojžísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretí kniha Mojžíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzeci Ks. Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzeci Ks. Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzecia Ks Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzecia Ks Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třeti kniha Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třeti kniha Mojzišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třeti kniha Mojzísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třeti kniha Mojzíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třeti kniha Mojžisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třeti kniha Mojžišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třeti kniha Mojžísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třeti kniha Mojžíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třetí kniha Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třetí kniha Mojzišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třetí kniha Mojzísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třetí kniha Mojzíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třetí kniha Mojžisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třetí kniha Mojžišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třetí kniha Mojžísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třetí kniha Mojžíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-тє. книга Моисеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-тє. книга Мойсеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Ksiega Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Ksiega Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Ksiegi Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Ksiegi Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Księga Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Księga Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Księgi Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Księgi Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mooseksen kirja 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. kniha Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. kniha Mojzišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. kniha Mojzísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. kniha Mojzíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. kniha Mojžisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. kniha Mojžišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. kniha Mojžísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. kniha Mojžíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzeci Ks Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzeci Ks Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Трета книга Моисеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Трета книга Мојсеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Третя книга Моисеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Третя книга Мойсеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Третє книга Моисеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Третє книга Мойсеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Ksiega Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Ksiega Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Ksiegi Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Ksiegi Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Księga Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Księga Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Księgi Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Księgi Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-а. книга Моисеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-а. книга Мойсеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-е. книга Моисеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-е. книга Мойсеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-тє книга Моисеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-тє книга Мойсеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mooseksen kirja 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III kniha Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III kniha Mojzišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III kniha Mojzísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III kniha Mojzíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III kniha Mojžisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III kniha Mojžišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III kniha Mojžísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III kniha Mojžíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Ks. Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Ks. Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. книга Моисеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. книга Мойсеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-а книга Моисеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-а книга Мойсеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-е книга Моисеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-е книга Мойсеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mooseksen kirja 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. kniha Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. kniha Mojzišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. kniha Mojzísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. kniha Mojzíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. kniha Mojžisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. kniha Mojžišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. kniha Mojžísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. kniha Mojžíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Ks. Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Ks. Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III книга Моисеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III книга Мойсеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Ks Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Ks Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzecia Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzecia Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mooseksen kirja 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 kniha Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 kniha Mojzišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 kniha Mojzísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 kniha Mojzíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 kniha Mojžisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 kniha Mojžišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 kniha Mojžísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 kniha Mojžíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Ks. Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Ks. Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. книга Моисеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. книга Мойсеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Ks Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Ks Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzeci Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzeci Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("leviharuko pustak 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("leviharūko pustak 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("levīharuko pustak 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("levīharūko pustak 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Ks. Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Ks. Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 книга Моисеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 книга Мойсеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Ks Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Ks Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Dritte Buch Mose 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Kolmas Mooseksen 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Ksiega Kapłanska 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Ksiega Kapłańska 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Ksiegi Kapłanska 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Ksiegi Kapłańska 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Księga Kapłanska 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Księga Kapłańska 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Księgi Kapłanska 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Księgi Kapłańska 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Laaivyavyavastha 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitski zakonik 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tredje Moseboken 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretia Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretia Mojzišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretia Mojžisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretia Mojžišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Трећом Мојсијева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("लेवीहरूको पुस्तक 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Ks Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Ks Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Liber Leviticus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Mambo ya Walawi 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Treti Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Treti Mojzišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Treti Mojzísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Treti Mojzíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Treti Mojžisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Treti Mojžišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Treti Mojžísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Treti Mojžíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretí Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretí Mojzišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretí Mojzísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretí Mojzíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretí Mojžisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretí Mojžišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretí Mojžísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tretí Mojžíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třeti Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třeti Mojzišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třeti Mojzísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třeti Mojzíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třeti Mojžisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třeti Mojžišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třeti Mojžísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třeti Mojžíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třetí Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třetí Mojzišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třetí Mojzísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třetí Mojzíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třetí Mojžisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třetí Mojžišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třetí Mojžísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Třetí Mojžíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("levīāṃ dī potʰī 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Þriðja bok Mose 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Þriðja bok Móse 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Þriðja bók Mose 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Þriðja bók Móse 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Трећа Мојсијева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("लैव्य्व्य्वस्था 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 k. Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 k. Mojzišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 k. Mojžisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 k. Mojžišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Harmadik Mozes 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Harmadik Mózes 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mojzišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mojzísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mojzíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mojžisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mojžišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mojžísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mojžíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mooseksen 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Мојсијева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tredje Mosebog 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tredje Mosebok 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Þriðja Mosebok 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Þriðja Mosebók 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Þriðja Mósebok 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Þriðja Mósebók 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Левитска книга 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Трето Моисеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ਲੇਵੀਆਂ ਦੀ ਪੋਥੀ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 k Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 k Mojzišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 k Mojžisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 k Mojžišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3e. Moseboken 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mojzišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mojzísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mojzíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mojžisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mojžišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mojžísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mojžíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mooseksen 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Мојсијева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Моисеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Ks. Kapłanska 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Ks. Kapłańska 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Leviyarakamam 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Leviyarākamam 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lēviyarakamam 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lēviyarākamam 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("लैव्यव्यवस्था 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mojzeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mojżeszowa 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Buch Mose 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mojzišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mojzísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mojzíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mojžisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mojžišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mojžísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mojžíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mooseksen 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Moseboken 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Мојсијева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3e Moseboken 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Моисеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mosebok 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mosebók 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mósebok 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mósebók 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Ks Kapłanska 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Ks Kapłańska 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Laawiyiintii 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzecia Mojz 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzecia Mojż 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("سفر اللاويين 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("लैव्यव्यवस्थ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ଲେବୀୟ ପୁସ୍ତକ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Buch Mose 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mojzisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mojzišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mojzísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mojzíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mojžisova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mojžišova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mojžísova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mojžíšova 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mooseksen 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Moseboken 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Мојсијева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Моисеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3e. Mosebok 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Derde Mozes 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Dritte Mose 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mosebok 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mosebók 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mósebok 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mósebók 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzeci Mojz 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Trzeci Mojż 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Книга Левит 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Трећом Мојс 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ספר הלוויים 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("லேவியராகமம் 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Моисеева 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mosebog 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mosebok 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mosebók 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mósebok 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mósebók 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3e Mosebok 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mozes 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mózes 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Leviticusi 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Tredje Mos 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("leviharuko 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("leviharūko 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("levīharuko 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("levīharūko 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Трећа Мојс 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("लैव्यवस्था 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mosebog 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mosebok 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mosebók 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mósebok 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mósebók 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3e. Mozes 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mozes 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mózes 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mojz 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mojż 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Мојс 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lebitikus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lefiticus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levetecus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Leveticus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitecus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Leviticos 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Leviticul 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Leviticus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitiket 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitikus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitikët 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitique 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levíticos 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Livetecus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Liveticus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Livitecus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Liviticus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lévitique 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Mozes III 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Mózes III 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Λευιτικον 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Λευιτικόν 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Λευϊτικον 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Λευϊτικόν 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("लेवीहरूको 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mozes 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mózes 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3e Mozes 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mojz 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mojż 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Мојс 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mos 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. Mós 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Kaimaman 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lebitico 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lebitiko 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levetcus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitcus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitico 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitiku 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levítico 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Livetcus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Livitcus 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lê-vi ký 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Λευιτικο 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Λευιτικό 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Λευϊτικο 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Λευϊτικό 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Левитска 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("اللاويين 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("เลวีนิติ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mozes 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mózes 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mojz 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mojż 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mose 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Мојс 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Moj 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mos 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III Mós 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitak 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitic 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levitik 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Leviták 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Vajikra 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Wajikra 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("الأحبار 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("லேவியர் 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mojz 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mojż 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Moos 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mose 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Мојс 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mos 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mós 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Walawi 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("levīāṃ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ਲੇਵੀਆਂ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ﺍﻟﻼﻭﻳﻲ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Moj 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mos 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Moz 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mós 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Móz 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. Mo 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levyt 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lê-vi 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("iḥbār 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("lewiy 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("lewīy 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Λευιτ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Λευϊτ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Левит 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ויקרא 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("احبار 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("लेवीय 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("लैव्य 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ଲେବୀୟ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("《利未記》 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("《利未记》 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("《利末记》 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("《肋未紀》 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mo 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 Mz 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3Mós 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Kapl 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Kapł 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Laaw 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Levi 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("लेवि 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("लेवी 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("லேவி 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("《利未記 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("《利未记 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("《利末记 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("《肋未紀 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("利未記》 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("利未记》 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("利末记》 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("肋未紀》 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 М 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Kpl 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Kpł 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Law 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Leb 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lef 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lev 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lév 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Wal 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Λευ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Лев 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ลนต 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("《利》 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("レヒ記 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("レビ記 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("利未記 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("利未记 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("利末记 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("肋未紀 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("레위기 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Le 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lv 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lé 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Lê 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("Λε 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("أح 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("لا 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("《利 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("レヒ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("レビ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("利》 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("레위 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("레 1:1").osis()).toEqual("Lev.1.1")
		p.include_apocrypha(false)
		expect(p.parse("LIV PRENSIP LAVI NAN BONDYE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECIA KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECIA KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECIA KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECIA KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECIA KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECIA KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECIA KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECIA KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KITABU CHA TATU CHA MUSA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECI KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECI KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECI KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECI KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECI KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECI KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECI KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECI KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KOLMAS MOOSEKSEN KIRJA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETIA KNIHA MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETIA KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETIA KNIHA MOJŽISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETIA KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECIA KS. MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECIA KS. MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETI KNIHA MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETI KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETI KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETI KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETI KNIHA MOJŽISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETI KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETI KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETI KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETÍ KNIHA MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETÍ KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETÍ KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETÍ KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETÍ KNIHA MOJŽISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETÍ KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETÍ KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETÍ KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECI KS. MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECI KS. MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECIA KS MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECIA KS MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETI KNIHA MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETI KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETI KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETI KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETI KNIHA MOJŽISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETI KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETI KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETI KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETÍ KNIHA MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETÍ KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETÍ KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETÍ KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETÍ KNIHA MOJŽISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETÍ KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETÍ KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETÍ KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-ТЄ. КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-ТЄ. КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOOSEKSEN KIRJA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KNIHA MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KNIHA MOJŽISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECI KS MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECI KS MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ТРЕТА КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ТРЕТА КНИГА МОЈСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ТРЕТЯ КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ТРЕТЯ КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ТРЕТЄ КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ТРЕТЄ КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-А. КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-А. КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-Е. КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-Е. КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-ТЄ КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-ТЄ КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOOSEKSEN KIRJA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KNIHA MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KNIHA MOJŽISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KS. MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KS. MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-А КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-А КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-Е КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3-Е КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOOSEKSEN KIRJA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KNIHA MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KNIHA MOJŽISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KS. MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KS. MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KS MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. KS MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECIA MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECIA MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOOSEKSEN KIRJA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KNIHA MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KNIHA MOJŽISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KS. MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KS. MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KS MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III KS MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECI MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECI MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVIHARUKO PUSTAK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVIHARŪKO PUSTAK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVĪHARUKO PUSTAK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVĪHARŪKO PUSTAK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KS. MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KS. MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KS MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. KS MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("DRITTE BUCH MOSE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KOLMAS MOOSEKSEN 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KSIEGA KAPŁANSKA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KSIEGA KAPŁAŃSKA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KSIEGI KAPŁANSKA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KSIEGI KAPŁAŃSKA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KSIĘGA KAPŁANSKA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KSIĘGA KAPŁAŃSKA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KSIĘGI KAPŁANSKA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KSIĘGI KAPŁAŃSKA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LAAIVYAVYAVASTHA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITSKI ZAKONIK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TREDJE MOSEBOKEN 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETIA MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETIA MOJZIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETIA MOJŽISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETIA MOJŽIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ТРЕЋОМ МОЈСИЈЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("लेवीहरूको पुस्तक 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KS MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 KS MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LIBER LEVITICUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("MAMBO YA WALAWI 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETI MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETI MOJZIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETI MOJZÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETI MOJZÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETI MOJŽISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETI MOJŽIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETI MOJŽÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETI MOJŽÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETÍ MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETÍ MOJZIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETÍ MOJZÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETÍ MOJZÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETÍ MOJŽISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETÍ MOJŽIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETÍ MOJŽÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRETÍ MOJŽÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETI MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETI MOJZIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETI MOJZÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETI MOJZÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETI MOJŽISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETI MOJŽIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETI MOJŽÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETI MOJŽÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETÍ MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETÍ MOJZIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETÍ MOJZÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETÍ MOJZÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETÍ MOJŽISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETÍ MOJŽIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETÍ MOJŽÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TŘETÍ MOJŽÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVĪĀṂ DĪ POTʰĪ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ÞRIÐJA BOK MOSE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ÞRIÐJA BOK MÓSE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ÞRIÐJA BÓK MOSE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ÞRIÐJA BÓK MÓSE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ТРЕЋА МОЈСИЈЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("लैव्य्व्य्वस्था 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 K. MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 K. MOJZIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 K. MOJŽISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 K. MOJŽIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("HARMADIK MOZES 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("HARMADIK MÓZES 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOJZIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOJZÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOJZÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOJŽISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOJŽIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOJŽÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOJŽÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOOSEKSEN 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. МОЈСИЈЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TREDJE MOSEBOG 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TREDJE MOSEBOK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ÞRIÐJA MOSEBOK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ÞRIÐJA MOSEBÓK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ÞRIÐJA MÓSEBOK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ÞRIÐJA MÓSEBÓK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ЛЕВИТСКА КНИГА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ТРЕТО МОИСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ਲੇਵੀਆਂ ਦੀ ਪੋਥੀ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 K MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 K MOJZIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 K MOJŽISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 K MOJŽIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3E. MOSEBOKEN 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOJZIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOJZÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOJZÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOJŽISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOJŽIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOJŽÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOJŽÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOOSEKSEN 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III МОЈСИЈЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. МОИСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KS. KAPŁANSKA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KS. KAPŁAŃSKA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVIYARAKAMAM 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVIYARĀKAMAM 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LĒVIYARAKAMAM 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LĒVIYARĀKAMAM 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("लैव्यव्यवस्था 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOJZESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOJŻESZOWA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. BUCH MOSE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOJZIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOJZÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOJZÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOJŽISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOJŽIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOJŽÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOJŽÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOOSEKSEN 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOSEBOKEN 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. МОЈСИЈЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3E MOSEBOKEN 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III МОИСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOSEBOK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOSEBÓK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MÓSEBOK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MÓSEBÓK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KS KAPŁANSKA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KS KAPŁAŃSKA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LAAWIYIINTII 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECIA MOJZ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECIA MOJŻ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("سفر اللاويين 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("लैव्यव्यवस्थ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ଲେବୀୟ ପୁସ୍ତକ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 BUCH MOSE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOJZISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOJZIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOJZÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOJZÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOJŽISOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOJŽIŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOJŽÍSOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOJŽÍŠOVA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOOSEKSEN 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOSEBOKEN 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 МОЈСИЈЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. МОИСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3E. MOSEBOK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("DERDE MOZES 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("DRITTE MOSE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOSEBOK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOSEBÓK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MÓSEBOK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MÓSEBÓK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECI MOJZ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TRZECI MOJŻ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("КНИГА ЛЕВИТ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ТРЕЋОМ МОЈС 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ספר הלוויים 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("லேவியராகமம் 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 МОИСЕЕВА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOSEBOG 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOSEBOK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOSEBÓK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MÓSEBOK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MÓSEBÓK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3E MOSEBOK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOZES 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MÓZES 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITICUSI 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("TREDJE MOS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVIHARUKO 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVIHARŪKO 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVĪHARUKO 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVĪHARŪKO 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ТРЕЋА МОЈС 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("लैव्यवस्था 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOSEBOG 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOSEBOK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOSEBÓK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MÓSEBOK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MÓSEBÓK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3E. MOZES 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOZES 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MÓZES 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOJZ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOJŻ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. МОЈС 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEBITIKUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEFITICUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVETECUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVETICUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITECUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITICOS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITICUL 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITICUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITIKET 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITIKUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITIKËT 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITIQUE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVÍTICOS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LIVETECUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LIVETICUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LIVITECUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LIVITICUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LÉVITIQUE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("MOZES III 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("MÓZES III 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ΛΕΥΙΤΙΚΟΝ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ΛΕΥΙΤΙΚΌΝ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ΛΕΥΪΤΙΚΟΝ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ΛΕΥΪΤΙΚΌΝ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("लेवीहरूको 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOZES 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MÓZES 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3E MOZES 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOJZ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOJŻ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III МОЈС 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MOS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III. MÓS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KAIMAMAN 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEBITICO 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEBITIKO 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVETCUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITCUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITICO 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITIKU 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVÍTICO 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LIVETCUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LIVITCUS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LÊ-VI KÝ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ΛΕΥΙΤΙΚΟ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ΛΕΥΙΤΙΚΌ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ΛΕΥΪΤΙΚΟ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ΛΕΥΪΤΙΚΌ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ЛЕВИТСКА 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("اللاويين 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("เลวีนิติ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOZES 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MÓZES 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOJZ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOJŻ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOSE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. МОЈС 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOJ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MOS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("III MÓS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITAK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITIC 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITIK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVITÁK 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("VAJIKRA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("WAJIKRA 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("الأحبار 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("லேவியர் 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOJZ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOJŻ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOOS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOSE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 МОЈС 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MOS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MÓS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("WALAWI 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVĪĀṂ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ਲੇਵੀਆਂ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ﺍﻟﻼﻭﻳﻲ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOJ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MOZ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MÓS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MÓZ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3. MO 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVYT 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LÊ-VI 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("IḤBĀR 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEWIY 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEWĪY 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ΛΕΥΙΤ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ΛΕΥΪΤ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ЛЕВИТ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ויקרא 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("احبار 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("लेवीय 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("लैव्य 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ଲେବୀୟ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("《利未記》 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("《利未记》 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("《利末记》 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("《肋未紀》 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MO 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 MZ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3MÓS 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KAPL 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KAPŁ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LAAW 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEVI 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("लेवि 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("लेवी 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("லேவி 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("《利未記 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("《利未记 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("《利末记 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("《肋未紀 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("利未記》 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("利未记》 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("利末记》 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("肋未紀》 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("3 М 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KPL 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("KPŁ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LAW 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEB 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEF 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LEV 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LÉV 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("WAL 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ΛΕΥ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ЛЕВ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ลนต 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("《利》 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("レヒ記 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("レビ記 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("利未記 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("利未记 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("利末记 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("肋未紀 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("레위기 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LE 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LV 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LÉ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("LÊ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("ΛΕ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("أح 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("لا 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("《利 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("レヒ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("レビ 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("利》 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("레위 1:1").osis()).toEqual("Lev.1.1")
		expect(p.parse("레 1:1").osis()).toEqual("Lev.1.1")
		`
		true
describe "Localized book 2Thess (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Thess (full)", ->
		`
		expect(p.parse("Втора писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Второ писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Второ послание на св. ап. Павла до Солуняни 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("رسالة بولس الرسول الثانية إلى أهل تسالونيكي 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("தெசலோனிக்கருக்கு எழுதிய இரண்டாவது திருமுகம் 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("தெசலோனிக்கியருக்கு எழுதிய இரண்டாவது நிருபம் 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhe poslannja apostola Pavla do solunjan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Второ послание на св ап. Павла до Солуняни 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Второ послание на св. ап Павла до Солуняни 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("தெசலோனிக்கருக்கு எழுதிய இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Второ послание на св ап Павла до Солуняни 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("தெசலோனிக்கேயருக்கு எழுதிய இரண்டாம் கடிதம் 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Paulus' Andet Brev til Thessalonikerne 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Paulus’ Andet Brev til Thessalonikerne 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("تھسلنیکوں کے نام پو لس رسول کادوسرا خط 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Paulus’ andre brev til tessalonikerne 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bref Pals til Þessalonikumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bref Pals til Þessaloníkumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bref Páls til Þessalonikumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bref Páls til Þessaloníkumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bréf Pals til Þessalonikumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bréf Pals til Þessaloníkumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bréf Páls til Þessalonikumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bréf Páls til Þessaloníkumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bref Pals til Þessalonikumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bref Pals til Þessaloníkumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bref Páls til Þessalonikumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bref Páls til Þessaloníkumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bréf Pals til Þessalonikumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bréf Pals til Þessaloníkumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bréf Páls til Þessalonikumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bréf Páls til Þessaloníkumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Drugi List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Drugi List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("थिस्सलोनिकीहरूलाई पावलको दोस्रो पत्र 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga List św Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Drugi List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Drugi List św Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Pavlova druga poslanica Solunjanima 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalunīkiyōṅ ke nām kā dūsrā ḫaṭ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. List św Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("الرسالة الثانية إلى أهل تسالونيكي 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("पौलाचे थेस्सलनीकाकरांस दुसरे पत्र 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. List św Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II List św Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Seconda lettera ai Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Toinen Kirje tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Waraka wa Pili kwa Wathesalonike 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Waraka wa Pili kwa Wathesaloniki 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikiharulai dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikiharulaī dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikiharulāi dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikiharulāī dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikiharūlai dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikiharūlaī dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikiharūlāi dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikiharūlāī dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikīharulai dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikīharulaī dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikīharulāi dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikīharulāī dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikīharūlai dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikīharūlaī dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikīharūlāi dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikīharūlāī dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("تھِسّلُنیکیوں کے نام کا دوسرا خط 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 List św Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Barua ya Pili kwa Wathesalonike 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Epistula II ad Thessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Epistula ad Thessalonicenses II 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("थिस्सलोनिकीहरूलाई दोस्त्रो पत्र 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ଥେସଲନୀକୀୟଙ୍କ ପ୍ରତି ଦ୍ୱିତୀୟ ପତ୍ର 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Mga Taga- Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Mga Taga- Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰassalunīkīāṃ nū̃ dūjī pattrī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanikakarams dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanikakaraṃs dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanikakarāms dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanikakarāṃs dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanikākarams dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanikākaraṃs dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanikākarāms dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanikākarāṃs dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanīkakarams dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanīkakaraṃs dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanīkakarāms dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanīkakarāṃs dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanīkākarams dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanīkākaraṃs dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanīkākarāms dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanīkākarāṃs dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Kirje tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Mga Taga Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Mga Taga Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("تھسلنیکیوں کے نام کا دوسرا خط 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Kirje tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Kirje tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Второ послание към солунците 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Kirje tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga Solunjanima Poslanica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga poslanica Solunjanima 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Mga Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Mga Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Masodik Thesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Második Thesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Toinen Tessalonikalaiskirje 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("אגרת פולוס השנייה אל-התסלונ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("האיגרת השנייה אל התסלוניקים 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ਥੱਸਲੁਨੀਕੀਆਂ ਨੂੰ ਦੂਜੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga List do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Drugi List do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Masodik Tesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Második Tesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Toinen Tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга посланица Солуњанима 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("थेस्सलनीकाकरांस दुसरे पत्र 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Andra Thessalonikerbrevet 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Deuxiemes Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Deuxièmes Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá kniha Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá kniha Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Solunjanima Poslanica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bref Pals til Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bref Páls til Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bréf Pals til Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bréf Páls til Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bref Pals til Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bref Páls til Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bréf Pals til Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bréf Páls til Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Solunjanima Poslanica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Andra Tessalonikerbrevet 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Deuxieme Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Deuxiemes Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Deuxième Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Deuxièmes Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá kniha Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá kniha Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Solunjanima Poslanica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. List do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Mga Taga- Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Mga Taga- Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessalonikalaiskirje 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. посланица Солуњанима 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Solunjanima Poslanica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. List do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Taga- Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Taga- Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonikalaiskirje 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. посланица Солуњанима 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Anden Thessalonikerbrev 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Andet Thessalonikerbrev 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Deuxieme Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Deuxième Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha list Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha list Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá list Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá list Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II List do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Mga Taga- Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Mga Taga- Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessalonikalaiskirje 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II посланица Солуњанима 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Mga Taga Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Mga Taga Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Segunda Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Segundo Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tweede Thessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("رسالة تسالونيكي الثانية 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 List do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Taga- Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Taga- Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonikalaiskirje 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 посланица Солуњанима 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. к Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. к Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-я. к Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-я. к Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Taga Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Taga Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Taga-Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Taga-Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Taga-Tesalónica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Taga-Tesalónika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonikerbrevet 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikiharulai 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikiharulaī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikiharulāi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikiharulāī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikiharūlai 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikiharūlaī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikiharūlāi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikiharūlāī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikīharulai 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikīharulaī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikīharulāi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikīharulāī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikīharūlai 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikīharūlaī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikīharūlāi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikīharūlāī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Andre tessalonikerbrev 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Tessalonicenskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Tessalonicenským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Tessalonicenskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Tessalonicenským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Tessalonicenskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Tessalonicenským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá kniha Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá kniha Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá kniha Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá kniha Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Tessalonicenskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Tessalonicenským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Mga Taga Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Mga Taga Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Segundo Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Segundo Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara Þessalonikubref 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara Þessalonikubréf 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara Þessaloníkubref 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara Þessaloníkubréf 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara Þessalonikubref 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara Þessalonikubréf 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara Þessaloníkubref 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara Þessaloníkubréf 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tweede Tessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ad Thessalonicenses II 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Taga Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Taga Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Taga-Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Taga-Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Taga-Tesalónica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Taga-Tesalónika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonikerbrevet 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikiharulai 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikiharulaī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikiharulāi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikiharulāī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikiharūlai 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikiharūlaī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikiharūlāi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikiharūlāī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikīharulai 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikīharulaī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikīharulāi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikīharulāī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikīharūlai 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikīharūlaī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikīharūlāi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikīharūlāī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е к Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е к Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-я к Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-я к Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonikerbrevet 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2eme. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ème. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2е. к Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2е. к Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2я. к Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2я. к Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá kniha Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá kniha Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Mga Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Mga Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. list Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. list Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Masodik Thesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Második Thesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Seconda Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Secondo Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Segundo Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Segundo Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Zweite Thessalonicher 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικείς Β' 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικείς Βʹ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικείς Βʹ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικείς Β΄ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικείς Β’ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικεις Β' 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικεις Βʹ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικεις Βʹ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικεις Β΄ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικεις Β’ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tecalonikkiyarukku 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tecaloṉikkiyarukku 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tecalōnikkiyarukku 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tecalōṉikkiyarukku 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonikerbrevet 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanikakarams 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanikakaraṃs 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanikakarāms 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanikakarāṃs 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanikākarams 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanikākaraṃs 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanikākarāms 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanikākarāṃs 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanīkakarams 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanīkakaraṃs 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanīkakarāms 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanīkakarāṃs 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanīkākarams 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanīkākaraṃs 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanīkākarāms 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanīkākarāṃs 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-я. Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-я. Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thaissaluneekiyon 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonikerbrev 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. list Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. list Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. к Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. к Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. थिस्सलोनिकीहरूलाई 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2de. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e. Thessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2eme Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2eme. Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ème Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ème. Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2е к Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2е к Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2я к Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2я к Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Anden Tessalonikerne 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Andre Tessalonikerne 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga Tesalonicensow 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga Tesalonicensów 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Drugi Tesalonicensow 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Drugi Tesalonicensów 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha list Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha list Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha list Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha list Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá list Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá list Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá list Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá list Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Mga Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Mga Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II list Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II list Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessalonicenskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessalonicenským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Masodik Tesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Második Tesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("השנייה אל התסלוניקים 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("테살로니카 신자들에게 보낸 둘째 서간 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thaissaluneekiyon 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonikerbrev 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 e. Thesalonikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 i. Thesalonikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 list Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 list Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 к Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 к Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 थिस्सलोनिकीहरूलाई 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-я Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-я Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonicenskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonicenským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tessalonikerbrev 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o. Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o. Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º. Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º. Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2a. Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2d. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2de Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2de. Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e Thessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e. Tessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2eme Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o. Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ème Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2е. Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2е. Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2я. Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2я. Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Dezyem Tesalonikyen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Dezyèm Tesalonikyen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessalonicenskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessalonicenským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thê-sa-lô-ni-ca 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Thessalonicenses II 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonicenskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonicenským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 e Thesalonikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 i Thesalonikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tessalonikerbrev 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Taga-Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Taga-Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Taga-Tesalónica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Taga-Tesalónika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thê-sa-lô-ni-ca 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o. Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o. Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º. Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º. Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2a Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2d Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2d. Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2de Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e Tessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e. Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o. Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o. Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º. Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º. Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2е Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2е Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2я Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2я Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Andre Tessaloniker 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Drugi Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thê-sa-lô-ni-ca 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonicensow 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonicensów 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tê-sa-lô-ni-ca 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. list Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. list Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. list Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. list Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Pili Wathesalonike 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tesoloniika Labaad 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ଥେସଲନୀକୀୟଙ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Taga-Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Taga-Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Taga-Tesalónica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Taga-Tesalónika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thê-sa-lô-ni-ca 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 थेस्सलनीकाकरांस 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ਥੱਸਲੁਨੀਕੀਆਂ ਨੂੰ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonicensow 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonicensów 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonikerne 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonicher 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tê-sa-lô-ni-ca 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. list Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. list Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. list Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. list Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. थिस्सलुनीकियों 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2d Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o. Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o. Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2°. Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º. Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º. Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga Solunjanima 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonicensow 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonicensów 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tê-sa-lô-ni-ca 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II list Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II list Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II list Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II list Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Wathesalonike 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("دوم-تھِسّلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ﺍﻟﺜﺎﻧﻴﺔ ﺗﺴﺎﻟﻮﻧﻴﻜﻲ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonicensow 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonicensów 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonikerne 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonicher 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tê-sa-lô-ni-ca 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 e. Selanikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 i. Selanikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 list Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 list Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 list Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 list Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰassalunīkīāṃ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 थिस्सलुनीकियों 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 தெசலோனிக்கேயர் 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Wathesalonike 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.-تھِسّلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2° Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Dezyem Tesalonik 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Dezyèm Tesalonik 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Wathesalonike 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesaloniceni 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonikyen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Wathesalonike II 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β' Θεσσαλονικείς 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β' Θεσσαλονικεις 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ Θεσσαλονικείς 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ Θεσσαλονικεις 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ Θεσσαλονικείς 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ Θεσσαλονικεις 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β΄ Θεσσαλονικείς 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β΄ Θεσσαλονικεις 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β’ Θεσσαλονικείς 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β’ Θεσσαλονικεις 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга Солуњанима 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("دوم تھِسلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Wathesalonike 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 e Selanikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 i Selanikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-تھِسّلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesaloniceni 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonikyen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessaloniker 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. تھِسلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesaloniceni 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonikyen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Solunjanima 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesaloniika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thêxalônica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Втора Солунците 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Втора Солунјани 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Второ Солунците 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Второ Солунјани 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("دوم تھسّلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("۲-تھِسّلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesaloniceni 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonikyen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessaloniker 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 تھِسلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 தெசலோனிக்கர் 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Selanikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Solunjanima 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesaloniika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thêxalônica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. تھسّلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. थिस्सलोनिकी 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Solunjanima 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesaloniika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thêxalônica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tèsalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Солуњанима 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Masodik Thessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Második Thessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("دوم۔تھسلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("۲ تھِسلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Selanikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Solunjanima 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesaloniika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thêxalônica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 تھسّلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 थिस्सलोनिकी 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalónica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalónika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tèsalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Солуњанима 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. ଥେସଲନୀକୀୟଙ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. เธซะโลนิกา 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. เธสะโลนิกา 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.۔تھسلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tèsalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Солуњанима 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonik 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Солунците 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Солунјани 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Masodik Tessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Második Tessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Втора Солунци 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("دوم تھسلنیکوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("۲ تھسّلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("テサロニケの信徒への手紙二 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("テサロニケ人への第二の手紙 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalónica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalónika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tèsalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Солуњанима 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ଥେସଲନୀକୀୟଙ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 เธซะโลนิกา 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 เธสะโลนิกา 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonik 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Солунците 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Солунјани 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. تھسلنیکوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. थिसलुनिकी 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2۔تھسلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonik 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Солунците 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Солунјани 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tweede Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("۲۔تھسلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonik 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Солунците 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Солунјани 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 تھسلنیکوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 थिसलुनिकी 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Anden Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Солунци 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tweede Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("۲ تھسلنیکوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("テサロニケ人への後の書 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("テサロニケ人への手紙二 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Солунци 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Andre Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Солунци 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tweede Tes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Солунци 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e. Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Sol 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Sol 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Sol 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Sol 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Pili Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Втора Сол 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖撒罗尼迦后书》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖撒羅尼迦後書》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. थिस्स 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e. Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Te 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Te 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Te 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Te 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Pili The 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖撒罗尼迦后书 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖撒羅尼迦後書 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《得撒洛尼後書》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖撒罗尼迦后书》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖撒羅尼迦後書》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 थिस्स 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 தெசலோ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e. Tes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Sol 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. The 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Сол 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Pili Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《得撒洛尼後書 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("テサロニケ 2 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("テサロニケ後書 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖撒罗尼迦后书 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖撒羅尼迦後書 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("得撒洛尼後書》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("데살로니가2서 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("데살로니가후서 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("테살로니카2서 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Sol 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. The 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Сол 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e Tes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Sol 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II The 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Сол 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Te 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tê 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β' Θεσ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ Θεσ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ Θεσ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β΄ Θεσ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β’ Θεσ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("得撒洛尼後書 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Sol 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 The 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Сол 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Фес 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 தெச 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Te 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tê 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Te 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tê 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β' Θε 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ Θε 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ Θε 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β΄ Θε 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β’ Θε 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《莎倫後》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Te 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Ts 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tê 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 تس 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ธส 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖后》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖後》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《莎倫後 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("莎倫後》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2테살 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖后 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖後 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖后》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖後》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("莎倫後 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖后 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖後 1:1").osis()).toEqual("2Thess.1.1")
		`
		true
	it "should handle non-Latin digits in book: 2Thess (full)", ->
		p.set_options non_latin_digits_strategy: "replace"
		`
		expect(p.parse("Втора писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Второ писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Второ послание на св. ап. Павла до Солуняни 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("رسالة بولس الرسول الثانية إلى أهل تسالونيكي 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("தெசலோனிக்கருக்கு எழுதிய இரண்டாவது திருமுகம் 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("தெசலோனிக்கியருக்கு எழுதிய இரண்டாவது நிருபம் 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhe poslannja apostola Pavla do solunjan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Второ послание на св ап. Павла до Солуняни 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Второ послание на св. ап Павла до Солуняни 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("தெசலோனிக்கருக்கு எழுதிய இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Второ послание на св ап Павла до Солуняни 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("தெசலோனிக்கேயருக்கு எழுதிய இரண்டாம் கடிதம் 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 послання св. апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 послання св апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Paulus' Andet Brev til Thessalonikerne 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Paulus’ Andet Brev til Thessalonikerne 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("تھسلنیکوں کے نام پو لس رسول کادوسرا خط 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Paulus’ andre brev til tessalonikerne 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bref Pals til Þessalonikumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bref Pals til Þessaloníkumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bref Páls til Þessalonikumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bref Páls til Þessaloníkumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bréf Pals til Þessalonikumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bréf Pals til Þessaloníkumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bréf Páls til Þessalonikumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bréf Páls til Þessaloníkumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bref Pals til Þessalonikumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bref Pals til Þessaloníkumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bref Páls til Þessalonikumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bref Páls til Þessaloníkumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bréf Pals til Þessalonikumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bréf Pals til Þessaloníkumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bréf Páls til Þessalonikumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bréf Páls til Þessaloníkumanna 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 послання апостола Павла до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Drugi List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Drugi List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("थिस्सलोनिकीहरूलाई पावलको दोस्रो पत्र 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga List św Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Drugi List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Drugi List św Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Pavlova druga poslanica Solunjanima 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalunīkiyōṅ ke nām kā dūsrā ḫaṭ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. List św Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("الرسالة الثانية إلى أهل تسالونيكي 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("पौलाचे थेस्सलनीकाकरांस दुसरे पत्र 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. List św Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II List św Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Seconda lettera ai Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Toinen Kirje tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Waraka wa Pili kwa Wathesalonike 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Waraka wa Pili kwa Wathesaloniki 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikiharulai dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikiharulaī dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikiharulāi dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikiharulāī dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikiharūlai dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikiharūlaī dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikiharūlāi dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikiharūlāī dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikīharulai dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikīharulaī dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikīharulāi dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikīharulāī dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikīharūlai dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikīharūlaī dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikīharūlāi dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰissalonikīharūlāī dostro patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("تھِسّلُنیکیوں کے نام کا دوسرا خط 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 List św Pawła do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Barua ya Pili kwa Wathesalonike 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Epistula II ad Thessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Epistula ad Thessalonicenses II 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("थिस्सलोनिकीहरूलाई दोस्त्रो पत्र 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ଥେସଲନୀକୀୟଙ୍କ ପ୍ରତି ଦ୍ୱିତୀୟ ପତ୍ର 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Mga Taga- Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Mga Taga- Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰassalunīkīāṃ nū̃ dūjī pattrī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanikakarams dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanikakaraṃs dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanikakarāms dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanikakarāṃs dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanikākarams dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanikākaraṃs dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanikākarāms dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanikākarāṃs dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanīkakarams dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanīkakaraṃs dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanīkakarāms dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanīkakarāṃs dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanīkākarams dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanīkākaraṃs dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanīkākarāms dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("tʰessalanīkākarāṃs dusre patra 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 послання до фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 послання до фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Kirje tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Mga Taga Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Mga Taga Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("تھسلنیکیوں کے نام کا دوسرا خط 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Kirje tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Kirje tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Второ послание към солунците 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Kirje tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga Solunjanima Poslanica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga poslanica Solunjanima 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Mga Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Mga Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Masodik Thesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Második Thesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Toinen Tessalonikalaiskirje 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("אגרת פולוס השנייה אל-התסלונ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("האיגרת השנייה אל התסלוניקים 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ਥੱਸਲੁਨੀਕੀਆਂ ਨੂੰ ਦੂਜੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 послання до салонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 послання до салонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga List do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Drugi List do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Masodik Tesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Második Tesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Toinen Tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга посланица Солуњанима 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("थेस्सलनीकाकरांस दुसरे पत्र 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Andra Thessalonikerbrevet 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Deuxiemes Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Deuxièmes Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá kniha Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá kniha Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Solunjanima Poslanica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bref Pals til Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bref Páls til Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bréf Pals til Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara bréf Páls til Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bref Pals til Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bref Páls til Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bréf Pals til Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara bréf Páls til Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Solunjanima Poslanica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Andra Tessalonikerbrevet 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Deuxieme Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Deuxiemes Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Deuxième Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Deuxièmes Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá kniha Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá kniha Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Solunjanima Poslanica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. List do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Mga Taga- Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Mga Taga- Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessalonikalaiskirje 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. посланица Солуњанима 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Solunjanima Poslanica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. List do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Taga- Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Taga- Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonikalaiskirje 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. посланица Солуњанима 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Anden Thessalonikerbrev 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Andet Thessalonikerbrev 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Deuxieme Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Deuxième Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha list Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha list Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá list Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá list Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II List do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Mga Taga- Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Mga Taga- Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessalonikalaiskirje 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II посланица Солуњанима 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Mga Taga Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Mga Taga Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Segunda Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Segundo Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tweede Thessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("رسالة تسالونيكي الثانية 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 List do Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Taga- Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Taga- Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonikalaiskirje 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 посланица Солуњанима 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. к Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. к Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-я. к Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-я. к Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Taga Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Taga Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Taga-Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Taga-Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Taga-Tesalónica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Taga-Tesalónika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonikerbrevet 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikiharulai 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikiharulaī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikiharulāi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikiharulāī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikiharūlai 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikiharūlaī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikiharūlāi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikiharūlāī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikīharulai 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikīharulaī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikīharulāi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikīharulāī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikīharūlai 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikīharūlaī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikīharūlāi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tʰissalonikīharūlāī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Andre tessalonikerbrev 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Tessalonicenskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Tessalonicenským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Tessalonicenskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Tessalonicenským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Tessalonicenskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Tessalonicenským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá kniha Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá kniha Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá kniha Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá kniha Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Tessalonicenskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Tessalonicenským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Mga Taga Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Mga Taga Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Segundo Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Segundo Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara Þessalonikubref 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara Þessalonikubréf 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara Þessaloníkubref 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Siðara Þessaloníkubréf 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara Þessalonikubref 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara Þessalonikubréf 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara Þessaloníkubref 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Síðara Þessaloníkubréf 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tweede Tessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ad Thessalonicenses II 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Taga Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Taga Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Taga-Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Taga-Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Taga-Tesalónica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Taga-Tesalónika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonikalaisille 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonikerbrevet 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikiharulai 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikiharulaī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikiharulāi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikiharulāī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikiharūlai 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikiharūlaī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikiharūlāi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikiharūlāī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikīharulai 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikīharulaī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikīharulāi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikīharulāī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikīharūlai 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikīharūlaī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikīharūlāi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰissalonikīharūlāī 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 послання до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е к Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е к Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-я к Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-я к Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonikerbrevet 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2eme. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ème. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2е. к Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2е. к Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2я. к Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2я. к Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha kniha Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá kniha Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá kniha Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Mga Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Mga Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. list Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. list Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Masodik Thesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Második Thesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Seconda Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Secondo Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Segundo Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Segundo Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Zweite Thessalonicher 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικείς Β' 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικείς Βʹ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικείς Βʹ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικείς Β΄ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικείς Β’ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικεις Β' 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικεις Βʹ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικεις Βʹ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικεις Β΄ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικεις Β’ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tecalonikkiyarukku 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tecaloṉikkiyarukku 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tecalōnikkiyarukku 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tecalōṉikkiyarukku 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonikerbrevet 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesszalonikaiakhoz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanikakarams 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanikakaraṃs 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanikakarāms 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanikakarāṃs 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanikākarams 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanikākaraṃs 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanikākarāms 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanikākarāṃs 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanīkakarams 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanīkakaraṃs 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanīkakarāms 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanīkakarāṃs 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanīkākarams 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanīkākaraṃs 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanīkākarāms 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰessalanīkākarāṃs 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-я. Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-я. Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Mga Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thaissaluneekiyon 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonikerbrev 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. list Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. list Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. к Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. к Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. थिस्सलोनिकीहरूलाई 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2de. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e. Thessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2eme Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2eme. Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ème Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ème. Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2е к Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2е к Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2я к Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2я к Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Anden Tessalonikerne 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Andre Tessalonikerne 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga Tesalonicensow 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga Tesalonicensów 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Drugi Tesalonicensow 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Drugi Tesalonicensów 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha list Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha list Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha list Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha list Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy list Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá list Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá list Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá list Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá list Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý list Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Mga Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Mga Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II list Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II list Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessalonicenskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessalonicenským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Ikalawang Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Masodik Tesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Második Tesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("השנייה אל התסלוניקים 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("테살로니카 신자들에게 보낸 둘째 서간 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Mga Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thaissaluneekiyon 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonikerbrev 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 e. Thesalonikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 i. Thesalonikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 list Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 list Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 к Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 к Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 थिस्सलोनिकीहरूलाई 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-я Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-я Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonicenskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonicenským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. tessalonikerbrev 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o. Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o. Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º. Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º. Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2a. Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2d. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2de Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2de. Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e Thessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e. Tessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2eme Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o. Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ème Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2е. Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2е. Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2я. Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2я. Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Dezyem Tesalonikyen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Dezyèm Tesalonikyen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessalonicenskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessalonicenským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thê-sa-lô-ni-ca 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Thessalonicenses II 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonicenskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonicenským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 e Thesalonikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 i Thesalonikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tessalonikerbrev 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Taga-Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Taga-Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Taga-Tesalónica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Taga-Tesalónika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thê-sa-lô-ni-ca 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o. Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o. Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º. Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º. Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2a Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2d Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2d. Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2de Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e Tessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e. Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o. Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o. Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º. Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º. Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2е Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2е Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2я Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2я Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Andre Tessaloniker 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Drugi Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thê-sa-lô-ni-ca 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonicensow 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonicensów 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tê-sa-lô-ni-ca 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. list Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. list Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. list Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. list Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Pili Wathesalonike 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tesoloniika Labaad 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ଥେସଲନୀକୀୟଙ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Taga-Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Taga-Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Taga-Tesalónica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Taga-Tesalónika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonicenzen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonicians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thê-sa-lô-ni-ca 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Фессалоникиицам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Фессалоникийцам 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 фессалонікіиців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 фессалонікійців 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 थेस्सलनीकाकरांस 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ਥੱਸਲੁਨੀਕੀਆਂ ਨੂੰ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonicensow 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonicensów 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonikerne 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonicher 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tê-sa-lô-ni-ca 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. list Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. list Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. list Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. list Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. थिस्सलुनीकियों 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.o Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2d Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o. Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o. Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2°. Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º. Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º. Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druga Solunjanima 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonicensow 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonicensów 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tê-sa-lô-ni-ca 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II list Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II list Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II list Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II list Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Wathesalonike 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("دوم-تھِسّلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ﺍﻟﺜﺎﻧﻴﺔ ﺗﺴﺎﻟﻮﻧﻴﻜﻲ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonicenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonicensow 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonicensów 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonisenses 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonikerne 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesaloniciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonaians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonciens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloniaans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonicher 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloniions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonioans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonoians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tê-sa-lô-ni-ca 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 e. Selanikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 i. Selanikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 list Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 list Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 list Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 list Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 tʰassalunīkīāṃ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 थिस्सलुनीकियों 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 தெசலோனிக்கேயர் 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Wathesalonike 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.-تھِسّلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2o Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2° Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Dezyem Tesalonik 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Dezyèm Tesalonik 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Wathesalonike 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesaloniceni 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonikyen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Wathesalonike II 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β' Θεσσαλονικείς 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β' Θεσσαλονικεις 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ Θεσσαλονικείς 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ Θεσσαλονικεις 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ Θεσσαλονικείς 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ Θεσσαλονικεις 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β΄ Θεσσαλονικείς 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β΄ Θεσσαλονικεις 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β’ Θεσσαλονικείς 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β’ Θεσσαλονικεις 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга Солуњанима 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("دوم تھِسلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonicanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonicense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonisense 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesaloničanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessalonicesi 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesallonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonicans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesaloniians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloneans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessaloniens 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonoans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Wathesalonike 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 e Selanikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 i Selanikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-تھِسّلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesaloniceni 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonikyen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessaloniker 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. تھِسلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesaloniceni 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonikyen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Solunjanima 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesaloniika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thêxalônica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Втора Солунците 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Втора Солунјани 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Второ Солунците 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Второ Солунјани 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("دوم تھسّلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("۲-تھِسّلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesaloniceni 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonickym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonickým 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesaloniczan 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonikyen 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessaloniker 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesszalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesaloniaid 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonions 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Theselonains 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Theselonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesolonians 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonain 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonans 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessalonion 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessolonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k. Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 تھِسلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 தெசலோனிக்கர் 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Selanikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Solunjanima 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesaloniika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thêxalônica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. تھسّلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. थिस्सलोनिकी 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Solunjanima 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesaloniika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thêxalônica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tèsalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Солуњанима 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Masodik Thessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Második Thessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("دوم۔تھسلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("۲ تھِسلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Selanikasve 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Solunjanima 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesaloniika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesalonins 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Theselonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesolonian 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thêxalônica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 k Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 تھسّلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 थिस्सलोनिकी 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге. Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalónica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalónika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tèsalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Солуњанима 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. ଥେସଲନୀକୀୟଙ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. เธซะโลนิกา 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. เธสะโลนิกา 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.۔تھسلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tèsalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Солуњанима 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tesalonik 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Солунците 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Солунјани 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Masodik Tessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Második Tessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Втора Солунци 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друга Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Друге Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("دوم تھسلنیکوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("۲ تھسّلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("テサロニケの信徒への手紙二 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("テサロニケ人への第二の手紙 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Soluncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Solunčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Solúncanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Solúnčanom 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalónica 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalónika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tèsalonika 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Солуњанима 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 до солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ଥେସଲନୀକୀୟଙ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 เธซะโลนิกา 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 เธสะโลนิกา 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а. Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ге Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е. Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tesalonik 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Солунците 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Солунјани 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. تھسلنیکوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. थिसलुनिकी 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2۔تھسلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tesalonik 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Солунците 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Солунјани 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tweede Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("۲۔تھسلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Solunskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Solunským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Soluňskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Soluňským 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Solúnskym 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tesalonik 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Солунците 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Солунјани 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 تھسلنیکوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 थिसलुनिकी 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-а Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-е Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Anden Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Солунци 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tweede Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("۲ تھسلنیکوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("テサロニケ人への後の書 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("テサロニケ人への手紙二 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Солуньці 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Солунци 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Andre Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Солунци 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Tweede Tes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Солунци 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Солунян 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e. Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Sol 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Sol 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Sol 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Sol 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Pili Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Second Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Втора Сол 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖撒罗尼迦后书》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖撒羅尼迦後書》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thesss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. थिस्स 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e. Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druha Te 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhy Te 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhá Te 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Druhý Te 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Pili The 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖撒罗尼迦后书 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖撒羅尼迦後書 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《得撒洛尼後書》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖撒罗尼迦后书》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖撒羅尼迦後書》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tessz 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thsss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 थिस्स 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 தெசலோ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e. Tes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd. Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Sol 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. The 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Сол 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Pili Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《得撒洛尼後書 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("テサロニケ 2 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("テサロニケ後書 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖撒罗尼迦后书 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖撒羅尼迦後書 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("得撒洛尼後書》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("데살로니가2서 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("데살로니가후서 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("테살로니카2서 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Thss 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Þess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Sol 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. The 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Сол 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2Thess 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2e Tes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2nd Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Sol 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II The 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Сол 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Te 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. Tê 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β' Θεσ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ Θεσ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ Θεσ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β΄ Θεσ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β’ Θεσ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("得撒洛尼後書 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Sol 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tes 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 The 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Ths 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Сол 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Фес 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 தெச 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Te 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. Tê 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Te 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II Tê 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β' Θε 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ Θε 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ Θε 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β΄ Θε 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β’ Θε 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《莎倫後》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Te 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Th 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Ts 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 Tê 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 تس 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ธส 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖后》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖後》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《莎倫後 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("莎倫後》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2테살 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖后 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖後 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖后》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖後》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("莎倫後 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖后 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖後 1:1").osis()).toEqual("2Thess.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ВТОРА ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО СОЛУН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ВТОРО ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО СОЛУН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО СОЛУН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО СОЛУН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО СОЛУН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО СОЛУН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALONIKKIYARUKKU ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALONIKKIYARUKKU ELUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALONIKKIYARUKKU ELUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALONIKKIYARUKKU ELUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALONIKKIYARUKKU ELUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALONIKKIYARUKKU ELUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALONIKKIYARUKKU ELUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALONIKKIYARUKKU ELUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALONIKKIYARUKKU EḺUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALONIKKIYARUKKU EḺUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALONIKKIYARUKKU EḺUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALONIKKIYARUKKU EḺUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALONIKKIYARUKKU EḺUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALONIKKIYARUKKU EḺUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALONIKKIYARUKKU EḺUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALONIKKIYARUKKU EḺUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALOṈIKKIYARUKKU ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALOṈIKKIYARUKKU ELUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALOṈIKKIYARUKKU ELUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALOṈIKKIYARUKKU ELUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALOṈIKKIYARUKKU ELUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALOṈIKKIYARUKKU ELUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALOṈIKKIYARUKKU ELUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALOṈIKKIYARUKKU ELUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALOṈIKKIYARUKKU EḺUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALOṈIKKIYARUKKU EḺUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALOṈIKKIYARUKKU EḺUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALOṈIKKIYARUKKU EḺUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALOṈIKKIYARUKKU EḺUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALOṈIKKIYARUKKU EḺUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALOṈIKKIYARUKKU EḺUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALOṈIKKIYARUKKU EḺUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌNIKKIYARUKKU ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌNIKKIYARUKKU ELUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌNIKKIYARUKKU ELUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌNIKKIYARUKKU ELUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌNIKKIYARUKKU ELUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌNIKKIYARUKKU ELUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌNIKKIYARUKKU ELUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌNIKKIYARUKKU ELUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌNIKKIYARUKKU EḺUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌNIKKIYARUKKU EḺUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌNIKKIYARUKKU EḺUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌNIKKIYARUKKU EḺUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌNIKKIYARUKKU EḺUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌNIKKIYARUKKU EḺUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌNIKKIYARUKKU EḺUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌNIKKIYARUKKU EḺUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌṈIKKIYARUKKU ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌṈIKKIYARUKKU ELUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌṈIKKIYARUKKU ELUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌṈIKKIYARUKKU ELUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌṈIKKIYARUKKU ELUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌṈIKKIYARUKKU ELUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌṈIKKIYARUKKU ELUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌṈIKKIYARUKKU ELUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌṈIKKIYARUKKU EḺUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌṈIKKIYARUKKU EḺUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌṈIKKIYARUKKU EḺUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌṈIKKIYARUKKU EḺUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌṈIKKIYARUKKU EḺUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌṈIKKIYARUKKU EḺUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌṈIKKIYARUKKU EḺUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TECALŌṈIKKIYARUKKU EḺUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ. ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГА ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГЕ ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А. ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ. ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е. ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ВТОРО ПОСЛАНИЕ НА СВ. АП. ПАВЛА ДО СОЛУНЯНИ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГА ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГЕ ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("رسالة بولس الرسول الثانية إلى أهل تسالونيكي 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("தெசலோனிக்கருக்கு எழுதிய இரண்டாவது திருமுகம் 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("தெசலோனிக்கியருக்கு எழுதிய இரண்டாவது நிருபம் 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А. ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е. ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHE POSLANNJA APOSTOLA PAVLA DO SOLUNJAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ВТОРО ПОСЛАНИЕ НА СВ АП. ПАВЛА ДО СОЛУНЯНИ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ВТОРО ПОСЛАНИЕ НА СВ. АП ПАВЛА ДО СОЛУНЯНИ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("தெசலோனிக்கருக்கு எழுதிய இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ВТОРО ПОСЛАНИЕ НА СВ АП ПАВЛА ДО СОЛУНЯНИ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("தெசலோனிக்கேயருக்கு எழுதிய இரண்டாம் கடிதம் 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГА ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГЕ ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("PAULUS' ANDET BREV TIL THESSALONIKERNE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("PAULUS’ ANDET BREV TIL THESSALONIKERNE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("تھسلنیکوں کے نام پو لس رسول کادوسرا خط 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("PAULUS’ ANDRE BREV TIL TESSALONIKERNE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SIÐARA BREF PALS TIL ÞESSALONIKUMANNA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SIÐARA BREF PALS TIL ÞESSALONÍKUMANNA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SIÐARA BREF PÁLS TIL ÞESSALONIKUMANNA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SIÐARA BREF PÁLS TIL ÞESSALONÍKUMANNA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SIÐARA BRÉF PALS TIL ÞESSALONIKUMANNA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SIÐARA BRÉF PALS TIL ÞESSALONÍKUMANNA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SIÐARA BRÉF PÁLS TIL ÞESSALONIKUMANNA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SIÐARA BRÉF PÁLS TIL ÞESSALONÍKUMANNA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SÍÐARA BREF PALS TIL ÞESSALONIKUMANNA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SÍÐARA BREF PALS TIL ÞESSALONÍKUMANNA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SÍÐARA BREF PÁLS TIL ÞESSALONIKUMANNA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SÍÐARA BREF PÁLS TIL ÞESSALONÍKUMANNA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SÍÐARA BRÉF PALS TIL ÞESSALONIKUMANNA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SÍÐARA BRÉF PALS TIL ÞESSALONÍKUMANNA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SÍÐARA BRÉF PÁLS TIL ÞESSALONIKUMANNA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SÍÐARA BRÉF PÁLS TIL ÞESSALONÍKUMANNA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGA LIST SW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGA LIST ŚW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGI LIST SW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGI LIST ŚW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("थिस्सलोनिकीहरूलाई पावलको दोस्रो पत्र 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGA LIST SW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGA LIST ŚW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGI LIST SW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGI LIST ŚW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("PAVLOVA DRUGA POSLANICA SOLUNJANIMA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰISSALUNĪKIYŌṄ KE NĀM KĀ DŪSRĀ ḪAṬ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. LIST SW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. LIST ŚW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ. ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ. ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. LIST SW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. LIST ŚW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II LIST SW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II LIST ŚW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. LIST SW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. LIST ŚW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГА ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГА ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГЕ ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГЕ ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("الرسالة الثانية إلى أهل تسالونيكي 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("पौलाचे थेस्सलनीकाकरांस दुसरे पत्र 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 LIST SW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 LIST ŚW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А. ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А. ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е. ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е. ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. LIST SW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. LIST ŚW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II LIST SW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II LIST ŚW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECONDA LETTERA AI TESSALONICESI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TOINEN KIRJE TESSALONIKALAISILLE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("WARAKA WA PILI KWA WATHESALONIKE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("WARAKA WA PILI KWA WATHESALONIKI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰISSALONIKIHARULAI DOSTRO PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰISSALONIKIHARULAĪ DOSTRO PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰISSALONIKIHARULĀI DOSTRO PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰISSALONIKIHARULĀĪ DOSTRO PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰISSALONIKIHARŪLAI DOSTRO PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰISSALONIKIHARŪLAĪ DOSTRO PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰISSALONIKIHARŪLĀI DOSTRO PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰISSALONIKIHARŪLĀĪ DOSTRO PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰISSALONIKĪHARULAI DOSTRO PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰISSALONIKĪHARULAĪ DOSTRO PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰISSALONIKĪHARULĀI DOSTRO PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰISSALONIKĪHARULĀĪ DOSTRO PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰISSALONIKĪHARŪLAI DOSTRO PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰISSALONIKĪHARŪLAĪ DOSTRO PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰISSALONIKĪHARŪLĀI DOSTRO PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰISSALONIKĪHARŪLĀĪ DOSTRO PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("تھِسّلُنیکیوں کے نام کا دوسرا خط 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 LIST SW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 LIST ŚW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("BARUA YA PILI KWA WATHESALONIKE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("EPISTULA II AD THESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("EPISTULA AD THESSALONICENSES II 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("थिस्सलोनिकीहरूलाई दोस्त्रो पत्र 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ଥେସଲନୀକୀୟଙ୍କ ପ୍ରତି ଦ୍ୱିତୀୟ ପତ୍ର 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ. ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ. ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("IKALAWANG MGA TAGA- TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("IKALAWANG MGA TAGA- TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰASSALUNĪKĪĀṂ NŪ̃ DŪJĪ PATTRĪ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰESSALANIKAKARAMS DUSRE PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰESSALANIKAKARAṂS DUSRE PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰESSALANIKAKARĀMS DUSRE PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰESSALANIKAKARĀṂS DUSRE PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰESSALANIKĀKARAMS DUSRE PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰESSALANIKĀKARAṂS DUSRE PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰESSALANIKĀKARĀMS DUSRE PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰESSALANIKĀKARĀṂS DUSRE PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰESSALANĪKAKARAMS DUSRE PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰESSALANĪKAKARAṂS DUSRE PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰESSALANĪKAKARĀMS DUSRE PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰESSALANĪKAKARĀṂS DUSRE PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰESSALANĪKĀKARAMS DUSRE PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰESSALANĪKĀKARAṂS DUSRE PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰESSALANĪKĀKARĀMS DUSRE PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TʰESSALANĪKĀKARĀṂS DUSRE PATRA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГА ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГА ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГЕ ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГЕ ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А. ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А. ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е. ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е. ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. KIRJE TESSALONIKALAISILLE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("IKALAWANG MGA TAGA TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("IKALAWANG MGA TAGA TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("تھسلنیکیوں کے نام کا دوسرا خط 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. KIRJE TESSALONIKALAISILLE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II KIRJE TESSALONIKALAISILLE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ВТОРО ПОСЛАНИЕ КЪМ СОЛУНЦИТЕ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 KIRJE TESSALONIKALAISILLE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGA SOLUNJANIMA POSLANICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGA POSLANICA SOLUNJANIMA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("IKALAWANG MGA TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("IKALAWANG MGA TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("MASODIK THESSZALONIKAIAKHOZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("MÁSODIK THESSZALONIKAIAKHOZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TOINEN TESSALONIKALAISKIRJE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("אגרת פולוס השנייה אל-התסלונ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("האיגרת השנייה אל התסלוניקים 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ਥੱਸਲੁਨੀਕੀਆਂ ਨੂੰ ਦੂਜੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGA LIST DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGI LIST DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("MASODIK TESSZALONIKAIAKHOZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("MÁSODIK TESSZALONIKAIAKHOZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TOINEN TESSALONIKALAISILLE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГА ПОСЛАНИЦА СОЛУЊАНИМА 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("थेस्सलनीकाकरांस दुसरे पत्र 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ. ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ANDRA THESSALONIKERBREVET 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DEUXIEMES THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DEUXIÈMES THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA KNIHA TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA KNIHA TESALONIČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ KNIHA TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ KNIHA TESALONIČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. SOLUNJANIMA POSLANICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SIÐARA BREF PALS TIL ÞESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SIÐARA BREF PÁLS TIL ÞESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SIÐARA BRÉF PALS TIL ÞESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SIÐARA BRÉF PÁLS TIL ÞESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SÍÐARA BREF PALS TIL ÞESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SÍÐARA BREF PÁLS TIL ÞESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SÍÐARA BRÉF PALS TIL ÞESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SÍÐARA BRÉF PÁLS TIL ÞESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГА ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГЕ ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А. ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е. ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. SOLUNJANIMA POSLANICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ANDRA TESSALONIKERBREVET 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DEUXIEME THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DEUXIEMES THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DEUXIÈME THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DEUXIÈMES THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA KNIHA TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA KNIHA TESALONICKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY LIST TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY LIST TESALONIČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ KNIHA TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ KNIHA TESALONICKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ LIST TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ LIST TESALONIČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II SOLUNJANIMA POSLANICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. LIST DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. MGA TAGA- TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. MGA TAGA- TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESSALONIKALAISKIRJE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. ПОСЛАНИЦА СОЛУЊАНИМА 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 SOLUNJANIMA POSLANICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. LIST DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. MGA TAGA- TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. MGA TAGA- TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSALONIKALAISKIRJE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. ПОСЛАНИЦА СОЛУЊАНИМА 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ANDEN THESSALONIKERBREV 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ANDET THESSALONIKERBREV 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DEUXIEME THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DEUXIÈME THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA LIST TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA LIST TESALONICKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY LIST TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY LIST TESALONICKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ LIST TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ LIST TESALONICKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ LIST TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ LIST TESALONICKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II LIST DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II MGA TAGA- TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II MGA TAGA- TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESSALONIKALAISKIRJE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II ПОСЛАНИЦА СОЛУЊАНИМА 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. MGA TAGA TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. MGA TAGA TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESSALONIKALAISILLE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSZALONIKAIAKHOZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("IKALAWANG TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("IKALAWANG TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SEGUNDA TESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SEGUNDO TESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TWEEDE THESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("رسالة تسالونيكي الثانية 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 LIST DO TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 MGA TAGA- TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 MGA TAGA- TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSALONIKALAISKIRJE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ПОСЛАНИЦА СОЛУЊАНИМА 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е. К ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е. К ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Я. К ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Я. К ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. MGA TAGA TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. MGA TAGA TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. MGA TAGA-TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. MGA TAGA-TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. MGA TAGA-TESALÓNICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. MGA TAGA-TESALÓNIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSALONIKALAISILLE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIKERBREVET 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSZALONIKAIAKHOZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TʰISSALONIKIHARULAI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TʰISSALONIKIHARULAĪ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TʰISSALONIKIHARULĀI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TʰISSALONIKIHARULĀĪ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TʰISSALONIKIHARŪLAI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TʰISSALONIKIHARŪLAĪ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TʰISSALONIKIHARŪLĀI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TʰISSALONIKIHARŪLĀĪ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TʰISSALONIKĪHARULAI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TʰISSALONIKĪHARULAĪ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TʰISSALONIKĪHARULĀI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TʰISSALONIKĪHARULĀĪ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TʰISSALONIKĪHARŪLAI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TʰISSALONIKĪHARŪLAĪ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TʰISSALONIKĪHARŪLĀI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TʰISSALONIKĪHARŪLĀĪ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ANDRE TESSALONIKERBREV 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA TESSALONICENSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA TESSALONICENSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA KNIHA SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA KNIHA SOLUNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA KNIHA SOLÚNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA KNIHA SOLÚNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY TESSALONICENSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY TESSALONICENSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ TESSALONICENSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ TESSALONICENSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ KNIHA SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ KNIHA SOLUNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ KNIHA SOLÚNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ KNIHA SOLÚNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ TESSALONICENSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ TESSALONICENSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II MGA TAGA TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II MGA TAGA TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESSALONIKALAISILLE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSZALONIKAIAKHOZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESSZALONIKAIAKHOZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONICIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SEGUNDO TESALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SEGUNDO TESALONISENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SIÐARA ÞESSALONIKUBREF 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SIÐARA ÞESSALONIKUBRÉF 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SIÐARA ÞESSALONÍKUBREF 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SIÐARA ÞESSALONÍKUBRÉF 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SÍÐARA ÞESSALONIKUBREF 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SÍÐARA ÞESSALONIKUBRÉF 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SÍÐARA ÞESSALONÍKUBREF 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SÍÐARA ÞESSALONÍKUBRÉF 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TWEEDE TESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("AD THESSALONICENSES II 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 MGA TAGA TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 MGA TAGA TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 MGA TAGA-TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 MGA TAGA-TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 MGA TAGA-TESALÓNICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 MGA TAGA-TESALÓNIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSALONIKALAISILLE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIKERBREVET 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSZALONIKAIAKHOZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰISSALONIKIHARULAI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰISSALONIKIHARULAĪ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰISSALONIKIHARULĀI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰISSALONIKIHARULĀĪ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰISSALONIKIHARŪLAI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰISSALONIKIHARŪLAĪ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰISSALONIKIHARŪLĀI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰISSALONIKIHARŪLĀĪ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰISSALONIKĪHARULAI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰISSALONIKĪHARULAĪ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰISSALONIKĪHARULĀI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰISSALONIKĪHARULĀĪ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰISSALONIKĪHARŪLAI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰISSALONIKĪHARŪLAĪ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰISSALONIKĪHARŪLĀI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰISSALONIKĪHARŪLĀĪ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ. ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ. ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е К ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е К ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Я К ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Я К ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSALONIKERBREVET 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSZALONIKAIAKHOZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2EME. THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ÈME. THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2Е. К ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2Е. К ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2Я. К ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2Я. К ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA KNIHA SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA KNIHA SOLÚNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY LIST SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY LIST SOLUNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY LIST SOLÚNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY LIST SOLÚNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ KNIHA SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ KNIHA SOLÚNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ LIST SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ LIST SOLUNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ LIST SOLÚNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ LIST SOLÚNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESSZALONIKAIAKHOZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. MGA TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. MGA TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. LIST TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. LIST TESALONICKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("MASODIK THESSZALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("MÁSODIK THESSZALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONAIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONCIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONIAANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONIIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONIOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONOIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECONDA TESSALONICESI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECONDO TESSALONICESI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SEGUNDO TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SEGUNDO TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ZWEITE THESSALONICHER 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ΠΡΟΣ ΘΕΣΣΑΛΟΝΙΚΕΊΣ Β' 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ΠΡΟΣ ΘΕΣΣΑΛΟΝΙΚΕΊΣ Βʹ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ΠΡΟΣ ΘΕΣΣΑΛΟΝΙΚΕΊΣ Βʹ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ΠΡΟΣ ΘΕΣΣΑΛΟΝΙΚΕΊΣ Β΄ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ΠΡΟΣ ΘΕΣΣΑΛΟΝΙΚΕΊΣ Β’ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ΠΡΟΣ ΘΕΣΣΑΛΟΝΙΚΕΙΣ Β' 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ΠΡΟΣ ΘΕΣΣΑΛΟΝΙΚΕΙΣ Βʹ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ΠΡΟΣ ΘΕΣΣΑΛΟΝΙΚΕΙΣ Βʹ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ΠΡΟΣ ΘΕΣΣΑΛΟΝΙΚΕΙΣ Β΄ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ΠΡΟΣ ΘΕΣΣΑΛΟΝΙΚΕΙΣ Β’ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГА ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГА ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГЕ ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГЕ ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TECALONIKKIYARUKKU 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TECALOṈIKKIYARUKKU 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TECALŌNIKKIYARUKKU 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TECALŌṈIKKIYARUKKU 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSALONIKERBREVET 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSZALONIKAIAKHOZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰESSALANIKAKARAMS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰESSALANIKAKARAṂS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰESSALANIKAKARĀMS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰESSALANIKAKARĀṂS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰESSALANIKĀKARAMS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰESSALANIKĀKARAṂS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰESSALANIKĀKARĀMS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰESSALANIKĀKARĀṂS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰESSALANĪKAKARAMS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰESSALANĪKAKARAṂS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰESSALANĪKAKARĀMS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰESSALANĪKAKARĀṂS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰESSALANĪKĀKARAMS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰESSALANĪKĀKARAṂS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰESSALANĪKĀKARĀMS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰESSALANĪKĀKARĀṂS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А. ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А. ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е. ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е. ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е. ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е. ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Я. ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Я. ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. MGA TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. MGA TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THAISSALUNEEKIYON 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIKERBREV 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. LIST TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. LIST TESALONICKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. К ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. К ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. थिस्सलोनिकीहरूलाई 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2DE. THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E. THESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2EME THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2EME. THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONICIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ÈME THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ÈME. THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2Е К ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2Е К ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2Я К ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2Я К ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ANDEN TESSALONIKERNE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ANDRE TESSALONIKERNE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGA TESALONICENSOW 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGA TESALONICENSÓW 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGI TESALONICENSOW 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGI TESALONICENSÓW 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA LIST SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA LIST SOLUNSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA LIST SOLUŇSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA LIST SOLUŇSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY LIST SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY LIST SOLUNSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY LIST SOLUŇSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY LIST SOLUŇSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY LIST SOLÚNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ LIST SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ LIST SOLUNSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ LIST SOLUŇSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ LIST SOLUŇSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ LIST SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ LIST SOLUNSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ LIST SOLUŇSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ LIST SOLUŇSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ LIST SOLÚNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II MGA TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II MGA TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II LIST TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II LIST TESALONICKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESSALONICENSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESSALONICENSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("IKALAWANG TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("IKALAWANG TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("MASODIK TESSZALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("MÁSODIK TESSZALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESALONIIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONEANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("השנייה אל התסלוניקים 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("테살로니카 신자들에게 보낸 둘째 서간 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 MGA TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 MGA TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THAISSALUNEEKIYON 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIKERBREV 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 E. THESALONIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 I. THESALONIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 LIST TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 LIST TESALONICKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 К ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 К ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 थिस्सलोनिकीहरूलाई 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Я ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Я ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSALONICENSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSALONICENSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSALONIKERBREV 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.O. TESALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.O. TESALONISENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º. TESALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º. TESALONISENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2A. TESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2D. THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2DE THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2DE. THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E THESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E. TESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E. THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2EME THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONICIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONAIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONCIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONIAANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONIIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONIOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONOIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2O. TESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ÈME THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2Е. ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2Е. ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2Я. ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2Я. ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DEZYEM TESALONIKYEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DEZYÈM TESALONIKYEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA TESALONIČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY TESALONIČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ TESALONIČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ TESALONIČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESSALONICENSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESSALONICENSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONICIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THÊ-SA-LÔ-NI-CA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONAIN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSALONION 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSOLONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("THESSALONICENSES II 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSALONICENSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSALONICENSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 E THESALONIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 I THESALONIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K. TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K. TESALONIČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSALONIKERBREV 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TAGA-TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TAGA-TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TAGA-TESALÓNICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TAGA-TESALÓNIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONICIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THÊ-SA-LÔ-NI-CA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.O TESALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.O TESALONISENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.O. TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.O. TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º TESALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º TESALONISENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º. TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º. TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2A TESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2D THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2D. THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2DE THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E TESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E. THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONAIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONCIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONIAANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONIIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONIOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONOIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESALONIIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONEANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2O TESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2O. TESALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2O. TESALONISENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º. TESALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º. TESALONISENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2Е ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2Е ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2Я ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2Я ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ANDRE TESSALONIKER 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGA TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGI TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA TESALONICKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY TESALONICKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ TESALONICKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ TESALONICKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONICIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THÊ-SA-LÔ-NI-CA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONICENSOW 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONICENSÓW 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONISENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONAIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONCIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIAANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONOIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TÊ-SA-LÔ-NI-CA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. LIST SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. LIST SOLUNSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. LIST SOLUŇSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. LIST SOLUŇSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("PILI WATHESALONIKE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TESOLONIIKA LABAAD 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ଥେସଲନୀକୀୟଙ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TAGA-TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TAGA-TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TAGA-TESALÓNICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TAGA-TESALÓNIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSALONICENZEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONICIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THÊ-SA-LÔ-NI-CA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K TESALONIČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K. TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K. TESALONICKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 थेस्सलनीकाकरांस 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ਥੱਸਲੁਨੀਕੀਆਂ ਨੂੰ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONICENSOW 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONICENSÓW 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONISENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSALONIKERNE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONAIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONCIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIAANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONICHER 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONOIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TÊ-SA-LÔ-NI-CA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. LIST SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. LIST SOLUNSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. LIST SOLUŇSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. LIST SOLUŇSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. थिस्सलुनीकियों 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.O TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.O TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.º TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2D THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESALONIIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONEANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONAIN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSALONION 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSOLONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2O TESALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2O TESALONISENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2O. TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2O. TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2°. TESSALONICESI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º TESALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º TESALONISENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º. TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º. TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUGA SOLUNJANIMA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONICENSOW 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONICENSÓW 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONISENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONAIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONCIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIAANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONOIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TÊ-SA-LÔ-NI-CA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II LIST SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II LIST SOLUNSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II LIST SOLUŇSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II LIST SOLUŇSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONIČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESSALONICESI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALONIIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONEANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIAID 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSZALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. WATHESALONIKE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("دوم-تھِسّلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ﺍﻟﺜﺎﻧﻴﺔ ﺗﺴﺎﻟﻮﻧﻴﻜﻲ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONICENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONICENSOW 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONICENSÓW 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONISENSES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSALONIKERNE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONICIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONAIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONCIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIAANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONICHER 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONOIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TÊ-SA-LÔ-NI-CA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 E. SELANIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 I. SELANIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K TESALONICKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 LIST SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 LIST SOLUNSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 LIST SOLUŇSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 LIST SOLUŇSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TʰASSALUNĪKĪĀṂ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 थिस्सलुनीकियों 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 தெசலோனிக்கேயர் 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ. ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONIČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSALONICESI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONIIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONEANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIAID 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSZALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. WATHESALONIKE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.-تھِسّلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONAIN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSALONION 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSOLONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2O TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2O TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2° TESSALONICESI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2º TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DEZYEM TESALONIK 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DEZYÈM TESALONIK 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA SOLUNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA SOLÚNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA SOLÚNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY SOLUNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY SOLÚNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY SOLÚNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ SOLUNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ SOLÚNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ SOLÚNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ SOLUNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ SOLÚNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ SOLÚNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONIČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESSALONICESI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALONIIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONEANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIAID 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSZALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II WATHESALONIKE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONICENI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONICKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONIKYEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESSZALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALONIAID 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONAIN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSALONION 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSOLONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("WATHESALONIKE II 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β' ΘΕΣΣΑΛΟΝΙΚΕΊΣ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β' ΘΕΣΣΑΛΟΝΙΚΕΙΣ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ ΘΕΣΣΑΛΟΝΙΚΕΊΣ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ ΘΕΣΣΑΛΟΝΙΚΕΙΣ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ ΘΕΣΣΑΛΟΝΙΚΕΊΣ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ ΘΕΣΣΑΛΟΝΙΚΕΙΣ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β΄ ΘΕΣΣΑΛΟΝΙΚΕΊΣ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β΄ ΘΕΣΣΑΛΟΝΙΚΕΙΣ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β’ ΘΕΣΣΑΛΟΝΙΚΕΊΣ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β’ ΘΕΣΣΑΛΟΝΙΚΕΙΣ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГА СОЛУЊАНИМА 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГА ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГЕ ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("دوم تھِسلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONICANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONICENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONISENSE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONIČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSALONICESI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONICANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONIIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONEANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIAID 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIENS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONOANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSZALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 WATHESALONIKE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 E SELANIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 I SELANIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K. SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K. SOLUNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K. SOLÚNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K. SOLÚNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А. ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е. ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-تھِسّلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONICENI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONICKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONIKYEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSALONIKER 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSZALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONIAID 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONAIN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSALONION 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSOLONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. تھِسلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA SOLUNSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA SOLUŇSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA SOLUŇSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA SOLÚNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY SOLUNSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY SOLUŇSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY SOLUŇSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY SOLÚNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ SOLUNSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ SOLUŇSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ SOLUŇSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ SOLÚNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ SOLUNSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ SOLUŇSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ SOLUŇSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ SOLÚNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONICENI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONICKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONIKYEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESSZALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALONIAID 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONAIN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSALONION 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSOLONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. SOLUNJANIMA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONIIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THÊXALÔNICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ВТОРА СОЛУНЦИТЕ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ВТОРА СОЛУНЈАНИ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ВТОРО СОЛУНЦИТЕ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ВТОРО СОЛУНЈАНИ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("دوم تھسّلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("۲-تھِسّلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONICENI 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONICKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONICKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONICZAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONIKYEN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSALONIKER 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSZALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONIAID 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONIONS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESELONAINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESELONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESOLONIANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONAIN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONANS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSALONION 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSOLONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K SOLUNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K SOLÚNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K SOLÚNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K. SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K. SOLÚNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 تھِسلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 தெசலோனிக்கர் 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ. СОЛУНЬЦІ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. SELANIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. SOLUNJANIMA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONIIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THÊXALÔNICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. تھسّلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. थिस्सलोनिकी 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II SOLUNJANIMA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONIIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THÊXALÔNICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. SOLUNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. SOLÚNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. SOLÚNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TÈSALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. СОЛУЊАНИМА 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("MASODIK THESSZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("MÁSODIK THESSZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГА СОЛУНЬЦІ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГЕ СОЛУНЬЦІ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("دوم۔تھسلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("۲ تھِسلُنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 SELANIKASVE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 SOLUNJANIMA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONIIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESALONINS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESELONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESOLONIAN 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THÊXALÔNICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 K SOLÚNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 تھسّلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 थिस्सलोनिकी 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А. СОЛУНЬЦІ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ СОЛУНЬЦІ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ. СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е. СОЛУНЬЦІ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. SOLUNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. SOLÚNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. SOLÚNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALÓNICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALÓNIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TÈSALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. СОЛУЊАНИМА 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. ଥେସଲନୀକୀୟଙ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. เธซะโลนิกา 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. เธสะโลนิกา 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2.۔تھسلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II SOLUNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II SOLÚNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II SOLÚNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TÈSALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II СОЛУЊАНИМА 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. SOLUNSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. SOLUŇSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. SOLUŇSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. SOLÚNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESALONIK 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. СОЛУНЦИТЕ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. СОЛУНЈАНИ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("MASODIK TESSZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("MÁSODIK TESSZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ВТОРА СОЛУНЦИ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГА СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ДРУГЕ СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("دوم تھسلنیکوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("۲ تھسّلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("テサロニケの信徒への手紙二 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("テサロニケ人への第二の手紙 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 SOLUNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 SOLUNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 SOLÚNCANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 SOLÚNČANOM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALÓNICA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALÓNIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TÈSALONIKA 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 СОЛУЊАНИМА 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ДО СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ଥେସଲନୀକୀୟଙ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 เธซะโลนิกา 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 เธสะโลนิกา 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А СОЛУНЬЦІ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А. СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-ГЕ СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е СОЛУНЬЦІ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е. СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. SOLUNSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. SOLUŇSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. SOLUŇSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. SOLÚNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESALONIK 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. СОЛУНЦИТЕ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. СОЛУНЈАНИ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. تھسلنیکوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. थिसलुनिकी 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2۔تھسلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II SOLUNSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II SOLUŇSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II SOLUŇSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II SOLÚNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESALONIK 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II СОЛУНЦИТЕ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II СОЛУНЈАНИ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. СОЛУНЬЦІ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THSSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TWEEDE THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("۲۔تھسلنیکیوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 SOLUNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 SOLUNSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 SOLUŇSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 SOLUŇSKÝM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 SOLÚNSKYM 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESALONIK 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 СОЛУНЦИТЕ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 СОЛУНЈАНИ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 تھسلنیکوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 थिसलुनिकी 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-А СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2-Е СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. СОЛУНЬЦІ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ANDEN THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II СОЛУНЬЦІ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. СОЛУНЦИ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TWEEDE TESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("۲ تھسلنیکوں 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("テサロニケ人への後の書 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("テサロニケ人への手紙二 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 СОЛУНЬЦІ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. СОЛУНЦИ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THSSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ANDRE TESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II СОЛУНЦИ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESSZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND THS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("TWEEDE TES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 СОЛУНЦИ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 СОЛУНЯН 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESSZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E. THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THSSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA SOL 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY SOL 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ SOL 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ SOL 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESSZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESSZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THSSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("PILI THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("SECOND TH 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("ВТОРА СОЛ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖撒罗尼迦后书》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖撒羅尼迦後書》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESSZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESSZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THSSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. थिस्स 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E. TESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. THS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHA TE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHY TE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÁ TE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("DRUHÝ TE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESSZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THSSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. ÞESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("PILI THE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖撒罗尼迦后书 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖撒羅尼迦後書 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《得撒洛尼後書》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖撒罗尼迦后书》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖撒羅尼迦後書》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESSZ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THSSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 थिस्स 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 தெசலோ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. ÞESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E TESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E. TES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND THS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND. TH 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II ÞESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. SOL 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. THS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. СОЛ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("PILI TH 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《得撒洛尼後書 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("テサロニケ 2 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("テサロニケ後書 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖撒罗尼迦后书 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖撒羅尼迦後書 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("得撒洛尼後書》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("데살로니가2서 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("데살로니가후서 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("테살로니카2서 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THSS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ÞESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. SOL 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. THS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. СОЛ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2THESS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2E TES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2ND TH 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II SOL 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II THS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II СОЛ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TH 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II. TÊ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β' ΘΕΣ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ ΘΕΣ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ ΘΕΣ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β΄ ΘΕΣ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β’ ΘΕΣ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("得撒洛尼後書 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 SOL 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TES 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 THS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 СОЛ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ФЕС 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 தெச 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TH 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2. TÊ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TH 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("II TÊ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β' ΘΕ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ ΘΕ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Βʹ ΘΕ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β΄ ΘΕ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("Β’ ΘΕ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《莎倫後》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TE 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TH 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TS 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 TÊ 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 تس 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2 ธส 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖后》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖後》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《莎倫後 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("莎倫後》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("2테살 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖后 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("《帖後 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖后》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖後》 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("莎倫後 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖后 1:1").osis()).toEqual("2Thess.1.1")
		expect(p.parse("帖後 1:1").osis()).toEqual("2Thess.1.1")
		`
		true
describe "Localized book 1Thess (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Thess (full)", ->
		`
		expect(p.parse("Прва писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Прво писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Първо послание на св. ап. Павла до Солуняни 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Perse poslannja apostola Pavla do solunjan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Perše poslannja apostola Pavla do solunjan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Първо послание на св ап. Павла до Солуняни 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Първо послание на св. ап Павла до Солуняни 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("رسالة بولس الرسول الأولى إلى أهل تسالونيكي 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("தெசலோனிக்கியருக்கு எழுதிய முதலாவது நிருபம் 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Първо послание на св ап Павла до Солуняни 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("தெசலோனிக்கேயருக்கு எழுதிய முதலாம் கடிதம் 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Paulus' Første Brev til Thessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Paulus’ Første Brev til Thessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsza List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsza List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsze List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsze List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwszy List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwszy List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("تھسّلنیکیوں کے نام پولس رسول کا پہلا خط 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("தெசலோனிக்கருக்கு எழுதிய முதல் திருமுகம் 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Paulus’ første brev til tessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsza List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsza List św Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsze List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsze List św Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwszy List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwszy List św Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Ensimmainen Kirje tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Ensimmäinen Kirje tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bref Pals til Þessalonikumanna 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bref Pals til Þessaloníkumanna 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bref Páls til Þessalonikumanna 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bref Páls til Þessaloníkumanna 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bréf Pals til Þessalonikumanna 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bréf Pals til Þessaloníkumanna 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bréf Páls til Þessalonikumanna 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bréf Páls til Þessaloníkumanna 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Paulus' 1. Brev til Thessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Paulus’ 1. Brev til Thessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalunīkiyōṅ ke nām kā pahlā ḫaṭ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("थिस्सलोनिकीहरूलाई पावलको पहिलो पत्र 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Paulus' 1 Brev til Thessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Paulus’ 1 Brev til Thessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pavlova prva poslanica Solunjanima 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Waraka wa Kwanza kwa Wathesalonike 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Waraka wa Kwanza kwa Wathesaloniki 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Barua ya Kwanza kwa Wathesalonike 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("पौलाचे थेस्सलनीकाकरांस पहिले पत्र 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. List św Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Ensimmainen Tessalonikalaiskirje 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Ensimmäinen Tessalonikalaiskirje 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. List św Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰassalunīkīāṃ nū̃ pahilī pattrī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikiharulai pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikiharulaī pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikiharulāi pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikiharulāī pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikiharūlai pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikiharūlaī pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikiharūlāi pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikiharūlāī pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikīharulai pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikīharulaī pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikīharulāi pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikīharulāī pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikīharūlai pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikīharūlaī pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikīharūlāi pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikīharūlāī pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("الرسالة الأولى إلى أهل تسالونيكي 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 List św Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Ensimmainen Tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Ensimmäinen Tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I List św Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanikakarams pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanikakaraṃs pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanikakarāms pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanikakarāṃs pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanikākarams pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanikākaraṃs pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanikākarāms pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanikākarāṃs pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanīkakarams pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanīkakaraṃs pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanīkakarāms pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanīkakarāṃs pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanīkākarams pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanīkākaraṃs pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanīkākarāms pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanīkākarāṃs pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("تھِسّلُنیکیوں کے نام کا پہلا خط 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Epistula I ad Thessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Epistula ad Thessalonicenses I 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prima lettera ai Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsza List do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsze List do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwszy List do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ଥେସଲନୀକୀୟଙ୍କ ପ୍ରତି ପ୍ରଥମ ପତ୍ର 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Kirje tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Kirje tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Първо послание към солунците 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("האיגרת הראשונה אל התסלוניקים 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("تھسلنیکیوں کے نام کا پہلا خط 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("थिस्सलोनिकीहरूलाई पहिलो पत्र 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ਥਸੱਲੁਨੀਕੀਆਂ ਨੂੰ ਪਹਿਲੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ਥੱਸਲੁਨੀਕੀਆਂ ਨੂੰ ਪਹਿਲੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Kirje tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Kirje tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("אגרת פולוס הראשונה אל-התסלו 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Forsta Thessalonikerbrevet 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Första Thessalonikerbrevet 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Solunjanima Poslanica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva poslanica Solunjanima 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Mga Taga- Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Mga Taga- Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("थेस्सलनीकाकरांस पहिले पत्र 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Forsta Tessalonikerbrevet 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bref Pals til Þessa 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bref Páls til Þessa 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bréf Pals til Þessa 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bréf Páls til Þessa 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Första Tessalonikerbrevet 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premieres Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premières Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Mga Taga Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Mga Taga Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Прва посланица Солуњанима 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Solunjanima Poslanica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Elso Thesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Első Thesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Første Thessalonikerbrev 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Solunjanima Poslanica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premiere Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premieres Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premiers Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Première Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premières Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primeira Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primeiro Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá kniha Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá kniha Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Mga Taga- Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Mga Taga- Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Solunjanima Poslanica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. List do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Taga- Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Taga- Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonikalaiskirje 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. посланица Солуњанима 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Eerste Thessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Elso Tesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Első Tesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Første tessalonikerbrev 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Solunjanima Poslanica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. List do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Mga Taga- Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Mga Taga- Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessalonikalaiskirje 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. посланица Солуњанима 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsza Tesalonicensow 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsza Tesalonicensów 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsze Tesalonicensow 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsze Tesalonicensów 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwszy Tesalonicensow 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwszy Tesalonicensów 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premier Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premiere Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premiers Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Première Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni list Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni list Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První list Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První list Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá kniha Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá kniha Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý list Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý list Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Mga Taga Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Mga Taga Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Mga Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Mga Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 List do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Taga- Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Taga- Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonikalaiskirje 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 посланица Солуњанима 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. к Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. к Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-я. к Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-я. к Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Taga Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Taga Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Taga-Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Taga-Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Taga-Tesalónica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Taga-Tesalónika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonikerbrevet 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikiharulai 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikiharulaī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikiharulāi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikiharulāī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikiharūlai 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikiharūlaī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikiharūlāi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikiharūlāī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikīharulai 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikīharulaī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikīharulāi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikīharulāī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikīharūlai 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikīharūlaī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikīharūlāi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikīharūlāī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Eerste Tessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I List do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Mga Taga- Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Mga Taga- Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessalonikalaiskirje 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I посланица Солуњанима 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Mga Taga Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Mga Taga Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premier Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primero Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primero Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Tessalonicenskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Tessalonicenským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První Tessalonicenskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První Tessalonicenským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý list Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý list Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("رسالة تسالونيكي الأولى 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Taga Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Taga Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Taga-Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Taga-Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Taga-Tesalónica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Taga-Tesalónika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonikerbrevet 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikiharulai 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikiharulaī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikiharulāi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikiharulāī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikiharūlai 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikiharūlaī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikiharūlāi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikiharūlāī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikīharulai 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikīharulaī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikīharulāi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikīharulāī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikīharūlai 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikīharūlaī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikīharūlāi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikīharūlāī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е к Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е к Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-я к Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-я к Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonikerbrevet 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ere. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ère. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1е. к Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1е. к Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1я. к Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1я. к Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra Þessalonikubref 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra Þessalonikubréf 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra Þessaloníkubref 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra Þessaloníkubréf 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Første Tessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Mga Taga Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Mga Taga Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsza Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsze Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwszy Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primer Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primer Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primero Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primero Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá kniha Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá kniha Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá kniha Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá kniha Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Mga Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Mga Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ad Thessalonicenses I 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικείς Α' 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικείς Αʹ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικείς Αʹ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικείς Α΄ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικείς Α’ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικεις Α' 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικεις Αʹ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικεις Αʹ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικεις Α΄ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικεις Α’ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("הראשונה אל התסלוניקים 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tecalonikkiyarukku 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tecaloṉikkiyarukku 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tecalōnikkiyarukku 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tecalōṉikkiyarukku 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonikerbrevet 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanikakarams 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanikakaraṃs 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanikakarāms 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanikakarāṃs 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanikākarams 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanikākaraṃs 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanikākarāms 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanikākarāṃs 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanīkakarams 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanīkakaraṃs 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanīkakarāms 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanīkakarāṃs 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanīkākarams 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanīkākaraṃs 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanīkākarāms 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanīkākarāṃs 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-я. Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-я. Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thaissaluneekiyon 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonikerbrev 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. list Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. list Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. к Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. к Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. थिस्सलोनिकीहरूलाई 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e. Thessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1er. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ere Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ere. Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1re. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ère Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ère. Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1е к Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1е к Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1я к Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1я к Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Erste Thessalonicher 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Mga Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Mga Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. list Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. list Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Kwanza Wathesalonike 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primer Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primer Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni list Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni list Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni list Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni list Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První list Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První list Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První list Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První list Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá kniha Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá kniha Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý list Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý list Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý list Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý list Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("테살로니카 신자들에게 보낸 첫째 서간 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thaissaluneekiyon 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonikerbrev 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 e. Thesalonikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 i. Thesalonikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 list Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 list Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 к Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 к Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 थिस्सलोनिकीहरूलाई 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-я Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-я Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonicenskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonicenským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tessalonikerbrev 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o. Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o. Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º. Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º. Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1a. Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e Thessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e. Tessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1er Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1er. Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ere Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o. Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1re Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1re. Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ère Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1е. Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1е. Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1я. Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1я. Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Første Tessaloniker 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Mga Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Mga Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I list Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I list Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessalonicenskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessalonicenským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premye Tesalonikyen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prima Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primo Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý list Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý list Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonicenskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonicenským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 e Thesalonikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 i Thesalonikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tessalonikerbrev 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Taga-Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Taga-Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Taga-Tesalónica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Taga-Tesalónika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thê-sa-lô-ni-ca 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o. Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o. Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º. Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º. Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1a Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e Tessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1er Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o. Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o. Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1re Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º. Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º. Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1е Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1е Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1я Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1я Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Elso Thesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Első Thesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessalonicenskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessalonicenským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thê-sa-lô-ni-ca 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tesoloniika Kowaad 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonicenses I 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("اوّل-تھِسّلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Taga-Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Taga-Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Taga-Tesalónica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Taga-Tesalónika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thê-sa-lô-ni-ca 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 थेस्सलनीकाकरांस 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ਥੱਸਲੁਨੀਕੀਆਂ ਨੂੰ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonicensow 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonicensów 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonicher 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tê-sa-lô-ni-ca 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. list Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. list Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. list Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. list Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. थिस्सलुनीकियों 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o. Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o. Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1°. Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º. Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º. Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Elso Tesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Első Tesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thê-sa-lô-ni-ca 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonicensow 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonicensów 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tê-sa-lô-ni-ca 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. list Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. list Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. list Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. list Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("اوّل تھِسلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonicensow 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonicensów 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonicher 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tê-sa-lô-ni-ca 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 e. Selanikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 i. Selanikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 list Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 list Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 list Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 list Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰassalunīkīāṃ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 थिस्सलुनीकियों 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 தெசலோனிக்கேயர் 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Wathesalonike 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.-تھِسّلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1° Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonicensow 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonicensów 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tê-sa-lô-ni-ca 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I list Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I list Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I list Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I list Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Wathesalonike 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premye Tesalonik 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Solunjanima 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α' Θεσσαλονικείς 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α' Θεσσαλονικεις 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ Θεσσαλονικείς 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ Θεσσαλονικεις 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ Θεσσαλονικείς 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ Θεσσαλονικεις 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α΄ Θεσσαλονικείς 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α΄ Θεσσαλονικεις 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α’ Θεσσαλονικείς 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α’ Θεσσαλονικεις 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("اوّل تھسّلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ପ୍ରଥମ ଥେସଲନୀକୀୟଙ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Wathesalonike 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 e Selanikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 i Selanikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-تھِسّلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesaloniceni 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonikyen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessaloniker 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. تھِسلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Wathesalonike 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesaloniceni 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonikyen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Wathesalonike I 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Прва Солуњанима 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Първа Солунците 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("اوّل۔تھسلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("۱-تھِسّلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesaloniceni 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonikyen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessaloniker 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 تھِسلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 தெசலோனிக்கர் 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Selanikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Solunjanima 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesaloniika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thêxalônica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. تھسّلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. थिस्सलोनिकी 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesaloniceni 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonikyen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Solunjanima 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesaloniika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thêxalônica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Прва Солунците 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Прва Солунјани 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Прво Солунците 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Прво Солунјани 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("۱ تھِسلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ﺍﻻﻭﻝ ﺗﺴﺎﻟﻮﻧﻴﻜﻲ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Selanikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Solunjanima 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesaloniika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thêxalônica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 تھسّلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 थिस्सलोनिकी 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalónica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalónika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tèsalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Солуњанима 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. ଥେସଲନୀକୀୟଙ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. เธซะโลนิกา 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. เธสะโลนิกา 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.۔تھسلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Solunjanima 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesaloniika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thêxalônica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tèsalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Солуњанима 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Първа Солунци 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("۱ تھسّلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("テサロニケの信徒への手紙一 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("テサロニケ人への第一の手紙 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalónica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalónika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tèsalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Солуњанима 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ଥେସଲନୀକୀୟଙ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 เธซะโลนิกา 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 เธสะโลนิกา 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonik 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Солунците 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Солунјани 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. थिसलुनिकी 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1۔تھسلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Eerste Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Første Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tèsalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Солуњанима 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonik 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Солунците 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Солунјани 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("۱۔تھسلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonik 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Солунците 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Солунјани 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 थिसलुनिकी 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Eerste Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Elso Thessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Első Thessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Første Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonik 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Солунците 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Солунјани 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Kwanza Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("テサロニケ人への前の書 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("テサロニケ人への手紙一 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Солунци 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Eerste Tes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Elso Tessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Első Tessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Солунци 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Kwanza The 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Солунци 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e. Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Солунци 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Kwanza Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Sol 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První Sol 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Първа Сол 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《帖撒罗尼迦前书》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《帖撒羅尼迦前書》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. थिस्स 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e. Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Te 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První Te 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《帖撒罗尼迦前书 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《帖撒羅尼迦前書 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《得撒洛尼前書》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("帖撒罗尼迦前书》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("帖撒羅尼迦前書》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 थिस्स 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 தெசலோ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Þess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e. Tes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Þess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《得撒洛尼前書 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("テサロニケ 1 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("テサロニケ前書 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("帖撒罗尼迦前书 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("帖撒羅尼迦前書 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("得撒洛尼前書》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("데살로니가1서 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("데살로니가전서 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("테살로니카1서 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Þess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Sol 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. The 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Сол 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e Tes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Þess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Sol 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. The 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Сол 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α' Θεσ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ Θεσ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ Θεσ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α΄ Θεσ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α’ Θεσ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("得撒洛尼前書 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Sol 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 The 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Сол 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Фес 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 தெச 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Te 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tê 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Sol 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I The 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Сол 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Te 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tê 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α' Θε 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ Θε 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ Θε 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α΄ Θε 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α’ Θε 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《莎倫前》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Te 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Ts 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tê 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 تس 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ธส 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Te 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tê 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《帖前》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《莎倫前 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("莎倫前》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1테살 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《帖前 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("帖前》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("莎倫前 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("帖前 1:1").osis()).toEqual("1Thess.1.1")
		`
		true
	it "should handle non-Latin digits in book: 1Thess (full)", ->
		p.set_options non_latin_digits_strategy: "replace"
		`
		expect(p.parse("Прва писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Прво писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I писмо од апостол Павле до христијаните во Солун 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalonikkiyarukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecaloṉikkiyarukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalōnikkiyarukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tecalōṉikkiyarukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Първо послание на св. ап. Павла до Солуняни 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Perse poslannja apostola Pavla do solunjan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Perše poslannja apostola Pavla do solunjan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Първо послание на св ап. Павла до Солуняни 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Първо послание на св. ап Павла до Солуняни 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("رسالة بولس الرسول الأولى إلى أهل تسالونيكي 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("தெசலோனிக்கியருக்கு எழுதிய முதலாவது நிருபம் 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Първо послание на св ап Павла до Солуняни 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I послання св. апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("தெசலோனிக்கேயருக்கு எழுதிய முதலாம் கடிதம் 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I послання св апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Paulus' Første Brev til Thessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Paulus’ Første Brev til Thessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsza List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsza List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsze List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsze List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwszy List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwszy List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("تھسّلنیکیوں کے نام پولس رسول کا پہلا خط 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("தெசலோனிக்கருக்கு எழுதிய முதல் திருமுகம் 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Paulus’ første brev til tessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsza List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsza List św Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsze List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsze List św Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwszy List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwszy List św Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Ensimmainen Kirje tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Ensimmäinen Kirje tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bref Pals til Þessalonikumanna 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bref Pals til Þessaloníkumanna 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bref Páls til Þessalonikumanna 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bref Páls til Þessaloníkumanna 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bréf Pals til Þessalonikumanna 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bréf Pals til Þessaloníkumanna 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bréf Páls til Þessalonikumanna 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bréf Páls til Þessaloníkumanna 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I послання апостола Павла до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Paulus' 1. Brev til Thessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Paulus’ 1. Brev til Thessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalunīkiyōṅ ke nām kā pahlā ḫaṭ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("थिस्सलोनिकीहरूलाई पावलको पहिलो पत्र 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Paulus' 1 Brev til Thessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Paulus’ 1 Brev til Thessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pavlova prva poslanica Solunjanima 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Waraka wa Kwanza kwa Wathesalonike 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Waraka wa Kwanza kwa Wathesaloniki 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Barua ya Kwanza kwa Wathesalonike 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("पौलाचे थेस्सलनीकाकरांस पहिले पत्र 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. List św Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Ensimmainen Tessalonikalaiskirje 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Ensimmäinen Tessalonikalaiskirje 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I List sw. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I List św. Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. List św Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰassalunīkīāṃ nū̃ pahilī pattrī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikiharulai pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikiharulaī pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikiharulāi pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikiharulāī pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikiharūlai pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikiharūlaī pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikiharūlāi pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikiharūlāī pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikīharulai pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikīharulaī pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikīharulāi pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikīharulāī pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikīharūlai pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikīharūlaī pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikīharūlāi pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰissalonikīharūlāī pahilo patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("الرسالة الأولى إلى أهل تسالونيكي 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 List św Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Ensimmainen Tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Ensimmäinen Tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I List sw Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I List św Pawła do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanikakarams pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanikakaraṃs pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanikakarāms pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanikakarāṃs pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanikākarams pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanikākaraṃs pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanikākarāms pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanikākarāṃs pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanīkakarams pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanīkakaraṃs pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanīkakarāms pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanīkakarāṃs pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanīkākarams pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanīkākaraṃs pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanīkākarāms pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("tʰessalanīkākarāṃs pahile patra 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("تھِسّلُنیکیوں کے نام کا پہلا خط 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Epistula I ad Thessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Epistula ad Thessalonicenses I 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prima lettera ai Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I послання до фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I послання до фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsza List do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsze List do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwszy List do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ଥେସଲନୀକୀୟଙ୍କ ପ୍ରତି ପ୍ରଥମ ପତ୍ର 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Kirje tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Kirje tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Първо послание към солунците 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("האיגרת הראשונה אל התסלוניקים 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("تھسلنیکیوں کے نام کا پہلا خط 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("थिस्सलोनिकीहरूलाई पहिलो पत्र 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ਥਸੱਲੁਨੀਕੀਆਂ ਨੂੰ ਪਹਿਲੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ਥੱਸਲੁਨੀਕੀਆਂ ਨੂੰ ਪਹਿਲੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Kirje tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Kirje tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("אגרת פולוס הראשונה אל-התסלו 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Forsta Thessalonikerbrevet 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Första Thessalonikerbrevet 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I послання до салонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I послання до салонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Solunjanima Poslanica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva poslanica Solunjanima 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Mga Taga- Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Mga Taga- Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("थेस्सलनीकाकरांस पहिले पत्र 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Forsta Tessalonikerbrevet 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bref Pals til Þessa 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bref Páls til Þessa 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bréf Pals til Þessa 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra bréf Páls til Þessa 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Första Tessalonikerbrevet 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premieres Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premières Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Mga Taga Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Mga Taga Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Прва посланица Солуњанима 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Solunjanima Poslanica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Elso Thesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Első Thesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Første Thessalonikerbrev 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Solunjanima Poslanica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premiere Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premieres Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premiers Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Première Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premières Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primeira Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primeiro Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá kniha Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá kniha Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Mga Taga- Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Mga Taga- Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Solunjanima Poslanica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. List do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Taga- Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Taga- Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonikalaiskirje 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. посланица Солуњанима 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Eerste Thessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Elso Tesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Első Tesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Første tessalonikerbrev 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Solunjanima Poslanica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. List do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Mga Taga- Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Mga Taga- Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessalonikalaiskirje 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. посланица Солуњанима 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsza Tesalonicensow 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsza Tesalonicensów 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsze Tesalonicensow 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsze Tesalonicensów 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwszy Tesalonicensow 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwszy Tesalonicensów 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premier Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premiere Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premiers Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Première Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni list Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni list Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První list Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První list Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá kniha Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá kniha Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý list Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý list Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Mga Taga Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Mga Taga Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Mga Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Mga Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 List do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Taga- Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Taga- Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonikalaiskirje 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 посланица Солуњанима 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. к Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. к Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-я. к Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-я. к Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Taga Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Taga Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Taga-Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Taga-Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Taga-Tesalónica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Taga-Tesalónika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonikerbrevet 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikiharulai 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikiharulaī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikiharulāi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikiharulāī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikiharūlai 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikiharūlaī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikiharūlāi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikiharūlāī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikīharulai 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikīharulaī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikīharulāi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikīharulāī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikīharūlai 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikīharūlaī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikīharūlāi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tʰissalonikīharūlāī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Eerste Tessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I List do Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Mga Taga- Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Mga Taga- Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessalonikalaiskirje 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I посланица Солуњанима 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Mga Taga Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Mga Taga Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premier Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primero Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primero Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Tessalonicenskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Tessalonicenským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První Tessalonicenskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První Tessalonicenským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý list Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý list Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("رسالة تسالونيكي الأولى 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Taga Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Taga Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Taga-Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Taga-Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Taga-Tesalónica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Taga-Tesalónika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonikerbrevet 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikiharulai 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikiharulaī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikiharulāi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikiharulāī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikiharūlai 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikiharūlaī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikiharūlāi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikiharūlāī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikīharulai 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikīharulaī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikīharulāi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikīharulāī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikīharūlai 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikīharūlaī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikīharūlāi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰissalonikīharūlāī 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е к Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е к Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-я к Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-я к Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonikerbrevet 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ere. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ère. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1е. к Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1е. к Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1я. к Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1я. к Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra Þessalonikubref 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra Þessalonikubréf 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra Þessaloníkubref 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Fyrra Þessaloníkubréf 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Første Tessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Mga Taga Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Mga Taga Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessalonikalaisille 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I послання до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsza Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwsze Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Pierwszy Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primer Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primer Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primero Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primero Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá kniha Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá kniha Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá kniha Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá kniha Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Mga Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Mga Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ad Thessalonicenses I 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικείς Α' 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικείς Αʹ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικείς Αʹ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικείς Α΄ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικείς Α’ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικεις Α' 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικεις Αʹ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικεις Αʹ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικεις Α΄ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Προς Θεσσαλονικεις Α’ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("הראשונה אל התסלוניקים 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tecalonikkiyarukku 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tecaloṉikkiyarukku 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tecalōnikkiyarukku 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tecalōṉikkiyarukku 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonikerbrevet 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanikakarams 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanikakaraṃs 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanikakarāms 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanikakarāṃs 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanikākarams 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanikākaraṃs 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanikākarāms 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanikākarāṃs 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanīkakarams 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanīkakaraṃs 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanīkakarāms 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanīkakarāṃs 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanīkākarams 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanīkākaraṃs 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanīkākarāms 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰessalanīkākarāṃs 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-я. Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-я. Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Mga Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thaissaluneekiyon 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonikerbrev 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. list Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. list Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. к Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. к Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. थिस्सलोनिकीहरूलाई 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e. Thessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1er. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ere Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ere. Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1re. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ère Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ère. Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1е к Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1е к Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1я к Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1я к Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Erste Thessalonicher 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesszalonikaiakhoz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Mga Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Mga Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. list Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. list Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Kwanza Wathesalonike 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primer Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primer Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva kniha Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni list Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni list Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni list Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni list Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První list Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První list Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První list Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První list Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá kniha Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá kniha Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý list Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý list Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý list Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý list Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("테살로니카 신자들에게 보낸 첫째 서간 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Mga Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thaissaluneekiyon 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonikerbrev 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 e. Thesalonikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 i. Thesalonikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 list Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 list Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 к Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 к Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 थिस्सलोनिकीहरूलाई 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-я Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-я Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonicenskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonicenským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. tessalonikerbrev 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o. Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o. Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º. Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º. Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1a. Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e Thessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e. Tessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1er Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1er. Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ere Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o. Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1re Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1re. Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ère Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1е. Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1е. Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1я. Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1я. Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Første Tessaloniker 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Mga Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Mga Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I list Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I list Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessalonicenskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessalonicenským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premye Tesalonikyen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prima Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Primo Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy list Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý list Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý list Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonicenskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonicenským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 e Thesalonikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 i Thesalonikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tessalonikerbrev 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Taga-Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Taga-Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Taga-Tesalónica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Taga-Tesalónika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thê-sa-lô-ni-ca 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o. Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o. Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º. Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º. Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1a Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e Tessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1er Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o. Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o. Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1re Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º. Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º. Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1е Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1е Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1я Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1я Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Elso Thesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Első Thesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessalonicenskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessalonicenským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thê-sa-lô-ni-ca 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Tesoloniika Kowaad 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonicenses I 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("اوّل-تھِسّلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Taga-Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Taga-Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Taga-Tesalónica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Taga-Tesalónika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thê-sa-lô-ni-ca 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Фессалоникиицам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Фессалоникийцам 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 थेस्सलनीकाकरांस 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ਥੱਸਲੁਨੀਕੀਆਂ ਨੂੰ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonicensow 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonicensów 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonicher 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tê-sa-lô-ni-ca 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. list Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. list Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. list Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. list Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. थिस्सलुनीकियों 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.o Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o. Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o. Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1°. Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º. Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º. Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Elso Tesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Első Tesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessalonicenzen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thê-sa-lô-ni-ca 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I фессалонікіиців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I фессалонікійців 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonicensow 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonicensów 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tê-sa-lô-ni-ca 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. list Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. list Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. list Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. list Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("اوّل تھِسلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonicensow 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonicensów 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonikerne 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonicher 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tê-sa-lô-ni-ca 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 e. Selanikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 i. Selanikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 list Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 list Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 list Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 list Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 tʰassalunīkīāṃ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 थिस्सलुनीकियों 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 தெசலோனிக்கேயர் 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Wathesalonike 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.-تھِسّلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1o Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1° Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonicenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonicensow 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonicensów 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonisenses 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tê-sa-lô-ni-ca 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I list Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I list Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I list Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I list Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Wathesalonike 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Premye Tesalonik 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Solunjanima 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Unang Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α' Θεσσαλονικείς 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α' Θεσσαλονικεις 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ Θεσσαλονικείς 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ Θεσσαλονικεις 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ Θεσσαλονικείς 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ Θεσσαλονικεις 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α΄ Θεσσαλονικείς 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α΄ Θεσσαλονικεις 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α’ Θεσσαλονικείς 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α’ Θεσσαλονικεις 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("اوّل تھسّلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ପ୍ରଥମ ଥେସଲନୀକୀୟଙ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Wathesalonike 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 e Selanikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 i Selanikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-تھِسّلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesaloniceni 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonikyen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessaloniker 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. تھِسلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonicanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonicense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonisense 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesaloničanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessalonicesi 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessaloniens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Wathesalonike 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesaloniceni 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonikyen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonicians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessaloniciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Wathesalonike I 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Прва Солуњанима 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Първа Солунците 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("اوّل۔تھسلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("۱-تھِسّلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesaloniceni 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonikyen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessaloniker 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k. Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 تھِسلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 தெசலோனிக்கர் 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Selanikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Solunjanima 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesaloniika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thêxalônica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. تھسّلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. थिस्सलोनिकी 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesaloniceni 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonickym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonickým 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesaloniczan 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonikyen 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesszalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesaloniaid 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Solunjanima 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesaloniika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thêxalônica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prva Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvy Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvá Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvý Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonaians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonciens 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessaloniaans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessaloniions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonioans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonoians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Una Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Прва Солунците 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Прва Солунјани 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Прво Солунците 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Прво Солунјани 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("۱ تھِسلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ﺍﻻﻭﻝ ﺗﺴﺎﻟﻮﻧﻴﻜﻲ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Selanikasve 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Solunjanima 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesaloniika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thêxalônica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 k Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 تھسّلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 थिस्सलोनिकी 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше. Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalónica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalónika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tèsalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Солуњанима 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. ଥେସଲନୀକୀୟଙ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. เธซะโลนิกา 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. เธสะโลนิกา 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.۔تھسلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Solunjanima 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesaloniika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thêxalônica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tèsalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Солуњанима 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesallonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesalonicans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesaloniians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessaloneans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonoans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перша Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Перше Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Първа Солунци 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("۱ تھسّلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("テサロニケの信徒への手紙一 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("テサロニケ人への第一の手紙 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalónica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalónika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tèsalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Солуњанима 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ଥେସଲନୀକୀୟଙ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 เธซะโลนิกา 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 เธสะโลนิกา 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а. Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е. Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ше Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tesalonik 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Солунците 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Солунјани 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. थिसलुनिकी 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1۔تھسلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Eerste Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Første Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Soluncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Solunčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Solúncanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Solúnčanom 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonica 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tèsalonika 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Солуњанима 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I до солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tesalonik 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Солунците 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Солунјани 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesalonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesalonions 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Theselonains 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Theselonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesolonians 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonain 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonans 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessalonion 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thessolonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("۱۔تھسلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tesalonik 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Солунците 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Солунјани 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 थिसलुनिकी 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-а Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-е Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Eerste Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Elso Thessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Első Thessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Første Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Solunskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Solunským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Soluňskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Soluňským 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Solúnskym 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tesalonik 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Солунците 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Солунјани 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Kwanza Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesalonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesalonins 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Theselonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Thesolonian 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("テサロニケ人への前の書 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("テサロニケ人への手紙一 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Солунци 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Eerste Tes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Elso Tessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Első Tessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Солуньці 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Солунци 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Kwanza The 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Солунци 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e. Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Солунци 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Солунян 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Kwanza Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Sol 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První Sol 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Първа Сол 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《帖撒罗尼迦前书》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《帖撒羅尼迦前書》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. थिस्स 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e. Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("First Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thesss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Prvni Te 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("První Te 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《帖撒罗尼迦前书 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《帖撒羅尼迦前書 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《得撒洛尼前書》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("帖撒罗尼迦前书》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("帖撒羅尼迦前書》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 थिस्स 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 தெசலோ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Þess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e. Tes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st. Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tessz 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thsss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Þess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《得撒洛尼前書 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("テサロニケ 1 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("テサロニケ前書 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("帖撒罗尼迦前书 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("帖撒羅尼迦前書 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("得撒洛尼前書》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("데살로니가1서 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("데살로니가전서 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("테살로니카1서 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Þess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Sol 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. The 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Сол 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1Thess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1e Tes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1st Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Thss 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Þess 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Sol 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. The 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Сол 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α' Θεσ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ Θεσ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ Θεσ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α΄ Θεσ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α’ Θεσ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("得撒洛尼前書 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Sol 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 The 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Сол 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Фес 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 தெச 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Te 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. Tê 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Sol 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tes 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I The 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Ths 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Сол 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Te 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. Tê 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α' Θε 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ Θε 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ Θε 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α΄ Θε 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α’ Θε 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《莎倫前》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Te 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Ts 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 Tê 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 تس 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ธส 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Te 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Th 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I Tê 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《帖前》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《莎倫前 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("莎倫前》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1테살 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《帖前 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("帖前》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("莎倫前 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("帖前 1:1").osis()).toEqual("1Thess.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ПРВА ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО СОЛУН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПРВО ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО СОЛУН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО СОЛУН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО СОЛУН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО СОЛУН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО СОЛУН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TECALONIKKIYARUKKU ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TECALONIKKIYARUKKU ELUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TECALONIKKIYARUKKU EḺUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TECALONIKKIYARUKKU EḺUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TECALOṈIKKIYARUKKU ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TECALOṈIKKIYARUKKU ELUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TECALOṈIKKIYARUKKU EḺUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TECALOṈIKKIYARUKKU EḺUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TECALŌNIKKIYARUKKU ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TECALŌNIKKIYARUKKU ELUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TECALŌNIKKIYARUKKU EḺUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TECALŌNIKKIYARUKKU EḺUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TECALŌṈIKKIYARUKKU ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TECALŌṈIKKIYARUKKU ELUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TECALŌṈIKKIYARUKKU EḺUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TECALŌṈIKKIYARUKKU EḺUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ. ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРША ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРШЕ ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А. ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е. ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ. ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРША ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРШЕ ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЪРВО ПОСЛАНИЕ НА СВ. АП. ПАВЛА ДО СОЛУНЯНИ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А. ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е. ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PERSE POSLANNJA APOSTOLA PAVLA DO SOLUNJAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PERŠE POSLANNJA APOSTOLA PAVLA DO SOLUNJAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЪРВО ПОСЛАНИЕ НА СВ АП. ПАВЛА ДО СОЛУНЯНИ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЪРВО ПОСЛАНИЕ НА СВ. АП ПАВЛА ДО СОЛУНЯНИ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("رسالة بولس الرسول الأولى إلى أهل تسالونيكي 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("தெசலோனிக்கியருக்கு எழுதிய முதலாவது நிருபம் 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЪРВО ПОСЛАНИЕ НА СВ АП ПАВЛА ДО СОЛУНЯНИ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРША ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРШЕ ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("தெசலோனிக்கேயருக்கு எழுதிய முதலாம் கடிதம் 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PAULUS' FØRSTE BREV TIL THESSALONIKERNE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PAULUS’ FØRSTE BREV TIL THESSALONIKERNE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZA LIST SW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZA LIST ŚW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZE LIST SW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZE LIST ŚW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZY LIST SW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZY LIST ŚW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("تھسّلنیکیوں کے نام پولس رسول کا پہلا خط 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("தெசலோனிக்கருக்கு எழுதிய முதல் திருமுகம் 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PAULUS’ FØRSTE BREV TIL TESSALONIKERNE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZA LIST SW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZA LIST ŚW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZE LIST SW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZE LIST ŚW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZY LIST SW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZY LIST ŚW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ENSIMMAINEN KIRJE TESSALONIKALAISILLE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ENSIMMÄINEN KIRJE TESSALONIKALAISILLE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FYRRA BREF PALS TIL ÞESSALONIKUMANNA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FYRRA BREF PALS TIL ÞESSALONÍKUMANNA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FYRRA BREF PÁLS TIL ÞESSALONIKUMANNA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FYRRA BREF PÁLS TIL ÞESSALONÍKUMANNA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FYRRA BRÉF PALS TIL ÞESSALONIKUMANNA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FYRRA BRÉF PALS TIL ÞESSALONÍKUMANNA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FYRRA BRÉF PÁLS TIL ÞESSALONIKUMANNA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FYRRA BRÉF PÁLS TIL ÞESSALONÍKUMANNA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PAULUS' 1. BREV TIL THESSALONIKERNE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PAULUS’ 1. BREV TIL THESSALONIKERNE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰISSALUNĪKIYŌṄ KE NĀM KĀ PAHLĀ ḪAṬ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("थिस्सलोनिकीहरूलाई पावलको पहिलो पत्र 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PAULUS' 1 BREV TIL THESSALONIKERNE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PAULUS’ 1 BREV TIL THESSALONIKERNE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PAVLOVA PRVA POSLANICA SOLUNJANIMA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("WARAKA WA KWANZA KWA WATHESALONIKE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("WARAKA WA KWANZA KWA WATHESALONIKI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ. ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ. ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. LIST SW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. LIST ŚW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("BARUA YA KWANZA KWA WATHESALONIKE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. LIST SW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. LIST ŚW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРША ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРША ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРШЕ ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРШЕ ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("पौलाचे थेस्सलनीकाकरांस पहिले पत्र 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 LIST SW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 LIST ŚW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А. ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А. ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е. ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е. ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. LIST SW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. LIST ŚW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ENSIMMAINEN TESSALONIKALAISKIRJE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ENSIMMÄINEN TESSALONIKALAISKIRJE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I LIST SW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I LIST ŚW. PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. LIST SW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. LIST ŚW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰASSALUNĪKĪĀṂ NŪ̃ PAHILĪ PATTRĪ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰISSALONIKIHARULAI PAHILO PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰISSALONIKIHARULAĪ PAHILO PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰISSALONIKIHARULĀI PAHILO PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰISSALONIKIHARULĀĪ PAHILO PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰISSALONIKIHARŪLAI PAHILO PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰISSALONIKIHARŪLAĪ PAHILO PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰISSALONIKIHARŪLĀI PAHILO PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰISSALONIKIHARŪLĀĪ PAHILO PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰISSALONIKĪHARULAI PAHILO PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰISSALONIKĪHARULAĪ PAHILO PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰISSALONIKĪHARULĀI PAHILO PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰISSALONIKĪHARULĀĪ PAHILO PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰISSALONIKĪHARŪLAI PAHILO PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰISSALONIKĪHARŪLAĪ PAHILO PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰISSALONIKĪHARŪLĀI PAHILO PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰISSALONIKĪHARŪLĀĪ PAHILO PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("الرسالة الأولى إلى أهل تسالونيكي 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 LIST SW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 LIST ŚW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ENSIMMAINEN TESSALONIKALAISILLE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ENSIMMÄINEN TESSALONIKALAISILLE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I LIST SW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I LIST ŚW PAWŁA DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰESSALANIKAKARAMS PAHILE PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰESSALANIKAKARAṂS PAHILE PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰESSALANIKAKARĀMS PAHILE PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰESSALANIKAKARĀṂS PAHILE PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰESSALANIKĀKARAMS PAHILE PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰESSALANIKĀKARAṂS PAHILE PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰESSALANIKĀKARĀMS PAHILE PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰESSALANIKĀKARĀṂS PAHILE PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰESSALANĪKAKARAMS PAHILE PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰESSALANĪKAKARAṂS PAHILE PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰESSALANĪKAKARĀMS PAHILE PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰESSALANĪKAKARĀṂS PAHILE PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰESSALANĪKĀKARAMS PAHILE PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰESSALANĪKĀKARAṂS PAHILE PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰESSALANĪKĀKARĀMS PAHILE PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TʰESSALANĪKĀKARĀṂS PAHILE PATRA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("تھِسّلُنیکیوں کے نام کا پہلا خط 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ. ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ. ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("EPISTULA I AD THESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("EPISTULA AD THESSALONICENSES I 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMA LETTERA AI TESSALONICESI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРША ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРША ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРШЕ ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРШЕ ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А. ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А. ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е. ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е. ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I ПОСЛАННЯ ДО ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I ПОСЛАННЯ ДО ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZA LIST DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZE LIST DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZY LIST DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ଥେସଲନୀକୀୟଙ୍କ ପ୍ରତି ପ୍ରଥମ ପତ୍ର 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. KIRJE TESSALONIKALAISILLE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. KIRJE TESSALONIKALAISILLE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЪРВО ПОСЛАНИЕ КЪМ СОЛУНЦИТЕ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("האיגרת הראשונה אל התסלוניקים 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("تھسلنیکیوں کے نام کا پہلا خط 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("थिस्सलोनिकीहरूलाई पहिलो पत्र 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ਥਸੱਲੁਨੀਕੀਆਂ ਨੂੰ ਪਹਿਲੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ਥੱਸਲੁਨੀਕੀਆਂ ਨੂੰ ਪਹਿਲੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 KIRJE TESSALONIKALAISILLE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I KIRJE TESSALONIKALAISILLE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("אגרת פולוס הראשונה אל-התסלו 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FORSTA THESSALONIKERBREVET 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FÖRSTA THESSALONIKERBREVET 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I ПОСЛАННЯ ДО САЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I ПОСЛАННЯ ДО САЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA SOLUNJANIMA POSLANICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA POSLANICA SOLUNJANIMA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNANG MGA TAGA- TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNANG MGA TAGA- TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("थेस्सलनीकाकरांस पहिले पत्र 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ. ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FORSTA TESSALONIKERBREVET 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FYRRA BREF PALS TIL ÞESSA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FYRRA BREF PÁLS TIL ÞESSA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FYRRA BRÉF PALS TIL ÞESSA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FYRRA BRÉF PÁLS TIL ÞESSA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FÖRSTA TESSALONIKERBREVET 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMIERES THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMIÈRES THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNANG MGA TAGA TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNANG MGA TAGA TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРША ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРШЕ ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПРВА ПОСЛАНИЦА СОЛУЊАНИМА 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А. ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е. ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. SOLUNJANIMA POSLANICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ELSO THESSZALONIKAIAKHOZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ELSŐ THESSZALONIKAIAKHOZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FØRSTE THESSALONIKERBREV 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. SOLUNJANIMA POSLANICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMIERE THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMIERES THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMIERS THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMIÈRE THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMIÈRES THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMEIRA TESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMEIRO TESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA KNIHA TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA KNIHA TESALONIČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÁ KNIHA TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÁ KNIHA TESALONIČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNA MGA TAGA- TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNA MGA TAGA- TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 SOLUNJANIMA POSLANICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. LIST DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. MGA TAGA- TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. MGA TAGA- TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSALONIKALAISKIRJE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. ПОСЛАНИЦА СОЛУЊАНИМА 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("EERSTE THESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ELSO TESSZALONIKAIAKHOZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ELSŐ TESSZALONIKAIAKHOZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FØRSTE TESSALONIKERBREV 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I SOLUNJANIMA POSLANICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. LIST DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. MGA TAGA- TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. MGA TAGA- TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESSALONIKALAISKIRJE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. ПОСЛАНИЦА СОЛУЊАНИМА 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZA TESALONICENSOW 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZA TESALONICENSÓW 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZE TESALONICENSOW 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZE TESALONICENSÓW 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZY TESALONICENSOW 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZY TESALONICENSÓW 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMIER THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMIERE THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMIERS THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMIÈRE THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA KNIHA TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA KNIHA TESALONICKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI LIST TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI LIST TESALONICKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNÍ LIST TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNÍ LIST TESALONICKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY LIST TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY LIST TESALONIČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÁ KNIHA TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÁ KNIHA TESALONICKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÝ LIST TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÝ LIST TESALONIČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNA MGA TAGA TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNA MGA TAGA TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNANG MGA TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNANG MGA TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 LIST DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 MGA TAGA- TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 MGA TAGA- TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSALONIKALAISKIRJE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ПОСЛАНИЦА СОЛУЊАНИМА 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е. К ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е. К ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Я. К ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Я. К ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. MGA TAGA TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. MGA TAGA TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. MGA TAGA-TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. MGA TAGA-TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. MGA TAGA-TESALÓNICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. MGA TAGA-TESALÓNIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSALONIKALAISILLE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIKERBREVET 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSZALONIKAIAKHOZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TʰISSALONIKIHARULAI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TʰISSALONIKIHARULAĪ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TʰISSALONIKIHARULĀI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TʰISSALONIKIHARULĀĪ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TʰISSALONIKIHARŪLAI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TʰISSALONIKIHARŪLAĪ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TʰISSALONIKIHARŪLĀI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TʰISSALONIKIHARŪLĀĪ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TʰISSALONIKĪHARULAI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TʰISSALONIKĪHARULAĪ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TʰISSALONIKĪHARULĀI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TʰISSALONIKĪHARULĀĪ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TʰISSALONIKĪHARŪLAI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TʰISSALONIKĪHARŪLAĪ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TʰISSALONIKĪHARŪLĀI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TʰISSALONIKĪHARŪLĀĪ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("EERSTE TESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I LIST DO TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I MGA TAGA- TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I MGA TAGA- TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESSALONIKALAISKIRJE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I ПОСЛАНИЦА СОЛУЊАНИМА 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. MGA TAGA TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. MGA TAGA TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESSALONIKALAISILLE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSZALONIKAIAKHOZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMIER THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMERO TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMERO TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI TESSALONICENSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI TESSALONICENSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNÍ TESSALONICENSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNÍ TESSALONICENSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY LIST TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY LIST TESALONICKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÝ LIST TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÝ LIST TESALONICKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("رسالة تسالونيكي الأولى 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 MGA TAGA TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 MGA TAGA TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 MGA TAGA-TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 MGA TAGA-TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 MGA TAGA-TESALÓNICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 MGA TAGA-TESALÓNIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSALONIKALAISILLE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIKERBREVET 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSZALONIKAIAKHOZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰISSALONIKIHARULAI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰISSALONIKIHARULAĪ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰISSALONIKIHARULĀI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰISSALONIKIHARULĀĪ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰISSALONIKIHARŪLAI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰISSALONIKIHARŪLAĪ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰISSALONIKIHARŪLĀI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰISSALONIKIHARŪLĀĪ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰISSALONIKĪHARULAI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰISSALONIKĪHARULAĪ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰISSALONIKĪHARULĀI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰISSALONIKĪHARULĀĪ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰISSALONIKĪHARŪLAI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰISSALONIKĪHARŪLAĪ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰISSALONIKĪHARŪLĀI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰISSALONIKĪHARŪLĀĪ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е К ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е К ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ. ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ. ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Я К ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Я К ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSALONIKERBREVET 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSZALONIKAIAKHOZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ERE. THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ÈRE. THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1Е. К ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1Е. К ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1Я. К ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1Я. К ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FYRRA ÞESSALONIKUBREF 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FYRRA ÞESSALONIKUBRÉF 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FYRRA ÞESSALONÍKUBREF 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FYRRA ÞESSALONÍKUBRÉF 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FØRSTE TESSALONIKERNE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I MGA TAGA TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I MGA TAGA TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESSALONIKALAISILLE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSZALONIKAIAKHOZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I ПОСЛАННЯ ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESSZALONIKAIAKHOZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZA TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZE TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PIERWSZY TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMER TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMER TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMERO TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMERO TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA KNIHA SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA KNIHA SOLUNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA KNIHA SOLÚNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA KNIHA SOLÚNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÁ KNIHA SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÁ KNIHA SOLUNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÁ KNIHA SOLÚNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÁ KNIHA SOLÚNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNA MGA TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNA MGA TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("AD THESSALONICENSES I 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ΠΡΟΣ ΘΕΣΣΑΛΟΝΙΚΕΊΣ Α' 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ΠΡΟΣ ΘΕΣΣΑΛΟΝΙΚΕΊΣ Αʹ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ΠΡΟΣ ΘΕΣΣΑΛΟΝΙΚΕΊΣ Αʹ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ΠΡΟΣ ΘΕΣΣΑΛΟΝΙΚΕΊΣ Α΄ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ΠΡΟΣ ΘΕΣΣΑΛΟΝΙΚΕΊΣ Α’ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ΠΡΟΣ ΘΕΣΣΑΛΟΝΙΚΕΙΣ Α' 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ΠΡΟΣ ΘΕΣΣΑΛΟΝΙΚΕΙΣ Αʹ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ΠΡΟΣ ΘΕΣΣΑΛΟΝΙΚΕΙΣ Αʹ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ΠΡΟΣ ΘΕΣΣΑΛΟΝΙΚΕΙΣ Α΄ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ΠΡΟΣ ΘΕΣΣΑΛΟΝΙΚΕΙΣ Α’ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРША ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРША ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРШЕ ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРШЕ ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("הראשונה אל התסלוניקים 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TECALONIKKIYARUKKU 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TECALOṈIKKIYARUKKU 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TECALŌNIKKIYARUKKU 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TECALŌṈIKKIYARUKKU 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSALONIKERBREVET 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSZALONIKAIAKHOZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰESSALANIKAKARAMS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰESSALANIKAKARAṂS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰESSALANIKAKARĀMS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰESSALANIKAKARĀṂS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰESSALANIKĀKARAMS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰESSALANIKĀKARAṂS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰESSALANIKĀKARĀMS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰESSALANIKĀKARĀṂS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰESSALANĪKAKARAMS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰESSALANĪKAKARAṂS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰESSALANĪKAKARĀMS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰESSALANĪKAKARĀṂS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰESSALANĪKĀKARAMS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰESSALANĪKĀKARAṂS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰESSALANĪKĀKARĀMS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰESSALANĪKĀKARĀṂS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А. ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А. ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е. ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е. ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е. ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е. ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Я. ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Я. ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. MGA TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. MGA TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THAISSALUNEEKIYON 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIKERBREV 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. LIST TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. LIST TESALONICKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. К ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. К ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. थिस्सलोनिकीहरूलाई 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1E. THESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ER. THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ERE THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ERE. THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1RE. THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ÈRE THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ÈRE. THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1Е К ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1Е К ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1Я К ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1Я К ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ERSTE THESSALONICHER 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESSZALONIKAIAKHOZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. MGA TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. MGA TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. LIST TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. LIST TESALONICKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("KWANZA WATHESALONIKE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMER TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMER TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA KNIHA SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA KNIHA SOLÚNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI LIST SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI LIST SOLUNSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI LIST SOLUŇSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI LIST SOLUŇSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNÍ LIST SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNÍ LIST SOLUNSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNÍ LIST SOLUŇSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNÍ LIST SOLUŇSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY LIST SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY LIST SOLUNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY LIST SOLÚNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY LIST SOLÚNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÁ KNIHA SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÁ KNIHA SOLÚNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÝ LIST SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÝ LIST SOLUNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÝ LIST SOLÚNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÝ LIST SOLÚNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("테살로니카 신자들에게 보낸 첫째 서간 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 MGA TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 MGA TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THAISSALUNEEKIYON 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIKERBREV 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 E. THESALONIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 I. THESALONIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 LIST TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 LIST TESALONICKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 К ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 К ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 थिस्सलोनिकीहरूलाई 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Я ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Я ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSALONICENSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSALONICENSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSALONIKERBREV 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.O. TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.O. TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º. TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º. TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1A. TESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1E THESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1E. TESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ER THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ER. THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ERE THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1O. TESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1RE THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1RE. THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ÈRE THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1Е. ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1Е. ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1Я. ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1Я. ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FØRSTE TESSALONIKER 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I MGA TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I MGA TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I LIST TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I LIST TESALONICKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESSALONICENSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESSALONICENSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMYE TESALONIKYEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMA TESSALONICESI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRIMO TESSALONICESI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY LIST SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY LIST SOLÚNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÝ LIST SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÝ LIST SOLÚNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNANG TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNANG TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSALONICENSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSALONICENSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 E THESALONIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 I THESALONIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K. TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K. TESALONIČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSALONIKERBREV 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TAGA-TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TAGA-TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TAGA-TESALÓNICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TAGA-TESALÓNIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THÊ-SA-LÔ-NI-CA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.O TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.O TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.O. TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.O. TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º. TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º. TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1A TESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1E TESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ER THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1O TESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1O. TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1O. TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1RE THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º. TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º. TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1Е ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1Е ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1Я ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1Я ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ELSO THESSZALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ELSŐ THESSZALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESSALONICENSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESSALONICENSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THÊ-SA-LÔ-NI-CA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA TESALONIČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI TESALONICKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNÍ TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNÍ TESALONICKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY TESALONIČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÁ TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÁ TESALONIČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÝ TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÝ TESALONIČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("TESOLONIIKA KOWAAD 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONICENSES I 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("اوّل-تھِسّلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TAGA-TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TAGA-TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TAGA-TESALÓNICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TAGA-TESALÓNIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THÊ-SA-LÔ-NI-CA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K TESALONIČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K. TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K. TESALONICKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ФЕССАЛОНИКИИЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ФЕССАЛОНИКИЙЦАМ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 थेस्सलनीकाकरांस 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ਥੱਸਲੁਨੀਕੀਆਂ ਨੂੰ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONICENSOW 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONICENSÓW 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSALONIKERNE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONICHER 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TÊ-SA-LÔ-NI-CA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. LIST SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. LIST SOLUNSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. LIST SOLUŇSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. LIST SOLUŇSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. थिस्सलुनीकियों 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.O TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.O TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.º TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1O TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1O TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1O. TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1O. TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1°. TESSALONICESI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º. TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º. TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ELSO TESSZALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ELSŐ TESSZALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESSALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESSALONICENZEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THÊ-SA-LÔ-NI-CA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I ФЕССАЛОНІКІИЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I ФЕССАЛОНІКІЙЦІВ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONICENSOW 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONICENSÓW 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TÊ-SA-LÔ-NI-CA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. LIST SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. LIST SOLUNSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. LIST SOLUŇSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. LIST SOLUŇSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA TESALONICKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY TESALONICKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÁ TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÁ TESALONICKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÝ TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÝ TESALONICKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNA TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNA TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("اوّل تھِسلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONICENSOW 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONICENSÓW 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSALONIKERNE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONICHER 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TÊ-SA-LÔ-NI-CA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 E. SELANIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 I. SELANIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K TESALONICKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 LIST SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 LIST SOLUNSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 LIST SOLUŇSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 LIST SOLUŇSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TʰASSALUNĪKĪĀṂ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 थिस्सलुनीकियों 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 தெசலோனிக்கேயர் 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ. ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONIČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSALONICESI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIAID 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSZALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. WATHESALONIKE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.-تھِسّلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1O TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1O TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1° TESSALONICESI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1º TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONICENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONICENSOW 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONICENSÓW 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONISENSES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TÊ-SA-LÔ-NI-CA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I LIST SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I LIST SOLUNSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I LIST SOLUŇSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I LIST SOLUŇSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONIČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESSALONICESI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIAID 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSZALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. WATHESALONIKE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PREMYE TESALONIK 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA SOLUNJANIMA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNANG TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNANG TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α' ΘΕΣΣΑΛΟΝΙΚΕΊΣ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α' ΘΕΣΣΑΛΟΝΙΚΕΙΣ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ ΘΕΣΣΑΛΟΝΙΚΕΊΣ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ ΘΕΣΣΑΛΟΝΙΚΕΙΣ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ ΘΕΣΣΑΛΟΝΙΚΕΊΣ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ ΘΕΣΣΑΛΟΝΙΚΕΙΣ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α΄ ΘΕΣΣΑΛΟΝΙΚΕΊΣ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α΄ ΘΕΣΣΑΛΟΝΙΚΕΙΣ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α’ ΘΕΣΣΑΛΟΝΙΚΕΊΣ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α’ ΘΕΣΣΑΛΟΝΙΚΕΙΣ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРША ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРШЕ ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("اوّل تھسّلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ପ୍ରଥମ ଥେସଲନୀକୀୟଙ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONIČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSALONICESI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIAID 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSZALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 WATHESALONIKE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 E SELANIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 I SELANIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K. SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K. SOLUNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K. SOLÚNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K. SOLÚNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А. ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е. ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-تھِسّلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONICENI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONICKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONIKYEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSALONIKER 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSZALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONIAID 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. تھِسلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONICANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONICENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONISENSE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONIČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESSALONICESI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIAID 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSZALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I WATHESALONIKE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONICENI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONICKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONIKYEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESSZALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALONIAID 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA SOLUNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA SOLÚNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA SOLÚNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI SOLUNSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI SOLUŇSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI SOLUŇSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNÍ SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNÍ SOLUNSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNÍ SOLUŇSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNÍ SOLUŇSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY SOLUNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY SOLÚNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY SOLÚNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÁ SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÁ SOLUNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÁ SOLÚNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÁ SOLÚNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÝ SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÝ SOLUNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÝ SOLÚNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÝ SOLÚNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONICIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONICIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("WATHESALONIKE I 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПРВА СОЛУЊАНИМА 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЪРВА СОЛУНЦИТЕ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("اوّل۔تھسلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("۱-تھِسّلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONICENI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONICKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONIKYEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSALONIKER 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSZALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONIAID 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K SOLUNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K SOLÚNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K SOLÚNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K. SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K. SOLÚNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 تھِسلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 தெசலோனிக்கர் 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ. СОЛУНЬЦІ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. SELANIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. SOLUNJANIMA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONIIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THÊXALÔNICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. تھسّلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. थिस्सलोनिकी 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONICENI 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONICKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONICKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONICZAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONIKYEN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESSZALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALONIAID 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. SOLUNJANIMA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONIIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THÊXALÔNICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVA SOLÚNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVY SOLÚNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÁ SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÁ SOLÚNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÝ SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVÝ SOLÚNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONAIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONCIENS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONIAANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONIIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONIOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONOIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNA TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("UNA TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРША СОЛУНЬЦІ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРШЕ СОЛУНЬЦІ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПРВА СОЛУНЦИТЕ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПРВА СОЛУНЈАНИ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПРВО СОЛУНЦИТЕ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПРВО СОЛУНЈАНИ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("۱ تھِسلُنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ﺍﻻﻭﻝ ﺗﺴﺎﻟﻮﻧﻴﻜﻲ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 SELANIKASVE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 SOLUNJANIMA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONIIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THÊXALÔNICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 K SOLÚNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 تھسّلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 थिस्सलोनिकी 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А. СОЛУНЬЦІ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е. СОЛУНЬЦІ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ СОЛУНЬЦІ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ. СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. SOLUNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. SOLÚNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. SOLÚNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALÓNICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALÓNIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TÈSALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. СОЛУЊАНИМА 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. ଥେସଲନୀକୀୟଙ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. เธซะโลนิกา 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. เธสะโลนิกา 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1.۔تھسلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I SOLUNJANIMA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONIIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THÊXALÔNICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. SOLUNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. SOLÚNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. SOLÚNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TÈSALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. СОЛУЊАНИМА 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESALLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESALONICANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESALONIIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONEANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONOANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРША СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЕРШЕ СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЪРВА СОЛУНЦИ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("۱ تھسّلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("テサロニケの信徒への手紙一 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("テサロニケ人への第一の手紙 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 SOLUNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 SOLÚNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 SOLÚNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALÓNICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALÓNIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TÈSALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 СОЛУЊАНИМА 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ଥେସଲନୀକୀୟଙ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 เธซะโลนิกา 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 เธสะโลนิกา 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А СОЛУНЬЦІ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А. СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е СОЛУНЬЦІ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е. СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-ШЕ СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. SOLUNSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. SOLUŇSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. SOLUŇSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. SOLÚNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESALONIK 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. СОЛУНЦИТЕ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. СОЛУНЈАНИ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. थिसलुनिकी 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1۔تھسلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("EERSTE THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FØRSTE THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I SOLUNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I SOLUNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I SOLÚNCANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I SOLÚNČANOM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONICA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TÈSALONIKA 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I СОЛУЊАНИМА 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I ДО СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. SOLUNSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. SOLUŇSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. SOLUŇSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. SOLÚNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESALONIK 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. СОЛУНЦИТЕ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. СОЛУНЈАНИ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESALONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESALONIONS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESELONAINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESELONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESOLONIANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONAIN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONANS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSALONION 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESSOLONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("۱۔تھسلنیکیوں 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 SOLUNSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 SOLUŇSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 SOLUŇSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 SOLÚNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESALONIK 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 СОЛУНЦИТЕ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 СОЛУНЈАНИ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 थिसलुनिकी 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-А СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1-Е СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. СОЛУНЬЦІ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("EERSTE TESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ELSO THESSZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ELSŐ THESSZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THSSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FØRSTE TESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I SOLUNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I SOLUNSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I SOLUŇSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I SOLUŇSKÝM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I SOLÚNSKYM 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESALONIK 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I СОЛУНЦИТЕ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I СОЛУНЈАНИ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. СОЛУНЬЦІ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("KWANZA THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESALONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESALONINS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESELONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("THESOLONIAN 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("テサロニケ人への前の書 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("テサロニケ人への手紙一 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 СОЛУНЬЦІ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. СОЛУНЦИ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THSSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("EERSTE TES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ELSO TESSZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ELSŐ TESSZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I СОЛУНЬЦІ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. СОЛУНЦИ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("KWANZA THE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 СОЛУНЦИ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESSZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1E. THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THSSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST THS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I СОЛУНЦИ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I СОЛУНЯН 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESSZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("KWANZA TH 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI SOL 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNÍ SOL 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("ПЪРВА СОЛ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《帖撒罗尼迦前书》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《帖撒羅尼迦前書》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESSZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESSZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THSSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. थिस्स 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1E THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1E. TESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. THS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("FIRST TH 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESSZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESSZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THSSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNI TE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("PRVNÍ TE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《帖撒罗尼迦前书 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《帖撒羅尼迦前書 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《得撒洛尼前書》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("帖撒罗尼迦前书》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("帖撒羅尼迦前書》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESSZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THSSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 थिस्स 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 தெசலோ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. ÞESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1E TESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1E. TES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST THS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST. TH 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESSZ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THSSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. ÞESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《得撒洛尼前書 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("テサロニケ 1 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("テサロニケ前書 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("帖撒罗尼迦前书 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("帖撒羅尼迦前書 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("得撒洛尼前書》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("데살로니가1서 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("데살로니가전서 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("테살로니카1서 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ÞESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. SOL 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. THS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. СОЛ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1THESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1E TES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1ST TH 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THSS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I ÞESS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. SOL 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. THS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. СОЛ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α' ΘΕΣ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ ΘΕΣ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ ΘΕΣ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α΄ ΘΕΣ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α’ ΘΕΣ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("得撒洛尼前書 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 SOL 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 THS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 СОЛ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ФЕС 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 தெச 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TH 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1. TÊ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I SOL 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TES 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I THS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I СОЛ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TH 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I. TÊ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α' ΘΕ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ ΘΕ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Αʹ ΘΕ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α΄ ΘΕ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("Α’ ΘΕ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《莎倫前》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TH 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TS 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 TÊ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 تس 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1 ธส 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TE 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TH 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("I TÊ 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《帖前》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《莎倫前 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("莎倫前》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("1테살 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("《帖前 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("帖前》 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("莎倫前 1:1").osis()).toEqual("1Thess.1.1")
		expect(p.parse("帖前 1:1").osis()).toEqual("1Thess.1.1")
		`
		true
describe "Localized book 2Kgs (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Kgs (full)", ->
		`
		expect(p.parse("இராஜாக்களின் இரண்டாம் புத்தகம் 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Kitabu cha Pili cha Wafalme 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("राजाओ का विर्तान्त 2रा भाग 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("राजाओ का विर्तान्त २रा भाग 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga knjiga o Kraljevima 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Cartea a patra a Regilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Ksiega Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Ksiegi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Księga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Księga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Księgi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Księgi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Fjerde Kongerigernes Bog 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Toinen Kuninkaiden kirja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Четвърта Книга на царете 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Четвърта книга на царете 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Втора книга за царевите 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Второ книга за царевите 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("राजाहरूको दोस्रो पुस्तक 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ରାଜାବଳୀର ଦ୍ୱିତୀୟ ପୁସ୍ତକ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiega Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiegi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księgi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księgi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiega Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiegi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księgi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księgi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Четвърта книга Царства 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Ks. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha kniha kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha kniha kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha kniha královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha kniha královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy kniha kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy kniha kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy kniha královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy kniha královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá kniha kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá kniha kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá kniha královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá kniha královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý kniha kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý kniha kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý kniha královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý kniha královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kuninkaiden kirja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. книга за царевите 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Siðari bok konunganna 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Siðari bók konunganna 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Síðari bok konunganna 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Síðari bók konunganna 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kuninkaiden kirja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. книга за царевите 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Kongerigernes Bog 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Ks Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kuninkaiden kirja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II книга за царевите 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiega Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiegi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księgi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księgi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Ksiega Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Ksiegi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Księga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Księga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Księgi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Księgi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("rājiāṃ dī dūjī potʰī 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kuninkaiden kirja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 книга за царевите 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiega Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiegi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księgi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księgi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Kongerigernes Bog 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Ksiega Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Ksiegi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Księga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Księga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Księgi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Księgi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Cartea IV a Regilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiega Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiega Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiega Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiega Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiegi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiegi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiegi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiegi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księga Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księga Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księga Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księga Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księgi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księgi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księgi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księgi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiega Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiega Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiega Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiega Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiegi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiegi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiegi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiegi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księga Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księga Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księga Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księga Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księgi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księgi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księgi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księgi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiega Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiegi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księgi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księgi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. kniha kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. kniha kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. kniha královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. kniha královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Ksiega Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Ksiegi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Księga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Księga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Księgi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Księgi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Книга на царете 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrta kniha Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrta kniha Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrta kniha Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrta kniha Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrtá kniha Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrtá kniha Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrtá kniha Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrtá kniha Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrta kniha Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrta kniha Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrta kniha Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrta kniha Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrtá kniha Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrtá kniha Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrtá kniha Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrtá kniha Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικος Βασιλέων Β' 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικος Βασιλέων Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικος Βασιλέων Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικος Βασιλέων Β΄ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικος Βασιλέων Β’ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικος Βασιλεων Β' 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικος Βασιλεων Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικος Βασιλεων Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικος Βασιλεων Β΄ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικος Βασιλεων Β’ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικός Βασιλέων Β' 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικός Βασιλέων Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικός Βασιλέων Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικός Βασιλέων Β΄ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικός Βασιλέων Β’ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικός Βασιλεων Β' 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικός Βασιλεων Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικός Βασιλεων Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικός Βασιλεων Β΄ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικός Βασιλεων Β’ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ਰਾਜਿਆਂ ਦੀ ਦੂਜੀ ਪੋਥੀ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiega Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiegi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księgi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księgi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. kniha kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. kniha kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. kniha královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. kniha královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ksiega Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ksiegi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Księga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Księga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Księgi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Księgi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Книга на царете 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Andra Konungaboken 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha kniha Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha kniha Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha kniha Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha kniha Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá kniha Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá kniha Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá kniha Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá kniha Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II kniha kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II kniha kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II kniha královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II kniha královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Книга на царете 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Ikalawang Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Toinen Kuninkaiden 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Четврта краљевства 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 kniha kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 kniha kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 kniha královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 kniha královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-ге. книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Книга на царете 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-е. Книга Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-я. Книга Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Boqorradii Labaad 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy list Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy list Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy list Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy list Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý list Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý list Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý list Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý list Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiega Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiega Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiega Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiega Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiegi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiegi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiegi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiegi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księga Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księga Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księga Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księga Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księgi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księgi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księgi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księgi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Ks. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Siðari Konungabok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Siðari Konungabók 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Síðari Konungabok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Síðari Konungabók 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Síðari konungabók 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Друга книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Друге книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Четврта краљевима 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("سفر الملوك الثاني 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-а. книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-ге книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-е. книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiega Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiega Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiega Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiega Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiegi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiegi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiegi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiegi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księga Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księga Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księga Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księga Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księgi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księgi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księgi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księgi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-е Книга Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-я Книга Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Ks. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4е. Книга Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4я. Книга Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Andra Kungaboken 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Dezyem liv Wa yo 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Dezyèm liv Wa yo 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Kraljevima 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks. Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks. Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks. Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks. Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks. Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks. Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks. Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks. Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiega Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiega Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiega Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiega Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiegi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiegi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiegi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiegi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księga Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księga Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księga Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księga Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księgi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księgi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księgi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księgi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II a Imparatilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II a Imparaţilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II a Impăratilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II a Impăraţilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II a Împaratilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II a Împaraţilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II a Împăratilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II a Împăraţilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Ks. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Ks Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Ikaapat Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Masodik Kiralyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Masodik Királyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Második Kiralyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Második Királyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Друга о царевима 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Четвърта Царства 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ରାଜାବଳୀର 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiega Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiega Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiega Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiega Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiegi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiegi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiegi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiegi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księga Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księga Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księga Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księga Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księgi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księgi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księgi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księgi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-а книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-е книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Konungaboken 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. พงศ์กษัตริย์ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ks. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Ks Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Книга Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4е Книга Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4я Книга Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá Kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá Kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá Královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá Královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý Kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý Kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý Královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý Královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Fourth Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Brenhinoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kuninkaiden 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Ks Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Tweede Koningen 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ରାଜାବଳୀ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Konungaboken 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 e. Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 e. Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 i. Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 i. Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 พงศ์กษัตริย์ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Brenhinoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kuninkaiden 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ks Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 e. Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 e. Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 i. Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 i. Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Книга Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Anden Kongebog 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Andre Kongebok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Deuxiemes Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Deuxièmes Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Brenhinoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kuninkaiden 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Boqorradii 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Breninoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kraljevima 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks. Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks. Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks. Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks. Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. о царевима 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. краљевства 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Ikalawang Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Liber II Regum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Zweite Koenige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Четверта Царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("الممالك الرابع 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Brenhinoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kuninkaiden 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 e Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 e Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 i Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 i Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Boqorradii 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Breninoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kraljevima 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks. Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks. Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks. Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks. Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kungaboken 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. raǳaharuko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. raǳaharūko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. raǳāharuko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. raǳāharūko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. rāǳaharuko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. rāǳaharūko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. rāǳāharuko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. rāǳāharūko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. о царевима 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 e Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 e Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 i Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 i Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. краљевства 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4th. Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Deuxieme Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Deuxième Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Boqorradii 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Breninoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kraljevima 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks. Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks. Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks. Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks. Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II о царевима 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Para Raja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV краљевства 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. краљевима 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Quarta Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Quarto Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Segundo Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrta Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrta Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrta Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrta Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrtá Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrtá Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrtá Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrtá Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Zweite Konige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Zweite Könige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrta Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrta Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrta Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrta Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrtá Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrtá Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrtá Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrtá Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Друга краљева 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Четвърта Царе 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ﺍﻟﻤﻠﻮﻙ ﺍﻟﺜﺎﻧﻲ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Boqorradii 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Breninoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kraljevima 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks. Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks. Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks. Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks. Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kungaboken 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 raǳaharuko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 raǳaharūko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 raǳāharuko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 raǳāharūko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 rāǳaharuko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 rāǳaharūko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 rāǳāharuko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 rāǳāharūko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 о царевима 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 இராஜாக்கள் 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Para Raja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. राजाहरूको 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e. Koningen 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 краљевства 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. краљевима 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4th Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Para Raja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Imparati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Imparaţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Impărati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Impăraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kiralyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Királyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Koningen 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Împarati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Împaraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Împărati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Împăraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV краљевима 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Regnorum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Pili Wafalme 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Segunda Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Segundo Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βασιλειων Δ' 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βασιλειων Δʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βασιλειων Δʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βασιλειων Δ΄ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βασιλειων Δ’ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βασιλειών Δ' 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βασιλειών Δʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βασιλειών Δʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βασιλειών Δ΄ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βασιλειών Δ’ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Втора Цареви 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Второ Цареви 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Друга Царева 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Irajakkal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Irajakkaḷ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Irajākkal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Irajākkaḷ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Irājakkal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Irājakkaḷ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Irājākkal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Irājākkaḷ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Para Raja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 k. Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 k. Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 k. Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 k. Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 राजाहरूको 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-ге. Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-ге. царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Imparati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Imparaţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Impărati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Impăraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kiralyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Királyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kongebog 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kongebok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Koningen 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Împarati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Împaraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Împărati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Împăraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. ରାଜାବଳୀର 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e Koningen 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 k. Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 k. Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 k. Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 k. Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 краљевима 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-е. Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-я. Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Regnorum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Imparati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Imparaţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Impărati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Impăraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kiralyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Királyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Koningen 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Împarati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Împaraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Împărati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Împăraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Các Vua 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Wafalme 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. краљева 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Regnorum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Царства 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Kiralyok II 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Királyok II 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Masodik Kir 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Második Kir 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β' Βασιλέων 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β' Βασιλεων 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ Βασιλέων 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ Βασιλεων 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ Βασιλέων 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ Βασιλεων 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β΄ Βασιλέων 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β΄ Βασιλεων 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β’ Βασιλέων 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β’ Βασιλεων 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Друга Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Друга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Друге Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Друге царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("دوم-سلاطِین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Imparati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Imparaţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Impărati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Impăraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kiralyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Királyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kongebog 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kongebok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Koningen 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 k Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 k Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 k Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 k Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Împarati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Împaraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Împărati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Împăraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 ରାଜାବଳୀର 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 அரசர்கள் 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-а. Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-а. царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-ге Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-ге царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-е. Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-е. Цареи 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-е. Царей 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-е. царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-я. Цареи 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-я. Царей 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Các Vua 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Koenige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Wafalme 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. краљева 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. ରାଜାବଳୀ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2.-سلاطِین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2.o. Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2.º. Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2eme. Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ème. Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Regnorum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 k Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 k Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 k Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 k Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-е Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-я Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Царства 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4a. Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4o. Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4е. Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4я. Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Anden Kong 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Andre Kong 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Kral 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Král 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Kral 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Král 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá Kral 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá Král 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý Kral 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý Král 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Các Vua 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Wafalme 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II краљева 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Царева 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Цареви 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Царства 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Seconda Re 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Secondo Re 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Tweede Kon 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Wafalme II 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("دوم سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("دوم۔سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("दुसरे राजे 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Các Vua 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Koenige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Wafalme 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 salāṭīn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 краљева 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 ରାଜାବଳୀ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-а Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-а царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-е Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-е Цареи 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-е Царей 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-е царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-я Цареи 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-я Царей 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-سلاطِین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Konige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Könige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Царева 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Цареви 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. राजाओं 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2.o Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2.º Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2.۔سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2de. Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2eme Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2o. Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2º. Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ème Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2е. Цареи 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2е. Царей 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2я. Цареи 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2я. Царей 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Царства 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 அரசுகள் 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4a Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4o Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4е Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4я Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Dezyem Wa 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Dezyèm Wa 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Царева 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Цареви 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Regum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Tweede Ko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("۲-سلاطِین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Konige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Könige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 rājiāṃ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Царева 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Цареви 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 الملوك 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 राजाओं 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 ਰਾਜਿਆਂ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Regum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Цареи 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Царей 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2a. Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2d. Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2de Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e. Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2o Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2o. Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2º Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2е Цареи 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2е Царей 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2я Цареи 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2я Царей 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2۔سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Kr 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Kr 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá Kr 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý Kr 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Regum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kral 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Král 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Царе 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Pili Fal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Regum II 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("מלכים ב' 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("מלכים ב’ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("۲ سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("۲۔سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Regum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Цареи 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Царей 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 இராஜா 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kong 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kral 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Král 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Raja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. राजा 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2a Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2d Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e. Kon 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2o Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Царе 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kral 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Král 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Boq 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Fal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Imp 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kir 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kon 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Reg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Vua 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Împ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Царе 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("מלכים ב 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Bren 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kong 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kral 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Krol 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Král 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Król 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kung 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Raja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Rees 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Reye 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Reys 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ryes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 raǳe 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 rāǳe 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 राजा 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 राजे 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Boq 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Fal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Imp 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kir 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kon 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kön 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Reg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Vua 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Împ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. พกษ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e Kon 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e. Ko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2°. Re 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Царе 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Boq 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Fal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Imp 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kir 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kon 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Reg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Vua 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Împ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kr 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Re 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Wa 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β' Βασ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ Βασ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ Βασ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β΄ Βασ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β’ Βασ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《列王紀下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《列王纪下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《列王记下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王記第四巻 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("열왕기 하권 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Boq 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Fal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Imp 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kir 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kon 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Krl 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Krľ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kun 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kön 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ree 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Reg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Res 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Rey 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Rye 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Rys 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Vua 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Împ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 இரா 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 พกษ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kr 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Wa 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e Ko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2° Re 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Цар 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kr 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Re 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Wa 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β' Βα 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ Βα 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ Βα 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β΄ Βα 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β’ Βα 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《列王紀下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《列王纪下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《列王记下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王紀下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王紀略下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王纪下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王记下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("열왕기 하 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ha 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kr 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Mb 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Rs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ry 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Wa 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 مل 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 அர 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《王下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王 2 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王紀下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王纪下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王記下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王记下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("열왕기하 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 R 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2열왕 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ц 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《王下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("王下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("王下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("왕하 1:1").osis()).toEqual("2Kgs.1.1")
		`
		true
	it "should handle non-Latin digits in book: 2Kgs (full)", ->
		p.set_options non_latin_digits_strategy: "replace"
		`
		expect(p.parse("இராஜாக்களின் இரண்டாம் புத்தகம் 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Kitabu cha Pili cha Wafalme 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("राजाओ का विर्तान्त 2रा भाग 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("राजाओ का विर्तान्त २रा भाग 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga knjiga o Kraljevima 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Cartea a patra a Regilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Ksiega Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Ksiegi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Księga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Księga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Księgi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Księgi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Fjerde Kongerigernes Bog 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Toinen Kuninkaiden kirja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Четвърта Книга на царете 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Четвърта книга на царете 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Втора книга за царевите 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Второ книга за царевите 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("राजाहरूको दोस्रो पुस्तक 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ରାଜାବଳୀର ଦ୍ୱିତୀୟ ପୁସ୍ତକ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiega Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiegi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księgi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księgi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiega Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiegi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księgi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księgi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Четвърта книга Царства 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Ks. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha kniha kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha kniha kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha kniha královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha kniha královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy kniha kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy kniha kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy kniha královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy kniha královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá kniha kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá kniha kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá kniha královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá kniha královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý kniha kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý kniha kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý kniha královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý kniha královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kuninkaiden kirja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. книга за царевите 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Siðari bok konunganna 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Siðari bók konunganna 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Síðari bok konunganna 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Síðari bók konunganna 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kuninkaiden kirja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. книга за царевите 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Kongerigernes Bog 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Czwarta Ks Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kuninkaiden kirja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II книга за царевите 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiega Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiegi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księgi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księgi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Ksiega Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Ksiegi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Księga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Księga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Księgi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Księgi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("rājiāṃ dī dūjī potʰī 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kuninkaiden kirja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 книга за царевите 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiega Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiegi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księgi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księgi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Kongerigernes Bog 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Ksiega Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Ksiegi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Księga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Księga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Księgi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Księgi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Cartea IV a Regilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiega Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiega Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiega Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiega Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiegi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiegi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiegi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ksiegi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księga Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księga Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księga Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księga Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księgi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księgi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księgi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Księgi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiega Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiega Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiega Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiega Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiegi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiegi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiegi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ksiegi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księga Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księga Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księga Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księga Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księgi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księgi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księgi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Księgi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiega Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiegi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księgi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księgi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. kniha kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. kniha kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. kniha královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. kniha královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Ksiega Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Ksiegi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Księga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Księga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Księgi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Księgi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Книга на царете 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrta kniha Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrta kniha Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrta kniha Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrta kniha Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrtá kniha Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrtá kniha Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrtá kniha Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrtá kniha Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrta kniha Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrta kniha Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrta kniha Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrta kniha Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrtá kniha Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrtá kniha Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrtá kniha Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrtá kniha Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικος Βασιλέων Β' 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικος Βασιλέων Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικος Βασιλέων Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικος Βασιλέων Β΄ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικος Βασιλέων Β’ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικος Βασιλεων Β' 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικος Βασιλεων Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικος Βασιλεων Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικος Βασιλεων Β΄ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικος Βασιλεων Β’ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικός Βασιλέων Β' 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικός Βασιλέων Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικός Βασιλέων Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικός Βασιλέων Β΄ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικός Βασιλέων Β’ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικός Βασιλεων Β' 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικός Βασιλεων Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικός Βασιλεων Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικός Βασιλεων Β΄ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("δυτικός Βασιλεων Β’ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ਰਾਜਿਆਂ ਦੀ ਦੂਜੀ ਪੋਥੀ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiega Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiegi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księgi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księgi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. kniha kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. kniha kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. kniha královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. kniha královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ksiega Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ksiega Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ksiegi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ksiegi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Księga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Księga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Księgi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Księgi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Книга на царете 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Andra Konungaboken 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha kniha Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha kniha Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha kniha Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha kniha Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá kniha Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá kniha Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá kniha Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá kniha Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II kniha kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II kniha kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II kniha královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II kniha královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Книга на царете 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Ikalawang Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Toinen Kuninkaiden 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Четврта краљевства 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 kniha kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 kniha kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 kniha královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 kniha královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-ге. книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Книга на царете 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-е. Книга Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-я. Книга Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Boqorradii Labaad 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy list Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy list Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy list Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy list Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý list Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý list Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý list Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý list Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiega Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiega Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiega Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiega Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiegi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiegi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiegi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ksiegi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księga Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księga Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księga Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księga Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księgi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księgi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księgi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Księgi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Ks. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Siðari Konungabok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Siðari Konungabók 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Síðari Konungabok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Síðari Konungabók 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Síðari konungabók 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Друга книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Друге книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Четврта краљевима 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("سفر الملوك الثاني 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-а. книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-ге книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-е. книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiega Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiega Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiega Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiega Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiegi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiegi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiegi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ksiegi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księga Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księga Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księga Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księga Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księgi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księgi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księgi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Księgi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-е Книга Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-я Книга Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Ks. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4е. Книга Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4я. Книга Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Andra Kungaboken 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Dezyem liv Wa yo 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Dezyèm liv Wa yo 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Kraljevima 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks. Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks. Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks. Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks. Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks. Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks. Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks. Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks. Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiega Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiega Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiega Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiega Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiegi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiegi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiegi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ksiegi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księga Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księga Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księga Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księga Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księgi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księgi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księgi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Księgi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II a Imparatilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II a Imparaţilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II a Impăratilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II a Impăraţilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II a Împaratilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II a Împaraţilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II a Împăratilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II a Împăraţilor 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Ks. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Ks Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Ikaapat Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Masodik Kiralyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Masodik Királyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Második Kiralyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Második Királyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Друга о царевима 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Четвърта Царства 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ରାଜାବଳୀର 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiega Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiega Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiega Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiega Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiegi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiegi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiegi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ksiegi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księga Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księga Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księga Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księga Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księgi Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księgi Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księgi Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Księgi Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-а книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-е книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Konungaboken 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. พงศ์กษัตริย์ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ks. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ks. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Ks Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Книга Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4е Книга Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4я Книга Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druga Ks Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Drugi Ks Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá Kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá Kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá Královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá Královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý Kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý Kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý Královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý Královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Fourth Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Brenhinoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kuninkaiden 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Ks Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Tweede Koningen 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ରାଜାବଳୀ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Konungaboken 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 e. Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 e. Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 i. Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 i. Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 พงศ์กษัตริย์ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Brenhinoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kuninkaiden 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ks Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ks Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 e. Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 e. Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 i. Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 i. Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Книга Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Anden Kongebog 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Andre Kongebok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Deuxiemes Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Deuxièmes Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Brenhinoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kuninkaiden 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Boqorradii 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Breninoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kraljevima 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks. Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks. Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks. Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks. Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. о царевима 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. краљевства 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Ikalawang Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Liber II Regum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Zweite Koenige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Четверта Царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("الممالك الرابع 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Brenhinoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kuninkaiden 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 e Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 e Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 i Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 i Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 книга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Boqorradii 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Breninoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kraljevima 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks. Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks. Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks. Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks. Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kungaboken 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. raǳaharuko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. raǳaharūko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. raǳāharuko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. raǳāharūko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. rāǳaharuko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. rāǳaharūko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. rāǳāharuko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. rāǳāharūko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. о царевима 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 e Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 e Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 i Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 i Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. краљевства 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4th. Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Deuxieme Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Deuxième Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Boqorradii 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Breninoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kraljevima 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks. Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks. Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks. Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks. Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II о царевима 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ks Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Para Raja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV краљевства 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. краљевима 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Quarta Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Quarto Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Segundo Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrta Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrta Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrta Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrta Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrtá Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrtá Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrtá Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Stvrtá Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Zweite Konige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Zweite Könige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrta Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrta Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrta Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrta Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrtá Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrtá Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrtá Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Štvrtá Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Друга краљева 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Четвърта Царе 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ﺍﻟﻤﻠﻮﻙ ﺍﻟﺜﺎﻧﻲ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Boqorradii 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Breninoedd 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kraljevima 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks. Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks. Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks. Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks. Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kungaboken 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 raǳaharuko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 raǳaharūko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 raǳāharuko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 raǳāharūko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 rāǳaharuko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 rāǳaharūko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 rāǳāharuko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 rāǳāharūko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 о царевима 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 இராஜாக்கள் 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Para Raja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. राजाहरूको 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e. Koningen 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 краљевства 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. краљевима 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4th Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Para Raja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Imparati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Imparaţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Impărati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Impăraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kiralyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Királyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Koningen 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Împarati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Împaraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Împărati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Împăraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV краљевима 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Regnorum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Pili Wafalme 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Segunda Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Segundo Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βασιλειων Δ' 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βασιλειων Δʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βασιλειων Δʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βασιλειων Δ΄ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βασιλειων Δ’ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βασιλειών Δ' 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βασιλειών Δʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βασιλειών Δʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βασιλειών Δ΄ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βασιλειών Δ’ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Втора Цареви 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Второ Цареви 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Друга Царева 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Irajakkal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Irajakkaḷ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Irajākkal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Irajākkaḷ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Irājakkal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Irājakkaḷ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Irājākkal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Irājākkaḷ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kralovska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kralovská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Krolewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Královska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Královská 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Królewska 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks Krolow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks Krolów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks Królow 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks Królów 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Para Raja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 k. Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 k. Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 k. Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 k. Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 राजाहरूको 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-ге. Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-ге. царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Imparati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Imparaţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Impărati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Impăraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kiralyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Királyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kongebog 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kongebok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Koningen 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Împarati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Împaraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Împărati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Împăraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. ରାଜାବଳୀର 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e Koningen 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Mbreterve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Mbretërve 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 k. Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 k. Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 k. Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 k. Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 краљевима 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-е. Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-я. Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Regnorum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Imparati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Imparaţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Impărati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Impăraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kiralyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Királyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Koningen 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Împarati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Împaraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Împărati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Împăraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Các Vua 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Wafalme 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. краљева 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Regnorum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Царства 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Kiralyok II 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Királyok II 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Masodik Kir 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Második Kir 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β' Βασιλέων 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β' Βασιλεων 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ Βασιλέων 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ Βασιλεων 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ Βασιλέων 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ Βασιλεων 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β΄ Βασιλέων 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β΄ Βασιλεων 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β’ Βασιλέων 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β’ Βασιλεων 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Друга Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Друга царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Друге Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Друге царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("دوم-سلاطِین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Imparati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Imparaţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Impărati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Impăraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kiralyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Királyok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kongebog 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kongebok 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Koningen 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 k Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 k Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 k Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 k Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Împarati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Împaraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Împărati 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Împăraţi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 ରାଜାବଳୀର 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 அரசர்கள் 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-а. Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-а. царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-ге Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-ге царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-е. Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-е. Цареи 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-е. Царей 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-е. царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-я. Цареи 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-я. Царей 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Các Vua 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Koenige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Wafalme 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. краљева 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. ରାଜାବଳୀ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2.-سلاطِین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2.o. Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2.º. Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2eme. Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ème. Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Kingdoms 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Mga Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Regnorum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 k Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 k Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 k Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 k Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-е Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-я Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Царства 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4a. Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4o. Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4е. Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4я. Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Anden Kong 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Andre Kong 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Kral 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Král 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Kral 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Král 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá Kral 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá Král 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý Kral 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý Král 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Các Vua 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Wafalme 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II краљева 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Царева 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Цареви 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Царства 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Seconda Re 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Secondo Re 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Tweede Kon 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Wafalme II 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("دوم سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("دوم۔سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("दुसरे राजे 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Các Vua 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Koenige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Wafalme 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 salāṭīn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 краљева 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 ରାଜାବଳୀ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-а Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-а царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-е Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-е Цареи 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-е Царей 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-е царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-я Цареи 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-я Царей 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-سلاطِین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Konige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Könige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Царева 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Цареви 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. राजाओं 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2.o Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2.º Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2.۔سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2de. Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2eme Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2o. Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2º. Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ème Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2е. Цареи 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2е. Царей 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2я. Цареи 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2я. Царей 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Царства 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 அரசுகள் 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4a Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4o Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4е Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4я Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Dezyem Wa 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Dezyèm Wa 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Царева 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Цареви 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Regum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Tweede Ko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("۲-سلاطِین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Konige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Könige 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 rājiāṃ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Царева 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Цареви 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 الملوك 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 राजाओं 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 ਰਾਜਿਆਂ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Regum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Цареи 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Царей 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2a. Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2d. Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2de Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e. Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2o Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2o. Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2º Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2е Цареи 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2е Царей 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2я Цареи 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2я Царей 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2۔سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Kralov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Kraľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Králov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Kráľov 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Reinos 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Царств 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druha Kr 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhy Kr 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhá Kr 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Druhý Kr 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Regum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kral 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Král 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. Царе 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Pili Fal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Regum II 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Second K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("מלכים ב' 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("מלכים ב’ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("۲ سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("۲۔سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Cariv 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kings 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Regum 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Reyes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Цареи 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Царей 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 இராஜா 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kong 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kral 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Král 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Raja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. राजा 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2a Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2d Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e. Kon 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2o Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Царів 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. Царе 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kral 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Král 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Boq 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Fal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Imp 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kir 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kon 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Reg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Vua 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Împ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV Царе 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("מלכים ב 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Bren 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Hari 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kigs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 King 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kins 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kngs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kong 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kral 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Krol 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Král 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Król 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kung 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Raja 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Rees 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Reis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Reye 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Reys 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Rois 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ryes 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 raǳe 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 rāǳe 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 राजा 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 राजे 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Boq 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Fal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Imp 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kir 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kon 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kön 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Reg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Vua 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Împ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. พกษ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e Kon 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e. Ko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd. K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2°. Re 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Regi 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Царе 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Boq 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Fal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Imp 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kir 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kon 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Reg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Vua 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Împ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Ko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Kr 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Re 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. Wa 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β' Βασ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ Βασ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ Βασ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β΄ Βασ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β’ Βασ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《列王紀下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《列王纪下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《列王记下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王記第四巻 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("열왕기 하권 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Boq 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Fal 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Imp 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kig 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kin 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kir 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kis 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kng 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kns 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kon 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Krl 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Krľ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kun 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kön 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ree 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Reg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Res 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Rey 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Rye 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Rys 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Vua 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Împ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 இரா 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 พกษ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Kr 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Wa 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2e Ko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2nd K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2° Re 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Цар 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Kr 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Re 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Wa 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β' Βα 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ Βα 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ Βα 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β΄ Βα 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β’ Βα 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《列王紀下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《列王纪下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《列王记下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王紀下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王紀略下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王纪下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王记下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("열왕기 하 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ha 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kg 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ki 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kn 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ko 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Kr 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Mb 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Rs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ry 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Wa 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 مل 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 அர 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2Kgs 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《王下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王 2 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王紀下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王纪下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王記下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王记下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("열왕기하 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 R 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2열왕 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ц 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《王下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("王下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("王下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("왕하 1:1").osis()).toEqual("2Kgs.1.1")
		p.include_apocrypha(false)
		expect(p.parse("இராஜாக்களின் இரண்டாம் புத்தகம் 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("KITABU CHA PILI CHA WAFALME 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("राजाओ का विर्तान्त 2रा भाग 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("राजाओ का विर्तान्त २रा भाग 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KNJIGA O KRALJEVIMA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("CARTEA A PATRA A REGILOR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("CZWARTA KSIEGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("CZWARTA KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("CZWARTA KSIEGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("CZWARTA KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("CZWARTA KSIĘGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("CZWARTA KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("CZWARTA KSIĘGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("CZWARTA KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("FJERDE KONGERIGERNES BOG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("TOINEN KUNINKAIDEN KIRJA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ЧЕТВЪРТА КНИГА НА ЦАРЕТЕ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ЧЕТВЪРТА КНИГА НА ЦАРЕТЕ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ВТОРА КНИГА ЗА ЦАРЕВИТЕ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ВТОРО КНИГА ЗА ЦАРЕВИТЕ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("राजाहरूको दोस्रो पुस्तक 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ରାଜାବଳୀର ଦ୍ୱିତୀୟ ପୁସ୍ତକ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIEGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIEGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIĘGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIĘGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIEGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIEGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIĘGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIĘGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ЧЕТВЪРТА КНИГА ЦАРСТВА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("CZWARTA KS. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("CZWARTA KS. KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KNIHA KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KNIHA KRALOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KNIHA KRÁLOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KNIHA KRÁLOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY KNIHA KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY KNIHA KRALOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY KNIHA KRÁLOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY KNIHA KRÁLOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÁ KNIHA KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÁ KNIHA KRALOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÁ KNIHA KRÁLOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÁ KNIHA KRÁLOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÝ KNIHA KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÝ KNIHA KRALOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÝ KNIHA KRÁLOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÝ KNIHA KRÁLOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KUNINKAIDEN KIRJA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. КНИГА ЗА ЦАРЕВИТЕ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SIÐARI BOK KONUNGANNA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SIÐARI BÓK KONUNGANNA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SÍÐARI BOK KONUNGANNA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SÍÐARI BÓK KONUNGANNA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KUNINKAIDEN KIRJA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. КНИГА ЗА ЦАРЕВИТЕ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KONGERIGERNES BOG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("CZWARTA KS KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("CZWARTA KS KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KUNINKAIDEN KIRJA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II КНИГА ЗА ЦАРЕВИТЕ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIEGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIEGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIĘGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIĘGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KSIEGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KSIEGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KSIĘGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KSIĘGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("RĀJIĀṂ DĪ DŪJĪ POTʰĪ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KUNINKAIDEN KIRJA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 КНИГА ЗА ЦАРЕВИТЕ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIEGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIEGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIĘGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIĘGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KONGERIGERNES BOG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KSIEGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KSIEGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KSIĘGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KSIĘGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("CARTEA IV A REGILOR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KS. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KS. KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIEGA KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIEGA KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIEGA KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIEGA KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIEGI KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIEGI KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIEGI KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIEGI KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIĘGA KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIĘGA KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIĘGA KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIĘGA KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIĘGI KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIĘGI KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIĘGI KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KSIĘGI KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KS. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KS. KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIEGA KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIEGA KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIEGA KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIEGA KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIEGI KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIEGI KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIEGI KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIEGI KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIĘGA KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIĘGA KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIĘGA KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIĘGA KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIĘGI KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIĘGI KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIĘGI KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KSIĘGI KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIEGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIEGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIĘGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIĘGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KNIHA KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KNIHA KRALOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KNIHA KRÁLOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KNIHA KRÁLOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KSIEGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KSIEGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KSIĘGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KSIĘGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. КНИГА НА ЦАРЕТЕ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("STVRTA KNIHA KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("STVRTA KNIHA KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("STVRTA KNIHA KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("STVRTA KNIHA KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("STVRTÁ KNIHA KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("STVRTÁ KNIHA KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("STVRTÁ KNIHA KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("STVRTÁ KNIHA KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ŠTVRTA KNIHA KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ŠTVRTA KNIHA KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ŠTVRTA KNIHA KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ŠTVRTA KNIHA KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ŠTVRTÁ KNIHA KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ŠTVRTÁ KNIHA KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ŠTVRTÁ KNIHA KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ŠTVRTÁ KNIHA KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΒΑΣΙΛΈΩΝ Β' 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΒΑΣΙΛΈΩΝ Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΒΑΣΙΛΈΩΝ Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΒΑΣΙΛΈΩΝ Β΄ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΒΑΣΙΛΈΩΝ Β’ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΒΑΣΙΛΕΩΝ Β' 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΒΑΣΙΛΕΩΝ Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΒΑΣΙΛΕΩΝ Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΒΑΣΙΛΕΩΝ Β΄ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΒΑΣΙΛΕΩΝ Β’ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΒΑΣΙΛΈΩΝ Β' 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΒΑΣΙΛΈΩΝ Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΒΑΣΙΛΈΩΝ Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΒΑΣΙΛΈΩΝ Β΄ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΒΑΣΙΛΈΩΝ Β’ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΒΑΣΙΛΕΩΝ Β' 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΒΑΣΙΛΕΩΝ Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΒΑΣΙΛΕΩΝ Βʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΒΑΣΙΛΕΩΝ Β΄ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΒΑΣΙΛΕΩΝ Β’ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ਰਾਜਿਆਂ ਦੀ ਦੂਜੀ ਪੋਥੀ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIEGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIEGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIĘGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIĘGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KNIHA KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KNIHA KRALOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KNIHA KRÁLOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KNIHA KRÁLOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KSIEGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KSIEGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KSIĘGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KSIĘGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. КНИГА НА ЦАРЕТЕ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ANDRA KONUNGABOKEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KS KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KS KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KS KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KS KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KNIHA KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KNIHA KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KNIHA KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KNIHA KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÁ KNIHA KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÁ KNIHA KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÁ KNIHA KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÁ KNIHA KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KNIHA KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KNIHA KRALOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KNIHA KRÁLOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KNIHA KRÁLOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV КНИГА НА ЦАРЕТЕ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IKALAWANG MGA HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("TOINEN KUNINKAIDEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ЧЕТВРТА КРАЉЕВСТВА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KNIHA KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KNIHA KRALOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KNIHA KRÁLOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KNIHA KRÁLOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-ГЕ. КНИГА ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 КНИГА НА ЦАРЕТЕ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-Е. КНИГА ЦАРСТВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-Я. КНИГА ЦАРСТВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("BOQORRADII LABAAD 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY LIST KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY LIST KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY LIST KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY LIST KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÝ LIST KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÝ LIST KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÝ LIST KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÝ LIST KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KS. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KS. KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIEGA KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIEGA KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIEGA KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIEGA KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIEGI KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIEGI KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIEGI KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIEGI KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIĘGA KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIĘGA KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIĘGA KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIĘGA KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIĘGI KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIĘGI KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIĘGI KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KSIĘGI KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KS. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KS. KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SIÐARI KONUNGABOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SIÐARI KONUNGABÓK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SÍÐARI KONUNGABOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SÍÐARI KONUNGABÓK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SÍÐARI KONUNGABÓK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ДРУГА КНИГА ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ДРУГЕ КНИГА ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ЧЕТВРТА КРАЉЕВИМА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("سفر الملوك الثاني 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-А. КНИГА ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-ГЕ КНИГА ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-Е. КНИГА ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KS. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KS. KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIEGA KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIEGA KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIEGA KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIEGA KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIEGI KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIEGI KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIEGI KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIEGI KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIĘGA KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIĘGA KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIĘGA KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIĘGA KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIĘGI KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIĘGI KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIĘGI KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KSIĘGI KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-Е КНИГА ЦАРСТВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-Я КНИГА ЦАРСТВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KS. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KS. KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4Е. КНИГА ЦАРСТВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4Я. КНИГА ЦАРСТВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ANDRA KUNGABOKEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DEZYEM LIV WA YO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DEZYÈM LIV WA YO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KRALJEVIMA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KS. KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KS. KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KS. KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KS. KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KS. KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KS. KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KS. KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KS. KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KS. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KS. KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIEGA KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIEGA KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIEGA KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIEGA KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIEGI KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIEGI KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIEGI KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIEGI KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIĘGA KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIĘGA KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIĘGA KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIĘGA KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIĘGI KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIĘGI KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIĘGI KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KSIĘGI KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II A IMPARATILOR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II A IMPARAŢILOR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II A IMPĂRATILOR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II A IMPĂRAŢILOR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II A ÎMPARATILOR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II A ÎMPARAŢILOR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II A ÎMPĂRATILOR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II A ÎMPĂRAŢILOR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KS KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KS KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KS. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KS. KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KS KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KS KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IKAAPAT MGA HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("MASODIK KIRALYOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("MASODIK KIRÁLYOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("MÁSODIK KIRALYOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("MÁSODIK KIRÁLYOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ДРУГА О ЦАРЕВИМА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ЧЕТВЪРТА ЦАРСТВА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ରାଜାବଳୀର 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KS. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KS. KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIEGA KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIEGA KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIEGA KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIEGA KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIEGI KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIEGI KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIEGI KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIEGI KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIĘGA KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIĘGA KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIĘGA KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIĘGA KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIĘGI KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIĘGI KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIĘGI KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KSIĘGI KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-А КНИГА ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-Е КНИГА ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KONUNGABOKEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KS KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KS KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. พงศ์กษัตริย์ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KS. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KS. KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KS KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KS KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. КНИГА ЦАРСТВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4Е КНИГА ЦАРСТВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4Я КНИГА ЦАРСТВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KS KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KS KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KS KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGA KS KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KS KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KS KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KS KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUGI KS KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KRALOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KRÁLOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KRÁLOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY KRALOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY KRÁLOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY KRÁLOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÁ KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÁ KRALOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÁ KRÁLOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÁ KRÁLOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÝ KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÝ KRALOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÝ KRÁLOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÝ KRÁLOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("FOURTH KINGDOMS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KS KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KS KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. BRENHINOEDD 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KUNINKAIDEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. КНИГА ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KS KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KS KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("TWEEDE KONINGEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ରାଜାବଳୀ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KONUNGABOKEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KS KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KS KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 E. MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 E. MBRETËRVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 I. MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 I. MBRETËRVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 พงศ์กษัตริย์ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. BRENHINOEDD 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KUNINKAIDEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. КНИГА ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KS KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KS KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 E. MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 E. MBRETËRVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 I. MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 I. MBRETËRVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 КНИГА ЦАРСТВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ANDEN KONGEBOG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ANDRE KONGEBOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DEUXIEMES ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DEUXIÈMES ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II BRENHINOEDD 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KUNINKAIDEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II КНИГА ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. BOQORRADII 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. BRENINOEDD 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KRALJEVIMA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KS. KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KS. KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KS. KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KS. KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. О ЦАРЕВИМА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. КРАЉЕВСТВА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IKALAWANG HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("LIBER II REGUM 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ZWEITE KOENIGE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ЧЕТВЕРТА ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("الممالك الرابع 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 BRENHINOEDD 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KUNINKAIDEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 E MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 E MBRETËRVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 I MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 I MBRETËRVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 КНИГА ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. BOQORRADII 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. BRENINOEDD 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KRALJEVIMA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KS. KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KS. KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KS. KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KS. KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KUNGABOKEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. RAǱAHARUKO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. RAǱAHARŪKO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. RAǱĀHARUKO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. RAǱĀHARŪKO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. RĀǱAHARUKO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. RĀǱAHARŪKO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. RĀǱĀHARUKO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. RĀǱĀHARŪKO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. О ЦАРЕВИМА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 E MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 E MBRETËRVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 I MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 I MBRETËRVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. КРАЉЕВСТВА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4TH. KINGDOMS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DEUXIEME ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DEUXIÈME ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II BOQORRADII 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II BRENINOEDD 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KRALJEVIMA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KS. KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KS. KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KS. KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KS. KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II О ЦАРЕВИМА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KRALOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KRÁLOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KRÁLOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KS KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KS KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KS KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KS KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. PARA RAJA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV КРАЉЕВСТВА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. КРАЉЕВИМА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("QUARTA REINOS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("QUARTO REINOS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SEGUNDO REYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("STVRTA KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("STVRTA KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("STVRTA KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("STVRTA KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("STVRTÁ KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("STVRTÁ KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("STVRTÁ KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("STVRTÁ KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ZWEITE KONIGE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ZWEITE KÖNIGE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ŠTVRTA KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ŠTVRTA KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ŠTVRTA KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ŠTVRTA KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ŠTVRTÁ KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ŠTVRTÁ KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ŠTVRTÁ KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ŠTVRTÁ KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ДРУГА КРАЉЕВА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ЧЕТВЪРТА ЦАРЕ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ﺍﻟﻤﻠﻮﻙ ﺍﻟﺜﺎﻧﻲ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 BOQORRADII 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 BRENINOEDD 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KRALJEVIMA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KS. KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KS. KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KS. KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KS. KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KUNGABOKEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RAǱAHARUKO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RAǱAHARŪKO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RAǱĀHARUKO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RAǱĀHARŪKO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RĀǱAHARUKO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RĀǱAHARŪKO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RĀǱĀHARUKO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RĀǱĀHARŪKO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 О ЦАРЕВИМА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 இராஜாக்கள் 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KRALOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KRÁLOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KRÁLOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KS KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KS KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KS KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KS KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. MBRETËRVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. PARA RAJA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. राजाहरूको 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2E. KONINGEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 КРАЉЕВСТВА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. MBRETËRVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. КРАЉЕВИМА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4TH KINGDOMS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÁ KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÁ KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÁ KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÁ KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÝ KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÝ KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÝ KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÝ KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KRALOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KRÁLOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KRÁLOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KS KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KS KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KS KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KS KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II PARA RAJA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. IMPARATI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. IMPARAŢI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. IMPĂRATI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. IMPĂRAŢI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KIRALYOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KIRÁLYOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KONINGEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. MGA HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. ÎMPARATI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. ÎMPARAŢI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. ÎMPĂRATI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. ÎMPĂRAŢI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV КРАЉЕВИМА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KINGDOMS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. MGA HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. REGNORUM 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("PILI WAFALME 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KINGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SEGUNDA REIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SEGUNDO REIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΩΝ Δ' 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΩΝ Δʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΩΝ Δʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΩΝ Δ΄ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΩΝ Δ’ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΏΝ Δ' 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΏΝ Δʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΏΝ Δʹ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΏΝ Δ΄ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΏΝ Δ’ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ВТОРА ЦАРЕВИ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ВТОРО ЦАРЕВИ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ДРУГА ЦАРЕВА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 IRAJAKKAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 IRAJAKKAḶ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 IRAJĀKKAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 IRAJĀKKAḶ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 IRĀJAKKAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 IRĀJAKKAḶ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 IRĀJĀKKAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 IRĀJĀKKAḶ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KRALOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KRALOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KROLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KRÁLOVSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KRÁLOVSKÁ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KRÓLEWSKA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KS KROLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KS KROLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KS KRÓLOW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KS KRÓLÓW 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 MBRETËRVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 PARA RAJA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 K. KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 K. KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 K. KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 K. KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 राजाहरूको 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-ГЕ. CARIV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-ГЕ. ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. IMPARATI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. IMPARAŢI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. IMPĂRATI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. IMPĂRAŢI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KIRALYOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KIRÁLYOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KONGEBOG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KONGEBOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KONINGEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. MGA HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. ÎMPARATI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. ÎMPARAŢI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. ÎMPĂRATI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. ÎMPĂRAŢI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. ରାଜାବଳୀର 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2E KONINGEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 MBRETERVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 MBRETËRVE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 K. KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 K. KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 K. KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 K. KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 КРАЉЕВИМА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-Е. ЦАРСТВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-Я. ЦАРСТВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KINGDOMS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. MGA HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. REGNORUM 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II IMPARATI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II IMPARAŢI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II IMPĂRATI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II IMPĂRAŢI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KIRALYOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KIRÁLYOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KONINGEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II MGA HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II ÎMPARATI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II ÎMPARAŢI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II ÎMPĂRATI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II ÎMPĂRAŢI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. CÁC VUA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. WAFALME 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. КРАЉЕВА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KINGDOMS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV MGA HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV REGNORUM 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. ЦАРСТВА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("KIRALYOK II 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("KIRÁLYOK II 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("MASODIK KIR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("MÁSODIK KIR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KIGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KING 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KINS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KNGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β' ΒΑΣΙΛΈΩΝ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β' ΒΑΣΙΛΕΩΝ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ ΒΑΣΙΛΈΩΝ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ ΒΑΣΙΛΕΩΝ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ ΒΑΣΙΛΈΩΝ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ ΒΑΣΙΛΕΩΝ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β΄ ΒΑΣΙΛΈΩΝ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β΄ ΒΑΣΙΛΕΩΝ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β’ ΒΑΣΙΛΈΩΝ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β’ ΒΑΣΙΛΕΩΝ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ДРУГА CARIV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ДРУГА ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ДРУГЕ CARIV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ДРУГЕ ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("دوم-سلاطِین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 IMPARATI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 IMPARAŢI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 IMPĂRATI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 IMPĂRAŢI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KIRALYOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KIRÁLYOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KONGEBOG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KONGEBOK 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KONINGEN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 MGA HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 K KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 K KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 K KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 K KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 ÎMPARATI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 ÎMPARAŢI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 ÎMPĂRATI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 ÎMPĂRAŢI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 ରାଜାବଳୀର 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 அரசர்கள் 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-А. CARIV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-А. ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-ГЕ CARIV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-ГЕ ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-Е. CARIV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-Е. ЦАРЕИ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-Е. ЦАРЕЙ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-Е. ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-Я. ЦАРЕИ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-Я. ЦАРЕЙ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. CÁC VUA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KOENIGE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. WAFALME 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. КРАЉЕВА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. ରାଜାବଳୀ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2.-سلاطِین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2.O. REYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2.º. REYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2EME. ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KINGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ÈME. ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KINGDOMS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 MGA HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 REGNORUM 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 K KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 K KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 K KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 K KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-Е ЦАРСТВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4-Я ЦАРСТВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. ЦАРСТВА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4A. REINOS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4O. REINOS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4Е. ЦАРСТВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4Я. ЦАРСТВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ANDEN KONG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("ANDRE KONG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KRAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KRÁL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY KRAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY KRÁL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÁ KRAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÁ KRÁL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÝ KRAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÝ KRÁL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II CÁC VUA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II WAFALME 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II КРАЉЕВА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. ЦАРЕВА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. ЦАРЕВИ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV ЦАРСТВА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. REINOS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KIG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KIN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KNS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECONDA RE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECONDO RE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("TWEEDE KON 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("WAFALME II 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("دوم سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("دوم۔سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("दुसरे राजे 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 CÁC VUA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KOENIGE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 WAFALME 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 SALĀṬĪN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 КРАЉЕВА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 ରାଜାବଳୀ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-А CARIV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-А ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-Е CARIV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-Е ЦАРЕИ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-Е ЦАРЕЙ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-Е ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-Я ЦАРЕИ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-Я ЦАРЕЙ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2-سلاطِین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KONIGE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KÖNIGE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. ЦАРЕВА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. ЦАРЕВИ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. राजाओं 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2.O REYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2.º REYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2.۔سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2DE. ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2EME ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KINGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KIGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KING 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KINS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KNGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2O. REYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2º. REYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ÈME ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2Е. ЦАРЕИ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2Е. ЦАРЕЙ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2Я. ЦАРЕИ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2Я. ЦАРЕЙ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 ЦАРСТВА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 அரசுகள் 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. REINOS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. ЦАРСТВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4A REINOS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4O REINOS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4Е ЦАРСТВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4Я ЦАРСТВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DEZYEM WA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DEZYÈM WA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II ЦАРЕВА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II ЦАРЕВИ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. CARIV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KINGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. REGUM 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. REYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV REINOS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND KS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("TWEEDE KO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("۲-سلاطِین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KONIGE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KÖNIGE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RĀJIĀṂ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 ЦАРЕВА 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 ЦАРЕВИ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 الملوك 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 राजाओं 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 ਰਾਜਿਆਂ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. CARIV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KINGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. REGUM 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. REYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. ЦАРЕИ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. ЦАРЕЙ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2A. REIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2D. ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2DE ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2E. ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KIGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KING 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KINS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KNGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KIG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KIN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KNS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2O REYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2O. REIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2º REYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2Е ЦАРЕИ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2Е ЦАРЕЙ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2Я ЦАРЕИ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2Я ЦАРЕЙ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2۔سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KRALOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KRAĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KRÁLOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 KRÁĽOV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 REINOS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 ЦАРСТВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHA KR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHY KR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÁ KR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("DRUHÝ KR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II CARIV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KINGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II REGUM 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II REYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KIGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KING 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KINS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KNGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KRAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KRÁL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. REGI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. REIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. REGI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV. ЦАРЕ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("PILI FAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("REGUM II 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("SECOND K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("מלכים ב' 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("מלכים ב’ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("۲ سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("۲۔سلاطین 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 CARIV 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KINGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 REGUM 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 REYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 ЦАРЕИ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 ЦАРЕЙ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 இராஜா 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KIGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KING 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KINS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KNGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KONG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KRAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KRÁL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. RAJA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. REGI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. REIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. राजा 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2A REIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2D ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2E ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2E. KON 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KIG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KIN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KNS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. KS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2O REIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 ЦАРІВ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. REGI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4. ЦАРЕ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KIGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KING 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KINS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KNGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KRAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KRÁL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II REGI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II REIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. BOQ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. FAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. IMP 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KIG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KIN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KIR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KNS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KON 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. REG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. VUA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. ÎMP 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV REGI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("IV ЦАРЕ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("מלכים ב 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 BREN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 HARI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KIGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KING 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KINS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KNGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KONG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KRAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KROL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KRÁL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KRÓL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KUNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RAJA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 REES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 REGI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 REIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 REYE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 REYS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 ROIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RYES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RAǱE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RĀǱE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 राजा 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 राजे 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. BOQ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. FAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. IMP 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KIG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KIN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KIR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KNS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KON 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KÖN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. REG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. VUA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. ÎMP 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. พกษ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2E KON 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2E. KO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND KS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND. K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2°. RE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 REGI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 ЦАРЕ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II BOQ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II FAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II IMP 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KIG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KIN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KIR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KNS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KON 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II REG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II VUA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II ÎMP 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. KR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. RE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II. WA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β' ΒΑΣ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ ΒΑΣ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ ΒΑΣ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β΄ ΒΑΣ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β’ ΒΑΣ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《列王紀下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《列王纪下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《列王记下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王記第四巻 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("열왕기 하권 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 BOQ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 FAL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 IMP 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KIG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KIN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KIR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KIS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KNG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KNS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KON 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KRL 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KRĽ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KUN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KÖN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 REE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 REG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RES 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 REY 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RYE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RYS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 VUA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 ÎMP 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 இரா 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 พกษ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. WA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2E KO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2ND K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2° RE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 ЦАР 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II RE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II WA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β' ΒΑ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ ΒΑ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Βʹ ΒΑ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β΄ ΒΑ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("Β’ ΒΑ 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《列王紀下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《列王纪下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《列王记下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王紀下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王紀略下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王纪下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王记下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("열왕기 하 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 HA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KG 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KI 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KN 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KO 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KR 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 MB 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RY 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 WA 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 مل 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 அர 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2KGS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II K 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《王下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王 2 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王紀下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王纪下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王記下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列王记下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("열왕기하 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 R 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2열왕 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("4 Ц 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("《王下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("王下》 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("列下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("王下 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("왕하 1:1").osis()).toEqual("2Kgs.1.1")
		`
		true
describe "Localized book 1Kgs (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Kgs (full)", ->
		`
		expect(p.parse("Ensimmainen Kuninkaiden kirja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Ensimmäinen Kuninkaiden kirja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kitabu cha Kwanza cha Wafalme 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("இராஜாக்களின் முதலாம் புத்தகம் 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("राजाओ का विर्तान्त 1ला भाग् 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("राजाओ का विर्तान्त १ला भाग् 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Cartea a treia a Regilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva knjiga o Kraljevima 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tredje Kongerigernes Bog 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Ensimmainen Kuninkaiden 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Ensimmäinen Kuninkaiden 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiega Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiega Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiega Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiega Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiegi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiegi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiegi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiegi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księga Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księga Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księga Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księga Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księgi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księgi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księgi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księgi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiega Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiega Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiega Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiega Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiegi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiegi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiegi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiegi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księga Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księga Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księga Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księga Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księgi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księgi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księgi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księgi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiega Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiega Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiega Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiega Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiegi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiegi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiegi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiegi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księga Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księga Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księga Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księga Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księgi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księgi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księgi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księgi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("rājiāṃ dī pahilī potʰī 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Прва книга за царевите 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Прво книга за царевите 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni kniha kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni kniha kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni kniha královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni kniha královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("První kniha kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("První kniha kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("První kniha královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("První kniha královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Трета книга на царете 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Трето Книга на царете 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ରାଜାବଳୀର ପ୍ରଥମ ପୁସ୍ତକ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kuninkaiden kirja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. книга за царевите 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Kongerigernes Bog 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Cartea III a Regilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Fyrri bok konunganna 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Fyrri bók konunganna 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kuninkaiden kirja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. книга за царевите 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Книга на царете 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("राजाहरूक पहिल पुस्तक 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ਰਾਜਿਆਂ ਦੀ ਪਹਿਲੀ ਪੋਥੀ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kuninkaiden kirja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 книга за царевите 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Kongerigernes Bog 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Forsta Konungaboken 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Första Konungaboken 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kuninkaiden kirja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I книга за царевите 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Книга на царете 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks. Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks. Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks. Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks. Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks. Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks. Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks. Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks. Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks. Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks. Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks. Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks. Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretia kniha Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretia kniha Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretia kniha Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretia kniha Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικος Βασιλέων Α' 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικος Βασιλέων Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικος Βασιλέων Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικος Βασιλέων Α΄ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικος Βασιλέων Α’ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικος Βασιλεων Α' 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικος Βασιλεων Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικος Βασιλεων Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικος Βασιλεων Α΄ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικος Βασιλεων Α’ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικός Βασιλέων Α' 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικός Βασιλέων Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικός Βασιλέων Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικός Βασιλέων Α΄ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικός Βασιλέων Α’ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικός Βασιλεων Α' 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικός Βασιλεων Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικός Βασιλεων Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικός Βασιλεων Α΄ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικός Βασιλεων Α’ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Трета книга Царства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. kniha kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. kniha kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. kniha královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. kniha královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Книга на царете 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. kniha kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. kniha kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. kniha královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. kniha královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 kniha kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 kniha kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 kniha královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 kniha královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-ше. книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Книга на царете 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-е. Книга Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-я. Книга Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Boqorradii Kowaad 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Forsta Kungaboken 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Första Kungaboken 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I kniha kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I kniha kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I kniha královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I kniha královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Ikatlong Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva kniha Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva kniha Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva kniha Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva kniha Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvá kniha Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvá kniha Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvá kniha Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvá kniha Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("raǳaharuko pustak 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("raǳaharūko pustak 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("raǳāharuko pustak 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("raǳāharūko pustak 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("rāǳaharuko pustak 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("rāǳaharūko pustak 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("rāǳāharuko pustak 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("rāǳāharūko pustak 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Перша книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Перше книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Трећом краљевства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-а. книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-е. книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-ше книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiega Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiega Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiega Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiega Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiegi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiegi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiegi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiegi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księga Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księga Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księga Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księga Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księgi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księgi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księgi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księgi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-е Книга Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-я Книга Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3е. Книга Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3я. Книга Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Fyrri Konungabok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Fyrri Konungabók 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Fyrri konungabók 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiega Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiega Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiega Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiega Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiegi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiegi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiegi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiegi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księga Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księga Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księga Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księga Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księgi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księgi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księgi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księgi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Premye liv Wa yo 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvy list Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvy list Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvy list Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvy list Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvý list Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvý list Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvý list Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvý list Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Трећа краљевства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Трећом краљевима 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("سفر الملوك الأول 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiega Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiega Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiega Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiega Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiegi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiegi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiegi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiegi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księga Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księga Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księga Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księga Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księgi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księgi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księgi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księgi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-а книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-е книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Konungaboken 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. พงศ์กษัตริย์ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Книга Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3е Книга Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3я Книга Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Eerste Koningen 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Første Kongebog 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Første Kongebok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiega Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiega Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiega Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiega Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiegi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiegi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiegi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiegi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księga Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księga Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księga Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księga Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księgi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księgi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księgi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księgi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I a Imparatilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I a Imparaţilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I a Impăratilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I a Impăraţilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I a Împaratilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I a Împaraţilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I a Împăratilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I a Împăraţilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. краљевства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva Kraljevima 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni Kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni Kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni Královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni Královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("První Kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("První Kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("První Královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("První Královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Terceira Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Terceiro Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Прва о царевима 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Трећа краљевима 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Konungaboken 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 e. Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 e. Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 i. Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 i. Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 พงศ์กษัตริย์ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Brenhinoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kuninkaiden 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 e. Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 e. Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 i. Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 i. Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Книга Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Brenhinoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kuninkaiden 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III краљевства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. краљевима 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kwanza Wafalme 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Premieres Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Premières Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Third Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Unang Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("الممالك الثالث 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ପ୍ରଥମ ରାଜାବଳୀର 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Brenhinoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kuninkaiden 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 e Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 e Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 i Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 i Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Boqorradii 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Breninoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kraljevima 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks. Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks. Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks. Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks. Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kungaboken 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. raǳaharuko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. raǳaharūko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. raǳāharuko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. raǳāharūko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. rāǳaharuko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. rāǳaharūko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. rāǳāharuko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. rāǳāharūko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. о царевима 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 e Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 e Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 i Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 i Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. краљевства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3rd. Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Elso Kiralyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Elso Királyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Első Kiralyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Első Királyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Erste Koenige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Brenhinoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kuninkaiden 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Boqorradii 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Breninoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kraljevima 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks. Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks. Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks. Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks. Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. о царевима 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III краљевима 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Regnorum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Liber I Regum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Premiere Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Premiers Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Première Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Primeira Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Primeiro Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Primero Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretia Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretia Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretia Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretia Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Трето Царства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ପ୍ରଥମ ରାଜାବଳୀ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Boqorradii 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Breninoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kraljevima 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks. Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks. Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks. Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks. Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kungaboken 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 raǳaharuko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 raǳaharūko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 raǳāharuko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 raǳāharūko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 rāǳaharuko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 rāǳaharūko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 rāǳāharuko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 rāǳāharūko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 о царевима 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 இராஜாக்கள் 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Para Raja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. राजाहरूको 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1e. Koningen 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 краљевства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. краљевима 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3rd Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Erste Konige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Erste Könige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Boqorradii 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Breninoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kraljevima 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks. Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks. Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks. Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks. Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I о царевима 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Para Raja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Regnorum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Царства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Premier Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Primer Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Treti Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Treti Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Treti Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Treti Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretí Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretí Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretí Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretí Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Una Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Βασιλειων Γ' 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Βασιλειων Γʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Βασιλειων Γʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Βασιλειων Γ΄ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Βασιλειων Γ’ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Βασιλειών Γ' 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Βασιλειών Γʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Βασιλειών Γʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Βασιλειών Γ΄ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Βασιλειών Γ’ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Прва краљева 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("الملوك الأول 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("اوّل-سلاطِین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Irajakkal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Irajakkaḷ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Irajākkal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Irajākkaḷ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Irājakkal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Irājakkaḷ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Irājākkal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Irājākkaḷ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Para Raja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 k. Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 k. Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 k. Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 k. Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 राजाहरूको 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-ше. Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-ше. царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Imparati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Imparaţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Impărati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Impăraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kiralyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Királyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kongebog 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kongebok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Koningen 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Împarati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Împaraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Împărati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Împăraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. ରାଜାବଳୀର 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1e Koningen 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 k. Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 k. Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 k. Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 k. Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 краљевима 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-е. Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-тє. Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-я. Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Regnorum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Første Kong 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Para Raja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Imparati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Imparaţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Impărati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Impăraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kiralyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Királyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Koningen 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Împarati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Împaraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Împărati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Împăraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Царства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvy Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvy Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvy Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvy Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvá Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvá Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvá Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvá Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvý Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvý Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvý Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvý Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α' Βασιλέων 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α' Βασιλεων 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ Βασιλέων 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ Βασιλεων 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ Βασιλέων 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ Βασιλεων 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α΄ Βασιλέων 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α΄ Βασιλεων 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α’ Βασιλέων 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α’ Βασιλεων 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Перша Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Перша царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Перше Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Перше царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Прва Царева 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Прва Цареви 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Прво Цареви 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Третя Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Третє Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("اوّل سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("اوّل۔سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Imparati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Imparaţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Impărati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Impăraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kiralyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Királyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kongebog 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kongebok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Koningen 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 k Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 k Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 k Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 k Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Împarati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Împaraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Împărati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Împăraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 ରାଜାବଳୀର 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 அரசர்கள் 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-а. Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-а. царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-е. Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-е. Цареи 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-е. Царей 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-е. царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-ше Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-ше царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-я. Цареи 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-я. Царей 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Các Vua 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Koenige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Wafalme 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. краљева 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. ରାଜାବଳୀ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1.-سلاطِین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1.o. Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1.º. Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ere. Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ère. Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Regnorum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 k Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 k Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 k Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 k Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-а. Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-е Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-е. Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-тє Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-я Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Царства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3a. Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3o. Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3е. Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3я. Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Eerste Kon 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Imparati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Imparaţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Impărati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Impăraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kiralyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Királyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Koningen 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Împarati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Împaraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Împărati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Împăraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Các Vua 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Wafalme 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. краљева 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kiralyok I 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Királyok I 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kwanza Fal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni Kral 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni Král 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("První Kral 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("První Král 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Unang Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Трето Царе 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("पहिले राजे 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ﺍﻟﻤﻠﻮﻙ ﺍﻷﻭ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Các Vua 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Koenige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Wafalme 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 salāṭīn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 краљева 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 ରାଜାବଳୀ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-а Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-а царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-е Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-е Цареи 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-е Царей 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-е царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-я Цареи 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-я Царей 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-سلاطِین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Konige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Könige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Царева 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Цареви 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. राजाओं 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1.o Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1.º Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1.۔سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1er. Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ere Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1o. Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1re. Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1º. Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ère Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1е. Цареи 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1е. Царей 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1я. Цареи 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1я. Царей 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Царства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 அரசுகள் 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-а Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-е Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3a Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3o Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3е Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3я Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Eerste Ko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Các Vua 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Wafalme 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I краљева 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Царева 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Цареви 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Царе 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Premye Wa 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Wafalme I 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("۱-سلاطِین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Konige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Könige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 rājiāṃ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Царева 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Цареви 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 الملوك 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 राजाओं 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 ਰਾਜਿਆਂ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Regum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Цареи 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Царей 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1a. Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1er Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1o Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1o. Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1re Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1º Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1е Цареи 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1е Царей 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1я Цареи 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1я Царей 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1۔سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Elso Kir 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Első Kir 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Ks 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Царева 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Цареви 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Regum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Царе 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prima Re 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Primo Re 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni Kr 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("První Kr 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Una Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("מלכים א' 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("מלכים א’ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("۱ سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("۱۔سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Regum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Цареи 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Царей 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 இராஜா 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kong 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kral 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Král 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Raja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. राजा 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1a Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1e. Kon 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1o Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Ks 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Царе 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Regum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kral 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Král 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Regum I 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("מלכים א 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Bren 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kong 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kral 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Krol 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Král 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Król 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kung 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Raja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Rees 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Reye 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Reys 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ryes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 raǳe 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 rāǳe 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 राजा 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 राजे 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Boq 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Fal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Imp 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kir 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kon 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kön 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Reg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Vua 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Împ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. พกษ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1e Kon 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1e. Ko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Ks 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1°. Re 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Царе 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kral 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Král 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Boq 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Fal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Imp 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kir 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kon 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Reg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Vua 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Împ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α' Βασ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ Βασ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ Βασ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α΄ Βασ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α’ Βασ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《列王紀上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《列王纪上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《列王记上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王記第三巻 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("열왕기 상권 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Boq 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Fal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Imp 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kir 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kon 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Krl 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Krľ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kun 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kön 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ree 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Reg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Res 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Rey 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Rye 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Rys 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Vua 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Împ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 இரா 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 พกษ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kr 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Wa 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1e Ko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1° Re 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Цар 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Boq 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Fal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Imp 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kir 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kon 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Reg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Vua 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Împ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kr 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Re 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Wa 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α' Βα 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ Βα 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ Βα 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α΄ Βα 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α’ Βα 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《列王紀上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《列王纪上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《列王记上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王紀上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王紀略上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王纪上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王记上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("열왕기 상 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ha 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kr 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Mb 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Rs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ry 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Wa 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 مل 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 அர 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kr 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Re 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Wa 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《王上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王 1 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王紀上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王纪上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王記上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王记上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("열왕기상 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 R 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1열왕 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ц 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《王上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("王上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("王上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("왕상 1:1").osis()).toEqual("1Kgs.1.1")
		`
		true
	it "should handle non-Latin digits in book: 1Kgs (full)", ->
		p.set_options non_latin_digits_strategy: "replace"
		`
		expect(p.parse("Ensimmainen Kuninkaiden kirja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Ensimmäinen Kuninkaiden kirja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kitabu cha Kwanza cha Wafalme 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("இராஜாக்களின் முதலாம் புத்தகம் 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("राजाओ का विर्तान्त 1ला भाग् 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("राजाओ का विर्तान्त १ला भाग् 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Cartea a treia a Regilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva knjiga o Kraljevima 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tredje Kongerigernes Bog 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Ensimmainen Kuninkaiden 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Ensimmäinen Kuninkaiden 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiega Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiega Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiega Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiega Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiegi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiegi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiegi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ksiegi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księga Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księga Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księga Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księga Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księgi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księgi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księgi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Księgi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiega Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiega Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiega Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiega Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiegi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiegi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiegi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ksiegi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księga Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księga Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księga Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księga Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księgi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księgi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księgi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Księgi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiega Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiega Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiega Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiega Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiegi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiegi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiegi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ksiegi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księga Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księga Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księga Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księga Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księgi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księgi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księgi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Księgi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("rājiāṃ dī pahilī potʰī 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Прва книга за царевите 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Прво книга за царевите 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni kniha kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni kniha kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni kniha královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni kniha královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("První kniha kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("První kniha kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("První kniha královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("První kniha královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Трета книга на царете 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Трето Книга на царете 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ରାଜାବଳୀର ପ୍ରଥମ ପୁସ୍ତକ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kuninkaiden kirja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. книга за царевите 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Kongerigernes Bog 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Cartea III a Regilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Fyrri bok konunganna 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Fyrri bók konunganna 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kuninkaiden kirja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. книга за царевите 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Книга на царете 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzecia Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("राजाहरूक पहिल पुस्तक 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ਰਾਜਿਆਂ ਦੀ ਪਹਿਲੀ ਪੋਥੀ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kuninkaiden kirja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 книга за царевите 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Kongerigernes Bog 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Forsta Konungaboken 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Första Konungaboken 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kuninkaiden kirja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I книга за царевите 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Книга на царете 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks. Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks. Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks. Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks. Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks. Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks. Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks. Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks. Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks. Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks. Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks. Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks. Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretia kniha Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretia kniha Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretia kniha Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretia kniha Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Trzeci Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικος Βασιλέων Α' 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικος Βασιλέων Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικος Βασιλέων Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικος Βασιλέων Α΄ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικος Βασιλέων Α’ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικος Βασιλεων Α' 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικος Βασιλεων Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικος Βασιλεων Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικος Βασιλεων Α΄ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικος Βασιλεων Α’ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικός Βασιλέων Α' 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικός Βασιλέων Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικός Βασιλέων Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικός Βασιλέων Α΄ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικός Βασιλέων Α’ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικός Βασιλεων Α' 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικός Βασιλεων Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικός Βασιλεων Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικός Βασιλεων Α΄ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("δυτικός Βασιλεων Α’ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Трета книга Царства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. kniha kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. kniha kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. kniha královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. kniha královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Книга на царете 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiega Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiega Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiegi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiegi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księga Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księga Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księgi Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księgi Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. kniha kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. kniha kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. kniha královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. kniha královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsza Ks Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwsze Ks Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Pierwszy Ks Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 kniha kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 kniha kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 kniha královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 kniha královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-ше. книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Книга на царете 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-е. Книга Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-я. Книга Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Boqorradii Kowaad 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Forsta Kungaboken 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Första Kungaboken 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I kniha kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I kniha kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I kniha královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I kniha královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Ikatlong Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva kniha Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva kniha Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva kniha Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva kniha Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvá kniha Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvá kniha Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvá kniha Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvá kniha Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("raǳaharuko pustak 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("raǳaharūko pustak 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("raǳāharuko pustak 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("raǳāharūko pustak 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("rāǳaharuko pustak 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("rāǳaharūko pustak 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("rāǳāharuko pustak 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("rāǳāharūko pustak 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Перша книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Перше книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Трећом краљевства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-а. книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-е. книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-ше книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiega Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiega Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiega Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiega Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiegi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiegi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiegi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ksiegi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księga Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księga Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księga Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księga Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księgi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księgi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księgi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Księgi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-е Книга Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-я Книга Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3е. Книга Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3я. Книга Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Fyrri Konungabok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Fyrri Konungabók 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Fyrri konungabók 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiega Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiega Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiega Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiega Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiegi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiegi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiegi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ksiegi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księga Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księga Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księga Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księga Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księgi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księgi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księgi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Księgi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Premye liv Wa yo 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvy list Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvy list Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvy list Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvy list Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvý list Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvý list Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvý list Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvý list Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Трећа краљевства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Трећом краљевима 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("سفر الملوك الأول 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiega Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiega Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiega Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiega Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiegi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiegi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiegi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ksiegi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księga Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księga Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księga Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księga Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księgi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księgi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księgi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Księgi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-а книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-е книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Konungaboken 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. พงศ์กษัตริย์ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Книга Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3е Книга Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3я Книга Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Eerste Koningen 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Første Kongebog 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Første Kongebok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiega Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiega Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiega Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiega Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiegi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiegi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiegi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ksiegi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księga Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księga Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księga Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księga Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księgi Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księgi Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księgi Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Księgi Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I a Imparatilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I a Imparaţilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I a Impăratilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I a Impăraţilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I a Împaratilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I a Împaraţilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I a Împăratilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I a Împăraţilor 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. краљевства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva Kraljevima 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni Kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni Kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni Královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni Královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("První Kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("První Kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("První Královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("První Královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Terceira Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Terceiro Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Прва о царевима 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Трећа краљевима 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Konungaboken 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 e. Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 e. Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 i. Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 i. Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 พงศ์กษัตริย์ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Brenhinoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kuninkaiden 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 e. Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 e. Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 i. Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 i. Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Книга Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Brenhinoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kuninkaiden 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III краљевства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. краљевима 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kwanza Wafalme 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Premieres Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Premières Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Third Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Unang Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("الممالك الثالث 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ପ୍ରଥମ ରାଜାବଳୀର 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Brenhinoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kuninkaiden 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 e Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 e Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 i Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 i Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Boqorradii 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Breninoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kraljevima 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks. Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks. Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks. Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks. Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kungaboken 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. raǳaharuko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. raǳaharūko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. raǳāharuko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. raǳāharūko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. rāǳaharuko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. rāǳaharūko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. rāǳāharuko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. rāǳāharūko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. о царевима 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 e Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 e Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 i Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 i Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. краљевства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3rd. Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Elso Kiralyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Elso Királyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Első Kiralyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Első Királyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Erste Koenige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Brenhinoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kuninkaiden 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I книга царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Boqorradii 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Breninoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kraljevima 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks. Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks. Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks. Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks. Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. о царевима 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III краљевима 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Regnorum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Liber I Regum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Premiere Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Premiers Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Première Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Primeira Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Primeiro Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Primero Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretia Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretia Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretia Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretia Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Трето Царства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ପ୍ରଥମ ରାଜାବଳୀ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Boqorradii 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Breninoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kraljevima 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks. Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks. Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks. Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks. Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kungaboken 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 raǳaharuko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 raǳaharūko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 raǳāharuko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 raǳāharūko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 rāǳaharuko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 rāǳaharūko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 rāǳāharuko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 rāǳāharūko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 о царевима 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 இராஜாக்கள் 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ks Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Para Raja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. राजाहरूको 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1e. Koningen 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 краљевства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. краљевима 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3rd Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Erste Konige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Erste Könige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Boqorradii 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Breninoedd 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kraljevima 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks. Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks. Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks. Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks. Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I о царевима 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Para Raja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Regnorum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Царства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Premier Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Primer Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Treti Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Treti Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Treti Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Treti Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretí Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretí Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretí Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Tretí Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Una Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Βασιλειων Γ' 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Βασιλειων Γʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Βασιλειων Γʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Βασιλειων Γ΄ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Βασιλειων Γ’ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Βασιλειών Γ' 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Βασιλειών Γʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Βασιλειών Γʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Βασιλειών Γ΄ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Βασιλειών Γ’ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Прва краљева 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("الملوك الأول 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("اوّل-سلاطِین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Irajakkal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Irajakkaḷ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Irajākkal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Irajākkaḷ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Irājakkal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Irājakkaḷ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Irājākkal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Irājākkaḷ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Para Raja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 k. Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 k. Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 k. Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 k. Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 राजाहरूको 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-ше. Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-ше. царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Imparati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Imparaţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Impărati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Impăraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kiralyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Királyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kongebog 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kongebok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Koningen 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Împarati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Împaraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Împărati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Împăraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. ରାଜାବଳୀର 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1e Koningen 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Mbreterve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Mbretërve 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 k. Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 k. Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 k. Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 k. Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 краљевима 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-е. Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-тє. Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-я. Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Regnorum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Første Kong 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kralovska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kralovská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Krolewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Královska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Královská 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Królewska 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks Krolow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks Krolów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks Królow 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks Królów 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Para Raja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Imparati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Imparaţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Impărati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Impăraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kiralyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Királyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Koningen 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Împarati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Împaraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Împărati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Împăraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Царства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prva Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvy Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvy Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvy Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvy Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvá Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvá Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvá Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvá Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvý Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvý Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvý Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvý Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α' Βασιλέων 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α' Βασιλεων 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ Βασιλέων 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ Βασιλεων 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ Βασιλέων 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ Βασιλεων 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α΄ Βασιλέων 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α΄ Βασιλεων 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α’ Βασιλέων 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α’ Βασιλεων 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Перша Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Перша царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Перше Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Перше царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Прва Царева 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Прва Цареви 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Прво Цареви 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Третя Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Третє Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("اوّل سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("اوّل۔سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Imparati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Imparaţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Impărati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Impăraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kiralyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Királyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kongebog 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kongebok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Koningen 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 k Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 k Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 k Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 k Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Împarati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Împaraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Împărati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Împăraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 ରାଜାବଳୀର 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 அரசர்கள் 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-а. Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-а. царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-е. Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-е. Цареи 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-е. Царей 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-е. царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-ше Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-ше царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-я. Цареи 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-я. Царей 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Các Vua 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Koenige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Wafalme 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. краљева 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. ରାଜାବଳୀ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1.-سلاطِین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1.o. Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1.º. Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ere. Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ère. Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Kingdoms 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Regnorum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 k Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 k Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 k Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 k Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-а. Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-е Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-е. Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-тє Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-я Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Царства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3a. Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3o. Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3е. Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3я. Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Eerste Kon 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Imparati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Imparaţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Impărati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Impăraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kiralyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Királyok 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Koningen 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Mga Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Împarati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Împaraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Împărati 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Împăraţi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Các Vua 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Wafalme 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. краљева 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kiralyok I 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Királyok I 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kwanza Fal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni Kral 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni Král 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("První Kral 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("První Král 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Unang Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Трето Царе 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("पहिले राजे 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ﺍﻟﻤﻠﻮﻙ ﺍﻷﻭ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Các Vua 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Koenige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Wafalme 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 salāṭīn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 краљева 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 ରାଜାବଳୀ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-а Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-а царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-е Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-е Цареи 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-е Царей 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-е царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-я Цареи 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-я Царей 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-سلاطِین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Konige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Könige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Царева 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Цареви 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. राजाओं 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1.o Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1.º Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1.۔سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1er. Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ere Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1o. Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1re. Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1º. Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ère Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1е. Цареи 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1е. Царей 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1я. Цареи 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1я. Царей 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Царства 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 அரசுகள் 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-а Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-е Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3a Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3o Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3е Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3я Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Eerste Ko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Các Vua 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Wafalme 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I краљева 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Царева 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Цареви 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. Царе 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Premye Wa 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Wafalme I 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("۱-سلاطِین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Konige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Könige 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 rājiāṃ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Царева 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Цареви 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 الملوك 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 राजाओं 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 ਰਾਜਿਆਂ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Regum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Цареи 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Царей 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1a. Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1er Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1o Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1o. Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1re Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1º Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1е Цареи 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1е Царей 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1я Цареи 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1я Царей 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1۔سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Reinos 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Царств 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Elso Kir 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Első Kir 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First Ks 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kralov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kraľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Králov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kráľov 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Царева 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Цареви 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Regum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III Царе 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prima Re 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Primo Re 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Prvni Kr 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("První Kr 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Una Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("מלכים א' 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("מלכים א’ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("۱ سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("۱۔سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Regum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Цареи 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Царей 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 இராஜா 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kong 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kral 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Král 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Raja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. राजा 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1a Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1e. Kon 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1o Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. Ks 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. Царе 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("First K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Cariv 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Regum 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Reyes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I царів 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kral 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Král 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Regum I 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("מלכים א 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Bren 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kong 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kral 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Krol 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Král 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Król 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kung 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Raja 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Rees 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Reye 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Reys 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ryes 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 raǳe 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 rāǳe 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 राजा 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 राजे 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Boq 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Fal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Imp 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kir 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kon 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kön 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Reg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Vua 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Împ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. พกษ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1e Kon 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1e. Ko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st Ks 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st. K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1°. Re 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Царе 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Hari 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kigs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I King 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kins 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kral 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Král 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Regi 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Reis 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Rois 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Boq 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Fal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Imp 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kir 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kon 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Reg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Vua 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Împ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α' Βασ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ Βασ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ Βασ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α΄ Βασ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α’ Βασ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《列王紀上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《列王纪上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《列王记上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王記第三巻 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("열왕기 상권 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Boq 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Fal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Imp 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kir 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kon 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Krl 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Krľ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kun 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kön 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ree 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Reg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Res 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Rey 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Rye 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Rys 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Vua 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Împ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 இரா 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 พกษ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Ko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Kr 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Wa 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1e Ko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1st K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1° Re 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Цар 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Boq 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Fal 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Imp 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kig 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kir 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kng 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kns 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kon 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Reg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Vua 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Împ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Kr 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Re 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Wa 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kings 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α' Βα 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ Βα 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ Βα 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α΄ Βα 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α’ Βα 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《列王紀上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《列王纪上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《列王记上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王紀上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王紀略上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王纪上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王记上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("열왕기 상 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ha 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Kr 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Mb 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Rs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ry 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Wa 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 مل 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 அர 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kg 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ki 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kn 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ko 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Kr 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Re 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Wa 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kngs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《王上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王 1 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王紀上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王纪上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王記上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王记上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("열왕기상 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 R 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1열왕 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ц 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kgs 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Kin 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《王上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("王上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("王上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("왕상 1:1").osis()).toEqual("1Kgs.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ENSIMMAINEN KUNINKAIDEN KIRJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ENSIMMÄINEN KUNINKAIDEN KIRJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("KITABU CHA KWANZA CHA WAFALME 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("இராஜாக்களின் முதலாம் புத்தகம் 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("राजाओ का विर्तान्त 1ला भाग् 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("राजाओ का विर्तान्त १ला भाग् 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIĘGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIĘGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIĘGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIĘGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIĘGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIĘGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("CARTEA A TREIA A REGILOR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVA KNJIGA O KRALJEVIMA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TREDJE KONGERIGERNES BOG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECIA KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECIA KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECIA KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECIA KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECIA KSIĘGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECIA KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECIA KSIĘGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECIA KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ENSIMMAINEN KUNINKAIDEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ENSIMMÄINEN KUNINKAIDEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECI KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECI KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECI KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECI KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECI KSIĘGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECI KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECI KSIĘGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECI KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KS. KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIEGA KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIEGA KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIEGA KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIEGA KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIEGI KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIEGI KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIEGI KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIEGI KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIĘGA KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIĘGA KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIĘGA KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIĘGA KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIĘGI KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIĘGI KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIĘGI KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KSIĘGI KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KS. KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIEGA KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIEGA KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIEGA KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIEGA KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIEGI KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIEGI KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIEGI KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIEGI KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIĘGA KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIĘGA KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIĘGA KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIĘGA KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIĘGI KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIĘGI KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIĘGI KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KSIĘGI KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KS. KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIEGA KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIEGA KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIEGA KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIEGA KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIEGI KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIEGI KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIEGI KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIEGI KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIĘGA KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIĘGA KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIĘGA KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIĘGA KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIĘGI KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIĘGI KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIĘGI KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KSIĘGI KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("RĀJIĀṂ DĪ PAHILĪ POTʰĪ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ПРВА КНИГА ЗА ЦАРЕВИТЕ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ПРВО КНИГА ЗА ЦАРЕВИТЕ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KSIĘGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KSIĘGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KS KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KS KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KS KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNI KNIHA KRALOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNI KNIHA KRALOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNI KNIHA KRÁLOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNI KNIHA KRÁLOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNÍ KNIHA KRALOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNÍ KNIHA KRALOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNÍ KNIHA KRÁLOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNÍ KNIHA KRÁLOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECIA KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECIA KS. KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ТРЕТА КНИГА НА ЦАРЕТЕ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ТРЕТО КНИГА НА ЦАРЕТЕ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ରାଜାବଳୀର ପ୍ରଥମ ପୁସ୍ତକ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KUNINKAIDEN KIRJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. КНИГА ЗА ЦАРЕВИТЕ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KONGERIGERNES BOG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("CARTEA III A REGILOR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FYRRI BOK KONUNGANNA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FYRRI BÓK KONUNGANNA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KUNINKAIDEN KIRJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. КНИГА ЗА ЦАРЕВИТЕ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KSIĘGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KSIĘGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. КНИГА НА ЦАРЕТЕ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECI KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECI KS. KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECIA KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECIA KS KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("राजाहरूक पहिल पुस्तक 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ਰਾਜਿਆਂ ਦੀ ਪਹਿਲੀ ਪੋਥੀ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KUNINKAIDEN KIRJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 КНИГА ЗА ЦАРЕВИТЕ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIĘGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIĘGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KONGERIGERNES BOG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KSIĘGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KSIĘGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FORSTA KONUNGABOKEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FÖRSTA KONUNGABOKEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KUNINKAIDEN KIRJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I КНИГА ЗА ЦАРЕВИТЕ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIĘGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIĘGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III КНИГА НА ЦАРЕТЕ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KS. KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KS. KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KS. KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KS. KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KS. KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KS. KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KS. KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KS. KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KS. KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KS. KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KS. KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KS. KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRETIA KNIHA KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRETIA KNIHA KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRETIA KNIHA KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRETIA KNIHA KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECI KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRZECI KS KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΒΑΣΙΛΈΩΝ Α' 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΒΑΣΙΛΈΩΝ Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΒΑΣΙΛΈΩΝ Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΒΑΣΙΛΈΩΝ Α΄ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΒΑΣΙΛΈΩΝ Α’ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΒΑΣΙΛΕΩΝ Α' 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΒΑΣΙΛΕΩΝ Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΒΑΣΙΛΕΩΝ Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΒΑΣΙΛΕΩΝ Α΄ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΒΑΣΙΛΕΩΝ Α’ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΒΑΣΙΛΈΩΝ Α' 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΒΑΣΙΛΈΩΝ Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΒΑΣΙΛΈΩΝ Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΒΑΣΙΛΈΩΝ Α΄ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΒΑΣΙΛΈΩΝ Α’ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΒΑΣΙΛΕΩΝ Α' 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΒΑΣΙΛΕΩΝ Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΒΑΣΙΛΕΩΝ Αʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΒΑΣΙΛΕΩΝ Α΄ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΒΑΣΙΛΕΩΝ Α’ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ТРЕТА КНИГА ЦАРСТВА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIĘGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIĘGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KNIHA KRALOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KNIHA KRALOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KNIHA KRÁLOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KNIHA KRÁLOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KSIĘGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KSIĘGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. КНИГА НА ЦАРЕТЕ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIEGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIEGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIEGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIEGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIĘGA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIĘGA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIĘGI KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIĘGI KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KNIHA KRALOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KNIHA KRALOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KNIHA KRÁLOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KNIHA KRÁLOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KS. KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KS KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KS KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KS KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZA KS KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KS KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KS KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KS KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZE KS KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KS KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KS KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KS KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PIERWSZY KS KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KNIHA KRALOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KNIHA KRALOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KNIHA KRÁLOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KNIHA KRÁLOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-ШЕ. КНИГА ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 КНИГА НА ЦАРЕТЕ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-Е. КНИГА ЦАРСТВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-Я. КНИГА ЦАРСТВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("BOQORRADII KOWAAD 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FORSTA KUNGABOKEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FÖRSTA KUNGABOKEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KNIHA KRALOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KNIHA KRALOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KNIHA KRÁLOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KNIHA KRÁLOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KS. KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KS KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("IKATLONG MGA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVA KNIHA KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVA KNIHA KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVA KNIHA KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVA KNIHA KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVÁ KNIHA KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVÁ KNIHA KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVÁ KNIHA KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVÁ KNIHA KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("RAǱAHARUKO PUSTAK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("RAǱAHARŪKO PUSTAK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("RAǱĀHARUKO PUSTAK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("RAǱĀHARŪKO PUSTAK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("RĀǱAHARUKO PUSTAK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("RĀǱAHARŪKO PUSTAK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("RĀǱĀHARUKO PUSTAK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("RĀǱĀHARŪKO PUSTAK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ПЕРША КНИГА ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ПЕРШЕ КНИГА ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ТРЕЋОМ КРАЉЕВСТВА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-А. КНИГА ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-Е. КНИГА ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-ШЕ КНИГА ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KS. KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIEGA KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIEGA KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIEGA KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIEGA KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIEGI KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIEGI KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIEGI KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIEGI KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIĘGA KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIĘGA KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIĘGA KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIĘGA KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIĘGI KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIĘGI KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIĘGI KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KSIĘGI KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-Е КНИГА ЦАРСТВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-Я КНИГА ЦАРСТВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KS. KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3Е. КНИГА ЦАРСТВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3Я. КНИГА ЦАРСТВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FYRRI KONUNGABOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FYRRI KONUNGABÓK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FYRRI KONUNGABÓK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KS. KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIEGA KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIEGA KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIEGA KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIEGA KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIEGI KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIEGI KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIEGI KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIEGI KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIĘGA KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIĘGA KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIĘGA KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIĘGA KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIĘGI KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIĘGI KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIĘGI KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KSIĘGI KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KS KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PREMYE LIV WA YO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVY LIST KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVY LIST KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVY LIST KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVY LIST KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVÝ LIST KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVÝ LIST KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVÝ LIST KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVÝ LIST KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ТРЕЋА КРАЉЕВСТВА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ТРЕЋОМ КРАЉЕВИМА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("سفر الملوك الأول 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KS. KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIEGA KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIEGA KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIEGA KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIEGA KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIEGI KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIEGI KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIEGI KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIEGI KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIĘGA KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIĘGA KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIĘGA KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIĘGA KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIĘGI KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIĘGI KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIĘGI KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KSIĘGI KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-А КНИГА ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-Е КНИГА ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KONUNGABOKEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KS KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. พงศ์กษัตริย์ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KS. KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KS KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. КНИГА ЦАРСТВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3Е КНИГА ЦАРСТВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3Я КНИГА ЦАРСТВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("EERSTE KONINGEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FØRSTE KONGEBOG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FØRSTE KONGEBOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KS. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KS. KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIEGA KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIEGA KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIEGA KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIEGA KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIEGI KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIEGI KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIEGI KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIEGI KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIĘGA KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIĘGA KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIĘGA KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIĘGA KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIĘGI KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIĘGI KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIĘGI KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KSIĘGI KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I A IMPARATILOR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I A IMPARAŢILOR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I A IMPĂRATILOR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I A IMPĂRAŢILOR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I A ÎMPARATILOR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I A ÎMPARAŢILOR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I A ÎMPĂRATILOR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I A ÎMPĂRAŢILOR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KS KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. КРАЉЕВСТВА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVA KRALJEVIMA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNI KRALOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNI KRALOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNI KRÁLOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNI KRÁLOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNÍ KRALOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNÍ KRALOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNÍ KRÁLOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNÍ KRÁLOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TERCEIRA REINOS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TERCEIRO REINOS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ПРВА О ЦАРЕВИМА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ТРЕЋА КРАЉЕВИМА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KONUNGABOKEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KS KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 E. MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 E. MBRETËRVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 I. MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 I. MBRETËRVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 พงศ์กษัตริย์ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. BRENHINOEDD 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KUNINKAIDEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. КНИГА ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KS KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 E. MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 E. MBRETËRVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 I. MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 I. MBRETËRVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 КНИГА ЦАРСТВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KS KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KS KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. BRENHINOEDD 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KUNINKAIDEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. КНИГА ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III КРАЉЕВСТВА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. КРАЉЕВИМА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("KWANZA WAFALME 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PREMIERES ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PREMIÈRES ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("THIRD KINGDOMS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("UNANG MGA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("الممالك الثالث 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ପ୍ରଥମ ରାଜାବଳୀର 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 BRENHINOEDD 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KUNINKAIDEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 E MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 E MBRETËRVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 I MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 I MBRETËRVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 КНИГА ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. BOQORRADII 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. BRENINOEDD 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KRALJEVIMA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KS. KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KS. KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KS. KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KS. KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KUNGABOKEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. RAǱAHARUKO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. RAǱAHARŪKO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. RAǱĀHARUKO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. RAǱĀHARŪKO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. RĀǱAHARUKO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. RĀǱAHARŪKO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. RĀǱĀHARUKO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. RĀǱĀHARŪKO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. О ЦАРЕВИМА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 E MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 E MBRETËRVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 I MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 I MBRETËRVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. КРАЉЕВСТВА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3RD. KINGDOMS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ELSO KIRALYOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ELSO KIRÁLYOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ELSŐ KIRALYOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ELSŐ KIRÁLYOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ERSTE KOENIGE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I BRENHINOEDD 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KUNINKAIDEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I КНИГА ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. BOQORRADII 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. BRENINOEDD 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KRALJEVIMA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KS. KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KS. KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KS. KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KS. KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. О ЦАРЕВИМА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III КРАЉЕВИМА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KINGDOMS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. MGA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. REGNORUM 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("LIBER I REGUM 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PREMIERE ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PREMIERS ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PREMIÈRE ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRIMEIRA REIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRIMEIRO REIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRIMERO REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRETIA KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRETIA KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRETIA KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRETIA KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ТРЕТО ЦАРСТВА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ପ୍ରଥମ ରାଜାବଳୀ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 BOQORRADII 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 BRENINOEDD 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KRALJEVIMA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KS. KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KS. KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KS. KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KS. KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KUNGABOKEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RAǱAHARUKO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RAǱAHARŪKO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RAǱĀHARUKO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RAǱĀHARŪKO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RĀǱAHARUKO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RĀǱAHARŪKO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RĀǱĀHARUKO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RĀǱĀHARŪKO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 О ЦАРЕВИМА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 இராஜாக்கள் 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KRALOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KRALOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KRÁLOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KRÁLOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KS KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KS KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KS KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KS KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. MBRETËRVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. PARA RAJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. राजाहरूको 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1E. KONINGEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 КРАЉЕВСТВА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. MBRETËRVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. КРАЉЕВИМА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3RD KINGDOMS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ERSTE KONIGE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ERSTE KÖNIGE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I BOQORRADII 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I BRENINOEDD 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KRALJEVIMA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KS. KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KS. KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KS. KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KS. KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I О ЦАРЕВИМА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KRALOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KRALOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KRÁLOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KRÁLOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KS KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KS KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KS KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KS KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. PARA RAJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KINGDOMS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III MGA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III REGNORUM 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. ЦАРСТВА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PREMIER ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRIMER REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRETI KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRETI KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRETI KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRETI KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRETÍ KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRETÍ KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRETÍ KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("TRETÍ KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("UNA MGA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΩΝ Γ' 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΩΝ Γʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΩΝ Γʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΩΝ Γ΄ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΩΝ Γ’ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΏΝ Γ' 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΏΝ Γʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΏΝ Γʹ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΏΝ Γ΄ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΏΝ Γ’ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ПРВА КРАЉЕВА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("الملوك الأول 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("اوّل-سلاطِین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 IRAJAKKAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 IRAJAKKAḶ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 IRAJĀKKAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 IRAJĀKKAḶ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 IRĀJAKKAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 IRĀJAKKAḶ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 IRĀJĀKKAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 IRĀJĀKKAḶ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KRALOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KRALOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KRÁLOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KRÁLOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KS KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KS KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KS KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KS KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 MBRETËRVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 PARA RAJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 K. KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 K. KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 K. KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 K. KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 राजाहरूको 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-ШЕ. CARIV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-ШЕ. ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. IMPARATI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. IMPARAŢI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. IMPĂRATI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. IMPĂRAŢI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KIRALYOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KIRÁLYOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KONGEBOG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KONGEBOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KONINGEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. MGA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. ÎMPARATI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. ÎMPARAŢI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. ÎMPĂRATI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. ÎMPĂRAŢI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. ରାଜାବଳୀର 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1E KONINGEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 MBRETERVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 MBRETËRVE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 K. KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 K. KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 K. KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 K. KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 КРАЉЕВИМА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-Е. ЦАРСТВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-ТЄ. ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-Я. ЦАРСТВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KINGDOMS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. MGA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. REGNORUM 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FØRSTE KONG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KRALOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KRALOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KROLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KRÁLOVSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KRÁLOVSKÁ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KRÓLEWSKA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KS KROLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KS KROLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KS KRÓLOW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KS KRÓLÓW 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I PARA RAJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. IMPARATI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. IMPARAŢI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. IMPĂRATI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. IMPĂRAŢI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KIRALYOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KIRÁLYOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KONINGEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. MGA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. ÎMPARATI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. ÎMPARAŢI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. ÎMPĂRATI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. ÎMPĂRAŢI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III ЦАРСТВА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. REINOS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVA KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVA KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVA KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVA KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVY KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVY KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVY KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVY KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVÁ KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVÁ KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVÁ KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVÁ KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVÝ KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVÝ KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVÝ KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVÝ KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α' ΒΑΣΙΛΈΩΝ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α' ΒΑΣΙΛΕΩΝ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ ΒΑΣΙΛΈΩΝ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ ΒΑΣΙΛΕΩΝ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ ΒΑΣΙΛΈΩΝ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ ΒΑΣΙΛΕΩΝ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α΄ ΒΑΣΙΛΈΩΝ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α΄ ΒΑΣΙΛΕΩΝ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α’ ΒΑΣΙΛΈΩΝ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α’ ΒΑΣΙΛΕΩΝ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ПЕРША CARIV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ПЕРША ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ПЕРШЕ CARIV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ПЕРШЕ ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ПРВА ЦАРЕВА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ПРВА ЦАРЕВИ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ПРВО ЦАРЕВИ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ТРЕТЯ ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ТРЕТЄ ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("اوّل سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("اوّل۔سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 IMPARATI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 IMPARAŢI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 IMPĂRATI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 IMPĂRAŢI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KIRALYOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KIRÁLYOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KONGEBOG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KONGEBOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KONINGEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 MGA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 K KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 K KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 K KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 K KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 ÎMPARATI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 ÎMPARAŢI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 ÎMPĂRATI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 ÎMPĂRAŢI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 ରାଜାବଳୀର 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 அரசர்கள் 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-А. CARIV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-А. ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-Е. CARIV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-Е. ЦАРЕИ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-Е. ЦАРЕЙ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-Е. ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-ШЕ CARIV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-ШЕ ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-Я. ЦАРЕИ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-Я. ЦАРЕЙ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. CÁC VUA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KOENIGE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. WAFALME 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. КРАЉЕВА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. ରାଜାବଳୀ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1.-سلاطِین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1.O. REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1.º. REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ERE. ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ÈRE. ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KINGDOMS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 MGA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 REGNORUM 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 K KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 K KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 K KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 K KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-А. ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-Е ЦАРСТВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-Е. ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-ТЄ ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-Я ЦАРСТВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. ЦАРСТВА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3A. REINOS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3O. REINOS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3Е. ЦАРСТВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3Я. ЦАРСТВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("EERSTE KON 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KIGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KING 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KINS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I IMPARATI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I IMPARAŢI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I IMPĂRATI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I IMPĂRAŢI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KIRALYOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KIRÁLYOK 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KONINGEN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I MGA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I ÎMPARATI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I ÎMPARAŢI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I ÎMPĂRATI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I ÎMPĂRAŢI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. CÁC VUA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. WAFALME 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. КРАЉЕВА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III REINOS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("KIRALYOK I 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("KIRÁLYOK I 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("KWANZA FAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNI KRAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNI KRÁL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNÍ KRAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNÍ KRÁL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("UNANG HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ТРЕТО ЦАРЕ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("पहिले राजे 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ﺍﻟﻤﻠﻮﻙ ﺍﻷﻭ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 CÁC VUA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KOENIGE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 WAFALME 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 SALĀṬĪN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 КРАЉЕВА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 ରାଜାବଳୀ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-А CARIV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-А ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-Е CARIV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-Е ЦАРЕИ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-Е ЦАРЕЙ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-Е ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-Я ЦАРЕИ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-Я ЦАРЕЙ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1-سلاطِین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KONIGE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KÖNIGE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. ЦАРЕВА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. ЦАРЕВИ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. राजाओं 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1.O REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1.º REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1.۔سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ER. ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ERE ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1O. REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1RE. ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KIGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KING 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KINS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1º. REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ÈRE ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1Е. ЦАРЕИ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1Е. ЦАРЕЙ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1Я. ЦАРЕИ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1Я. ЦАРЕЙ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 ЦАРСТВА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 அரசுகள் 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-А ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3-Е ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. REINOS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. ЦАРСТВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3A REINOS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3O REINOS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3Е ЦАРСТВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3Я ЦАРСТВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("EERSTE KO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KIG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KIN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KNS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I CÁC VUA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I WAFALME 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I КРАЉЕВА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. ЦАРЕВА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. ЦАРЕВИ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. REGI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III. ЦАРЕ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PREMYE WA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("WAFALME I 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("۱-سلاطِین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KONIGE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KÖNIGE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RĀJIĀṂ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 ЦАРЕВА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 ЦАРЕВИ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 الملوك 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 राजाओं 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 ਰਾਜਿਆਂ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. CARIV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. REGUM 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. ЦАРЕИ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. ЦАРЕЙ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1A. REIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ER ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1O REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1O. REIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1RE ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KIGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KING 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KINS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KIG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KIN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KNS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1º REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1Е ЦАРЕИ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1Е ЦАРЕЙ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1Я ЦАРЕИ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1Я ЦАРЕЙ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1۔سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 REINOS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 ЦАРСТВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ELSO KIR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("ELSŐ KIR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST KS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KRALOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KRAĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KRÁLOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KRÁĽOV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I ЦАРЕВА 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I ЦАРЕВИ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. CARIV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. REGUM 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III REGI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("III ЦАРЕ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRIMA RE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRIMO RE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNI KR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("PRVNÍ KR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("UNA HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("מלכים א' 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("מלכים א’ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("۱ سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("۱۔سلاطین 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 CARIV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 REGUM 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 ЦАРЕИ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 ЦАРЕЙ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 இராஜா 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KIGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KING 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KINS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KONG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KRAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KRÁL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. RAJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. REGI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. REIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. राजा 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1A REIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1E. KON 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1O REIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KIG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KIN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KNS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. KS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. REGI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3. ЦАРЕ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("FIRST K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I CARIV 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I REGUM 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I REYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I ЦАРІВ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KIGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KING 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KINS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KRAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KRÁL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. REGI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. REIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("REGUM I 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("מלכים א 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 BREN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KIGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KING 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KINS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KONG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KRAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KROL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KRÁL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KRÓL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KUNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RAJA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 REES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 REGI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 REIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 REYE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 REYS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RYES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RAǱE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RĀǱE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 राजा 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 राजे 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. BOQ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. FAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. IMP 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KIG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KIN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KIR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KNS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KON 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KÖN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. REG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. VUA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. ÎMP 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. พกษ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1E KON 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1E. KO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST KS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST. K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1°. RE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 REGI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 ЦАРЕ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I HARI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KIGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KING 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KINS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KRAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KRÁL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I REGI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I REIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I ROIS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. BOQ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. FAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. IMP 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KIG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KIN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KIR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KNS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KON 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. REG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. VUA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. ÎMP 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α' ΒΑΣ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ ΒΑΣ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ ΒΑΣ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α΄ ΒΑΣ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α’ ΒΑΣ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《列王紀上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《列王纪上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《列王记上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王記第三巻 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("열왕기 상권 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 BOQ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 FAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 IMP 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KIG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KIN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KIR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KNS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KON 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KRL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KRĽ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KUN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KÖN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 REE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 REG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RES 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 REY 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RYE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RYS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 VUA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 ÎMP 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 இரா 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 พกษ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. KR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. WA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1E KO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1ST K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1° RE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 ЦАР 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I BOQ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I FAL 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I IMP 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KIG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KIN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KIR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KNG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KNS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KON 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I REG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I VUA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I ÎMP 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. RE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. WA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("KINGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α' ΒΑ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ ΒΑ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Αʹ ΒΑ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α΄ ΒΑ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("Α’ ΒΑ 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《列王紀上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《列王纪上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《列王记上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王紀上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王紀略上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王纪上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王记上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("열왕기 상 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 HA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 MB 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RY 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 WA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 مل 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 அர 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KG 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KI 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KO 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KR 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I RE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I WA 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("KNGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《王上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王 1 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王紀上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王纪上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王記上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列王记上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("열왕기상 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 R 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1열왕 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("3 Ц 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I K 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("KGS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("KIN 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("《王上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("王上》 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("列上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("王上 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("왕상 1:1").osis()).toEqual("1Kgs.1.1")
		`
		true
describe "Localized book EpJer (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: EpJer (full)", ->
		`
		expect(p.parse("அவை இளைஞர் மூவரின் பாடல் 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("The Epistle of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Pismo Jeremije proroka 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("The Letter of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ang Liham ni Jeremias 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Epistola lui Ieremia 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("La Carta de Jeremias 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("La Carta de Jeremías 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("The Let. of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Посланица Јеремијина 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Epistle of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("The Ep. of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("The Let of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Послание на Иеремия 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Letter of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Lettera di Geremia 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("The Ep of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("எரேமியாவின் கடிதம் 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Brief des Jeremia 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Brief van Jeremia 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Carta de Jeremias 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Carta de Jeremías 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Epistle of Jeremy 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Epitre de Jeremie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Epitre de Jerémie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Epitre de Jéremie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Epitre de Jérémie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Epître de Jeremie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Epître de Jerémie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Epître de Jéremie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Epître de Jérémie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Liham ni Jeremias 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Épitre de Jeremie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Épitre de Jerémie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Épitre de Jéremie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Épitre de Jérémie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Épître de Jeremie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Épître de Jerémie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Épître de Jéremie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Épître de Jérémie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Επιστολή Ιερεμίου 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Επιστολή Ιερεμιου 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Επιστολη Ιερεμίου 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Επιστολη Ιερεμιου 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Barua ya Yeremia 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Jeremijino pismo 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Let. of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Llythyr Jeremeia 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Послание Иеремии 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("எரேமியாவின் மடல் 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep. of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Jeremias levele 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Jeremiasov list 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Jeremiašov list 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Jeremiás levele 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Jeremiásov list 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Jeremiášov list 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Let of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("List Jeremiasza 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("List Jeremjasuv 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("List Jeremjasův 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("List Jeremjašuv 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("List Jeremjašův 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("List Jeremjásuv 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("List Jeremjásův 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("List Jeremjášuv 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("List Jeremjášův 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Oratio Ieremiae 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Послання Єреміі 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Послання Єремії 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Carta Jeremias 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Carta Jeremías 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep of Jeremiah 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Jeremian kirje 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Jeremias' Brev 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Jeremias’ Brev 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Писма Јеремије 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Jeremias brev 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Επιστολη ᾿Ιερ 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Επιστολὴ ᾿Ιερ 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Bref Jeremia 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Bref Jeremía 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Bréf Jeremia 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Bréf Jeremía 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("איגרת ירמיהו 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep. Jeremie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep. Jerémie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep. Jéremie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep. Jérémie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ép. Jeremie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ép. Jerémie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ép. Jéremie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ép. Jérémie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Лист Єреміі 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Лист Єремії 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("رسالة إرميا 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep Jeremie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep Jerémie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep Jéremie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep Jérémie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ép Jeremie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ép Jerémie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ép Jéremie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ép Jérémie 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Cart. Jer 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Carta Jer 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Cart Jer 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("イエレミヤの達書 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("예레미야의 편지 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep. Jer 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep. Jér 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Let-ger 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Lih Jer 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Or. Ier 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ép. Jer 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ép. Jér 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("《EpJer》 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("エレミヤの手紙 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("エレミヤの書翰 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Br Jer 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep Jer 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ep Jér 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("EpJer》 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Jer br 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Or Ier 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ép Jer 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Ép Jér 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("《EpJer 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("エレミヤ・手 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("EpJer 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("Jerbr 1:1").osis()).toEqual("EpJer.1.1")
		expect(p.parse("BJer 1:1").osis()).toEqual("EpJer.1.1")
		`
		true
describe "Localized book Lam (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Lam (full)", ->
		`
		expect(p.parse("Chante pou plenn So lavil Jerizalem 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Chante pou plenn So lavil Jerizalèm 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Chante pou plenn Sò lavil Jerizalem 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Chante pou plenn Sò lavil Jerizalèm 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plangerile profetului Ieremia 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plângerile profetului Ieremia 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Baroorashadii Yeremyaah 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentacoes de Jeremias 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentacôes de Jeremias 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentacões de Jeremias 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentations de Jeremie 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentations de Jerémie 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentations de Jéremie 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentations de Jérémie 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentaçoes de Jeremias 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentaçôes de Jeremias 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentações de Jeremias 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plangerile lui Ieremia 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plângerile lui Ieremia 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentacje Jeremiasza 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Maombolezo ya Yeremia 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Klagelieder Jeremias 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("எரேமியாவின் புலம்பல் 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Aklat ng Pananaghoy 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Jeremijine tuzaljke 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Jeremijine tužaljke 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Книга Плач Иеремиев 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Aklat ng Pagtaghoy 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Galarnad Jeremiah 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Jeremias siralmai 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Jeremiás siralmai 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Ksiega Lamentacji 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Ksiegi Lamentacji 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Księga Lamentacji 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Księgi Lamentacji 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Плачот на Еремија 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Плачът на Иеремия 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Плачът на Йеремия 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Kidung Pangadhuh 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Treny Jeremiasza 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Плачът на Еремия 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ଯିରିମିୟଙ୍କ ବିଳାପ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Jeremiasov Plac 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Jeremiasov Plač 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Jeremiašov Plac 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Jeremiašov Plač 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Jeremiásov Plac 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Jeremiásov Plač 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Jeremiášov Plac 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Jeremiášov Plač 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Kidung Pasambat 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Mga Lamentasyon 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Mga Pagbangotan 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremiasov 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremiasuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremiasův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremiašov 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremiašuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremiašův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremiásov 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremiásuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremiásův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremiášov 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremiášuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremiášův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremjasuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremjasův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremjašuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremjašův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremjásuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremjásův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremjášuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremjášův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač Jeremiasov 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač Jeremiasuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač Jeremiasův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač Jeremiašov 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač Jeremiašuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač Jeremiašův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač Jeremiásov 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač Jeremiásuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač Jeremiásův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač Jeremiášov 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač Jeremiášuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač Jeremiášův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač Jeremjasuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač Jeremjasův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač Jeremjašuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač Jeremjašův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač Jeremjásuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač Jeremjásův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač Jeremjášuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač Jeremjášův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plác Jeremiasuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plác Jeremiasův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plác Jeremiašuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plác Jeremiašův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plác Jeremiásuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plác Jeremiásův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plác Jeremiášuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plác Jeremiášův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plác Jeremjasuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plác Jeremjasův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plác Jeremjašuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plác Jeremjašův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plác Jeremjásuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plác Jeremjásův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plác Jeremjášuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plác Jeremjášův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pláč Jeremiasuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pláč Jeremiasův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pláč Jeremiašuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pláč Jeremiašův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pláč Jeremiásuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pláč Jeremiásův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pláč Jeremiášuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pláč Jeremiášův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pláč Jeremjasuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pláč Jeremjasův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pláč Jeremjašuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pláč Jeremjašův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pláč Jeremjásuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pláč Jeremjásův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pláč Jeremjášuv 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pláč Jeremjášův 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("yarmiyako vilap 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("yarmiyako vilāp 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("yarmiyāko vilap 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("yarmiyāko vilāp 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Θρήνοι Ιερεμίου 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Θρήνοι Ιερεμιου 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Θρηνοι Ιερεμίου 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Θρηνοι Ιερεμιου 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Плач на Еремиин 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("سفر مراثي إرميا 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("यर्मियाको विलाप 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Ks. Lamentacji 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Плач Јеремијин 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("บทเพลงคร่ำครวญ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Baroorashadii 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Klaagliederen 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Kniha narekov 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Kniha nárekov 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Ks Lamentacji 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentaciones 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentationes 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamintaciones 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Valitusvirret 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Плач Иеремиев 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Jeremias sir 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Jeremiás sir 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Klagesangene 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Klagovisorna 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentacione 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentations 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentazioni 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamintacione 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamintations 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Mga Panaghoy 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremii 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac Jeremiï 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač Jeremii 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač Jeremiï 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Плач Еремиев 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Плач Еремиин 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Плач Иеремии 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("เพลงคร่ำครวญ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Klagelieder 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Kniha narku 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Kniha narků 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Kniha nařku 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Kniha nařků 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Kniha nárku 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Kniha nárků 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Kniha nářku 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Kniha nářků 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamantasyon 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentacije 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentacoes 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentacões 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentation 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentaçoes 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentações 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamintation 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pagbangotan 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Плач Єреміі 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Плач Єремії 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("مراثي إرميا 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Harmljoðin 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Harmljóðin 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("K. narekov 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("K. nárekov 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lamentacje 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Maombolezo 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Vilapageet 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Ca thương 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("K narekov 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("K nárekov 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Zalospevy 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Žalospevy 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Galarnad 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Panaghoy 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plangeri 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plângeri 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pulampal 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Siralmak 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Tuzaljke 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Tužaljke 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Vajtimet 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("wilapgit 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("wilapgīt 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("wilāpgit 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("wilāpgīt 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("विलापगीत 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("विलापगेत 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("புலம்பல் 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("المراثي 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("《耶利米哀歌》 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("エレミヤの哀歌 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("예레미야 애가 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Baroor 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Klaagl 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Klages 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Nareky 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Náreky 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Siralm 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Zalosp 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("virlāp 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Žalosp 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Θρήνοι 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Θρηνοι 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("П. Иер 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("П. Йер 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ਵਿਰਲਾਪ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("《耶利米哀歌 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("《連同哀歌》 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("耶利米哀歌》 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("예레미아애가 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("예레미야애가 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Ai Ca 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Galar 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Panag 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plang 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plenn 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plâng 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Siral 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Treny 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Valit 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("П Иер 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("П Йер 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("קינות 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("نَوحہ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("विलाप 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("புலம் 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("《連同哀歌 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("耶利米哀歌 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("連同哀歌》 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Klag 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Klgl 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plac 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plač 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Plác 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pláč 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("nūḥâ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Плач 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("איכה 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("نوحہ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("連同哀歌 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Hlj 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lam 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Mao 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Nar 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Nár 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Omb 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Tuz 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Tuž 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Vaj 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("مرا 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("புல 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("พคค 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("《哀》 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Kl 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Lm 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Pl 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Tr 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("Θρ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("《哀 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("哀》 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("哀歌 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("애가 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("哀 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("애 1:1").osis()).toEqual("Lam.1.1")
		p.include_apocrypha(false)
		expect(p.parse("CHANTE POU PLENN SO LAVIL JERIZALEM 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("CHANTE POU PLENN SO LAVIL JERIZALÈM 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("CHANTE POU PLENN SÒ LAVIL JERIZALEM 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("CHANTE POU PLENN SÒ LAVIL JERIZALÈM 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLANGERILE PROFETULUI IEREMIA 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÂNGERILE PROFETULUI IEREMIA 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("BAROORASHADII YEREMYAAH 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTACOES DE JEREMIAS 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTACÔES DE JEREMIAS 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTACÕES DE JEREMIAS 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTATIONS DE JEREMIE 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTATIONS DE JERÉMIE 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTATIONS DE JÉREMIE 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTATIONS DE JÉRÉMIE 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTAÇOES DE JEREMIAS 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTAÇÔES DE JEREMIAS 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTAÇÕES DE JEREMIAS 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLANGERILE LUI IEREMIA 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÂNGERILE LUI IEREMIA 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTACJE JEREMIASZA 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("MAOMBOLEZO YA YEREMIA 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KLAGELIEDER JEREMIAS 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("எரேமியாவின் புலம்பல் 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("AKLAT NG PANANAGHOY 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("JEREMIJINE TUZALJKE 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("JEREMIJINE TUŽALJKE 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("КНИГА ПЛАЧ ИЕРЕМИЕВ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("AKLAT NG PAGTAGHOY 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("GALARNAD JEREMIAH 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("JEREMIAS SIRALMAI 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("JEREMIÁS SIRALMAI 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KSIEGA LAMENTACJI 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KSIEGI LAMENTACJI 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KSIĘGA LAMENTACJI 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KSIĘGI LAMENTACJI 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ПЛАЧОТ НА ЕРЕМИЈА 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ПЛАЧЪТ НА ИЕРЕМИЯ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ПЛАЧЪТ НА ЙЕРЕМИЯ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KIDUNG PANGADHUH 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("TRENY JEREMIASZA 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ПЛАЧЪТ НА ЕРЕМИЯ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ଯିରିମିୟଙ୍କ ବିଳାପ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("JEREMIASOV PLAC 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("JEREMIASOV PLAČ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("JEREMIAŠOV PLAC 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("JEREMIAŠOV PLAČ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("JEREMIÁSOV PLAC 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("JEREMIÁSOV PLAČ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("JEREMIÁŠOV PLAC 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("JEREMIÁŠOV PLAČ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KIDUNG PASAMBAT 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("MGA LAMENTASYON 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("MGA PAGBANGOTAN 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMIASOV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMIASUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMIASŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMIAŠOV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMIAŠUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMIAŠŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMIÁSOV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMIÁSUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMIÁSŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMIÁŠOV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMIÁŠUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMIÁŠŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMJASUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMJASŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMJAŠUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMJAŠŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMJÁSUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMJÁSŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMJÁŠUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMJÁŠŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ JEREMIASOV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ JEREMIASUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ JEREMIASŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ JEREMIAŠOV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ JEREMIAŠUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ JEREMIAŠŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ JEREMIÁSOV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ JEREMIÁSUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ JEREMIÁSŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ JEREMIÁŠOV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ JEREMIÁŠUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ JEREMIÁŠŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ JEREMJASUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ JEREMJASŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ JEREMJAŠUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ JEREMJAŠŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ JEREMJÁSUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ JEREMJÁSŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ JEREMJÁŠUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ JEREMJÁŠŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁC JEREMIASUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁC JEREMIASŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁC JEREMIAŠUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁC JEREMIAŠŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁC JEREMIÁSUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁC JEREMIÁSŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁC JEREMIÁŠUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁC JEREMIÁŠŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁC JEREMJASUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁC JEREMJASŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁC JEREMJAŠUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁC JEREMJAŠŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁC JEREMJÁSUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁC JEREMJÁSŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁC JEREMJÁŠUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁC JEREMJÁŠŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁČ JEREMIASUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁČ JEREMIASŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁČ JEREMIAŠUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁČ JEREMIAŠŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁČ JEREMIÁSUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁČ JEREMIÁSŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁČ JEREMIÁŠUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁČ JEREMIÁŠŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁČ JEREMJASUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁČ JEREMJASŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁČ JEREMJAŠUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁČ JEREMJAŠŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁČ JEREMJÁSUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁČ JEREMJÁSŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁČ JEREMJÁŠUV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁČ JEREMJÁŠŮV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("YARMIYAKO VILAP 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("YARMIYAKO VILĀP 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("YARMIYĀKO VILAP 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("YARMIYĀKO VILĀP 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ΘΡΉΝΟΙ ΙΕΡΕΜΊΟΥ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ΘΡΉΝΟΙ ΙΕΡΕΜΙΟΥ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ΘΡΗΝΟΙ ΙΕΡΕΜΊΟΥ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ΘΡΗΝΟΙ ΙΕΡΕΜΙΟΥ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ПЛАЧ НА ЕРЕМИИН 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("سفر مراثي إرميا 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("यर्मियाको विलाप 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KS. LAMENTACJI 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ПЛАЧ ЈЕРЕМИЈИН 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("บทเพลงคร่ำครวญ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("BAROORASHADII 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KLAAGLIEDEREN 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KNIHA NAREKOV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KNIHA NÁREKOV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KS LAMENTACJI 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTACIONES 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTATIONES 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMINTACIONES 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("VALITUSVIRRET 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ПЛАЧ ИЕРЕМИЕВ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("JEREMIAS SIR 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("JEREMIÁS SIR 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KLAGESANGENE 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KLAGOVISORNA 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTACIONE 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTATIONS 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTAZIONI 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMINTACIONE 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMINTATIONS 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("MGA PANAGHOY 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMII 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC JEREMIÏ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ JEREMII 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ JEREMIÏ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ПЛАЧ ЕРЕМИЕВ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ПЛАЧ ЕРЕМИИН 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ПЛАЧ ИЕРЕМИИ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("เพลงคร่ำครวญ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KLAGELIEDER 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KNIHA NARKU 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KNIHA NARKŮ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KNIHA NAŘKU 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KNIHA NAŘKŮ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KNIHA NÁRKU 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KNIHA NÁRKŮ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KNIHA NÁŘKU 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KNIHA NÁŘKŮ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMANTASYON 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTACIJE 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTACOES 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTACÕES 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTATION 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTAÇOES 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTAÇÕES 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMINTATION 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PAGBANGOTAN 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ПЛАЧ ЄРЕМІІ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ПЛАЧ ЄРЕМІЇ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("مراثي إرميا 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("HARMLJOÐIN 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("HARMLJÓÐIN 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("K. NAREKOV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("K. NÁREKOV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAMENTACJE 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("MAOMBOLEZO 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("VILAPAGEET 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("CA THƯƠNG 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("K NAREKOV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("K NÁREKOV 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ZALOSPEVY 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ŽALOSPEVY 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("GALARNAD 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PANAGHOY 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLANGERI 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÂNGERI 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PULAMPAL 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("SIRALMAK 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("TUZALJKE 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("TUŽALJKE 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("VAJTIMET 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("WILAPGIT 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("WILAPGĪT 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("WILĀPGIT 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("WILĀPGĪT 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("विलापगीत 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("विलापगेत 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("புலம்பல் 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("المراثي 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("《耶利米哀歌》 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("エレミヤの哀歌 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("예레미야 애가 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("BAROOR 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KLAAGL 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KLAGES 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("NAREKY 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("NÁREKY 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("SIRALM 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ZALOSP 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("VIRLĀP 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ŽALOSP 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ΘΡΉΝΟΙ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ΘΡΗΝΟΙ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("П. ИЕР 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("П. ЙЕР 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ਵਿਰਲਾਪ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("《耶利米哀歌 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("《連同哀歌》 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("耶利米哀歌》 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("예레미아애가 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("예레미야애가 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("AI CA 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("GALAR 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PANAG 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLANG 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLENN 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÂNG 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("SIRAL 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("TRENY 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("VALIT 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("П ИЕР 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("П ЙЕР 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("קינות 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("نَوحہ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("विलाप 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("புலம் 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("《連同哀歌 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("耶利米哀歌 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("連同哀歌》 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KLAG 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KLGL 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAC 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLAČ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁC 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PLÁČ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("NŪḤÂ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ПЛАЧ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("איכה 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("نوحہ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("連同哀歌 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("HLJ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LAM 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("MAO 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("NAR 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("NÁR 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("OMB 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("TUZ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("TUŽ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("VAJ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("مرا 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("புல 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("พคค 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("《哀》 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("KL 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("LM 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("PL 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("TR 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("ΘΡ 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("《哀 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("哀》 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("哀歌 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("애가 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("哀 1:1").osis()).toEqual("Lam.1.1")
		expect(p.parse("애 1:1").osis()).toEqual("Lam.1.1")
		`
		true
describe "Localized book Num (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Num (full)", ->
		`
		expect(p.parse("Czwarta Ksiega Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Czwarta Ksiega Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Czwarta Ksiegi Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Czwarta Ksiegi Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Czwarta Księga Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Czwarta Księga Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Czwarta Księgi Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Czwarta Księgi Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Kitabu cha Nne cha Musa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Четверта книга Моисеева 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Четверта книга Мойсеева 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Четвърта книга Моисеева 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrta kniha Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrta kniha Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrta kniha Mojzísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrta kniha Mojzíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrta kniha Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrta kniha Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrta kniha Mojžísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrta kniha Mojžíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrtá kniha Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrtá kniha Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrtá kniha Mojzísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrtá kniha Mojzíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrtá kniha Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrtá kniha Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrtá kniha Mojžísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrtá kniha Mojžíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Czwarta Ks. Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Czwarta Ks. Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Neljas Mooseksen kirja 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Neljäs Mooseksen kirja 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Stvrta kniha Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Stvrta kniha Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Stvrta kniha Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Stvrta kniha Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Stvrtá kniha Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Stvrtá kniha Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Stvrtá kniha Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Stvrtá kniha Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrta kniha Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrta kniha Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrta kniha Mojzísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrta kniha Mojzíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrta kniha Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrta kniha Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrta kniha Mojžísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrta kniha Mojžíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrtá kniha Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrtá kniha Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrtá kniha Mojzísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrtá kniha Mojzíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrtá kniha Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrtá kniha Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrtá kniha Mojžísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrtá kniha Mojžíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Štvrta kniha Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Štvrta kniha Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Štvrta kniha Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Štvrta kniha Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Štvrtá kniha Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Štvrtá kniha Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Štvrtá kniha Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Štvrtá kniha Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Четврта книга Мојсеева 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Czwarta Ks Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Czwarta Ks Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Ksiega Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Ksiega Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Ksiegi Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Ksiegi Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Księga Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Księga Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Księgi Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Księgi Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Ksiega Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Ksiega Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Ksiegi Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Ksiegi Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Księga Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Księga Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Księgi Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Księgi Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Ksiega Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Ksiega Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Ksiegi Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Ksiegi Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Księga Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Księga Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Księgi Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Księgi Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Ksiega Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Ksiega Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Ksiegi Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Ksiegi Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Księga Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Księga Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Księgi Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Księgi Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mooseksen kirja 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. kniha Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. kniha Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. kniha Mojzísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. kniha Mojzíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. kniha Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. kniha Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. kniha Mojžísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. kniha Mojžíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mooseksen kirja 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. kniha Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. kniha Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. kniha Mojzísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. kniha Mojzíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. kniha Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. kniha Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. kniha Mojžísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. kniha Mojžíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Czwarta Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Czwarta Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mooseksen kirja 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV kniha Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV kniha Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV kniha Mojzísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV kniha Mojzíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV kniha Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV kniha Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV kniha Mojžísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV kniha Mojžíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Ks. Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Ks. Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. книга Моисеева 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. книга Мойсеева 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mooseksen kirja 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 kniha Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 kniha Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 kniha Mojzísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 kniha Mojzíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 kniha Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 kniha Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 kniha Mojžísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 kniha Mojžíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Ks. Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Ks. Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. книга Моисеева 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. книга Мойсеева 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Ks. Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Ks. Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV книга Моисеева 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV книга Мойсеева 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Ks Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Ks Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Четврта Мојсијева 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Четвърта Моисеева 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Ks. Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Ks. Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 книга Моисеева 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 книга Мойсеева 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Ks Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Ks Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrta Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrta Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrta Mojzísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrta Mojzíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrta Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrta Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrta Mojžísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrta Mojžíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrtá Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrtá Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrtá Mojzísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrtá Mojzíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrtá Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrtá Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrtá Mojžísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ctvrtá Mojžíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjarde Moseboken 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjärde Moseboken 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Ks Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Ks Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Neljas Mooseksen 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Neljäs Mooseksen 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Stvrta Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Stvrta Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Stvrta Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Stvrta Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Stvrtá Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Stvrtá Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Stvrtá Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Stvrtá Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Vierte Buch Mose 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("liv Resansman an 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrta Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrta Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrta Mojzísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrta Mojzíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrta Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrta Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrta Mojžísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrta Mojžíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrtá Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrtá Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrtá Mojzísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrtá Mojzíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrtá Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrtá Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrtá Mojžísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čtvrtá Mojžíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Štvrta Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Štvrta Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Štvrta Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Štvrta Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Štvrtá Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Štvrtá Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Štvrtá Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Štvrtá Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Ks Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Ks Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjorða bok Mose 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjorða bok Móse 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjorða bók Mose 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjorða bók Móse 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjórða bok Mose 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjórða bok Móse 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjórða bók Mose 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjórða bók Móse 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 k. Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 k. Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 k. Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 k. Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjarde Mosebok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjerde Mosebog 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjerde Mosebok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjorða Mosebok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjorða Mosebók 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjorða Mósebok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjorða Mósebók 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjärde Mosebok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjórða Mosebok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjórða Mosebók 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjórða Mósebok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjórða Mósebók 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Knjiga Brojeva 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("gantiko pustak 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("gantīko pustak 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("गन्तीको पुस्तक 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 k Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 k Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 k Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 k Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mojzísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mojzíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mojžísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mojžíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mooseksen 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Мојсијева 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mojzeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mojżeszowa 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Buch Mose 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mojzísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mojzíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mojžísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mojžíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mooseksen 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Moseboken 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Мојсијева 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Czwarta Mojz 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Czwarta Mojż 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mojzísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mojzíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mojžísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mojžíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mooseksen 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Мојсијева 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Моисеева 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ksiega Liczb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ksiegi Liczb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Księga Liczb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Księgi Liczb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Liber Numeri 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Vierde Mozes 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Четврта Мојс 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Buch Mose 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mojzisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mojzišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mojzísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mojzíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mojžisova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mojžišova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mojžísova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mojžíšova 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mooseksen 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Moseboken 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Мојсијева 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Моисеева 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Моисеева 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mosebok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mosebók 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mósebok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mósebók 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Mga Numeros 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Vierte Mose 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Книга Чисел 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ଗଣନା ପୁସ୍ତକ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Моисеева 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mosebog 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mosebok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mosebók 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mósebok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mósebók 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Fjerde Mos 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mosebok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mosebók 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mósebok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mósebók 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Mga Bilang 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Mga Numero 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("กันดารวิถี 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mosebog 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mosebok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mosebók 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mósebok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mósebók 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Dân số ký 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ennakamam 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ennākamam 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Enṇakamam 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Enṇākamam 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Eṇnakamam 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Eṇnākamam 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Eṇṇakamam 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Eṇṇākamam 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mozes 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mózes 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ks. Liczb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Resansman 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("سفر العدد 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("எண்ணாகமம் 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("எண்ணிக்கை 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mozes 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mózes 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Bamidbar 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Bemidbar 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mozes 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mózes 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mojz 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mojż 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Мојс 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ks Liczb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Mozes IV 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Mózes IV 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Tirintii 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Wilangan 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mozes 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mózes 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mojz 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mojż 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mose 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Мојс 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Brojevi 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ginatee 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mojz 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mojż 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Мојс 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mos 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. Mós 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Nombres 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Numberi 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Numbers 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Numerii 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Numeros 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Números 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("gantiko 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("gantīko 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Αριθμοί 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Αριθμοι 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Бројеви 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("गन्तीको 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mojz 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mojż 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Moos 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mose 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Мојс 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mos 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mós 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Dân Số 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Hesabu 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Moj 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mos 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV Mós 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Number 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Numeri 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Numero 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Numrat 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Szamok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Számok 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ganana 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("gananā 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("gaṇana 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("gaṇanā 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Броеви 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Moj 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mos 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Moz 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mós 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Móz 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. Mo 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Cysla 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Liczb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("gintī 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("giṇtī 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Čysla 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Числа 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("במדבר 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("מניין 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ספירה 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("العدد 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("گِنتی 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("गन्ती 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("गिनती 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ਗਿਣਤੀ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("《戶籍紀》 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("《民数记》 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("《民數記》 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mo 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 Mz 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4Mós 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Nomb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Nonb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Numb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Szam 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Szám 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Αριθ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("گنتی 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("गणना 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ଗଣନା 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("《戶籍紀 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("《民数记 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("《民數記 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("戶籍紀》 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("民数记》 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("民數記》 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 М 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Bil 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Dân 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Nom 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Num 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Núm 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Res 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Tir 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Чис 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("எண் 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("กดว 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("《民》 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("戶籍紀 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("民数記 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("民数记 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("民數記 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("민수기 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Lb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Nb 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Nm 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("No 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Nu 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Nú 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Αρ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Бр 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("عد 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("Ἀρ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("《民 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("民》 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("민수 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("民 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("민 1:1").osis()).toEqual("Num.1.1")
		p.include_apocrypha(false)
		expect(p.parse("CZWARTA KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CZWARTA KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CZWARTA KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CZWARTA KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CZWARTA KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CZWARTA KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CZWARTA KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CZWARTA KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("KITABU CHA NNE CHA MUSA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ЧЕТВЕРТА КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ЧЕТВЕРТА КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ЧЕТВЪРТА КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTA KNIHA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTA KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTA KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTA KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTA KNIHA MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTA KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTA KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTA KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTÁ KNIHA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTÁ KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTÁ KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTÁ KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTÁ KNIHA MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTÁ KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTÁ KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTÁ KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CZWARTA KS. MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CZWARTA KS. MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NELJAS MOOSEKSEN KIRJA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NELJÄS MOOSEKSEN KIRJA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("STVRTA KNIHA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("STVRTA KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("STVRTA KNIHA MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("STVRTA KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("STVRTÁ KNIHA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("STVRTÁ KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("STVRTÁ KNIHA MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("STVRTÁ KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTA KNIHA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTA KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTA KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTA KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTA KNIHA MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTA KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTA KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTA KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTÁ KNIHA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTÁ KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTÁ KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTÁ KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTÁ KNIHA MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTÁ KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTÁ KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTÁ KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ŠTVRTA KNIHA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ŠTVRTA KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ŠTVRTA KNIHA MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ŠTVRTA KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ŠTVRTÁ KNIHA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ŠTVRTÁ KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ŠTVRTÁ KNIHA MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ŠTVRTÁ KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ЧЕТВРТА КНИГА МОЈСЕЕВА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CZWARTA KS MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CZWARTA KS MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOOSEKSEN KIRJA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KNIHA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KNIHA MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOOSEKSEN KIRJA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KNIHA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KNIHA MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CZWARTA MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CZWARTA MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOOSEKSEN KIRJA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KNIHA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KNIHA MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KS. MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KS. MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOOSEKSEN KIRJA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KNIHA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KNIHA MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KS. MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KS. MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KS. MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KS. MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KS MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. KS MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ЧЕТВРТА МОЈСИЈЕВА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ЧЕТВЪРТА МОИСЕЕВА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KS. MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KS. MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KS MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. KS MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTA MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTA MOJZÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTA MOJZÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTA MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTA MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTA MOJŽÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTA MOJŽÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTÁ MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTÁ MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTÁ MOJZÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTÁ MOJZÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTÁ MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTÁ MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTÁ MOJŽÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CTVRTÁ MOJŽÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJARDE MOSEBOKEN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJÄRDE MOSEBOKEN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KS MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV KS MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NELJAS MOOSEKSEN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NELJÄS MOOSEKSEN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("STVRTA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("STVRTA MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("STVRTA MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("STVRTA MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("STVRTÁ MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("STVRTÁ MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("STVRTÁ MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("STVRTÁ MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("VIERTE BUCH MOSE 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("LIV RESANSMAN AN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTA MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTA MOJZÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTA MOJZÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTA MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTA MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTA MOJŽÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTA MOJŽÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTÁ MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTÁ MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTÁ MOJZÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTÁ MOJZÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTÁ MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTÁ MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTÁ MOJŽÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČTVRTÁ MOJŽÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ŠTVRTA MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ŠTVRTA MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ŠTVRTA MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ŠTVRTA MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ŠTVRTÁ MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ŠTVRTÁ MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ŠTVRTÁ MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ŠTVRTÁ MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KS MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 KS MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJORÐA BOK MOSE 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJORÐA BOK MÓSE 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJORÐA BÓK MOSE 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJORÐA BÓK MÓSE 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJÓRÐA BOK MOSE 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJÓRÐA BOK MÓSE 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJÓRÐA BÓK MOSE 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJÓRÐA BÓK MÓSE 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 K. MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 K. MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 K. MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 K. MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJARDE MOSEBOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJERDE MOSEBOG 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJERDE MOSEBOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJORÐA MOSEBOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJORÐA MOSEBÓK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJORÐA MÓSEBOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJORÐA MÓSEBÓK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJÄRDE MOSEBOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJÓRÐA MOSEBOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJÓRÐA MOSEBÓK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJÓRÐA MÓSEBOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJÓRÐA MÓSEBÓK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("KNJIGA BROJEVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("GANTIKO PUSTAK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("GANTĪKO PUSTAK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("गन्तीको पुस्तक 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 K MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 K MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 K MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 K MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOJZÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOJZÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOJŽÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOJŽÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOOSEKSEN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. МОЈСИЈЕВА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOJZESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOJŻESZOWA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. BUCH MOSE 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOJZÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOJZÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOJŽÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOJŽÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOOSEKSEN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOSEBOKEN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. МОЈСИЈЕВА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CZWARTA MOJZ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CZWARTA MOJŻ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOJZÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOJZÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOJŽÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOJŽÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOOSEKSEN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV МОЈСИЈЕВА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. МОИСЕЕВА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("KSIEGA LICZB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("KSIEGI LICZB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("KSIĘGA LICZB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("KSIĘGI LICZB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("LIBER NUMERI 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("VIERDE MOZES 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ЧЕТВРТА МОЈС 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 BUCH MOSE 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOJZISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOJZIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOJZÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOJZÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOJŽISOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOJŽIŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOJŽÍSOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOJŽÍŠOVA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOOSEKSEN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOSEBOKEN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 МОЈСИЈЕВА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. МОИСЕЕВА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV МОИСЕЕВА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOSEBOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOSEBÓK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MÓSEBOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MÓSEBÓK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("MGA NUMEROS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("VIERTE MOSE 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("КНИГА ЧИСЕЛ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ଗଣନା ପୁସ୍ତକ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 МОИСЕЕВА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOSEBOG 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOSEBOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOSEBÓK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MÓSEBOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MÓSEBÓK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("FJERDE MOS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOSEBOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOSEBÓK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MÓSEBOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MÓSEBÓK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("MGA BILANG 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("MGA NUMERO 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("กันดารวิถี 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOSEBOG 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOSEBOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOSEBÓK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MÓSEBOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MÓSEBÓK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("DÂN SỐ KÝ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ENNAKAMAM 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ENNĀKAMAM 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ENṆAKAMAM 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ENṆĀKAMAM 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("EṆNAKAMAM 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("EṆNĀKAMAM 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("EṆṆAKAMAM 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("EṆṆĀKAMAM 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOZES 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MÓZES 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("KS. LICZB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("RESANSMAN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("سفر العدد 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("எண்ணாகமம் 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("எண்ணிக்கை 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOZES 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MÓZES 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("BAMIDBAR 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("BEMIDBAR 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOZES 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MÓZES 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOJZ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOJŻ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. МОЈС 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("KS LICZB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("MOZES IV 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("MÓZES IV 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("TIRINTII 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("WILANGAN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOZES 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MÓZES 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOJZ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOJŻ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOSE 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. МОЈС 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("BROJEVI 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("GINATEE 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOJZ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOJŻ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV МОЈС 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MOS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV. MÓS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NOMBRES 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUMBERI 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUMBERS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUMERII 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUMEROS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NÚMEROS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("GANTIKO 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("GANTĪKO 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ΑΡΙΘΜΟΊ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ΑΡΙΘΜΟΙ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("БРОЈЕВИ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("गन्तीको 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOJZ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOJŻ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOOS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOSE 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 МОЈС 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MOS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MÓS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("DÂN SỐ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("HESABU 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOJ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MOS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("IV MÓS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUMBER 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUMERI 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUMERO 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUMRAT 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("SZAMOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("SZÁMOK 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("GANANA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("GANANĀ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("GAṆANA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("GAṆANĀ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("БРОЕВИ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOJ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MOZ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MÓS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MÓZ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4. MO 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("CYSLA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("LICZB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("GINTĪ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("GIṆTĪ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ČYSLA 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ЧИСЛА 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("במדבר 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("מניין 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ספירה 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("العدد 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("گِنتی 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("गन्ती 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("गिनती 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ਗਿਣਤੀ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("《戶籍紀》 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("《民数记》 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("《民數記》 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MO 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 MZ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4MÓS 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NOMB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NONB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUMB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("SZAM 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("SZÁM 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ΑΡΙΘ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("گنتی 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("गणना 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ଗଣନା 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("《戶籍紀 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("《民数记 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("《民數記 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("戶籍紀》 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("民数记》 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("民數記》 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("4 М 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("BIL 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("DÂN 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NOM 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NUM 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NÚM 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("RES 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("TIR 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ЧИС 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("எண் 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("กดว 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("《民》 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("戶籍紀 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("民数記 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("民数记 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("民數記 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("민수기 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("LB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NB 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NM 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NO 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NU 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("NÚ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ΑΡ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("БР 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("عد 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("ἈΡ 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("《民 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("民》 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("민수 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("民 1:1").osis()).toEqual("Num.1.1")
		expect(p.parse("민 1:1").osis()).toEqual("Num.1.1")
		`
		true
describe "Localized book Sus (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Sus (full)", ->
		`
		expect(p.parse("Susanne et les deux vieillards 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Suzanne et les deux vieillards 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Сказанию о Сусанне и Данииле 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susanne et les vieillards 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Suzanne et les vieillards 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Fortellingen om Susanna 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Opowiadaniem o Zuzannie 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susanna und die Alten 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susanna ja vanhimmat 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Zsuzsanna es a venek 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Zsuzsanna es a vének 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Zsuzsanna és a venek 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Zsuzsanna és a vének 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Historia de Susana 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("História de Susana 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Historia Susannae 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Storia di Susanna 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Сусанна и старцы 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Istoria Susanei 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susanna i badet 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susanna im Bade 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susanne au bain 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Suzanne au bain 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("كتاب سوزانا 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Si Susana 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Zsuzsanna 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Shoshana 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susannae 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susannah 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Σουσάννα 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Σουσαννα 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susanei 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susanna 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susanne 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Suzanne 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Swsanna 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Súsanna 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Zuzanna 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Σωσάννα 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Σωσαννα 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Сусанна 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("சூசன்னா 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Susana 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Suzana 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Zuzana 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Zuzane 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("سوزانا 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("スサンナ物語 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("スザンナ物語 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Zsuzs 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("שושנה 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("《Sus》 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Sus》 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Zsuz 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Σουσ 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("《Sus 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("スサンナ 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("スザンナ 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Sus 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Suz 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Zuz 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Сус 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("수산나 1:1").osis()).toEqual("Sus.1.1")
		expect(p.parse("Su 1:1").osis()).toEqual("Sus.1.1")
		`
		true
describe "Localized book Sir (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Sir (full)", ->
		`
		expect(p.parse("Cartea intelepciunii lui Isus, fiul lui Sirah 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Cartea inţelepciunii lui Isus, fiul lui Sirah 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Cartea întelepciunii lui Isus, fiul lui Sirah 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Cartea înţelepciunii lui Isus, fiul lui Sirah 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Книга Премъдрост на Иисуса, син Сирахов 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ang Karunungan ni Jesus, Anak ni Sirac 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ang Karunungan ni Jesus Anak ni Sirac 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("The Wisdom of Jesus, Son of Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("The Wisdom of Jesus Son of Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Премудрости Иисуса, сына Сирахова 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Премудрість Ісуса, сина Сирахова 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Премъдрост на Иисус, син Сирахов 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Премудрости Исуса сина Сирахова 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("The Wisdom of Jesus ben Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Wisdom of Jesus, Son of Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Wijsheid van Jozua Ben Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Wisdom of Jesus Son of Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Karunungan ng Anak ni Sirac 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Wisdom of Jesus ben Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Wijsheid van Jezus Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Jesu Siraks sønns visdom 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Oratio Iesu filii Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Wijsheid van Ben Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Kitab Yesus bin Sirakh 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("La Sagesse de Ben Sira 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Jeesus Siirakin kirja 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Kniha Sirachovho syna 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Jesus Siirakin kirja 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Liber Ecclesiasticus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sapienza di Siracide 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Jesus Syraks vishet 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Kniha Ekleziastikus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sagesse de Ben Sira 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("K. Sirachovho syna 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Kniha Sirachovcova 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Kniha Sírachovcova 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sapienza di Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Премудрость Сираха 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("K Sirachovho syna 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirak bolcsessege 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirak bolcsessége 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirak bölcsessege 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirak bölcsessége 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirák bolcsessege 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirák bolcsessége 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirák bölcsessege 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirák bölcsessége 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("K. Ekleziastikus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Kniha Sirachovca 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("சீராக்கின் ஞானம் 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("K Ekleziastikus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("K. Sirachovcova 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Knjiga Sirahova 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Madrosc Syracha 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Madrosć Syracha 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Madrośc Syracha 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Madrość Syracha 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Mądrosc Syracha 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Mądrosć Syracha 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Mądrośc Syracha 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Mądrość Syracha 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Yoshua bin Sira 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ecclesiasticul 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ecclesiasticus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ecclesiastique 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ecclusiasticus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ecclésiastique 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ekklesiastikus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ekklesyastikus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("K Sirachovcova 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Siirakin kirja 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Еклезијастикус 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Книга на Сирах 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ecclesiastico 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ekklesiastiko 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ekklesyastiko 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Eklesiastikus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Eklesyastikus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("K. Sirachovca 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirakin kirja 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("سفر ابن سيراخ 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("يشوع بن سيراخ 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("シラフの子イイススの知恵書 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Eclesiastico 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Eclesiástico 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ekkleziastik 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Eklesiastiko 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Eklesyastiko 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Eklezjastyka 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Jesus Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Jezus Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("K Sirachovca 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirachovcova 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Σοφία Σειράχ 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Σοφία Σειραχ 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Σοφια Σειράχ 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Σοφια Σειραχ 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Книга Сираха 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("משלי בן סירא 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("משלי בן-סירא 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("சீராக் ஆகமம் 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ecleziastic 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Eklezjastyk 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Σοφία Σιραχ 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Σοφια Σιραχ 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("ספר בן סירא 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirachovec 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Siraks Bog 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Siraks bok 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sírachovec 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Бен Сираха 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Siracidas 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Siracides 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirak fia 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirakidas 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirakides 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Siraksbok 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Siraksbók 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirácidas 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirácides 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirák fia 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirákidas 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirákides 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Síraksbok 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Síraksbók 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Еклесіаст 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("シラ書（集会の書） 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ben Sira 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Siirakin 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Siracida 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Siracide 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirakida 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirakide 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Siràcide 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirácida 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirácide 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirákida 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirákide 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Сирахова 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("บุตรสิรา 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("ヘン・シラの智慧 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("ヘン・シラの知恵 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("ベン・シラの智慧 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("ベン・シラの知恵 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("벤시라크의 지혜 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("벤시리크의 지혜 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Huấn Ca 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirakin 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Syracha 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Сирахов 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("벤시라의 지혜 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("벤시라크 지혜 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ecclus 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirach 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirakh 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirách 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirákh 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Σειράχ 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Σειραχ 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Сираха 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Сирина 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("벤시라 지혜 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirac 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirak 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirác 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sirák 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Syrak 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("سيراخ 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("《德訓篇》 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Eccs 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Ekli 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sira 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("சீஞா 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("《德訓篇 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("德訓篇》 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("集会の書 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sir 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Syr 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Sír 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("YbS 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("ИсС 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Сир 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("シラ書 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("德訓篇 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("집회서 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("Si 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("سي 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("シラ 1:1").osis()).toEqual("Sir.1.1")
		expect(p.parse("집회 1:1").osis()).toEqual("Sir.1.1")
		`
		true
describe "Localized book PrMan (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: PrMan (full)", ->
		`
		expect(p.parse("Orazione di Manasse Re di Giuda 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Ang Panalangin ni Manases 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Rugaciunea regelui Manase 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Rugăciunea regelui Manase 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("The Prayers of Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("The Prayer of Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("La Oracion de Manases 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("La Oracion de Manasés 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("La Oración de Manases 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("La Oración de Manasés 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Oratio regis Manassae 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Panalangin ni Manases 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Rugaciunea lui Manase 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Rugăciunea lui Manase 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("La Priere de Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("La Priere de Manassé 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("La Prière de Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("La Prière de Manassé 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Preghiera di Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("The Prayers Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Dalangin ni Manases 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manasesova modlitba 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Orazione di Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Prayers of Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("The Prayer Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manassen rukouksen 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Modlitwa Manassesa 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Oracion de Manases 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Oracion de Manasés 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Oración de Manases 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Oración de Manasés 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Prayer of Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("The Pr of Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Молитва Манасијина 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Gebet des Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Prece de Manasses 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Prece de Manassés 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Priere de Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Priere de Manassé 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Prière de Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Prière de Manassé 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Dasal ni Manases 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manasse imadsaga 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manasse imadsága 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manasse imádsaga 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manasse imádsága 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manassé imadsaga 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manassé imadsága 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manassé imádsaga 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manassé imádsága 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Modlitbu Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Prayers Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Προσευχή Μανασσή 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Προσευχή Μανασση 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Προσευχη Μανασσή 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Προσευχη Μανασση 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Молитва Манассии 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Oratio Manassae 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Prayer Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("The Pr Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Gebet Manasses 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Gweddi Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manassze imaja 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manassze imája 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Pr of Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Gebet Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manasses bønn 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manasses’ bon 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manasses’ bön 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manasses Bøn 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manasses bon 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manasses bön 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Bæn Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manasse bon 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manasse bön 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Pr Manasseh 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Pr. Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Pr. Manassé 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Pr Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Pr Manassé 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("תפילת מנשה 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("صلاة منسى 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Geb Man 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manasse 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Or. Man 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Pr. Man 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("《PrMan》 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("マナセのいのり 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("므나쎄의 기도 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Man ru 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Manase 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Or Man 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Pr Man 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("PrMan》 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Πρ Μαν 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("《PrMan 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("マナセの祈り 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("マナセの祈禱 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("PrMan 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("BMn 1:1").osis()).toEqual("PrMan.1.1")
		expect(p.parse("Man 1:1").osis()).toEqual("PrMan.1.1")
		`
		true
describe "Localized book Acts (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Acts (full)", ->
		`
		expect(p.parse("Mabuting Balita ayon sa Espiritu Santo 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Mabuting Balita ng Espiritu Santo 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Ebanghelyo ng Espiritu Santo 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Handelingen van de apostelen 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ପ୍ରେରିତମାନଙ୍କ କାର୍ଯ୍ୟର ବିବରଣ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Los Hechos de los Apostoles 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Los Hechos de los Apóstoles 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Dijannja svjatyh apostoliv 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Dijannja svjatyȟ apostoliv 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Деяния на светите Апостоли 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Az apostolok cselekedetei 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Handelingen der apostelen 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Mga Gawa ng mga Apostoles 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("The Acts of the Apostles 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Дела на светите апостоли 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Hechos de los Apostoles 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Hechos de los Apóstoles 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Mga Gawa ng mga Apostol 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Діяння Святих Апостолів 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("அப்போஸ்தலருடைய நடபடிகள் 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apostolok cselekedetei 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Buhat sa mga Apostoles 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Mga Gawa ng mga Alagad 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Деянията на апостолите 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apostlenes gjerninger 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Dziejach Apostolskich 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Πράξεις των Αποστολων 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Πράξεις των Αποστόλων 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Πραξεις των Αποστολων 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Πραξεις των Αποστόλων 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Acts of the Apostles 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apostlenes Gerninger 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apostlenes-gjerninge 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Деяния на апостолите 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Діі святих апостолів 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Дії святих апостолів 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("प्रेषितांचीं कृत्यें 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Atti degli Apostoli 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Falimaha Rasuullada 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Faptele Apostolilor 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Gawa ng mga Apostol 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Lelakone Para Rasul 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitamcim kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitamcim kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitamciṃ kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitamciṃ kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitamcīm kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitamcīm kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitamcīṃ kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitamcīṃ kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitaṃcim kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitaṃcim kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitaṃciṃ kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitaṃciṃ kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitaṃcīm kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitaṃcīm kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitaṃcīṃ kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitaṃcīṃ kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitāmcim kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitāmcim kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitāmciṃ kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitāmciṃ kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitāmcīm kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitāmcīm kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitāmcīṃ kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitāmcīṃ kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitāṃcim kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitāṃcim kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitāṃciṃ kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitāṃciṃ kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitāṃcīm kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitāṃcīm kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitāṃcīṃ kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("presitāṃcīṃ kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitamcim kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitamcim kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitamciṃ kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitamciṃ kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitamcīm kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitamcīm kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitamcīṃ kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitamcīṃ kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitaṃcim kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitaṃcim kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitaṃciṃ kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitaṃciṃ kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitaṃcīm kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitaṃcīm kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitaṃcīṃ kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitaṃcīṃ kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitāmcim kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitāmcim kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitāmciṃ kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitāmciṃ kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitāmcīm kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitāmcīm kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitāmcīṃ kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitāmcīṃ kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitāṃcim kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitāṃcim kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitāṃciṃ kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitāṃciṃ kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitāṃcīm kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitāṃcīm kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitāṃcīṃ kr̥tyem 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("prešitāṃcīṃ kr̥tyeṃ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("प्रेषितांची कृत्यें 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("प्रेषितांचीं कृत्ये 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Actau'r Apostolion 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Actau’r Apostolion 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apostelgjerningene 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apostlagarningarna 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apostlagärningarna 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Atos dos Apostolos 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Atos dos Apóstolos 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Dzieje Apostolskie 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Veprat e Apostujve 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Veprat e apostujve 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("rasūlāṃ de kartabb 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Дела на апостолите 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("प्रेरितों के कामों 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("திருத்தூதர் பணிகள் 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("กิจการ​ของ​อัครทูต 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Actes des Apotres 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Actes des Apôtres 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Actus Apostolorum 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Ang Mga Binuhatan 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apostelgeschichte 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Công vụ các Sứ đồ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Fapte Apostolilor 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Gawa ng Apostoles 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Matendo ya Mitume 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Skutky apostolske 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Skutky apostolské 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Skutky apoštolske 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Skutky apoštolské 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Djela apostolska 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Praeriton Ke Kam 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Skutky apostolov 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Skutky apoštolov 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("preritharuka kam 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("preritharuka kām 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("preritharukā kam 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("preritharukā kām 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("preritharūka kam 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("preritharūka kām 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("preritharūkā kam 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("preritharūkā kām 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("rasūlōṅ ke aʿmāl 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("رسُولوں کے اعمال 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("प्रेरितहरूका काम 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("प्रेरितों के काम 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apostolien teot 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Appostalar Pani 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Appostalar Paṇi 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Appōstalar Pani 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Appōstalar Paṇi 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Công vụ Tông đồ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Skutky apostolu 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Skutky apostolů 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Skutky apoštolu 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Skutky apoštolů 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Дела Апостолска 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("رسولوں کے اعمال 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("سفر أعمال الرسل 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ਰਸੂਲਾਂ ਦੇ ਕਰਤੱਬ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("அப்போஸ்தலர் பணி 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Aksyon apot yo 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Aksyon apòt yo 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Travay apot yo 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Travay apòt yo 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("یوحنا کے اعمال 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Діі Апостолів 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Дії Апостолів 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Cselekedetek 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Dzieje Apost 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Postulasagan 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("מעשי השליחים 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Handelingen 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("أعمال الرسل 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("அப்போஸ்தலர் 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ﺍﻋﻤﺎﻝ ﺍﻟﺮﺳﻞ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Los Hechos 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Mga Gawain 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Para Rasul 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Akdezapot 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Akdèzapot 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apostolok 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Az ApCsel 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Binuhatan 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Gerninger 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Ap. Csel 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Mga Gawa 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("मसीह-दूत 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Ap Csel 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Công Vụ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Faptele 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Matendo 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Πράξεις 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Πραξεις 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Дела Ап 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("प्रेरित 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ପ୍ରେରିତ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("《宗徒大事錄》 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Actsss 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ApCsel 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Dzieje 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Hechos 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Skutky 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Travay 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Veprat 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Деяния 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Діяння 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("اَعمال 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("رسولوں 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("प्र. क 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("กิจการ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("《使徒行传》 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("《使徒行傳》 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("《宗徒大事錄 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("《宗徒行實》 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("宗徒大事錄》 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Actau 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Actes 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Actss 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Actus 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Ap. t 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Dz Ap 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("F. Ap 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Fapte 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Sứ đồ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("اعمال 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("प्र क 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("प्र.क 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("அப்போ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("《使徒行传 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("《使徒行傳 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("《宗徒行實 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("使徒行传》 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("使徒行傳》 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("使徒言行録 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("宗徒大事錄 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("宗徒行實》 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Acta 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Acts 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Ap t 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Ap.G 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Ap.t 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Atos 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Atti 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Công 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("F Ap 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Fapt 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Gawa 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Hand 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Hech 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Teot 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Πράξ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Πραξ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Д. А 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Дела 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Деян 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Діян 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("प्रक 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("使徒行伝 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("使徒行传 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("使徒行傳 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("使徒行録 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("宗徒行實 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("사도행전 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Act 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ApG 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apg 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Apt 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Bin 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("F.A 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Fal 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Fap 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Hch 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Hec 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Hnd 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Mdo 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Vep 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Πρξ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Д А 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Дап 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Діі 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Дії 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("அப் 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("திப 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("《徒》 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("使徒書 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Ac 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("At 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Dj 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Dz 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("FA 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Gw 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Hc 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Sk 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("اع 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("กจ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("《徒 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("使徒 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("徒》 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("사도 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("徒 1:1").osis()).toEqual("Acts.1.1")
		p.include_apocrypha(false)
		expect(p.parse("MABUTING BALITA AYON SA ESPIRITU SANTO 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("MABUTING BALITA NG ESPIRITU SANTO 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("EBANGHELYO NG ESPIRITU SANTO 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HANDELINGEN VAN DE APOSTELEN 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ପ୍ରେରିତମାନଙ୍କ କାର୍ଯ୍ୟର ବିବରଣ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("LOS HECHOS DE LOS APOSTOLES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("LOS HECHOS DE LOS APÓSTOLES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("DIJANNJA SVJATYH APOSTOLIV 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("DIJANNJA SVJATYȞ APOSTOLIV 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ДЕЯНИЯ НА СВЕТИТЕ АПОСТОЛИ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AZ APOSTOLOK CSELEKEDETEI 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HANDELINGEN DER APOSTELEN 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("MGA GAWA NG MGA APOSTOLES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("THE ACTS OF THE APOSTLES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ДЕЛА НА СВЕТИТЕ АПОСТОЛИ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HECHOS DE LOS APOSTOLES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HECHOS DE LOS APÓSTOLES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("MGA GAWA NG MGA APOSTOL 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ДІЯННЯ СВЯТИХ АПОСТОЛІВ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("அப்போஸ்தலருடைய நடபடிகள் 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APOSTOLOK CSELEKEDETEI 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("BUHAT SA MGA APOSTOLES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("MGA GAWA NG MGA ALAGAD 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ДЕЯНИЯТА НА АПОСТОЛИТЕ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APOSTLENES GJERNINGER 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("DZIEJACH APOSTOLSKICH 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ΠΡΆΞΕΙΣ ΤΩΝ ΑΠΟΣΤΟΛΩΝ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ΠΡΆΞΕΙΣ ΤΩΝ ΑΠΟΣΤΌΛΩΝ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ΠΡΑΞΕΙΣ ΤΩΝ ΑΠΟΣΤΟΛΩΝ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ΠΡΑΞΕΙΣ ΤΩΝ ΑΠΟΣΤΌΛΩΝ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTS OF THE APOSTLES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APOSTLENES GERNINGER 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APOSTLENES-GJERNINGE 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ДЕЯНИЯ НА АПОСТОЛИТЕ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ДІІ СВЯТИХ АПОСТОЛІВ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ДІЇ СВЯТИХ АПОСТОЛІВ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("प्रेषितांचीं कृत्यें 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ATTI DEGLI APOSTOLI 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("FALIMAHA RASUULLADA 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("FAPTELE APOSTOLILOR 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("GAWA NG MGA APOSTOL 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("LELAKONE PARA RASUL 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITAMCIM KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITAMCIM KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITAMCIṂ KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITAMCIṂ KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITAMCĪM KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITAMCĪM KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITAMCĪṂ KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITAMCĪṂ KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITAṂCIM KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITAṂCIM KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITAṂCIṂ KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITAṂCIṂ KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITAṂCĪM KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITAṂCĪM KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITAṂCĪṂ KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITAṂCĪṂ KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITĀMCIM KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITĀMCIM KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITĀMCIṂ KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITĀMCIṂ KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITĀMCĪM KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITĀMCĪM KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITĀMCĪṂ KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITĀMCĪṂ KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITĀṂCIM KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITĀṂCIM KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITĀṂCIṂ KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITĀṂCIṂ KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITĀṂCĪM KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITĀṂCĪM KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITĀṂCĪṂ KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRESITĀṂCĪṂ KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITAMCIM KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITAMCIM KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITAMCIṂ KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITAMCIṂ KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITAMCĪM KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITAMCĪM KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITAMCĪṂ KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITAMCĪṂ KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITAṂCIM KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITAṂCIM KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITAṂCIṂ KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITAṂCIṂ KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITAṂCĪM KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITAṂCĪM KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITAṂCĪṂ KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITAṂCĪṂ KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITĀMCIM KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITĀMCIM KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITĀMCIṂ KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITĀMCIṂ KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITĀMCĪM KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITĀMCĪM KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITĀMCĪṂ KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITĀMCĪṂ KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITĀṂCIM KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITĀṂCIM KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITĀṂCIṂ KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITĀṂCIṂ KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITĀṂCĪM KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITĀṂCĪM KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITĀṂCĪṂ KR̥TYEM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PREŠITĀṂCĪṂ KR̥TYEṂ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("प्रेषितांची कृत्यें 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("प्रेषितांचीं कृत्ये 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTAU'R APOSTOLION 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTAU’R APOSTOLION 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APOSTELGJERNINGENE 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APOSTLAGARNINGARNA 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APOSTLAGÄRNINGARNA 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ATOS DOS APOSTOLOS 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ATOS DOS APÓSTOLOS 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("DZIEJE APOSTOLSKIE 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("VEPRAT E APOSTUJVE 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("VEPRAT E APOSTUJVE 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("RASŪLĀṂ DE KARTABB 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ДЕЛА НА АПОСТОЛИТЕ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("प्रेरितों के कामों 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("திருத்தூதர் பணிகள் 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("กิจการ​ของ​อัครทูต 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTES DES APOTRES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTES DES APÔTRES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTUS APOSTOLORUM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ANG MGA BINUHATAN 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APOSTELGESCHICHTE 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("CÔNG VỤ CÁC SỨ ĐỒ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("FAPTE APOSTOLILOR 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("GAWA NG APOSTOLES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("MATENDO YA MITUME 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("SKUTKY APOSTOLSKE 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("SKUTKY APOSTOLSKÉ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("SKUTKY APOŠTOLSKE 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("SKUTKY APOŠTOLSKÉ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("DJELA APOSTOLSKA 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRAERITON KE KAM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("SKUTKY APOSTOLOV 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("SKUTKY APOŠTOLOV 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRERITHARUKA KAM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRERITHARUKA KĀM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRERITHARUKĀ KAM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRERITHARUKĀ KĀM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRERITHARŪKA KAM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRERITHARŪKA KĀM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRERITHARŪKĀ KAM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PRERITHARŪKĀ KĀM 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("RASŪLŌṄ KE AʿMĀL 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("رسُولوں کے اعمال 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("प्रेरितहरूका काम 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("प्रेरितों के काम 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APOSTOLIEN TEOT 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APPOSTALAR PANI 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APPOSTALAR PAṆI 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APPŌSTALAR PANI 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APPŌSTALAR PAṆI 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("CÔNG VỤ TÔNG ĐỒ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("SKUTKY APOSTOLU 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("SKUTKY APOSTOLŮ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("SKUTKY APOŠTOLU 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("SKUTKY APOŠTOLŮ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ДЕЛА АПОСТОЛСКА 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("رسولوں کے اعمال 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("سفر أعمال الرسل 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ਰਸੂਲਾਂ ਦੇ ਕਰਤੱਬ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("அப்போஸ்தலர் பணி 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AKSYON APOT YO 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AKSYON APÒT YO 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("TRAVAY APOT YO 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("TRAVAY APÒT YO 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("یوحنا کے اعمال 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ДІІ АПОСТОЛІВ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ДІЇ АПОСТОЛІВ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("CSELEKEDETEK 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("DZIEJE APOST 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("POSTULASAGAN 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("מעשי השליחים 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HANDELINGEN 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("أعمال الرسل 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("அப்போஸ்தலர் 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ﺍﻋﻤﺎﻝ ﺍﻟﺮﺳﻞ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("LOS HECHOS 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("MGA GAWAIN 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("PARA RASUL 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AKDEZAPOT 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AKDÈZAPOT 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APOSTOLOK 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AZ APCSEL 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("BINUHATAN 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("GERNINGER 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AP. CSEL 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("MGA GAWA 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("मसीह-दूत 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AP CSEL 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("CÔNG VỤ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("FAPTELE 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("MATENDO 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ΠΡΆΞΕΙΣ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ΠΡΑΞΕΙΣ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ДЕЛА АП 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("प्रेरित 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ପ୍ରେରିତ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("《宗徒大事錄》 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTSSS 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APCSEL 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("DZIEJE 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HECHOS 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("SKUTKY 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("TRAVAY 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("VEPRAT 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ДЕЯНИЯ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ДІЯННЯ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("اَعمال 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("رسولوں 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("प्र. क 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("กิจการ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("《使徒行传》 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("《使徒行傳》 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("《宗徒大事錄 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("《宗徒行實》 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("宗徒大事錄》 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTAU 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTES 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTSS 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTUS 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AP. T 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("DZ AP 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("F. AP 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("FAPTE 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("SỨ ĐỒ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("اعمال 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("प्र क 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("प्र.क 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("அப்போ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("《使徒行传 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("《使徒行傳 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("《宗徒行實 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("使徒行传》 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("使徒行傳》 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("使徒言行録 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("宗徒大事錄 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("宗徒行實》 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTA 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACTS 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AP T 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AP.G 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AP.T 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ATOS 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ATTI 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("CÔNG 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("F AP 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("FAPT 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("GAWA 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HAND 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HECH 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("TEOT 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ΠΡΆΞ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ΠΡΑΞ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Д. А 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ДЕЛА 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ДЕЯН 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ДІЯН 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("प्रक 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("使徒行伝 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("使徒行传 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("使徒行傳 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("使徒行録 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("宗徒行實 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("사도행전 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ACT 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APG 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APG 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("APT 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("BIN 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("F.A 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("FAL 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("FAP 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HCH 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HEC 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HND 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("MDO 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("VEP 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ΠΡΞ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("Д А 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ДАП 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ДІІ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("ДІЇ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("அப் 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("திப 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("《徒》 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("使徒書 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AC 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("AT 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("DJ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("DZ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("FA 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("GW 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("HC 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("SK 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("اع 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("กจ 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("《徒 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("使徒 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("徒》 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("사도 1:1").osis()).toEqual("Acts.1.1")
		expect(p.parse("徒 1:1").osis()).toEqual("Acts.1.1")
		`
		true
describe "Localized book Rev (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Rev (full)", ->
		`
		expect(p.parse("Откровение на св. Иоана Богослова 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("யோவானுக்கு வெளிப்படுத்தின விசேஷம் 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Откровение на св Иоана Богослова 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Об'явлення св. Івана Богослова 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Об'явлення св. Иоана Богослова 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Об'явлення св. Йоана Богослова 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Об’явлення св. Івана Богослова 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Об’явлення св. Иоана Богослова 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Об’явлення св. Йоана Богослова 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanala ǳʰalele prakatikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanala ǳʰalele prakatikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanala ǳʰalele prakatīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanala ǳʰalele prakatīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanala ǳʰalele prakaṭikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanala ǳʰalele prakaṭikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanala ǳʰalele prakaṭīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanala ǳʰalele prakaṭīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanala ǳʰālele prakatikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanala ǳʰālele prakatikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanala ǳʰālele prakatīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanala ǳʰālele prakatīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanala ǳʰālele prakaṭikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanala ǳʰālele prakaṭikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanala ǳʰālele prakaṭīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanala ǳʰālele prakaṭīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanalā ǳʰalele prakatikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanalā ǳʰalele prakatikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanalā ǳʰalele prakatīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanalā ǳʰalele prakatīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanalā ǳʰalele prakaṭikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanalā ǳʰalele prakaṭikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanalā ǳʰalele prakaṭīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanalā ǳʰalele prakaṭīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanalā ǳʰālele prakatikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanalā ǳʰālele prakatikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanalā ǳʰālele prakatīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanalā ǳʰālele prakatīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanalā ǳʰālele prakaṭikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanalā ǳʰālele prakaṭikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanalā ǳʰālele prakaṭīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanalā ǳʰālele prakaṭīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanāla ǳʰalele prakatikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanāla ǳʰalele prakatikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanāla ǳʰalele prakatīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanāla ǳʰalele prakatīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanāla ǳʰalele prakaṭikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanāla ǳʰalele prakaṭikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanāla ǳʰalele prakaṭīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanāla ǳʰalele prakaṭīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanāla ǳʰālele prakatikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanāla ǳʰālele prakatikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanāla ǳʰālele prakatīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanāla ǳʰālele prakatīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanāla ǳʰālele prakaṭikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanāla ǳʰālele prakaṭikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanāla ǳʰālele prakaṭīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanāla ǳʰālele prakaṭīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanālā ǳʰalele prakatikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanālā ǳʰalele prakatikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanālā ǳʰalele prakatīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanālā ǳʰalele prakatīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanālā ǳʰalele prakaṭikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanālā ǳʰalele prakaṭikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanālā ǳʰalele prakaṭīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanālā ǳʰalele prakaṭīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanālā ǳʰālele prakatikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanālā ǳʰālele prakatikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanālā ǳʰālele prakatīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanālā ǳʰālele prakatīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanālā ǳʰālele prakaṭikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanālā ǳʰālele prakaṭikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanālā ǳʰālele prakaṭīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohanālā ǳʰālele prakaṭīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānala ǳʰalele prakatikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānala ǳʰalele prakatikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānala ǳʰalele prakatīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānala ǳʰalele prakatīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānala ǳʰalele prakaṭikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānala ǳʰalele prakaṭikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānala ǳʰalele prakaṭīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānala ǳʰalele prakaṭīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānala ǳʰālele prakatikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānala ǳʰālele prakatikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānala ǳʰālele prakatīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānala ǳʰālele prakatīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānala ǳʰālele prakaṭikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānala ǳʰālele prakaṭikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānala ǳʰālele prakaṭīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānala ǳʰālele prakaṭīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānalā ǳʰalele prakatikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānalā ǳʰalele prakatikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānalā ǳʰalele prakatīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānalā ǳʰalele prakatīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānalā ǳʰalele prakaṭikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānalā ǳʰalele prakaṭikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānalā ǳʰalele prakaṭīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānalā ǳʰalele prakaṭīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānalā ǳʰālele prakatikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānalā ǳʰālele prakatikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānalā ǳʰālele prakatīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānalā ǳʰālele prakatīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānalā ǳʰālele prakaṭikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānalā ǳʰālele prakaṭikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānalā ǳʰālele prakaṭīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānalā ǳʰālele prakaṭīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānāla ǳʰalele prakatikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānāla ǳʰalele prakatikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānāla ǳʰalele prakatīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānāla ǳʰalele prakatīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānāla ǳʰalele prakaṭikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānāla ǳʰalele prakaṭikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānāla ǳʰalele prakaṭīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānāla ǳʰalele prakaṭīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānāla ǳʰālele prakatikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānāla ǳʰālele prakatikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānāla ǳʰālele prakatīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānāla ǳʰālele prakatīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānāla ǳʰālele prakaṭikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānāla ǳʰālele prakaṭikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānāla ǳʰālele prakaṭīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānāla ǳʰālele prakaṭīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānālā ǳʰalele prakatikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānālā ǳʰalele prakatikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānālā ǳʰalele prakatīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānālā ǳʰalele prakatīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānālā ǳʰalele prakaṭikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānālā ǳʰalele prakaṭikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānālā ǳʰalele prakaṭīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānālā ǳʰalele prakaṭīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānālā ǳʰālele prakatikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānālā ǳʰālele prakatikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānālā ǳʰālele prakatīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānālā ǳʰālele prakatīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānālā ǳʰālele prakaṭikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānālā ǳʰālele prakaṭikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānālā ǳʰālele prakaṭīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yohānālā ǳʰālele prakaṭīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Об'явлення св Івана Богослова 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Об'явлення св Иоана Богослова 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Об'явлення св Йоана Богослова 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Об’явлення св Івана Богослова 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Об’явлення св Иоана Богослова 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Об’явлення св Йоана Богослова 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalypsis Ioannis Apostoli 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ob'javlennja Ivana Bohoslova 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ob’javlennja Ivana Bohoslova 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ଯୋହନଙ୍କ ପ୍ରତି ପ୍ରକାଶିତ ବାକ୍ୟ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Об'явлення Івана Богослова 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Об’явлення Івана Богослова 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Одкровення Івана Богослова 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Opinberunarbok Johannesar 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Opinberunarbok Jóhannesar 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Opinberunarbók Johannesar 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Opinberunarbók Jóhannesar 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttina Vicetankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttina Vicetankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttina Vicetaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttina Vicetaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttina Viceṭankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttina Viceṭankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttina Viceṭaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttina Viceṭaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttina Vicētankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttina Vicētankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttina Vicētaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttina Vicētaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttina Vicēṭankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttina Vicēṭankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttina Vicēṭaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttina Vicēṭaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttiṉa Vicetankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttiṉa Vicetankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttiṉa Vicetaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttiṉa Vicetaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttiṉa Viceṭankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttiṉa Viceṭankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttiṉa Viceṭaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttiṉa Viceṭaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttiṉa Vicētankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttiṉa Vicētankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttiṉa Vicētaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttiṉa Vicētaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttiṉa Vicēṭankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttiṉa Vicēṭankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttiṉa Vicēṭaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttiṉa Vicēṭaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttina Vicetankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttina Vicetankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttina Vicetaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttina Vicetaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttina Viceṭankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttina Viceṭankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttina Viceṭaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttina Viceṭaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttina Vicētankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttina Vicētankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttina Vicētaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttina Vicētaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttina Vicēṭankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttina Vicēṭankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttina Vicēṭaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttina Vicēṭaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttiṉa Vicetankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttiṉa Vicetankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttiṉa Vicetaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttiṉa Vicetaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttiṉa Viceṭankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttiṉa Viceṭankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttiṉa Viceṭaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttiṉa Viceṭaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttiṉa Vicētankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttiṉa Vicētankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttiṉa Vicētaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttiṉa Vicētaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttiṉa Vicēṭankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttiṉa Vicēṭankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttiṉa Vicēṭaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttiṉa Vicēṭaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttina Vicetankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttina Vicetankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttina Vicetaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttina Vicetaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttina Viceṭankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttina Viceṭankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttina Viceṭaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttina Viceṭaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttina Vicētankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttina Vicētankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttina Vicētaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttina Vicētaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttina Vicēṭankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttina Vicēṭankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttina Vicēṭaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttina Vicēṭaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttiṉa Vicetankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttiṉa Vicetankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttiṉa Vicetaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttiṉa Vicetaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttiṉa Viceṭankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttiṉa Viceṭankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttiṉa Viceṭaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttiṉa Viceṭaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttiṉa Vicētankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttiṉa Vicētankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttiṉa Vicētaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttiṉa Vicētaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttiṉa Vicēṭankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttiṉa Vicēṭankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttiṉa Vicēṭaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttiṉa Vicēṭaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttina Vicetankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttina Vicetankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttina Vicetaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttina Vicetaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttina Viceṭankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttina Viceṭankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttina Viceṭaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttina Viceṭaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttina Vicētankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttina Vicētankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttina Vicētaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttina Vicētaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttina Vicēṭankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttina Vicēṭankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttina Vicēṭaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttina Vicēṭaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttiṉa Vicetankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttiṉa Vicetankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttiṉa Vicetaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttiṉa Vicetaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttiṉa Viceṭankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttiṉa Viceṭankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttiṉa Viceṭaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttiṉa Viceṭaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttiṉa Vicētankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttiṉa Vicētankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttiṉa Vicētaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttiṉa Vicētaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttiṉa Vicēṭankal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttiṉa Vicēṭankaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttiṉa Vicēṭaṅkal 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttiṉa Vicēṭaṅkaḷ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhãnā de prakāš dī potʰī 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūḥannā ʿārif kā mukāšafâ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("یُو حنّا عارِف کا مُکاشفہ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("योहानाला झालेले प्रकटीकरण 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("வெளிப்படுத்தின விசேடங்கள் 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalipsa Swietego Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalipsa Swiętego Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalipsa Świetego Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalipsa Świętego Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannalai bʰaeko prakas 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannalai bʰaeko prakaš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannalai bʰaeko prakās 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannalai bʰaeko prakāš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannalaī bʰaeko prakas 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannalaī bʰaeko prakaš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannalaī bʰaeko prakās 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannalaī bʰaeko prakāš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannalāi bʰaeko prakas 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannalāi bʰaeko prakaš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannalāi bʰaeko prakās 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannalāi bʰaeko prakāš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannalāī bʰaeko prakas 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannalāī bʰaeko prakaš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannalāī bʰaeko prakās 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannalāī bʰaeko prakāš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannālai bʰaeko prakas 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannālai bʰaeko prakaš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannālai bʰaeko prakās 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannālai bʰaeko prakāš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannālaī bʰaeko prakas 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannālaī bʰaeko prakaš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannālaī bʰaeko prakās 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannālaī bʰaeko prakāš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannālāi bʰaeko prakas 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannālāi bʰaeko prakaš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannālāi bʰaeko prakās 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannālāi bʰaeko prakāš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannālāī bʰaeko prakas 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannālāī bʰaeko prakaš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannālāī bʰaeko prakās 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yuhannālāī bʰaeko prakāš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannalai bʰaeko prakas 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannalai bʰaeko prakaš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannalai bʰaeko prakās 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannalai bʰaeko prakāš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannalaī bʰaeko prakas 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannalaī bʰaeko prakaš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannalaī bʰaeko prakās 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannalaī bʰaeko prakāš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannalāi bʰaeko prakas 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannalāi bʰaeko prakaš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannalāi bʰaeko prakās 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannalāi bʰaeko prakāš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannalāī bʰaeko prakas 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannalāī bʰaeko prakaš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannalāī bʰaeko prakās 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannalāī bʰaeko prakāš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannālai bʰaeko prakas 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannālai bʰaeko prakaš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannālai bʰaeko prakās 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannālai bʰaeko prakāš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannālaī bʰaeko prakas 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannālaī bʰaeko prakaš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannālaī bʰaeko prakās 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannālaī bʰaeko prakāš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannālāi bʰaeko prakas 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannālāi bʰaeko prakaš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannālāi bʰaeko prakās 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannālāi bʰaeko prakāš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannālāī bʰaeko prakas 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannālāī bʰaeko prakaš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannālāī bʰaeko prakās 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhannālāī bʰaeko prakāš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ਯੂਹੰਨਾ ਦੇ ਪਰਕਾਸ਼ ਦੀ ਪੋਥੀ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Openbaring van Johannes 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalipse de Sao Joao 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalipse de Sao João 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalipse de São Joao 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalipse de São João 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalisse di Giovanni 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjavenie Apostola Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjavenie Apostola Jána 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjavenie Apoštola Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjavenie Apoštola Jána 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("यूहन्नालाई भएको प्रकाश 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johannes Uppenbarelse 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjavenie svateho Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjavenie svateho Jána 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjavenie svatého Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjavenie svatého Jána 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjavenie sväteho Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjavenie sväteho Jána 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjavenie svätého Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjavenie svätého Jána 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("یو حنا عارف کا مکاشفہ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("یُوحنا عارف کا مکاشفہ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johanneksen ilmestys 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johannes' Abenbaring 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johannes' apenbaring 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johannes' Åbenbaring 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johannes' åpenbaring 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johannes’ Abenbaring 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johannes’ apenbaring 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johannes’ Åbenbaring 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johannes’ åpenbaring 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Opinberun Johannesar 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Opinberun Jóhannesar 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjeveni svateho Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjeveni svatého Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Откровението на Иоан 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Откровението на Йоан 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalipsa lui Ioan 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalipsis ni Juan 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalypsis Ioannis 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalipsa sw. Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalipsa św. Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalipsis ni Juan 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johannesapokalypsen 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Khải Huyền của John 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Objawienie sw. Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Objawienie św. Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalipse de Joao 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalipse de João 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalypse de Jean 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalipsa sw Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalipsa św Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johannes apokalyps 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Objawienie sw Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Objawienie św Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Otkrivenje Ivanovo 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Αποκάλυψις Ιωάννου 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Αποκάλυψις Ιωαννου 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Αποκαλυψις Ιωάννου 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Αποκαλυψις Ιωαννου 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Откривење Јованово 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Откровение на Иоан 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Откровение на Йоан 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Откровење Јованово 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ksiega Apokalipsy 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ksiega Objawienia 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ksiegi Apokalipsy 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ksiegi Objawienia 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Księga Apokalipsy 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Księga Objawienia 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Księgi Apokalipsy 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Księgi Objawienia 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Uppenbarelseboken 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Abenbaringsbogen 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apenbaringsboken 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johs. Abenbaring 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johs. Åbenbaring 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Opinberunarbokin 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Opinberunarbókin 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Pahayag kay Juan 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Prakashaitavakya 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ufunua wa Yohana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ufunuo wa Yohana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ufunuo wa Yohane 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("yūhãnā de prakāš 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Åbenbaringsbogen 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Åpenbaringsboken 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Janos jelenesei 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Janos jelenései 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johs Abenbaring 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Johs Åbenbaring 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("János jelenesei 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("János jelenései 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Objawienie Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Відкриття Івана 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("प्रकाशित-वाक्‍य 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("El Apocalipsis 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ks. Apokalipsy 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ks. Objawienia 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttina 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippatuttiṉa 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttina 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Velippaṭuttiṉa 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttina 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippatuttiṉa 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttina 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Veḷippaṭuttiṉa 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjeveni Janovo 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjevení Janovo 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("प्रकाशित वाक्य 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ਪਰਕਾਸ਼ ਦੀ ਪੋਥੀ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("திருவெளிப்பாடு 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Aabenbaringen 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ilmestyskirja 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Kniha Zjeveni 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Kniha Zjevení 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ks Apokalipsy 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ks Objawienia 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjavenie Jana 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjavenie Jána 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("प्रकाशितवाक्य 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Abenbaringen 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apenbaringen 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalipszis 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Openbaringen 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("prakatikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("prakatikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("prakatīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("prakatīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("prakaṭikaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("prakaṭikaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("prakaṭīkaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("prakaṭīkaraṇ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Åbenbaringen 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Åpenbaringen 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Апока́ліпсис 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalipsis 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalypsis 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalipsis 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalypsen 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Kitab Wahyu 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Offenbarung 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revalations 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revelations 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revolations 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Rivelazione 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Αποκαλυψεις 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Αποκαλύψεις 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Апокaліпсис 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Апокáліпсис 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Апокалiпсис 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Апокалíпсис 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Апокалипсис 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Апокаліпсис 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apenbaring 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalipsa 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalipse 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalisse 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalypse 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalipsa 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalypsa 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Datguddiad 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Khải Huyền 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Objawienie 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Openbaring 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Otkrivenje 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Rebelasyon 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revalation 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revelasyon 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revelation 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revlations 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revolation 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Об'явлення 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Об’явлення 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Откровение 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("חזון יוחנן 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("رؤيا يوحنا 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ﻳﻮﺣﻨﺎ ﺭﺅﻳﺎ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apocalyps 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apokalips 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Gipadayag 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Jelenesek 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Jelenések 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Muujintii 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Pamedaran 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revlation 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Αποκάλυψη 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Αποκαλυψη 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Откривење 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("प्रकटीकरण 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ilmestys 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Khải thị 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjavenie 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Одкриттє 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("الرؤيــا 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Datgudd 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Pahayag 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zbulesa 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjeveni 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjevení 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ההתגלות 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("مُکاشفہ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《若望默示錄》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ヨハネの默示録 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ヨハネの黙示録 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ufunuo 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("התגלות 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("مکاشفہ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("प्र. व 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("प्रकाश 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("วิวรณ์ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《若望默示錄 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("若望默示錄》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("요한 계시록 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("요한 묵시록 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Openb 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Revel 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Wahyu 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("प्र व 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《启示录》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《啓示錄》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《啟示錄》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《默示錄》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("若望默示錄 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("요한계시록 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("요한묵시록 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apoc 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Khải 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Muuj 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Offb 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjav 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Αποκ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Откр 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("திவெ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("வெளி 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《启示录 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《啓示錄 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《啟示錄 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《默示錄 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("启示录》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("啓示錄》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("啟示錄》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("默示錄》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apc 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apk 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Apo 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Dat 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ilm 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Jel 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Obj 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Opb 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Otk 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Pah 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Rev 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Riv 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ufu 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Upp 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zbu 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zjv 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Отк 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("᾿Απ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《启》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《啟》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("启示录 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("啓示錄 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("啟示錄 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("默示錄 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("黙示録 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Ap 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Op 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Rv 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Uf 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zb 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Zj 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Åb 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Åp 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Απ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("Об 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("رؤ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("วว 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《启 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《啟 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("启》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("啟》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("묵시 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("启 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("啟 1:1").osis()).toEqual("Rev.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ОТКРОВЕНИЕ НА СВ. ИОАНА БОГОСЛОВА 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("யோவானுக்கு வெளிப்படுத்தின விசேஷம் 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОТКРОВЕНИЕ НА СВ ИОАНА БОГОСЛОВА 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОБ'ЯВЛЕННЯ СВ. ІВАНА БОГОСЛОВА 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОБ'ЯВЛЕННЯ СВ. ИОАНА БОГОСЛОВА 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОБ'ЯВЛЕННЯ СВ. ЙОАНА БОГОСЛОВА 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОБ’ЯВЛЕННЯ СВ. ІВАНА БОГОСЛОВА 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОБ’ЯВЛЕННЯ СВ. ИОАНА БОГОСЛОВА 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОБ’ЯВЛЕННЯ СВ. ЙОАНА БОГОСЛОВА 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALA ǱʰALELE PRAKATIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALA ǱʰALELE PRAKATIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALA ǱʰALELE PRAKATĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALA ǱʰALELE PRAKATĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALA ǱʰALELE PRAKAṬIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALA ǱʰALELE PRAKAṬIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALA ǱʰALELE PRAKAṬĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALA ǱʰALELE PRAKAṬĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALA ǱʰĀLELE PRAKATIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALA ǱʰĀLELE PRAKATIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALA ǱʰĀLELE PRAKATĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALA ǱʰĀLELE PRAKATĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALA ǱʰĀLELE PRAKAṬIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALA ǱʰĀLELE PRAKAṬIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALA ǱʰĀLELE PRAKAṬĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALA ǱʰĀLELE PRAKAṬĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALĀ ǱʰALELE PRAKATIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALĀ ǱʰALELE PRAKATIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALĀ ǱʰALELE PRAKATĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALĀ ǱʰALELE PRAKATĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALĀ ǱʰALELE PRAKAṬIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALĀ ǱʰALELE PRAKAṬIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALĀ ǱʰALELE PRAKAṬĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALĀ ǱʰALELE PRAKAṬĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALĀ ǱʰĀLELE PRAKATIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALĀ ǱʰĀLELE PRAKATIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALĀ ǱʰĀLELE PRAKATĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALĀ ǱʰĀLELE PRAKATĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALĀ ǱʰĀLELE PRAKAṬIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALĀ ǱʰĀLELE PRAKAṬIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALĀ ǱʰĀLELE PRAKAṬĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANALĀ ǱʰĀLELE PRAKAṬĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLA ǱʰALELE PRAKATIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLA ǱʰALELE PRAKATIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLA ǱʰALELE PRAKATĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLA ǱʰALELE PRAKATĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLA ǱʰALELE PRAKAṬIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLA ǱʰALELE PRAKAṬIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLA ǱʰALELE PRAKAṬĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLA ǱʰALELE PRAKAṬĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLA ǱʰĀLELE PRAKATIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLA ǱʰĀLELE PRAKATIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLA ǱʰĀLELE PRAKATĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLA ǱʰĀLELE PRAKATĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLA ǱʰĀLELE PRAKAṬIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLA ǱʰĀLELE PRAKAṬIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLA ǱʰĀLELE PRAKAṬĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLA ǱʰĀLELE PRAKAṬĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLĀ ǱʰALELE PRAKATIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLĀ ǱʰALELE PRAKATIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLĀ ǱʰALELE PRAKATĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLĀ ǱʰALELE PRAKATĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLĀ ǱʰALELE PRAKAṬIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLĀ ǱʰALELE PRAKAṬIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLĀ ǱʰALELE PRAKAṬĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLĀ ǱʰALELE PRAKAṬĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLĀ ǱʰĀLELE PRAKATIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLĀ ǱʰĀLELE PRAKATIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLĀ ǱʰĀLELE PRAKATĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLĀ ǱʰĀLELE PRAKATĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLĀ ǱʰĀLELE PRAKAṬIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLĀ ǱʰĀLELE PRAKAṬIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLĀ ǱʰĀLELE PRAKAṬĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHANĀLĀ ǱʰĀLELE PRAKAṬĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALA ǱʰALELE PRAKATIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALA ǱʰALELE PRAKATIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALA ǱʰALELE PRAKATĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALA ǱʰALELE PRAKATĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALA ǱʰALELE PRAKAṬIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALA ǱʰALELE PRAKAṬIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALA ǱʰALELE PRAKAṬĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALA ǱʰALELE PRAKAṬĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALA ǱʰĀLELE PRAKATIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALA ǱʰĀLELE PRAKATIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALA ǱʰĀLELE PRAKATĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALA ǱʰĀLELE PRAKATĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALA ǱʰĀLELE PRAKAṬIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALA ǱʰĀLELE PRAKAṬIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALA ǱʰĀLELE PRAKAṬĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALA ǱʰĀLELE PRAKAṬĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALĀ ǱʰALELE PRAKATIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALĀ ǱʰALELE PRAKATIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALĀ ǱʰALELE PRAKATĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALĀ ǱʰALELE PRAKATĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALĀ ǱʰALELE PRAKAṬIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALĀ ǱʰALELE PRAKAṬIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALĀ ǱʰALELE PRAKAṬĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALĀ ǱʰALELE PRAKAṬĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALĀ ǱʰĀLELE PRAKATIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALĀ ǱʰĀLELE PRAKATIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALĀ ǱʰĀLELE PRAKATĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALĀ ǱʰĀLELE PRAKATĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALĀ ǱʰĀLELE PRAKAṬIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALĀ ǱʰĀLELE PRAKAṬIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALĀ ǱʰĀLELE PRAKAṬĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNALĀ ǱʰĀLELE PRAKAṬĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLA ǱʰALELE PRAKATIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLA ǱʰALELE PRAKATIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLA ǱʰALELE PRAKATĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLA ǱʰALELE PRAKATĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLA ǱʰALELE PRAKAṬIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLA ǱʰALELE PRAKAṬIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLA ǱʰALELE PRAKAṬĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLA ǱʰALELE PRAKAṬĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLA ǱʰĀLELE PRAKATIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLA ǱʰĀLELE PRAKATIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLA ǱʰĀLELE PRAKATĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLA ǱʰĀLELE PRAKATĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLA ǱʰĀLELE PRAKAṬIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLA ǱʰĀLELE PRAKAṬIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLA ǱʰĀLELE PRAKAṬĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLA ǱʰĀLELE PRAKAṬĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLĀ ǱʰALELE PRAKATIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLĀ ǱʰALELE PRAKATIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLĀ ǱʰALELE PRAKATĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLĀ ǱʰALELE PRAKATĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLĀ ǱʰALELE PRAKAṬIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLĀ ǱʰALELE PRAKAṬIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLĀ ǱʰALELE PRAKAṬĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLĀ ǱʰALELE PRAKAṬĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLĀ ǱʰĀLELE PRAKATIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLĀ ǱʰĀLELE PRAKATIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLĀ ǱʰĀLELE PRAKATĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLĀ ǱʰĀLELE PRAKATĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLĀ ǱʰĀLELE PRAKAṬIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLĀ ǱʰĀLELE PRAKAṬIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLĀ ǱʰĀLELE PRAKAṬĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YOHĀNĀLĀ ǱʰĀLELE PRAKAṬĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОБ'ЯВЛЕННЯ СВ ІВАНА БОГОСЛОВА 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОБ'ЯВЛЕННЯ СВ ИОАНА БОГОСЛОВА 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОБ'ЯВЛЕННЯ СВ ЙОАНА БОГОСЛОВА 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОБ’ЯВЛЕННЯ СВ ІВАНА БОГОСЛОВА 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОБ’ЯВЛЕННЯ СВ ИОАНА БОГОСЛОВА 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОБ’ЯВЛЕННЯ СВ ЙОАНА БОГОСЛОВА 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALYPSIS IOANNIS APOSTOLI 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OB'JAVLENNJA IVANA BOHOSLOVA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OB’JAVLENNJA IVANA BOHOSLOVA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ଯୋହନଙ୍କ ପ୍ରତି ପ୍ରକାଶିତ ବାକ୍ୟ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОБ'ЯВЛЕННЯ ІВАНА БОГОСЛОВА 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОБ’ЯВЛЕННЯ ІВАНА БОГОСЛОВА 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОДКРОВЕННЯ ІВАНА БОГОСЛОВА 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OPINBERUNARBOK JOHANNESAR 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OPINBERUNARBOK JÓHANNESAR 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OPINBERUNARBÓK JOHANNESAR 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OPINBERUNARBÓK JÓHANNESAR 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTINA VICETANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTINA VICETANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTINA VICETAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTINA VICETAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTINA VICEṬANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTINA VICEṬANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTINA VICEṬAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTINA VICEṬAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTINA VICĒTANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTINA VICĒTANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTINA VICĒTAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTINA VICĒTAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTINA VICĒṬANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTINA VICĒṬANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTINA VICĒṬAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTINA VICĒṬAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTIṈA VICETANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTIṈA VICETANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTIṈA VICETAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTIṈA VICETAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTIṈA VICEṬANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTIṈA VICEṬANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTIṈA VICEṬAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTIṈA VICEṬAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTIṈA VICĒTANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTIṈA VICĒTANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTIṈA VICĒTAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTIṈA VICĒTAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTIṈA VICĒṬANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTIṈA VICĒṬANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTIṈA VICĒṬAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTIṈA VICĒṬAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTINA VICETANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTINA VICETANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTINA VICETAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTINA VICETAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTINA VICEṬANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTINA VICEṬANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTINA VICEṬAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTINA VICEṬAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTINA VICĒTANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTINA VICĒTANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTINA VICĒTAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTINA VICĒTAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTINA VICĒṬANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTINA VICĒṬANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTINA VICĒṬAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTINA VICĒṬAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTIṈA VICETANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTIṈA VICETANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTIṈA VICETAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTIṈA VICETAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTIṈA VICEṬANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTIṈA VICEṬANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTIṈA VICEṬAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTIṈA VICEṬAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTIṈA VICĒTANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTIṈA VICĒTANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTIṈA VICĒTAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTIṈA VICĒTAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTIṈA VICĒṬANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTIṈA VICĒṬANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTIṈA VICĒṬAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTIṈA VICĒṬAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTINA VICETANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTINA VICETANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTINA VICETAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTINA VICETAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTINA VICEṬANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTINA VICEṬANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTINA VICEṬAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTINA VICEṬAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTINA VICĒTANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTINA VICĒTANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTINA VICĒTAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTINA VICĒTAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTINA VICĒṬANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTINA VICĒṬANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTINA VICĒṬAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTINA VICĒṬAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTIṈA VICETANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTIṈA VICETANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTIṈA VICETAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTIṈA VICETAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTIṈA VICEṬANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTIṈA VICEṬANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTIṈA VICEṬAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTIṈA VICEṬAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTIṈA VICĒTANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTIṈA VICĒTANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTIṈA VICĒTAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTIṈA VICĒTAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTIṈA VICĒṬANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTIṈA VICĒṬANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTIṈA VICĒṬAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTIṈA VICĒṬAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTINA VICETANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTINA VICETANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTINA VICETAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTINA VICETAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTINA VICEṬANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTINA VICEṬANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTINA VICEṬAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTINA VICEṬAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTINA VICĒTANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTINA VICĒTANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTINA VICĒTAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTINA VICĒTAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTINA VICĒṬANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTINA VICĒṬANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTINA VICĒṬAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTINA VICĒṬAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTIṈA VICETANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTIṈA VICETANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTIṈA VICETAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTIṈA VICETAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTIṈA VICEṬANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTIṈA VICEṬANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTIṈA VICEṬAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTIṈA VICEṬAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTIṈA VICĒTANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTIṈA VICĒTANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTIṈA VICĒTAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTIṈA VICĒTAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTIṈA VICĒṬANKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTIṈA VICĒṬANKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTIṈA VICĒṬAṄKAL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTIṈA VICĒṬAṄKAḶ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHÃNĀ DE PRAKĀŠ DĪ POTʰĪ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪḤANNĀ ʿĀRIF KĀ MUKĀŠAFÂ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("یُو حنّا عارِف کا مُکاشفہ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("योहानाला झालेले प्रकटीकरण 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("வெளிப்படுத்தின விசேடங்கள் 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALIPSA SWIETEGO JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALIPSA SWIĘTEGO JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALIPSA ŚWIETEGO JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALIPSA ŚWIĘTEGO JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNALAI BʰAEKO PRAKAS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNALAI BʰAEKO PRAKAŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNALAI BʰAEKO PRAKĀS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNALAI BʰAEKO PRAKĀŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNALAĪ BʰAEKO PRAKAS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNALAĪ BʰAEKO PRAKAŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNALAĪ BʰAEKO PRAKĀS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNALAĪ BʰAEKO PRAKĀŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNALĀI BʰAEKO PRAKAS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNALĀI BʰAEKO PRAKAŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNALĀI BʰAEKO PRAKĀS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNALĀI BʰAEKO PRAKĀŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNALĀĪ BʰAEKO PRAKAS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNALĀĪ BʰAEKO PRAKAŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNALĀĪ BʰAEKO PRAKĀS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNALĀĪ BʰAEKO PRAKĀŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNĀLAI BʰAEKO PRAKAS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNĀLAI BʰAEKO PRAKAŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNĀLAI BʰAEKO PRAKĀS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNĀLAI BʰAEKO PRAKĀŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNĀLAĪ BʰAEKO PRAKAS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNĀLAĪ BʰAEKO PRAKAŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNĀLAĪ BʰAEKO PRAKĀS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNĀLAĪ BʰAEKO PRAKĀŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNĀLĀI BʰAEKO PRAKAS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNĀLĀI BʰAEKO PRAKAŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNĀLĀI BʰAEKO PRAKĀS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNĀLĀI BʰAEKO PRAKĀŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNĀLĀĪ BʰAEKO PRAKAS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNĀLĀĪ BʰAEKO PRAKAŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNĀLĀĪ BʰAEKO PRAKĀS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YUHANNĀLĀĪ BʰAEKO PRAKĀŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNALAI BʰAEKO PRAKAS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNALAI BʰAEKO PRAKAŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNALAI BʰAEKO PRAKĀS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNALAI BʰAEKO PRAKĀŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNALAĪ BʰAEKO PRAKAS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNALAĪ BʰAEKO PRAKAŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNALAĪ BʰAEKO PRAKĀS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNALAĪ BʰAEKO PRAKĀŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNALĀI BʰAEKO PRAKAS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNALĀI BʰAEKO PRAKAŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNALĀI BʰAEKO PRAKĀS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNALĀI BʰAEKO PRAKĀŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNALĀĪ BʰAEKO PRAKAS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNALĀĪ BʰAEKO PRAKAŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNALĀĪ BʰAEKO PRAKĀS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNALĀĪ BʰAEKO PRAKĀŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNĀLAI BʰAEKO PRAKAS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNĀLAI BʰAEKO PRAKAŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNĀLAI BʰAEKO PRAKĀS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNĀLAI BʰAEKO PRAKĀŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNĀLAĪ BʰAEKO PRAKAS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNĀLAĪ BʰAEKO PRAKAŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNĀLAĪ BʰAEKO PRAKĀS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNĀLAĪ BʰAEKO PRAKĀŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNĀLĀI BʰAEKO PRAKAS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNĀLĀI BʰAEKO PRAKAŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNĀLĀI BʰAEKO PRAKĀS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNĀLĀI BʰAEKO PRAKĀŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNĀLĀĪ BʰAEKO PRAKAS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNĀLĀĪ BʰAEKO PRAKAŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNĀLĀĪ BʰAEKO PRAKĀS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHANNĀLĀĪ BʰAEKO PRAKĀŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ਯੂਹੰਨਾ ਦੇ ਪਰਕਾਸ਼ ਦੀ ਪੋਥੀ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OPENBARING VAN JOHANNES 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALIPSE DE SAO JOAO 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALIPSE DE SAO JOÃO 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALIPSE DE SÃO JOAO 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALIPSE DE SÃO JOÃO 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALISSE DI GIOVANNI 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJAVENIE APOSTOLA JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJAVENIE APOSTOLA JÁNA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJAVENIE APOŠTOLA JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJAVENIE APOŠTOLA JÁNA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("यूहन्नालाई भएको प्रकाश 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHANNES UPPENBARELSE 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJAVENIE SVATEHO JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJAVENIE SVATEHO JÁNA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJAVENIE SVATÉHO JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJAVENIE SVATÉHO JÁNA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJAVENIE SVÄTEHO JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJAVENIE SVÄTEHO JÁNA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJAVENIE SVÄTÉHO JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJAVENIE SVÄTÉHO JÁNA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("یو حنا عارف کا مکاشفہ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("یُوحنا عارف کا مکاشفہ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHANNEKSEN ILMESTYS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHANNES' ABENBARING 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHANNES' APENBARING 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHANNES' ÅBENBARING 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHANNES' ÅPENBARING 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHANNES’ ABENBARING 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHANNES’ APENBARING 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHANNES’ ÅBENBARING 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHANNES’ ÅPENBARING 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OPINBERUN JOHANNESAR 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OPINBERUN JÓHANNESAR 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJEVENI SVATEHO JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJEVENI SVATÉHO JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОТКРОВЕНИЕТО НА ИОАН 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОТКРОВЕНИЕТО НА ЙОАН 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALIPSA LUI IOAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALIPSIS NI JUAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALYPSIS IOANNIS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALIPSA SW. JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALIPSA ŚW. JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALIPSIS NI JUAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHANNESAPOKALYPSEN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KHẢI HUYỀN CỦA JOHN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OBJAWIENIE SW. JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OBJAWIENIE ŚW. JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALIPSE DE JOAO 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALIPSE DE JOÃO 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALYPSE DE JEAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALIPSA SW JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALIPSA ŚW JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHANNES APOKALYPS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OBJAWIENIE SW JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OBJAWIENIE ŚW JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OTKRIVENJE IVANOVO 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ΑΠΟΚΆΛΥΨΙΣ ΙΩΆΝΝΟΥ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ΑΠΟΚΆΛΥΨΙΣ ΙΩΑΝΝΟΥ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ΑΠΟΚΑΛΥΨΙΣ ΙΩΆΝΝΟΥ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ΑΠΟΚΑΛΥΨΙΣ ΙΩΑΝΝΟΥ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОТКРИВЕЊЕ ЈОВАНОВО 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОТКРОВЕНИЕ НА ИОАН 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОТКРОВЕНИЕ НА ЙОАН 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОТКРОВЕЊЕ ЈОВАНОВО 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KSIEGA APOKALIPSY 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KSIEGA OBJAWIENIA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KSIEGI APOKALIPSY 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KSIEGI OBJAWIENIA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KSIĘGA APOKALIPSY 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KSIĘGA OBJAWIENIA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KSIĘGI APOKALIPSY 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KSIĘGI OBJAWIENIA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("UPPENBARELSEBOKEN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ABENBARINGSBOGEN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APENBARINGSBOKEN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHS. ABENBARING 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHS. ÅBENBARING 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OPINBERUNARBOKIN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OPINBERUNARBÓKIN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("PAHAYAG KAY JUAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("PRAKASHAITAVAKYA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("UFUNUA WA YOHANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("UFUNUO WA YOHANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("UFUNUO WA YOHANE 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("YŪHÃNĀ DE PRAKĀŠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ÅBENBARINGSBOGEN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ÅPENBARINGSBOKEN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JANOS JELENESEI 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JANOS JELENÉSEI 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHS ABENBARING 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JOHS ÅBENBARING 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JÁNOS JELENESEI 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JÁNOS JELENÉSEI 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OBJAWIENIE JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ВІДКРИТТЯ ІВАНА 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("प्रकाशित-वाक्‍य 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("EL APOCALIPSIS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KS. APOKALIPSY 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KS. OBJAWIENIA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTINA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPATUTTIṈA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTINA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VELIPPAṬUTTIṈA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTINA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPATUTTIṈA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTINA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("VEḶIPPAṬUTTIṈA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJEVENI JANOVO 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJEVENÍ JANOVO 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("प्रकाशित वाक्य 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ਪਰਕਾਸ਼ ਦੀ ਪੋਥੀ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("திருவெளிப்பாடு 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("AABENBARINGEN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ILMESTYSKIRJA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KNIHA ZJEVENI 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KNIHA ZJEVENÍ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KS APOKALIPSY 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KS OBJAWIENIA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJAVENIE JANA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJAVENIE JÁNA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("प्रकाशितवाक्य 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ABENBARINGEN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APENBARINGEN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALIPSZIS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OPENBARINGEN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("PRAKATIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("PRAKATIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("PRAKATĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("PRAKATĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("PRAKAṬIKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("PRAKAṬIKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("PRAKAṬĪKARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("PRAKAṬĪKARAṆ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ÅBENBARINGEN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ÅPENBARINGEN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("АПОКА́ЛІПСИС 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALIPSIS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALYPSIS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALIPSIS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALYPSEN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KITAB WAHYU 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OFFENBARUNG 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVALATIONS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVELATIONS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVOLATIONS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("RIVELAZIONE 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ΑΠΟΚΑΛΥΨΕΙΣ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ΑΠΟΚΑΛΎΨΕΙΣ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("АПОКAЛІПСИС 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("АПОКÁЛІПСИС 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("АПОКАЛIПСИС 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("АПОКАЛÍПСИС 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("АПОКАЛИПСИС 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("АПОКАЛІПСИС 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APENBARING 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALIPSA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALIPSE 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALISSE 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALYPSE 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALIPSA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALYPSA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("DATGUDDIAD 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KHẢI HUYỀN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OBJAWIENIE 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OPENBARING 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OTKRIVENJE 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REBELASYON 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVALATION 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVELASYON 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVELATION 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVLATIONS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVOLATION 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОБ'ЯВЛЕННЯ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОБ’ЯВЛЕННЯ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОТКРОВЕНИЕ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("חזון יוחנן 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("رؤيا يوحنا 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ﻳﻮﺣﻨﺎ ﺭﺅﻳﺎ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOCALYPS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOKALIPS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("GIPADAYAG 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JELENESEK 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JELENÉSEK 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("MUUJINTII 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("PAMEDARAN 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVLATION 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ΑΠΟΚΆΛΥΨΗ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ΑΠΟΚΑΛΥΨΗ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОТКРИВЕЊЕ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("प्रकटीकरण 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ILMESTYS 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KHẢI THỊ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJAVENIE 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОДКРИТТЄ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("الرؤيــا 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("DATGUDD 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("PAHAYAG 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZBULESA 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJEVENI 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJEVENÍ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ההתגלות 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("مُکاشفہ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《若望默示錄》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ヨハネの默示録 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ヨハネの黙示録 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("UFUNUO 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("התגלות 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("مکاشفہ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("प्र. व 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("प्रकाश 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("วิวรณ์ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《若望默示錄 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("若望默示錄》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("요한 계시록 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("요한 묵시록 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OPENB 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REVEL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("WAHYU 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("प्र व 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《启示录》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《啓示錄》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《啟示錄》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《默示錄》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("若望默示錄 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("요한계시록 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("요한묵시록 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APOC 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("KHẢI 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("MUUJ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OFFB 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJAV 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ΑΠΟΚ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОТКР 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("திவெ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("வெளி 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《启示录 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《啓示錄 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《啟示錄 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《默示錄 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("启示录》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("啓示錄》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("啟示錄》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("默示錄》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APC 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APK 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("APO 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("DAT 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ILM 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("JEL 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OBJ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OPB 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OTK 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("PAH 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("REV 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("RIV 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("UFU 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("UPP 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZBU 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJV 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОТК 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("᾿ΑΠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《启》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《啟》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("启示录 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("啓示錄 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("啟示錄 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("默示錄 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("黙示録 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("AP 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("OP 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("RV 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("UF 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZB 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ZJ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ÅB 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ÅP 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ΑΠ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("ОБ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("رؤ 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("วว 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《启 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("《啟 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("启》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("啟》 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("묵시 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("启 1:1").osis()).toEqual("Rev.1.1")
		expect(p.parse("啟 1:1").osis()).toEqual("Rev.1.1")
		`
		true
describe "Localized book PrAzar (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: PrAzar (full)", ->
		`
		expect(p.parse("Ang Panalangin ni Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("The Prayers of Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("תפילת עזריה בתוך הכבשן 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Panalangin ni Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Rugaciunea lui Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Rugăciunea lui Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("The Prayer of Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("The Prayers of Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("The Prayer of Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azarjasova modlitba 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azarjašova modlitba 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azarjásova modlitba 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azarjášova modlitba 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("La Priere d'Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("La Priere d'Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("La Priere d’Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("La Priere d’Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("La Prière d'Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("La Prière d'Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("La Prière d’Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("La Prière d’Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Preghiera di Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Cantico de Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Cantico de Azarías 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Cántico de Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Cántico de Azarías 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Modlitwa Azariasza 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Modlitwą Azariasza 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Oracion de Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Oracion de Azarías 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Oración de Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Oración de Azarías 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Prayers of Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Prayer of Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Prayers of Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("The Pr of Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azarias imadsaga 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azarias imadsága 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azarias imádsaga 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azarias imádsága 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azariás imadsaga 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azariás imadsága 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azariás imádsaga 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azariás imádsága 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azárias imadsaga 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azárias imadsága 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azárias imádsaga 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azárias imádsága 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azáriás imadsaga 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azáriás imadsága 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azáriás imádsaga 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azáriás imádsága 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Gebed van Azarja 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Gebet des Asarja 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Prayer of Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Priere d'Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Priere d'Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Priere d’Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Priere d’Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Prière d'Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Prière d'Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Prière d’Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Prière d’Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Salmo de Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("The Pr of Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Προσευχή Αζαρίου 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Προσευχή Αζαριου 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Προσευχη Αζαρίου 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Προσευχη Αζαριου 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Piesn Azariasza 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Piesń Azariasza 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Pieśn Azariasza 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Pieśń Azariasza 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Asarjan rukous 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Gweddi Asarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Oratio Azariae 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Молитва Азария 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Молитва Азаріі 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Молитва Азарії 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azarias imaja 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azarias imája 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azariás imaja 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azariás imája 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azárias imaja 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azárias imája 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azáriás imaja 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azáriás imája 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Pr of Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Asarias’ bon 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Asarias’ bön 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Asarjas bønn 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Asarjas’ bon 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Asarjas’ bön 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Pr of Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Asarias bon 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Asarias bön 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Asarjas bon 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Asarjas bön 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azarjas Bøn 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azarjas bøn 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("תפילת עזריה 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Bæn Asarja 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("صلاة عزريا 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Or. Azar 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Pr. Azar 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Sal Azar 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("《PrAzar》 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Asar ru 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azariah 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azarias 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azarías 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Or Azar 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Pr Azar 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("PrAzar》 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Πρ Αζαρ 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("《PrAzar 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("アサルヤの祈り 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("アザルヤの祈り 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Azaria 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Geb As 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("PrAzar 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("அசரியா 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("Or Az 1:1").osis()).toEqual("PrAzar.1.1")
		expect(p.parse("PrAzr 1:1").osis()).toEqual("PrAzar.1.1")
		`
		true
describe "Localized book SgThree (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: SgThree (full)", ->
		`
		expect(p.parse("Kolmen nuoren miehen ollessa tulisessa patsissa 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Kolmen nuoren miehen ollessa tulisessa patsissä 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Kolmen nuoren miehen ollessa tulisessa pätsissa 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Kolmen nuoren miehen ollessa tulisessa pätsissä 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Lobgesang der drei jungen Manner im Feuerofen 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Lobgesang der drei jungen Männer im Feuerofen 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Der Gesang der Drei Manner im feurigen Ofen 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Der Gesang der Drei Männer im feurigen Ofen 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cantico dei tre giovani nella fornace 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Canto de los Tres Jovenes Hebreos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Canto de los Tres Jóvenes Hebreos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Himno de los Tres Jovenes Hebreos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Himno de los Tres Jóvenes Hebreos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Canto de los Tres Jovenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Canto de los Tres Jovenes Judíos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Canto de los Tres Jóvenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Canto de los Tres Jóvenes Judíos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Himno de los Tres Jovenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Himno de los Tres Jovenes Judíos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Himno de los Tres Jóvenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Himno de los Tres Jóvenes Judíos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the Three Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Gezang der drie mannen in het vuur 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Awit ng Tatlong Banal na Kabataan 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Canto de los Tres Jovenes Hebreos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Canto de los Tres Jóvenes Hebreos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Canto de los 3 Jovenes Hebreos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Canto de los 3 Jóvenes Hebreos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Himno de los 3 Jovenes Hebreos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Himno de los 3 Jóvenes Hebreos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Kolmen miehen kiitosvirsi tulessa 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Canto de los Tres Jovenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Canto de los Tres Jovenes Judíos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Canto de los Tres Jóvenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Canto de los Tres Jóvenes Judíos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Canto de los 3 Jovenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Canto de los 3 Jovenes Judíos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Canto de los 3 Jóvenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Canto de los 3 Jóvenes Judíos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Himno de los 3 Jovenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Himno de los 3 Jovenes Judíos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Himno de los 3 Jóvenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("El Himno de los 3 Jóvenes Judíos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Himno de los Tres Jovenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Himno de los Tres Jovenes Judíos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Himno de los Tres Jóvenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Himno de los Tres Jóvenes Judíos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Lobgesang der drei jungen Manner 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Lobgesang der drei jungen Männer 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Traja mladenci v rozpalenej peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Traja mladenci v rozpálenej peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Traja mládenci v rozpalenej peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Traja mládenci v rozpálenej peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Awit ng Tatlong Kabataang Banal 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piesen mladencov v ohnivej peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piesen mládencov v ohnivej peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pieseň mladencov v ohnivej peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pieseň mládencov v ohnivej peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the Three Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of Three Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the 3 Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the Three Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Canto de los 3 Jovenes Hebreos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Canto de los 3 Jóvenes Hebreos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Himno de los 3 Jovenes Hebreos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Himno de los 3 Jóvenes Hebreos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Благодарственная песнь отроков 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Canto de los 3 Jovenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Canto de los 3 Jovenes Judíos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Canto de los 3 Jóvenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Canto de los 3 Jóvenes Judíos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Himno de los 3 Jovenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Himno de los 3 Jovenes Judíos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Himno de los 3 Jóvenes Judios 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Himno de los 3 Jóvenes Judíos 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Lobgesang der 3 jungen Manner 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Lobgesang der 3 jungen Männer 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Lofsongur ungmennanna þriggja 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Lofsöngur ungmennanna þriggja 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Lied van de drie jongemannen 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mladencu v horici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mladencu v horicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mladencu v horíci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mladencu v horící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mladencu v hořici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mladencu v hořicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mladencu v hoříci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mladencu v hořící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mladenců v horici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mladenců v horicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mladenců v horíci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mladenců v horící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mladenců v hořici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mladenců v hořicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mladenců v hoříci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mladenců v hořící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mládencu v horici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mládencu v horicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mládencu v horíci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mládencu v horící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mládencu v hořici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mládencu v hořicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mládencu v hoříci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mládencu v hořící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mládenců v horici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mládenců v horicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mládenců v horíci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mládenců v horící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mládenců v hořici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mládenců v hořicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mládenců v hoříci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pisen mládenců v hořící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mladencu v horici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mladencu v horicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mladencu v horíci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mladencu v horící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mladencu v hořici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mladencu v hořicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mladencu v hoříci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mladencu v hořící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mladenců v horici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mladenců v horicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mladenců v horíci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mladenců v horící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mladenců v hořici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mladenců v hořicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mladenců v hoříci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mladenců v hořící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mládencu v horici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mládencu v horicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mládencu v horíci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mládencu v horící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mládencu v hořici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mládencu v hořicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mládencu v hoříci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mládencu v hořící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mládenců v horici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mládenců v horicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mládenců v horíci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mládenců v horící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mládenců v hořici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mládenců v hořicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mládenců v hoříci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piseň mládenců v hořící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mladencu v horici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mladencu v horicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mladencu v horíci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mladencu v horící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mladencu v hořici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mladencu v hořicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mladencu v hoříci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mladencu v hořící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mladenců v horici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mladenců v horicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mladenců v horíci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mladenců v horící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mladenců v hořici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mladenců v hořicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mladenců v hoříci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mladenců v hořící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mládencu v horici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mládencu v horicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mládencu v horíci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mládencu v horící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mládencu v hořici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mládencu v hořicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mládencu v hoříci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mládencu v hořící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mládenců v horici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mládenců v horicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mládenců v horíci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mládenců v horící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mládenců v hořici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mládenců v hořicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mládenců v hoříci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Písen mládenců v hořící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mladencu v horici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mladencu v horicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mladencu v horíci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mladencu v horící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mladencu v hořici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mladencu v hořicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mladencu v hoříci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mladencu v hořící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mladenců v horici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mladenců v horicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mladenců v horíci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mladenců v horící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mladenců v hořici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mladenců v hořicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mladenců v hoříci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mladenců v hořící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mládencu v horici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mládencu v horicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mládencu v horíci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mládencu v horící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mládencu v hořici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mládencu v hořicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mládencu v hoříci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mládencu v hořící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mládenců v horici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mládenců v horicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mládenců v horíci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mládenců v horící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mládenců v hořici peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mládenců v hořicí peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mládenců v hoříci peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Píseň mládenců v hořící peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the Three Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of Three Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the 3 Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the Three Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of 3 Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of Three Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the 3 Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Молитва святых трех отроков 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cantarea celor trei tineri 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cantique des Trois Enfants 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cântarea celor trei tineri 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("De tre mennenes sang føyer 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piesnia trzech młodziencow 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piesnia trzech młodzienców 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piesnia trzech młodzieńcow 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piesnia trzech młodzieńców 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piesnią trzech młodziencow 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piesnią trzech młodzienców 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piesnią trzech młodzieńcow 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piesnią trzech młodzieńców 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pieśnia trzech młodziencow 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pieśnia trzech młodzienców 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pieśnia trzech młodzieńcow 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pieśnia trzech młodzieńców 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pieśnią trzech młodziencow 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pieśnią trzech młodzienców 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pieśnią trzech młodzieńcow 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pieśnią trzech młodzieńców 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the Three Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cantarea celor trei evrei 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cantico dei tre fanciulli 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Canto de los Tres Jovenes 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Canto de los Tres Jóvenes 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cântarea celor trei evrei 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Himno de los Tres Jovenes 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Himno de los Tres Jóvenes 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Kolmen miehen kiitosvirsi 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Tri muzi v rozpalene peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Tri muzi v rozpalené peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Tri muzi v rozpálene peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Tri muzi v rozpálené peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Tri muži v rozpalene peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Tri muži v rozpalené peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Tri muži v rozpálene peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Tri muži v rozpálené peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Tři muzi v rozpalene peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Tři muzi v rozpalené peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Tři muzi v rozpálene peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Tři muzi v rozpálené peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Tři muži v rozpalene peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Tři muži v rozpalené peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Tři muži v rozpálene peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Tři muži v rozpálené peci 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Awit ng Tatlong Kabataan 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piesn trzech młodziencow 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piesn trzech młodzienców 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piesn trzech młodzieńcow 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piesn trzech młodzieńców 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piesń trzech młodziencow 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piesń trzech młodzienców 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piesń trzech młodzieńcow 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Piesń trzech młodzieńców 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pieśn trzech młodziencow 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pieśn trzech młodzienców 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pieśn trzech młodzieńcow 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pieśn trzech młodzieńców 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pieśń trzech młodziencow 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pieśń trzech młodzienców 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pieśń trzech młodzieńcow 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Pieśń trzech młodzieńców 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the Three Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of Three Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the 3 Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cantico dos Tres Jovens 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cantico dos Três Jovens 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cântico dos Tres Jovens 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cântico dos Três Jovens 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Harom fiatalember eneke 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Harom fiatalember éneke 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Három fiatalember eneke 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Három fiatalember éneke 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of 3 Holy Children 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of Three Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the 3 Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of 3 Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("שירת שלושת הנערים בכבשן 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Awit ng Tatlong Binata 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cantique des 3 Enfants 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Canto de los 3 Jovenes 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Canto de los 3 Jóvenes 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("De tre mannens lovsang 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("De tre mannens lovsång 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("De tre männens lovsang 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("De tre männens lovsång 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Himno de los 3 Jovenes 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Himno de los 3 Jóvenes 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the Three Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of Three Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of the 3 Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Wimbo wa Vijana Watatu 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Ύμνος των Τριων Παίδων 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Ύμνος των Τριων Παιδων 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Ύμνος των Τριών Παίδων 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Ύμνος των Τριών Παιδων 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Υμνος των Τριων Παίδων 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Υμνος των Τριων Παιδων 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Υμνος των Τριών Παίδων 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Υμνος των Τριών Παιδων 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("أنشودة الأطفال الثلاثة 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Hymnus trium puerorum 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cantico dos 3 Jovens 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cântico dos 3 Jovens 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("De Tre Mænds Lovsang 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("De tre mænds lovsang 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Kolmen nuoren miehen 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of Three Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the 3 Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of 3 Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("இளைஞர் மூவரின் பாடல் 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Der Gesang der Drei 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of 3 Young Men 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Пісня трьох отроків 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Awit ng 3 Kabataan 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of Three Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of the 3 Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("The Song of 3 Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Песнь трех отроков 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Песнь трёх отроков 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("De tre menns sang 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of 3 Youths 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Tatlong Kabataan 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Can y Tri Llanc 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cân y Tri Llanc 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Gesang der Drei 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Three. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Can y Tri Lanc 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Cân y Tri Lanc 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Three. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Three Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Three. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song of 3 Jews 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Kolmen miehen 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Three Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Three. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Three Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Three Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Three. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Th. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Tres Jovenes 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Tres Jóvenes 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Aw ng 3 Kab 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Three. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Th. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Three Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Three. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of 3. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Th Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Th. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Trei tineri 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Three Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Three. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of 3. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Th Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Th. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Three Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of 3 Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of 3. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of Th Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Song Three 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("3 Jovenes 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("3 Jóvenes 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Three Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of 3 Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of 3. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of Th Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Th. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. of 3 Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Sng Three 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("《SgThree》 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("3 tineri 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Th. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S of 3 Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. 3. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Th Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Th. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Sg Three 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("SgThree》 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("《SgThree 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("三人の若者の賛歌 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Ct 3 Jo 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Ct 3 Jó 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S 3. Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Th Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Th. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. 3 Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. 3. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. Th Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("SgThree 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Ct 3 E 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S 3 Ch 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S 3. Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S Th Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S. 3 Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("Sg Thr 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("S 3 Y 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("三童兒の歌 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("C3J 1:1").osis()).toEqual("SgThree.1.1")
		expect(p.parse("L3J 1:1").osis()).toEqual("SgThree.1.1")
		`
		true
describe "Localized book 2Pet (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Pet (full)", ->
		`
		expect(p.parse("2-ге. соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друга соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друге соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а. соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге. соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е. соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друга соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друге соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а. соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е. соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Второ съборно послание на св. ап. Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Второ съборно послание на св ап. Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Второ съборно послание на св. ап Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге. соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Второ съборно послание на св ап Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друга соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друге соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а. соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е. соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("பேதுரு எழுதிய இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Втора послание на апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Второ послание на апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("பேதுரு எழுதிய இரண்டாவது நிருபம் 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhe poslannja apostola Petra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге. послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. послание на апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друга послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друге послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("பேதுரு எழுதிய இரண்டாம் கடிதம் 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а. послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге. соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е. послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. послание на апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II послание на апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Втора писмо од апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Второ писмо од апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друга соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друге соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 послание на апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а. соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е. соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("אגרתו השנייה של פטרוס השליח 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. писмо од апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Siðara almenna bref Peturs 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Siðara almenna bref Péturs 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Siðara almenna bréf Peturs 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Siðara almenna bréf Péturs 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Síðara almenna bref Peturs 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Síðara almenna bref Péturs 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Síðara almenna bréf Peturs 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Síðara almenna bréf Péturs 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. писмо од апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II писмо од апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Seconda lettera di Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("رسالة القديس بطرس الثانية 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("பேதுரு இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 писмо од апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga Petrova Poslanica 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga Petrova poslanica 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Waraka wa Pili wa Petro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("paṭras kā dūsrā ʿām ḫaṭ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Второ послание на Петър 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друга посланица Петрова 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Barua ya Pili ya Petro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("पत्रुसको दोस्त्रो पत्र 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga List sw. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga List św. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Drugi List sw. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Drugi List św. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petrova Poslanica 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. посланица Петрова 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Toinen Pietarin kirje 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("patras dī dūjī pattrī 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("patrusko dostro patra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге. послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petrova Poslanica 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. посланица Петрова 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga List sw Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga List św Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Drugi List sw Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Drugi List św Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petrova Poslanica 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II посланица Петрова 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("petracem dusre patra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("petraceṃ dusre patra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("petrācem dusre patra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("petrāceṃ dusre patra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друга послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друге послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("پطرس کا دوسرا عام خط 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("पत्रुसको दोस्रो पत्र 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("पेत्राचें दुसरे पत्र 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ପିତରଙ୍କ ଦ୍ୱିତୀୟ ପତ୍ର 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petrova Poslanica 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 посланица Петрова 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а. послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е. послание Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е. послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-я. послание Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. List sw. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. List św. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ਪਤਰਸ ਦੀ ਦੂਜੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е послание Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-я послание Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. List sw. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. List św. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2е. послание Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2я. послание Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Andra Petrusbrevet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha kniha Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhá kniha Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II List sw. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II List św. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. List sw Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. List św Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pietarin kirje 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("איגרת פטרוס השנייה 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("رسالة بطرس الثانية 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("पौलाचें दुसरे पत्र 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 List sw. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 List św. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. List sw Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. List św Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pietarin kirje 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. послание Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2е послание Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2я послание Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga List Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Drugi List Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha list Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha list Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy Petrov list 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy list Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy list Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy list Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhá list Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhá list Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhý Petrov list 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhý list Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhý list Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhý list Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Epistula II Petri 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Epistula Petri II 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II List sw Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II List św Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pietarin kirje 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peters Andet Brev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peters andre brev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Petrus andra brev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Segundo San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Siðara Petursbref 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Siðara Petursbréf 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Siðara Pétursbref 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Siðara Pétursbréf 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Síðara Petursbref 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Síðara Petursbréf 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Síðara Pétursbref 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Síðara Pétursbréf 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 List sw Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 List św Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pietarin kirje 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 послание Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Anden Petersbrev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Andet Petersbrev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Andre Petersbrev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Deuxiemes Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Deuxièmes Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petrusbrevet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Deuxieme Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Deuxième Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. List Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. list Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. list Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Ikalawang Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Toinen Pietarin 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petrusbrevet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. List Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. list Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. list Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.o. San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.º. San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II List Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II list Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II list Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Seconda Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Secondo Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 List Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 list Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 list Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге. Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petersbrev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.o San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.º San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2o. San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2º. San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Butros Labaad 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhá Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhý Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Masodik Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Masodik Péter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Második Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Második Péter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Segunda Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Segundo Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Tweede Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Zweite Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Втора Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Второ Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друга Петрова 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друга Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друге Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ପିତରଙ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petersbrev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 e. Pjetrit 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 i. Pjetrit 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а. Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е. Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2eme. Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2o San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2º San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ème. Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Andre Peters 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Drugi Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhá Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhá Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhá Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhý Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhý Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhý Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Phi-e-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pietarin 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("بطرس الثانية 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("رسالة بطرس 2 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 e Pjetrit 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 i Pjetrit 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 k. Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 पेत्राचें 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 இராயப்பர் 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге. Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е. Петира 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-я. Петира 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Phi-e-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pietarin 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. patrusko 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. पत्रुसको 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2de. Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2eme Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ème Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Anden Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Andre Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga Piotr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Drugi Piotr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Phi-e-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pietarin 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Phia-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Петрова 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Masodik Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Masodik Pét 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Második Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Második Pét 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Tweede Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Втора Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Втора Петър 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Второ Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друга Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друге Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Phi-e-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pietarin 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 k Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 patrusko 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 petracem 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 petraceṃ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 petrācem 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 petrāceṃ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 पत्रुसको 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а. Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е Петира 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е. Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-я Петира 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-я. Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pataras 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Phia-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pjetrit 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Петрова 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.o. Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.º. Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2d. Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2de Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e. Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e. Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2°. Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2е. Петира 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2я. Петира 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Dezyem Pie 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Dezyem Piè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Dezyem Pye 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Dezyem Pyè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Dezyèm Pie 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Dezyèm Piè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Dezyèm Pye 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Dezyèm Pyè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhá Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhý Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Phia-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Петрова 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Butros 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Phi-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Phê-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pétrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pili Petro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Tweede Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Втора Петр 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("베드로의 둘째 서간 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pataras 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Phia-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pjetrit 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Петрова 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-я Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Butros 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Peters 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Phi-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Phê-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pétrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Петира 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. पत्रुस 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.o Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.º Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2a. Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2d Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2o. Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2° Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2º. Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2е Петира 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2е. Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2я Петира 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2я. Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Anden Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Andre Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Butros 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Phi-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Phê-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pétrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petri 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petru 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Phêrô 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Piotr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Péter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Петър 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' Πέτρου 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' Πετρου 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πέτρου 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πετρου 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πέτρου 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πετρου 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ Πέτρου 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ Πετρου 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ Πέτρου 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ Πετρου 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Πέτρου Β' 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Πέτρου Βʹ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Πέτρου Βʹ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Πέτρου Β΄ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Πέτρου Β’ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Πετρου Β' 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Πετρου Βʹ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Πετρου Βʹ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Πετρου Β΄ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Πετρου Β’ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Втора Пет 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("دوم پطر س 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ヘテロの第二の手紙 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ヘトロの第二の手紙 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ペテロの第二の手紙 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ペトロの第二の手紙 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Butros 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Peters 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Peturu 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Phi-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Phê-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pétrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pēturu 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 patras 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Петира 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 पत्रुस 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 பேதுரு 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petri 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petru 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Phêrô 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Piotr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Péter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Петър 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. پطر س 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. ପିତରଙ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. เปโตร 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2a Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e. Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2o Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2º Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2е Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2я Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhá Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhý Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petri 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petru 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Phêrô 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Piotr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Péter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Петър 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pedr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Phia 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Петр 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Petri II 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Petro II 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pili Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("دوم پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("دوم-پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("دوم۔پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petri 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petru 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Phêrô 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Piotr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Péter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Петър 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 پطر س 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 पेत्र 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ପିତରଙ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 เปโตร 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pedr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Phia 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Петр 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. पतरस 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.-پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.۔پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e. Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhá P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhý P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pedr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Phia 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Петр 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. But 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pie 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Piè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pye 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pyè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pét 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Пет 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' Πέτρ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' Πετρ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πέτρ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πετρ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πέτρ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πετρ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ Πέτρ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ Πετρ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ Πέτρ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ Πετρ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("۲ پطر س 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《伯多祿後書》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ヘテロの後の書 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ヘトロの手紙二 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ペテロの後の書 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ペトロの手紙二 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pedr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Phia 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Piet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Петр 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 पतरस 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ਪਤਰਸ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 பேது 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. But 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pie 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Piè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pye 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pyè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pét 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Пет 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. पतर 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2۔پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II But 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pie 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Piè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pye 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pyè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pét 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Пет 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' Πέτ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' Πετ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πέτ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πετ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πέτ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πετ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ Πέτ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ Πετ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ Πέτ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ Πετ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("۲ پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("۲-پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("۲۔پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《伯多祿後書 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼得后书》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼得後書》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《撇特爾後》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("伯多祿後書》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 But 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Ped 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pie 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Piè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pje 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pye 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pyè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pét 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Пет 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 पतर 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' Πέ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' Πε 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πέ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πε 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πέ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πε 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ Πέ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ Πε 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ Πέ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ Πε 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼得后书 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼得後書 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《撇特爾後 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ヘトロ 2 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ペトロ 2 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("伯多祿後書 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼得后书》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼得後書》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("撇特爾後》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("베드로2서 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("베드로후서 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pd 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pi 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pj 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 بط 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ปต 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼后》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼後》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("二ヘトロ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("二ペトロ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼得后书 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼得後書 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("撇特爾後 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2بط 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2베드 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼后 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼後 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼后》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼後》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼后 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼後 1:1").osis()).toEqual("2Pet.1.1")
		`
		true
	it "should handle non-Latin digits in book: 2Pet (full)", ->
		p.set_options non_latin_digits_strategy: "replace"
		`
		expect(p.parse("2-ге. соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друга соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друге соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а. соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге. соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е. соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друга соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друге соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а. соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е. соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Второ съборно послание на св. ап. Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Второ съборно послание на св ап. Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Второ съборно послание на св. ап Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 соборне послання св. апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге. соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Второ съборно послание на св ап Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друга соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друге соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 соборне послання св апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а. соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е. соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 соборне послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peturu Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pēturu Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("பேதுரு எழுதிய இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Втора послание на апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Второ послание на апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("பேதுரு எழுதிய இரண்டாவது நிருபம் 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhe poslannja apostola Petra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге. послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. послание на апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друга послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друге послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("பேதுரு எழுதிய இரண்டாம் கடிதம் 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а. послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге. соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е. послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. послание на апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II послание на апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Втора писмо од апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Второ писмо од апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друга соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друге соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 послание на апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а. соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е. соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("אגרתו השנייה של פטרוס השליח 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. писмо од апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Siðara almenna bref Peturs 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Siðara almenna bref Péturs 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Siðara almenna bréf Peturs 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Siðara almenna bréf Péturs 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Síðara almenna bref Peturs 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Síðara almenna bref Péturs 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Síðara almenna bréf Peturs 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Síðara almenna bréf Péturs 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 послання апостола Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. писмо од апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II писмо од апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Seconda lettera di Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("رسالة القديس بطرس الثانية 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("பேதுரு இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 писмо од апостол Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 соборне послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga Petrova Poslanica 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga Petrova poslanica 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Waraka wa Pili wa Petro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("paṭras kā dūsrā ʿām ḫaṭ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Второ послание на Петър 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друга посланица Петрова 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Barua ya Pili ya Petro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("पत्रुसको दोस्त्रो पत्र 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga List sw. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga List św. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Drugi List sw. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Drugi List św. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petrova Poslanica 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. посланица Петрова 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Toinen Pietarin kirje 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("patras dī dūjī pattrī 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("patrusko dostro patra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге. послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petrova Poslanica 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. посланица Петрова 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga List sw Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga List św Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Drugi List sw Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Drugi List św Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petrova Poslanica 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II посланица Петрова 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("petracem dusre patra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("petraceṃ dusre patra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("petrācem dusre patra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("petrāceṃ dusre patra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друга послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друге послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("پطرس کا دوسرا عام خط 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("पत्रुसको दोस्रो पत्र 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("पेत्राचें दुसरे पत्र 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ପିତରଙ୍କ ଦ୍ୱିତୀୟ ପତ୍ର 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petrova Poslanica 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 посланица Петрова 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а. послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е. послание Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е. послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-я. послание Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. List sw. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. List św. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ਪਤਰਸ ਦੀ ਦੂਜੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е послание Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-я послание Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. List sw. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. List św. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2е. послание Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2я. послание Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Andra Petrusbrevet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha kniha Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhá kniha Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II List sw. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II List św. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. List sw Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. List św Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pietarin kirje 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("איגרת פטרוס השנייה 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("رسالة بطرس الثانية 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("पौलाचें दुसरे पत्र 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 List sw. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 List św. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. List sw Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. List św Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pietarin kirje 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. послание Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2е послание Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2я послание Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga List Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Drugi List Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha list Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha list Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy Petrov list 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy list Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy list Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy list Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhá list Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhá list Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhý Petrov list 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhý list Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhý list Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhý list Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Epistula II Petri 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Epistula Petri II 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II List sw Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II List św Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pietarin kirje 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peters Andet Brev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Peters andre brev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Petrus andra brev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Segundo San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Siðara Petursbref 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Siðara Petursbréf 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Siðara Pétursbref 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Siðara Pétursbréf 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Síðara Petursbref 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Síðara Petursbréf 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Síðara Pétursbref 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Síðara Pétursbréf 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 List sw Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 List św Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pietarin kirje 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 послание Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 послання Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Anden Petersbrev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Andet Petersbrev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Andre Petersbrev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Deuxiemes Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Deuxièmes Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petrusbrevet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Deuxieme Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Deuxième Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. List Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. list Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. list Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Ikalawang Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Toinen Pietarin 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petrusbrevet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. List Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. list Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. list Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.o. San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.º. San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II List Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II list Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II list Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Seconda Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Secondo Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 List Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 list Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 list Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге. Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petersbrev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.o San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.º San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2o. San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2º. San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Butros Labaad 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhá Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhý Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Masodik Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Masodik Péter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Második Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Második Péter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Segunda Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Segundo Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Tweede Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Zweite Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Втора Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Второ Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друга Петрова 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друга Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друге Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ପିତରଙ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petersbrev 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 e. Pjetrit 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 i. Pjetrit 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а. Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е. Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2eme. Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2o San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2º San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ème. Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Andre Peters 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Drugi Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhá Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhá Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhá Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhý Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhý Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhý Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Phi-e-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pietarin 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("بطرس الثانية 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("رسالة بطرس 2 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 San Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 e Pjetrit 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 i Pjetrit 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 k. Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 पेत्राचें 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 இராயப்பர் 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге. Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е. Петира 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-я. Петира 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Phi-e-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pietarin 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. patrusko 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. पत्रुसको 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2de. Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2eme Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ème Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Anden Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Andre Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druga Piotr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Drugi Piotr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Phi-e-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pietarin 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Phia-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Петрова 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Masodik Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Masodik Pét 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Második Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Második Pét 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Tweede Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Втора Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Втора Петър 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Второ Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друга Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Друге Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Phi-e-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pietarin 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 k Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 patrusko 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 petracem 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 petraceṃ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 petrācem 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 petrāceṃ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 पत्रुसको 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а. Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ге Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е Петира 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е. Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-я Петира 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-я. Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pataras 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Phia-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pjetrit 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Петрова 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.o. Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.º. Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2d. Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2de Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e. Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e. Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2°. Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2е. Петира 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2я. Петира 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Dezyem Pie 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Dezyem Piè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Dezyem Pye 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Dezyem Pyè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Dezyèm Pie 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Dezyèm Piè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Dezyèm Pye 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Dezyèm Pyè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhá Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhý Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Phia-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Петрова 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Butros 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Phi-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Phê-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pétrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pili Petro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Tweede Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Втора Петр 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("베드로의 둘째 서간 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pataras 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petrova 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Phia-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pjetrit 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Петрова 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Петрово 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-а Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-е Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-я Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Butros 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Peters 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Phi-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Phê-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pétrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Петира 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. पत्रुस 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.o Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.º Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2a. Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2d Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2o. Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2° Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2º. Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2е Петира 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2е. Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2я Петира 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2я. Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Anden Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Andre Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Butros 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Phi-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Phê-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pétrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petri 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petru 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Phêrô 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Piotr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Péter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Петър 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' Πέτρου 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' Πετρου 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πέτρου 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πετρου 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πέτρου 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πετρου 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ Πέτρου 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ Πετρου 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ Πέτρου 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ Πετρου 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Πέτρου Β' 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Πέτρου Βʹ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Πέτρου Βʹ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Πέτρου Β΄ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Πέτρου Β’ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Πετρου Β' 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Πετρου Βʹ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Πετρου Βʹ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Πετρου Β΄ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Πετρου Β’ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Втора Пет 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("دوم پطر س 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ヘテロの第二の手紙 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ヘトロの第二の手紙 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ペテロの第二の手紙 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ペトロの第二の手紙 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Butros 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Peters 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petrov 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petruv 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petrův 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Peturu 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Phi-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Phê-rơ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pierre 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pietro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Piotra 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pétrus 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pēturu 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 patras 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Петира 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 पत्रुस 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 பேதுரு 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petri 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petru 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Phêrô 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Piotr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Péter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Петър 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. پطر س 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. ପିତରଙ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. เปโตร 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2a Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e. Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2o Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2º Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2е Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2я Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhá Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhý Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petri 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petru 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Phêrô 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Piotr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Péter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Петър 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pedr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Phia 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Петр 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Petri II 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Petro II 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Pili Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Second P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("دوم پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("دوم-پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("دوم۔پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pedro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Peter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petri 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petro 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petru 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Phêrô 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Piotr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Péter 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Петар 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Петра 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Петър 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 پطر س 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 पेत्र 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ପିତରଙ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 เปโตร 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pedr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Phia 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Петр 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. पतरस 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.-پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.۔پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e. Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druha P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhy P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhá P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Druhý P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pedr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Phia 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Петр 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. But 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pie 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Piè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pye 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pyè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pét 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Пет 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' Πέτρ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' Πετρ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πέτρ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πετρ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πέτρ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πετρ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ Πέτρ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ Πετρ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ Πέτρ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ Πετρ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("۲ پطر س 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《伯多祿後書》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ヘテロの後の書 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ヘトロの手紙二 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ペテロの後の書 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ペトロの手紙二 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pedr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pete 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Petr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Phia 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Piet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Петр 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 पतरस 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ਪਤਰਸ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 பேது 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. But 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pie 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Piè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pye 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pyè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pét 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Пет 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. पतर 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2e Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd. P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2۔پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II But 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pie 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Piè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pye 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pyè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pét 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Пет 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' Πέτ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' Πετ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πέτ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πετ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πέτ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πετ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ Πέτ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ Πετ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ Πέτ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ Πετ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("۲ پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("۲-پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("۲۔پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《伯多祿後書 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼得后书》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼得後書》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《撇特爾後》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("伯多祿後書》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 But 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Ped 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Per 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pie 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Piè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pje 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Ptr 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pye 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pyè 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pét 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Пет 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 पतर 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2nd P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' Πέ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' Πε 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πέ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πε 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πέ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ Πε 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ Πέ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ Πε 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ Πέ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ Πε 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼得后书 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼得後書 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《撇特爾後 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ヘトロ 2 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ペトロ 2 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("伯多祿後書 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼得后书》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼得後書》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("撇特爾後》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("베드로2서 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("베드로후서 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pd 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pe 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pi 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pj 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 Pt 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 بط 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ปต 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2Pet 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼后》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼後》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("二ヘトロ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("二ペトロ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼得后书 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼得後書 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("撇特爾後 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2بط 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2베드 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼后 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼後 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼后》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼後》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼后 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼後 1:1").osis()).toEqual("2Pet.1.1")
		p.include_apocrypha(false)
		expect(p.parse("2-ГЕ. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ДРУГА СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ДРУГЕ СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-А. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ГЕ СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ГЕ. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Е. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ДРУГА СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ДРУГЕ СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-А СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-А. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ГЕ СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Е СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Е. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ВТОРО СЪБОРНО ПОСЛАНИЕ НА СВ. АП. ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-А СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Е СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ВТОРО СЪБОРНО ПОСЛАНИЕ НА СВ АП. ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ВТОРО СЪБОРНО ПОСЛАНИЕ НА СВ. АП ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ГЕ. СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ВТОРО СЪБОРНО ПОСЛАНИЕ НА СВ АП ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ДРУГА СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ДРУГЕ СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-А. СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ГЕ СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Е. СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-А СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Е СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETURU ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETURU ELUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETURU ELUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETURU ELUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETURU ELUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETURU ELUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETURU ELUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETURU ELUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETURU EḺUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETURU EḺUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETURU EḺUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETURU EḺUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETURU EḺUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETURU EḺUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETURU EḺUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETURU EḺUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PĒTURU ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PĒTURU ELUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PĒTURU ELUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PĒTURU ELUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PĒTURU ELUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PĒTURU ELUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PĒTURU ELUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PĒTURU ELUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PĒTURU EḺUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PĒTURU EḺUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PĒTURU EḺUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PĒTURU EḺUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PĒTURU EḺUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PĒTURU EḺUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PĒTURU EḺUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PĒTURU EḺUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("பேதுரு எழுதிய இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ВТОРА ПОСЛАНИЕ НА АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ВТОРО ПОСЛАНИЕ НА АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("பேதுரு எழுதிய இரண்டாவது நிருபம் 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHE POSLANNJA APOSTOLA PETRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ГЕ. ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. ПОСЛАНИЕ НА АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ДРУГА ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ДРУГЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("பேதுரு எழுதிய இரண்டாம் கடிதம் 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-А. ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ГЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ГЕ. СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Е. ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. ПОСЛАНИЕ НА АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II ПОСЛАНИЕ НА АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ВТОРА ПИСМО ОД АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ВТОРО ПИСМО ОД АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ДРУГА СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ДРУГЕ СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ПОСЛАНИЕ НА АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-А ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-А. СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ГЕ СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Е ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Е. СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("אגרתו השנייה של פטרוס השליח 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-А СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Е СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. ПИСМО ОД АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SIÐARA ALMENNA BREF PETURS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SIÐARA ALMENNA BREF PÉTURS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SIÐARA ALMENNA BRÉF PETURS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SIÐARA ALMENNA BRÉF PÉTURS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SÍÐARA ALMENNA BREF PETURS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SÍÐARA ALMENNA BREF PÉTURS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SÍÐARA ALMENNA BRÉF PETURS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SÍÐARA ALMENNA BRÉF PÉTURS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. ПИСМО ОД АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II ПИСМО ОД АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECONDA LETTERA DI PIETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("رسالة القديس بطرس الثانية 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("பேதுரு இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ПИСМО ОД АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGA PETROVA POSLANICA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGA PETROVA POSLANICA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("WARAKA WA PILI WA PETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PAṬRAS KĀ DŪSRĀ ʿĀM ḪAṬ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ВТОРО ПОСЛАНИЕ НА ПЕТЪР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ДРУГА ПОСЛАНИЦА ПЕТРОВА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("BARUA YA PILI YA PETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("पत्रुसको दोस्त्रो पत्र 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGA LIST SW. PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGA LIST ŚW. PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGI LIST SW. PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGI LIST ŚW. PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETROVA POSLANICA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. ПОСЛАНИЦА ПЕТРОВА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("TOINEN PIETARIN KIRJE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PATRAS DĪ DŪJĪ PATTRĪ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PATRUSKO DOSTRO PATRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ГЕ. ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETROVA POSLANICA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. ПОСЛАНИЦА ПЕТРОВА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGA LIST SW PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGA LIST ŚW PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGI LIST SW PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGI LIST ŚW PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETROVA POSLANICA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II ПОСЛАНИЦА ПЕТРОВА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETRACEM DUSRE PATRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETRACEṂ DUSRE PATRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETRĀCEM DUSRE PATRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETRĀCEṂ DUSRE PATRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ДРУГА ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ДРУГЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("پطرس کا دوسرا عام خط 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("पत्रुसको दोस्रो पत्र 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("पेत्राचें दुसरे पत्र 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ପିତରଙ୍କ ଦ୍ୱିତୀୟ ପତ୍ର 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETROVA POSLANICA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ПОСЛАНИЦА ПЕТРОВА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-А. ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ГЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Е. ПОСЛАНИЕ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Е. ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Я. ПОСЛАНИЕ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. LIST SW. PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. LIST ŚW. PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ਪਤਰਸ ਦੀ ਦੂਜੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-А ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Е ПОСЛАНИЕ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Е ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Я ПОСЛАНИЕ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. LIST SW. PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. LIST ŚW. PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2Е. ПОСЛАНИЕ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2Я. ПОСЛАНИЕ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ANDRA PETRUSBREVET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHA KNIHA PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHÁ KNIHA PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II LIST SW. PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II LIST ŚW. PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. LIST SW PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. LIST ŚW PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PIETARIN KIRJE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("איגרת פטרוס השנייה 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("رسالة بطرس الثانية 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("पौलाचें दुसरे पत्र 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 LIST SW. PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 LIST ŚW. PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. LIST SW PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. LIST ŚW PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PIETARIN KIRJE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. ПОСЛАНИЕ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2Е ПОСЛАНИЕ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2Я ПОСЛАНИЕ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGA LIST PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGI LIST PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHA LIST PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHA LIST PETRŮV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHY PETROV LIST 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHY LIST PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHY LIST PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHY LIST PETRŮV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHÁ LIST PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHÁ LIST PETRŮV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHÝ PETROV LIST 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHÝ LIST PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHÝ LIST PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHÝ LIST PETRŮV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("EPISTULA II PETRI 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("EPISTULA PETRI II 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II LIST SW PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II LIST ŚW PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PIETARIN KIRJE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETERS ANDET BREV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETERS ANDRE BREV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETRUS ANDRA BREV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SEGUNDO SAN PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SIÐARA PETURSBREF 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SIÐARA PETURSBRÉF 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SIÐARA PÉTURSBREF 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SIÐARA PÉTURSBRÉF 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SÍÐARA PETURSBREF 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SÍÐARA PETURSBRÉF 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SÍÐARA PÉTURSBREF 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SÍÐARA PÉTURSBRÉF 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 LIST SW PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 LIST ŚW PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PIETARIN KIRJE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ПОСЛАНИЕ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ANDEN PETERSBREV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ANDET PETERSBREV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ANDRE PETERSBREV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DEUXIEMES PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DEUXIÈMES PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETRUSBREVET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DEUXIEME PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DEUXIÈME PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. LIST PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. LIST PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. LIST PETRŮV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("IKALAWANG PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("TOINEN PIETARIN 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETRUSBREVET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. LIST PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. LIST PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. LIST PETRŮV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.O. SAN PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.º. SAN PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II LIST PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II LIST PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II LIST PETRŮV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECONDA PIETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECONDO PIETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 LIST PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 LIST PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 LIST PETRŮV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ГЕ. ПЕТРОВО 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETERSBREV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.O SAN PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.º SAN PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2O. SAN PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2º. SAN PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("BUTROS LABAAD 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGA PETROVA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHA PETROVA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHY PETROVA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHÁ PETROVA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHÝ PETROVA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. SAN PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("MASODIK PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("MASODIK PÉTER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("MÁSODIK PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("MÁSODIK PÉTER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SEGUNDA PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SEGUNDO PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("TWEEDE PETRUS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ZWEITE PETRUS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ВТОРА ПЕТРОВО 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ВТОРО ПЕТРОВО 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ДРУГА ПЕТРОВА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ДРУГА ПЕТРОВО 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ДРУГЕ ПЕТРОВО 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ପିତରଙ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETERSBREV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 E. PJETRIT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 I. PJETRIT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-А. ПЕТРОВО 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ГЕ ПЕТРОВО 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Е. ПЕТРОВО 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. SAN PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2EME. PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2O SAN PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2º SAN PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ÈME. PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ANDRE PETERS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGA PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGI PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHA PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHA PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHA PETRŮV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHY PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHY PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHY PETRŮV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHÁ PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHÁ PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHÁ PETRŮV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHÝ PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHÝ PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHÝ PETRŮV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II SAN PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PHI-E-RƠ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PIETARIN 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("بطرس الثانية 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("رسالة بطرس 2 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 SAN PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 E PJETRIT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 I PJETRIT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 K. PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 पेत्राचें 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 இராயப்பர் 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-А ПЕТРОВО 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ГЕ. ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Е ПЕТРОВО 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Е. ПЕТИРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Я. ПЕТИРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PHI-E-RƠ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PIETARIN 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PATRUSKO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. पत्रुसको 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2DE. PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2EME PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ÈME PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ANDEN PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ANDRE PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGA PIOTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUGI PIOTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PHI-E-RƠ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PIETARIN 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETROVA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PHIA-RƠ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. ПЕТРОВА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. ПЕТРОВО 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("MASODIK PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("MASODIK PÉT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("MÁSODIK PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("MÁSODIK PÉT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PETE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("TWEEDE PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ВТОРА ПЕТАР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ВТОРА ПЕТЪР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ВТОРО ПЕТАР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ДРУГА ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ДРУГЕ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PHI-E-RƠ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PIETARIN 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 K PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PATRUSKO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETRACEM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETRACEṂ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETRĀCEM 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETRĀCEṂ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 पत्रुसको 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-А. ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-ГЕ ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Е ПЕТИРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Е. ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Я ПЕТИРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Я. ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PATARAS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETROVA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PHIA-RƠ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PJETRIT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. ПЕТРОВА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. ПЕТРОВО 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.O. PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.º. PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2D. PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2DE PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2E. PETRUS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2E. PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2°. PIETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2Е. ПЕТИРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2Я. ПЕТИРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DEZYEM PIE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DEZYEM PIÈ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DEZYEM PYE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DEZYEM PYÈ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DEZYÈM PIE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DEZYÈM PIÈ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DEZYÈM PYE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DEZYÈM PYÈ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHA PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHY PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHÁ PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHÝ PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETROVA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PHIA-RƠ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II ПЕТРОВА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II ПЕТРОВО 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. BUTROS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETRUS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETRŮV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PHI-RƠ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PHÊ-RƠ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PIETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PÉTRUS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PILI PETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("TWEEDE PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ВТОРА ПЕТР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("베드로의 둘째 서간 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PATARAS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETROVA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PHIA-RƠ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PJETRIT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ПЕТРОВА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ПЕТРОВО 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-А ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Е ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-Я ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. BUTROS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETERS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETRUS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETRŮV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PHI-RƠ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PHÊ-RƠ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PIETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PÉTRUS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. ПЕТИРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. पत्रुस 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.O PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.º PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2A. PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2D PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2E PETRUS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2E PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PETE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2O. PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2° PIETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2º. PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2Е ПЕТИРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2Е. ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2Я ПЕТИРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2Я. ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ANDEN PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ANDRE PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II BUTROS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETRUS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETRŮV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PHI-RƠ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PHÊ-RƠ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PIETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PÉTRUS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETRI 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETRU 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PHÊRÔ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PIOTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PÉTER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. ПЕТАР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. ПЕТЪР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' ΠΈΤΡΟΥ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' ΠΕΤΡΟΥ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ ΠΈΤΡΟΥ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ ΠΕΤΡΟΥ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ ΠΈΤΡΟΥ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ ΠΕΤΡΟΥ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ ΠΈΤΡΟΥ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ ΠΕΤΡΟΥ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ ΠΈΤΡΟΥ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ ΠΕΤΡΟΥ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ΠΈΤΡΟΥ Β' 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ΠΈΤΡΟΥ Βʹ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ΠΈΤΡΟΥ Βʹ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ΠΈΤΡΟΥ Β΄ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ΠΈΤΡΟΥ Β’ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ΠΕΤΡΟΥ Β' 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ΠΕΤΡΟΥ Βʹ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ΠΕΤΡΟΥ Βʹ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ΠΕΤΡΟΥ Β΄ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ΠΕΤΡΟΥ Β’ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ВТОРА ПЕТ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("دوم پطر س 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ヘテロの第二の手紙 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ヘトロの第二の手紙 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ペテロの第二の手紙 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ペトロの第二の手紙 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 BUTROS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETERS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETROV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETRUS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETRUV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETRŮV 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETURU 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PHI-RƠ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PHÊ-RƠ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PIERRE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PIETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PIOTRA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PÉTRUS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PĒTURU 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PATRAS 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ПЕТИРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 पत्रुस 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 பேதுரு 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETRI 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETRU 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PHÊRÔ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PIOTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PÉTER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. ПЕТАР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. ПЕТЪР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. پطر س 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. ପିତରଙ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. เปโตร 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2A PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2E. PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PETE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2O PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2º PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2Е ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2Я ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHA PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHY PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHÁ PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHÝ PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETRI 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETRU 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PHÊRÔ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PIOTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PÉTER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II ПЕТАР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II ПЕТЪР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PEDR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PHIA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. ПЕТР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETRI II 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PETRO II 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("PILI PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("SECOND P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("دوم پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("دوم-پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("دوم۔پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PEDRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETRI 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETRO 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETRU 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PHÊRÔ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PIOTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PÉTER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ПЕТАР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ПЕТРА 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ПЕТЪР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 پطر س 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 पेत्र 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ପିତରଙ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 เปโตร 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PEDR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PHIA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. ПЕТР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. पतरस 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.-پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2.۔پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2E PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2E. PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHA P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHY P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHÁ P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("DRUHÝ P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PEDR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PHIA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II ПЕТР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. BUT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PIE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PIÈ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PYE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PYÈ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PÉT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. ПЕТ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' ΠΈΤΡ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' ΠΕΤΡ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ ΠΈΤΡ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ ΠΕΤΡ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ ΠΈΤΡ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ ΠΕΤΡ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ ΠΈΤΡ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ ΠΕΤΡ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ ΠΈΤΡ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ ΠΕΤΡ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("۲ پطر س 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《伯多祿後書》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ヘテロの後の書 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ヘトロの手紙二 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ペテロの後の書 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ペトロの手紙二 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PEDR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PETR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PHIA 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PIET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ПЕТР 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 पतरस 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ਪਤਰਸ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 பேது 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2-پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. BUT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PIE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PIÈ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PYE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PYÈ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PÉT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. ПЕТ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. पतर 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2E PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND. P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2۔پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II BUT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PIE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PIÈ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PYE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PYÈ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PÉT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II ПЕТ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' ΠΈΤ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' ΠΕΤ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ ΠΈΤ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ ΠΕΤ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ ΠΈΤ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ ΠΕΤ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ ΠΈΤ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ ΠΕΤ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ ΠΈΤ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ ΠΕΤ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("۲ پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("۲-پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("۲۔پطرس 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《伯多祿後書 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼得后书》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼得後書》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《撇特爾後》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("伯多祿後書》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 BUT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PED 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PER 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PIE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PIÈ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PJE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PTR 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PYE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PYÈ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PÉT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ПЕТ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 पतर 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2ND P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II. P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' ΠΈ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β' ΠΕ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ ΠΈ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ ΠΕ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ ΠΈ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Βʹ ΠΕ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ ΠΈ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β΄ ΠΕ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ ΠΈ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("Β’ ΠΕ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼得后书 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼得後書 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《撇特爾後 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ヘトロ 2 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("ペトロ 2 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("伯多祿後書 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼得后书》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼得後書》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("撇特爾後》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("베드로2서 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("베드로후서 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PD 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PE 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PI 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PJ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 PT 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 بط 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 ปต 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2. P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2PET 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("II P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼后》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼後》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("二ヘトロ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("二ペトロ 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼得后书 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼得後書 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("撇特爾後 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2 P 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2بط 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("2베드 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼后 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("《彼後 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼后》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼後》 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼后 1:1").osis()).toEqual("2Pet.1.1")
		expect(p.parse("彼後 1:1").osis()).toEqual("2Pet.1.1")
		`
		true
describe "Localized book 1Pet (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Pet (full)", ->
		`
		expect(p.parse("1-ше. соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перша соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перше соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а. соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е. соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше. соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перша соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перше соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а. соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е. соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Първо съборно послание на св. ап. Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Първо съборно послание на св ап. Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Първо съборно послание на св. ап Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше. соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перша соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перше соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Първо съборно послание на св ап Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а. соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е. соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Peturu Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Peturu Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Peturu Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Peturu Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pēturu Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pēturu Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pēturu Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pēturu Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Perse poslannja apostola Petra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Perše poslannja apostola Petra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Прва послание на апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Прво послание на апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("பேதுரு எழுதிய முதலாவது நிருபம் 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше. послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перша послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перше послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("பேதுரு எழுதிய முதல் திருமுகம் 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а. послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е. послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше. соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. послание на апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. послание на апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перша соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перше соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("பேதுரு எழுதிய முதலாம் கடிதம் 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 послание на апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а. соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е. соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I послание на апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Прва писмо од апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Прво писмо од апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("אגרתו הראשונה של פטרוס השלי 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Ensimmainen Pietarin kirje 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Ensimmäinen Pietarin kirje 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. писмо од апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Fyrra almenna bref Peturs 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Fyrra almenna bref Péturs 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Fyrra almenna bréf Peturs 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Fyrra almenna bréf Péturs 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. писмо од апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Waraka wa Kwanza wa Petro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 писмо од апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Barua ya Kwanza ya Petro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I писмо од апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsza List sw. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsza List św. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsze List sw. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsze List św. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwszy List sw. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwszy List św. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("رسالة القديس بطرس الأولى 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsza List sw Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsza List św Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsze List sw Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsze List św Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwszy List sw Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwszy List św Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prima lettera di Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("patras dī pahilī pattrī 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("paṭras kā pahlā ʿām ḫaṭ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Първо послание на Петър 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prva Petrova Poslanica 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prva Petrova poslanica 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Прва посланица Петрова 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("பேதுரு முதல் திருமுகம் 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("patrusko pahilo patra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("petracem pahile patra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("petraceṃ pahile patra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("petrācem pahile patra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("petrāceṃ pahile patra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше. послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petrova Poslanica 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. посланица Петрова 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Ensimmainen Pietarin 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Ensimmäinen Pietarin 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petrova Poslanica 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. посланица Петрова 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsza List Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsze List Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwszy List Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перша послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перше послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("پطر س کاپہلا عا م خط 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("पेत्राचें पहिले पत्र 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ਪਤਰਸ ਦੀ ਪਹਿਲੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petrova Poslanica 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 посланица Петрова 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а. послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е. послание Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е. послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-я. послание Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Forsta Petrusbrevet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Första Petrusbrevet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petrova Poslanica 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I посланица Петрова 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("איגרת פטרוס הראשונה 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("پطرس کا پہلا عام خط 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("पत्रुसको पहिलो पत्र 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("पेत्राचे पहिले पत्र 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е послание Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-я послание Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. List sw. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. List św. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1е. послание Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1я. послание Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. List sw. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. List św. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Peters Første Brev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Peters første brev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Petrus forsta brev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Petrus första brev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ପିତରଙ୍କ ପ୍ରଥମ ପତ୍ର 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 List sw. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 List św. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. List sw Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. List św Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pietarin kirje 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. послание Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1е послание Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1я послание Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Første Petersbrev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I List sw. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I List św. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. List sw Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. List św Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pietarin kirje 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Primero San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prva kniha Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvni list Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvni list Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("První list Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("První list Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvá kniha Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("رسالة بطرس الأولى 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 List sw Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 List św Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pietarin kirje 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 послание Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Epistula I Petri 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Epistula Petri I 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Fyrra Petursbref 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Fyrra Petursbréf 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Fyrra Pétursbref 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Fyrra Pétursbréf 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I List sw Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I List św Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pietarin kirje 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premieres Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premières Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Primer San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvy Petrov list 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvy list Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvý Petrov list 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvý list Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petrusbrevet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsza Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsze Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwszy Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premiere Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premiers Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Première Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petrusbrevet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. List Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. list Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. list Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.o. San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.º. San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. List Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. list Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. list Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Peters 1. Brev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsza Piotr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsze Piotr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwszy Piotr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premier Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Primeira Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Primeiro Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 List Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 list Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 list Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше. Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petersbrev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.o San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.º San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1o. San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1º. San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Butros Kowaad 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Eerste Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Første Peters 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I List Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I list Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I list Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Peters 1 Brev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Primero Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvni Petrova 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("První Petrova 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перша Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перше Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Първа Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petersbrev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 e. Pjetrit 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 i. Pjetrit 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а. Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е. Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ere. Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1o San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1º San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ère. Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Erste Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Første Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Kwanza Petro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prima Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Primer Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Primo Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prva Petrova 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvni Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvni Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("První Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("První Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Прва Петрова 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Прва Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Прво Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("رسالة بطرس 1 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 e Pjetrit 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 i Pjetrit 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 k. Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 पेत्राचें 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 இராயப்பர் 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е. Петира 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше. Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-я. Петира 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Phi-e-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pietarin 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. patrusko 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. पत्रुसको 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1er. Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ere Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1re. Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ère Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Eerste Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Phi-e-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pietarin 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prva Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvy Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvá Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvý Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Unang Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перша Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перше Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Първа Петър 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("بطرس الأولى 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ପ୍ରଥମ ପିତରଙ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Phi-e-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pietarin 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 k Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 patrusko 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 petracem 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 petraceṃ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 petrācem 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 petrāceṃ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 पत्रुसको 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а. Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е Петира 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е. Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-я Петира 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-я. Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pataras 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petrova 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Phia-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pjetrit 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Петрова 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.o. Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.º. Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1e. Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1er Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1re Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1°. Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1е. Петира 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1я. Петира 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Eerste Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Elso Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Elso Péter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Első Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Első Péter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Første Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Phi-e-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pietarin 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petrova 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Phia-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Петрова 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Kwanza Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premye Pie 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premye Piè 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premye Pye 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premye Pyè 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvni Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("První Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Прва Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Прво Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Първа Петр 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("اوّل پطر س 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("베드로의 첫째 서간 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pataras 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petrova 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Phia-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pjetrit 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Петрова 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-я Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Butros 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Peters 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Phi-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Phê-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pétrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Петира 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. पत्रुस 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.o Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.º Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1a. Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1e Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1o. Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1° Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1º. Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1е Петира 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1е. Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1я Петира 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1я. Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petrova 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Phia-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Петрова 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Butros 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Phi-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Phê-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pétrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Una Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' Πέτρου 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' Πετρου 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πέτρου 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πετρου 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πέτρου 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πετρου 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ Πέτρου 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ Πετρου 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ Πέτρου 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ Πετρου 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Πέτρου Α' 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Πέτρου Αʹ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Πέτρου Αʹ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Πέτρου Α΄ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Πέτρου Α’ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Πετρου Α' 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Πετρου Αʹ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Πετρου Αʹ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Πετρου Α΄ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Πετρου Α’ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Първа Пет 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("اوّل پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("اوّل-پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("اوّل۔پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ヘテロの第一の手紙 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ヘトロの第一の手紙 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ペテロの第一の手紙 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ペトロの第一の手紙 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Butros 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Peters 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Peturu 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Phi-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Phê-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pétrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pēturu 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 patras 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Петира 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 पत्रुस 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 பேதுரு 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petri 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petru 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Phêrô 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Piotr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Péter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Петър 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. پطر س 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. ପିତରଙ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. เปโตร 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1a Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1e. Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1o Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1º Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1е Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1я Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Elso Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Elso Pét 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Első Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Első Pét 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Butros 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Phi-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Phê-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pétrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petri 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petru 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Phêrô 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Piotr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Péter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Петър 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvni Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("První Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petri 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petru 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Phêrô 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Piotr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Péter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Петър 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 پطر س 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 पेत्र 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ପିତରଙ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 เปโตร 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pedr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Phia 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Петр 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. पतरस 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.-پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.۔پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1e Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1e. Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petri 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petru 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Phêrô 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Piotr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Péter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Петър 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pedr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Phia 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Петр 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Petri I 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Petro I 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvni P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("První P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' Πέτρ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' Πετρ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πέτρ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πετρ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πέτρ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πετρ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ Πέτρ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ Πετρ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ Πέτρ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ Πετρ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("۱ پطر س 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《伯多祿前書》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ヘテロの前の書 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ヘトロの手紙一 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ペテロの前の書 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ペトロの手紙一 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pedr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Phia 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Piet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Петр 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 पतरस 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ਪਤਰਸ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 பேது 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. But 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pie 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Piè 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pye 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pyè 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pét 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Пет 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. पतर 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1e Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1۔پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pedr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Phia 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Петр 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. But 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pie 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Piè 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pye 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pyè 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pét 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Пет 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' Πέτ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' Πετ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πέτ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πετ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πέτ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πετ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ Πέτ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ Πετ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ Πέτ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ Πετ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("۱ پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("۱-پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("۱۔پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《伯多祿前書 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《彼得前书》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《彼得前書》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《撇特爾前》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("伯多祿前書》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 But 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Ped 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pie 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Piè 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pje 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pye 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pyè 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pét 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Пет 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 पतर 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I But 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pie 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Piè 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pye 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pyè 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pét 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Пет 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' Πέ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' Πε 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πέ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πε 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πέ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πε 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ Πέ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ Πε 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ Πέ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ Πε 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《彼得前书 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《彼得前書 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《撇特爾前 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ヘトロ 1 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ペトロ 1 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("伯多祿前書 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("彼得前书》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("彼得前書》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("撇特爾前》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("베드로1서 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("베드로전서 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pd 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pi 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pj 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 بط 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ปต 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《彼前》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("一ヘトロ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("一ペトロ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("彼得前书 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("彼得前書 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("撇特爾前 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1بط 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1베드 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《彼前 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("彼前》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("彼前 1:1").osis()).toEqual("1Pet.1.1")
		`
		true
	it "should handle non-Latin digits in book: 1Pet (full)", ->
		p.set_options non_latin_digits_strategy: "replace"
		`
		expect(p.parse("1-ше. соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перша соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перше соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а. соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е. соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше. соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перша соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перше соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а. соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е. соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Първо съборно послание на св. ап. Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Първо съборно послание на св ап. Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Първо съборно послание на св. ап Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше. соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I соборне послання св. апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перша соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перше соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Първо съборно послание на св ап Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а. соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е. соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I соборне послання св апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I соборне послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Peturu Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Peturu Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Peturu Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Peturu Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pēturu Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pēturu Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pēturu Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pēturu Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Perse poslannja apostola Petra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Perše poslannja apostola Petra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Прва послание на апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Прво послание на апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("பேதுரு எழுதிய முதலாவது நிருபம் 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше. послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перша послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перше послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("பேதுரு எழுதிய முதல் திருமுகம் 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а. послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е. послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше. соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. послание на апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. послание на апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перша соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перше соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("பேதுரு எழுதிய முதலாம் கடிதம் 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 послание на апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а. соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е. соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I послание на апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Прва писмо од апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Прво писмо од апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("אגרתו הראשונה של פטרוס השלי 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Ensimmainen Pietarin kirje 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Ensimmäinen Pietarin kirje 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. писмо од апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Fyrra almenna bref Peturs 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Fyrra almenna bref Péturs 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Fyrra almenna bréf Peturs 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Fyrra almenna bréf Péturs 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I послання апостола Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. писмо од апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Waraka wa Kwanza wa Petro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 писмо од апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Barua ya Kwanza ya Petro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I писмо од апостол Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I соборне послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsza List sw. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsza List św. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsze List sw. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsze List św. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwszy List sw. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwszy List św. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("رسالة القديس بطرس الأولى 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsza List sw Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsza List św Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsze List sw Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsze List św Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwszy List sw Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwszy List św Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prima lettera di Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("patras dī pahilī pattrī 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("paṭras kā pahlā ʿām ḫaṭ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Първо послание на Петър 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prva Petrova Poslanica 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prva Petrova poslanica 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Прва посланица Петрова 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("பேதுரு முதல் திருமுகம் 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("patrusko pahilo patra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("petracem pahile patra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("petraceṃ pahile patra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("petrācem pahile patra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("petrāceṃ pahile patra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше. послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petrova Poslanica 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. посланица Петрова 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Ensimmainen Pietarin 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Ensimmäinen Pietarin 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petrova Poslanica 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. посланица Петрова 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsza List Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsze List Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwszy List Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перша послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перше послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("پطر س کاپہلا عا م خط 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("पेत्राचें पहिले पत्र 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ਪਤਰਸ ਦੀ ਪਹਿਲੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petrova Poslanica 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 посланица Петрова 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а. послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е. послание Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е. послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-я. послание Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Forsta Petrusbrevet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Första Petrusbrevet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petrova Poslanica 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I посланица Петрова 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("איגרת פטרוס הראשונה 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("پطرس کا پہلا عام خط 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("पत्रुसको पहिलो पत्र 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("पेत्राचे पहिले पत्र 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е послание Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-я послание Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. List sw. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. List św. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1е. послание Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1я. послание Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. List sw. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. List św. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Peters Første Brev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Peters første brev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Petrus forsta brev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Petrus första brev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ପିତରଙ୍କ ପ୍ରଥମ ପତ୍ର 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 List sw. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 List św. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. List sw Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. List św Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pietarin kirje 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. послание Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1е послание Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1я послание Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Første Petersbrev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I List sw. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I List św. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. List sw Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. List św Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pietarin kirje 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Primero San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prva kniha Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvni list Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvni list Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("První list Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("První list Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvá kniha Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("رسالة بطرس الأولى 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 List sw Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 List św Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pietarin kirje 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 послание Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Epistula I Petri 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Epistula Petri I 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Fyrra Petursbref 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Fyrra Petursbréf 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Fyrra Pétursbref 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Fyrra Pétursbréf 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I List sw Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I List św Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pietarin kirje 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I послання Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premieres Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premières Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Primer San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvy Petrov list 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvy list Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvý Petrov list 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvý list Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petrusbrevet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsza Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsze Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwszy Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premiere Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premiers Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Première Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petrusbrevet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. List Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. list Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. list Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.o. San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.º. San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. List Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. list Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. list Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Peters 1. Brev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsza Piotr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwsze Piotr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Pierwszy Piotr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premier Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Primeira Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Primeiro Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 List Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 list Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 list Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше. Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petersbrev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.o San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.º San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1o. San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1º. San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Butros Kowaad 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Eerste Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Første Peters 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I List Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I list Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I list Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Peters 1 Brev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Primero Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvni Petrova 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("První Petrova 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перша Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перше Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Първа Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petersbrev 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 e. Pjetrit 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 i. Pjetrit 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а. Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е. Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ere. Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1o San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1º San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ère. Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Erste Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Første Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Kwanza Petro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prima Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Primer Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Primo Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prva Petrova 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvni Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvni Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("První Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("První Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Прва Петрова 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Прва Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Прво Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("رسالة بطرس 1 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 e Pjetrit 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 i Pjetrit 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 k. Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 पेत्राचें 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 இராயப்பர் 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е. Петира 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше. Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-я. Петира 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Phi-e-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pietarin 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. patrusko 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. पत्रुसको 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1er. Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ere Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1re. Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ère Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Eerste Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I San Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Phi-e-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pietarin 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prva Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvy Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvá Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvý Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Unang Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перша Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Перше Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Първа Петър 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("بطرس الأولى 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ପ୍ରଥମ ପିତରଙ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Phi-e-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pietarin 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 k Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 patrusko 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 petracem 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 petraceṃ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 petrācem 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 petrāceṃ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 पत्रुसको 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а. Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е Петира 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е. Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ше Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-я Петира 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-я. Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pataras 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petrova 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Phia-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pjetrit 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Петрова 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.o. Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.º. Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1e. Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1er Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1re Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1°. Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1е. Петира 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1я. Петира 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Eerste Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Elso Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Elso Péter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Első Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Első Péter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Første Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Phi-e-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pietarin 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petrova 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Phia-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Петрова 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Kwanza Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premye Pie 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premye Piè 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premye Pye 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Premye Pyè 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvni Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("První Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Прва Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Прво Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Първа Петр 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("اوّل پطر س 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("베드로의 첫째 서간 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pataras 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petrova 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Phia-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pjetrit 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Петрова 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-а Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-е Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-я Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Butros 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Peters 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Phi-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Phê-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pétrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Петира 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. पत्रुस 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.o Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.º Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1a. Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1e Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1o. Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1° Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1º. Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1е Петира 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1е. Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1я Петира 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1я. Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petrova 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Phia-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Петрова 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Петрово 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Butros 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Phi-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Phê-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pétrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Una Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' Πέτρου 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' Πετρου 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πέτρου 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πετρου 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πέτρου 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πετρου 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ Πέτρου 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ Πετρου 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ Πέτρου 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ Πετρου 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Πέτρου Α' 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Πέτρου Αʹ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Πέτρου Αʹ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Πέτρου Α΄ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Πέτρου Α’ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Πετρου Α' 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Πετρου Αʹ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Πετρου Αʹ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Πετρου Α΄ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Πετρου Α’ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Първа Пет 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("اوّل پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("اوّل-پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("اوّل۔پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ヘテロの第一の手紙 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ヘトロの第一の手紙 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ペテロの第一の手紙 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ペトロの第一の手紙 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Butros 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Peters 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Peturu 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Phi-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Phê-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pétrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pēturu 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 patras 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Петира 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 पत्रुस 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 பேதுரு 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petri 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petru 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Phêrô 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Piotr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Péter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Петър 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. پطر س 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. ପିତରଙ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. เปโตร 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1a Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1e. Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1o Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1º Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1е Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1я Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Elso Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Elso Pét 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Első Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Első Pét 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Butros 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petrov 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petruv 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petrův 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Phi-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Phê-rơ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pierre 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pietro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Piotra 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pétrus 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petri 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petru 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Phêrô 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Piotr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Péter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Петър 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvni Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("První Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petri 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petru 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Phêrô 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Piotr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Péter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Петър 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 پطر س 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 पेत्र 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ପିତରଙ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 เปโตร 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pedr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Phia 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Петр 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. पतरस 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.-پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.۔پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1e Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1e. Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("First P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pedro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petri 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petro 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petru 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Phêrô 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Piotr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Péter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Петар 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Петра 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Петър 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pedr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Phia 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Петр 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Petri I 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Petro I 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Prvni P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("První P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' Πέτρ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' Πετρ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πέτρ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πετρ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πέτρ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πετρ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ Πέτρ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ Πετρ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ Πέτρ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ Πετρ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("۱ پطر س 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《伯多祿前書》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ヘテロの前の書 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ヘトロの手紙一 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ペテロの前の書 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ペトロの手紙一 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pedr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Phia 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Piet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Петр 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 पतरस 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ਪਤਰਸ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 பேது 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. But 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pie 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Piè 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pye 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pyè 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pét 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Пет 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. पतर 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1e Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st. P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1۔پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pedr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pete 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Petr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Phia 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Петр 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. But 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pie 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Piè 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pye 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pyè 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pét 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Пет 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' Πέτ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' Πετ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πέτ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πετ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πέτ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πετ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ Πέτ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ Πετ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ Πέτ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ Πετ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("۱ پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("۱-پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("۱۔پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《伯多祿前書 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《彼得前书》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《彼得前書》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《撇特爾前》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("伯多祿前書》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 But 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Ped 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pie 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Piè 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pje 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pye 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pyè 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pét 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Пет 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 पतर 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1st P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I But 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Per 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pie 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Piè 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Ptr 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pye 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pyè 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pét 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Пет 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Peter 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' Πέ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' Πε 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πέ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πε 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πέ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ Πε 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ Πέ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ Πε 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ Πέ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ Πε 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《彼得前书 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《彼得前書 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《撇特爾前 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ヘトロ 1 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ペトロ 1 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("伯多祿前書 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("彼得前书》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("彼得前書》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("撇特爾前》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("베드로1서 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("베드로전서 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pd 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pi 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pj 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 بط 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ปต 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1Pet 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pe 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I Pt 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《彼前》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("一ヘトロ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("一ペトロ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("彼得前书 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("彼得前書 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("撇特爾前 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1بط 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1베드 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《彼前 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("彼前》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("彼前 1:1").osis()).toEqual("1Pet.1.1")
		p.include_apocrypha(false)
		expect(p.parse("1-ШЕ. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЕРША СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЕРШЕ СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-А. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Е. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ШЕ СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ШЕ. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЕРША СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЕРШЕ СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-А СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-А. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Е СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Е. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ШЕ СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЪРВО СЪБОРНО ПОСЛАНИЕ НА СВ. АП. ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-А СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Е СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЪРВО СЪБОРНО ПОСЛАНИЕ НА СВ АП. ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЪРВО СЪБОРНО ПОСЛАНИЕ НА СВ. АП ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ШЕ. СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЕРША СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЕРШЕ СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЪРВО СЪБОРНО ПОСЛАНИЕ НА СВ АП ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-А. СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Е. СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ШЕ СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-А СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Е СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I СОБОРНЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETURU ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETURU ELUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETURU EḺUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETURU EḺUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PĒTURU ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PĒTURU ELUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PĒTURU EḺUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PĒTURU EḺUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PERSE POSLANNJA APOSTOLA PETRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PERŠE POSLANNJA APOSTOLA PETRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПРВА ПОСЛАНИЕ НА АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПРВО ПОСЛАНИЕ НА АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("பேதுரு எழுதிய முதலாவது நிருபம் 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ШЕ. ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЕРША ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЕРШЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("பேதுரு எழுதிய முதல் திருமுகம் 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-А. ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Е. ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ШЕ ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ШЕ. СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. ПОСЛАНИЕ НА АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. ПОСЛАНИЕ НА АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЕРША СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЕРШЕ СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("பேதுரு எழுதிய முதலாம் கடிதம் 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ПОСЛАНИЕ НА АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-А ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-А. СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Е ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Е. СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ШЕ СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I ПОСЛАНИЕ НА АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПРВА ПИСМО ОД АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПРВО ПИСМО ОД АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("אגרתו הראשונה של פטרוס השלי 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-А СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Е СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ENSIMMAINEN PIETARIN KIRJE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ENSIMMÄINEN PIETARIN KIRJE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. ПИСМО ОД АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FYRRA ALMENNA BREF PETURS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FYRRA ALMENNA BREF PÉTURS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FYRRA ALMENNA BRÉF PETURS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FYRRA ALMENNA BRÉF PÉTURS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I ПОСЛАННЯ АПОСТОЛА ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. ПИСМО ОД АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("WARAKA WA KWANZA WA PETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ПИСМО ОД АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("BARUA YA KWANZA YA PETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I ПИСМО ОД АПОСТОЛ ПЕТАР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I СОБОРНЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZA LIST SW. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZA LIST ŚW. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZE LIST SW. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZE LIST ŚW. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZY LIST SW. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZY LIST ŚW. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("رسالة القديس بطرس الأولى 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZA LIST SW PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZA LIST ŚW PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZE LIST SW PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZE LIST ŚW PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZY LIST SW PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZY LIST ŚW PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRIMA LETTERA DI PIETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PATRAS DĪ PAHILĪ PATTRĪ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PAṬRAS KĀ PAHLĀ ʿĀM ḪAṬ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЪРВО ПОСЛАНИЕ НА ПЕТЪР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVA PETROVA POSLANICA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVA PETROVA POSLANICA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПРВА ПОСЛАНИЦА ПЕТРОВА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("பேதுரு முதல் திருமுகம் 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PATRUSKO PAHILO PATRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETRACEM PAHILE PATRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETRACEṂ PAHILE PATRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETRĀCEM PAHILE PATRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETRĀCEṂ PAHILE PATRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ШЕ. ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETROVA POSLANICA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. ПОСЛАНИЦА ПЕТРОВА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ENSIMMAINEN PIETARIN 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ENSIMMÄINEN PIETARIN 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETROVA POSLANICA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. ПОСЛАНИЦА ПЕТРОВА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZA LIST PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZE LIST PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZY LIST PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЕРША ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЕРШЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("پطر س کاپہلا عا م خط 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("पेत्राचें पहिले पत्र 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ਪਤਰਸ ਦੀ ਪਹਿਲੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETROVA POSLANICA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ПОСЛАНИЦА ПЕТРОВА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-А. ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Е. ПОСЛАНИЕ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Е. ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ШЕ ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Я. ПОСЛАНИЕ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FORSTA PETRUSBREVET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FÖRSTA PETRUSBREVET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETROVA POSLANICA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I ПОСЛАНИЦА ПЕТРОВА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("איגרת פטרוס הראשונה 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("پطرس کا پہلا عام خط 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("पत्रुसको पहिलो पत्र 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("पेत्राचे पहिले पत्र 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-А ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Е ПОСЛАНИЕ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Е ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Я ПОСЛАНИЕ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. LIST SW. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. LIST ŚW. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1Е. ПОСЛАНИЕ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1Я. ПОСЛАНИЕ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. LIST SW. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. LIST ŚW. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETERS FØRSTE BREV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETERS FØRSTE BREV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETRUS FORSTA BREV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETRUS FÖRSTA BREV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ପିତରଙ୍କ ପ୍ରଥମ ପତ୍ର 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 LIST SW. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 LIST ŚW. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. LIST SW PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. LIST ŚW PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PIETARIN KIRJE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. ПОСЛАНИЕ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1Е ПОСЛАНИЕ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1Я ПОСЛАНИЕ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FØRSTE PETERSBREV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I LIST SW. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I LIST ŚW. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. LIST SW PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. LIST ŚW PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PIETARIN KIRJE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRIMERO SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVA KNIHA PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVNI LIST PETRUV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVNI LIST PETRŮV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVNÍ LIST PETRUV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVNÍ LIST PETRŮV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVÁ KNIHA PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("رسالة بطرس الأولى 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 LIST SW PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 LIST ŚW PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PIETARIN KIRJE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ПОСЛАНИЕ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("EPISTULA I PETRI 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("EPISTULA PETRI I 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FYRRA PETURSBREF 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FYRRA PETURSBRÉF 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FYRRA PÉTURSBREF 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FYRRA PÉTURSBRÉF 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I LIST SW PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I LIST ŚW PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PIETARIN KIRJE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I ПОСЛАННЯ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PREMIERES PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PREMIÈRES PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRIMER SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVY PETROV LIST 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVY LIST PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVÝ PETROV LIST 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVÝ LIST PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETRUSBREVET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZA PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZE PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZY PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PREMIERE PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PREMIERS PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PREMIÈRE PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETRUSBREVET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. LIST PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. LIST PETRUV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. LIST PETRŮV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.O. SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.º. SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. LIST PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. LIST PETRUV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. LIST PETRŮV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETERS 1. BREV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZA PIOTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZE PIOTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PIERWSZY PIOTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PREMIER PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRIMEIRA PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRIMEIRO PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 LIST PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 LIST PETRUV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 LIST PETRŮV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ШЕ. ПЕТРОВО 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETERSBREV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.O SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.º SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1O. SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1º. SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("BUTROS KOWAAD 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("EERSTE PETRUS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FØRSTE PETERS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I LIST PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I LIST PETRUV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I LIST PETRŮV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETERS 1 BREV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRIMERO PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVNI PETROVA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVNÍ PETROVA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЕРША ПЕТРОВО 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЕРШЕ ПЕТРОВО 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЪРВА ПЕТРОВО 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETERSBREV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 E. PJETRIT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 I. PJETRIT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-А. ПЕТРОВО 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Е. ПЕТРОВО 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ШЕ ПЕТРОВО 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ERE. PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1O SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1º SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ÈRE. PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ERSTE PETRUS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FØRSTE PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("KWANZA PETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRIMA PIETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRIMER PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRIMO PIETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVA PETROVA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVNI PETRUV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVNI PETRŮV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVNÍ PETRUV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVNÍ PETRŮV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПРВА ПЕТРОВА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПРВА ПЕТРОВО 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПРВО ПЕТРОВО 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("رسالة بطرس 1 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 E PJETRIT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 I PJETRIT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 K. PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 पेत्राचें 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 இராயப்பர் 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-А ПЕТРОВО 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Е ПЕТРОВО 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Е. ПЕТИРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ШЕ. ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Я. ПЕТИРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PHI-E-RƠ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PIETARIN 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PATRUSKO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. पत्रुसको 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ER. PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ERE PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1RE. PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ÈRE PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("EERSTE PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I SAN PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PHI-E-RƠ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PIETARIN 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVA PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVY PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVÁ PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVÝ PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("UNANG PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЕРША ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЕРШЕ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЪРВА ПЕТЪР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("بطرس الأولى 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ପ୍ରଥମ ପିତରଙ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PHI-E-RƠ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PIETARIN 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 K PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PATRUSKO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETRACEM 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETRACEṂ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETRĀCEM 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETRĀCEṂ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 पत्रुसको 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-А. ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Е ПЕТИРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Е. ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-ШЕ ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Я ПЕТИРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Я. ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PATARAS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETROVA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PHIA-RƠ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PJETRIT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. ПЕТРОВА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. ПЕТРОВО 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.O. PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.º. PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1E. PETRUS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ER PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1RE PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1°. PIETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1Е. ПЕТИРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1Я. ПЕТИРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("EERSTE PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ELSO PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ELSO PÉTER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ELSŐ PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ELSŐ PÉTER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PETE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FØRSTE PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PHI-E-RƠ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PIETARIN 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETROVA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PHIA-RƠ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. ПЕТРОВА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. ПЕТРОВО 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("KWANZA PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PREMYE PIE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PREMYE PIÈ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PREMYE PYE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PREMYE PYÈ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVNI PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVNÍ PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПРВА ПЕТАР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПРВО ПЕТАР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЪРВА ПЕТР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("اوّل پطر س 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("베드로의 첫째 서간 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PATARAS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETROVA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PHIA-RƠ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PJETRIT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ПЕТРОВА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ПЕТРОВО 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-А ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Е ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-Я ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. BUTROS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETERS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETRUS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETRUV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETRŮV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PHI-RƠ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PHÊ-RƠ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PIETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PÉTRUS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. ПЕТИРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. पत्रुस 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.O PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.º PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1A. PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1E PETRUS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1O. PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PETE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1° PIETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1º. PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1Е ПЕТИРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1Е. ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1Я ПЕТИРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1Я. ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETROVA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PHIA-RƠ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I ПЕТРОВА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I ПЕТРОВО 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. BUTROS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETRUS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETRUV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETRŮV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PHI-RƠ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PHÊ-RƠ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PIETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PÉTRUS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("UNA PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' ΠΈΤΡΟΥ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' ΠΕΤΡΟΥ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ ΠΈΤΡΟΥ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ ΠΕΤΡΟΥ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ ΠΈΤΡΟΥ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ ΠΕΤΡΟΥ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ ΠΈΤΡΟΥ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ ΠΕΤΡΟΥ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ ΠΈΤΡΟΥ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ ΠΕΤΡΟΥ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ΠΈΤΡΟΥ Α' 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ΠΈΤΡΟΥ Αʹ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ΠΈΤΡΟΥ Αʹ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ΠΈΤΡΟΥ Α΄ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ΠΈΤΡΟΥ Α’ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ΠΕΤΡΟΥ Α' 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ΠΕΤΡΟΥ Αʹ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ΠΕΤΡΟΥ Αʹ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ΠΕΤΡΟΥ Α΄ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ΠΕΤΡΟΥ Α’ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ПЪРВА ПЕТ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("اوّل پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("اوّل-پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("اوّل۔پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ヘテロの第一の手紙 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ヘトロの第一の手紙 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ペテロの第一の手紙 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ペトロの第一の手紙 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 BUTROS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETERS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETRUS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETRUV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETRŮV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETURU 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PHI-RƠ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PHÊ-RƠ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PIETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PÉTRUS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PĒTURU 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PATRAS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ПЕТИРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 पत्रुस 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 பேதுரு 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETRI 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETRU 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PHÊRÔ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PIOTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PÉTER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. ПЕТАР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. ПЕТЪР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. پطر س 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. ପିତରଙ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. เปโตร 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1A PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1E. PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1O PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PETE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1º PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1Е ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1Я ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ELSO PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ELSO PÉT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ELSŐ PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ELSŐ PÉT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I BUTROS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETROV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETRUS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETRUV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETRŮV 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PHI-RƠ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PHÊ-RƠ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PIERRE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PIETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PIOTRA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PÉTRUS 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETRI 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETRU 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PHÊRÔ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PIOTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PÉTER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. ПЕТАР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. ПЕТЪР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVNI PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVNÍ PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETRI 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETRU 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PHÊRÔ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PIOTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PÉTER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ПЕТАР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ПЕТЪР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 پطر س 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 पेत्र 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ପିତରଙ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 เปโตร 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PEDR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PHIA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. ПЕТР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. पतरस 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.-پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1.۔پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1E PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1E. PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("FIRST P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PEDRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETRI 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETRO 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETRU 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PHÊRÔ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PIOTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PÉTER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I ПЕТАР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I ПЕТРА 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I ПЕТЪР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PEDR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PHIA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. ПЕТР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETRI I 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETRO I 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVNI P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PRVNÍ P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' ΠΈΤΡ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' ΠΕΤΡ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ ΠΈΤΡ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ ΠΕΤΡ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ ΠΈΤΡ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ ΠΕΤΡ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ ΠΈΤΡ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ ΠΕΤΡ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ ΠΈΤΡ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ ΠΕΤΡ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("۱ پطر س 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《伯多祿前書》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ヘテロの前の書 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ヘトロの手紙一 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ペテロの前の書 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ペトロの手紙一 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PEDR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PHIA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PIET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ПЕТР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 पतरस 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ਪਤਰਸ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 பேது 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1-پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. BUT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PIE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PIÈ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PYE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PYÈ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PÉT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. ПЕТ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. पतर 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1E PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST. P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1۔پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PEDR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PETR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PHIA 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I ПЕТР 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. BUT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PIE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PIÈ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PYE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PYÈ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PÉT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. ПЕТ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' ΠΈΤ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' ΠΕΤ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ ΠΈΤ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ ΠΕΤ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ ΠΈΤ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ ΠΕΤ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ ΠΈΤ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ ΠΕΤ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ ΠΈΤ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ ΠΕΤ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("۱ پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("۱-پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("۱۔پطرس 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《伯多祿前書 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《彼得前书》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《彼得前書》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《撇特爾前》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("伯多祿前書》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 BUT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PED 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PIE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PIÈ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PJE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PYE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PYÈ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PÉT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ПЕТ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 पतर 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1ST P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I BUT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PIE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PIÈ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PTR 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PYE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PYÈ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PÉT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I ПЕТ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("PETER 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' ΠΈ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α' ΠΕ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ ΠΈ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ ΠΕ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ ΠΈ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Αʹ ΠΕ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ ΠΈ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α΄ ΠΕ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ ΠΈ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("Α’ ΠΕ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《彼得前书 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《彼得前書 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《撇特爾前 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ヘトロ 1 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("ペトロ 1 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("伯多祿前書 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("彼得前书》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("彼得前書》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("撇特爾前》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("베드로1서 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("베드로전서 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PD 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PI 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PJ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 بط 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 ปต 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1. P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1PET 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PE 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I PT 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I. P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《彼前》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("一ヘトロ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("一ペトロ 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("彼得前书 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("彼得前書 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("撇特爾前 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1 P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1بط 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("1베드 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("I P 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("《彼前 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("彼前》 1:1").osis()).toEqual("1Pet.1.1")
		expect(p.parse("彼前 1:1").osis()).toEqual("1Pet.1.1")
		`
		true
describe "Localized book Rom (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Rom (full)", ->
		`
		expect(p.parse("Писмо од апостол Павле до христијаните во Рим 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Послання св. апостола Павла до римлян 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Послание на св. ап. Павла до Римляни 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Послання св апостола Павла до римлян 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Poslannja apostola Pavla do rymljan 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Послание на св ап. Павла до Римляни 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Послание на св. ап Павла до Римляни 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Послание на св ап Павла до Римляни 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Послання апостола Павла до римлян 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("رسالة بولس الرسول إلى أهل رومية 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ரோமாபுரியாருக்கு எழுதிய கடிதம் 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("رومیوں کے نام پولس رسول کا خط 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("உரோமையருக்கு எழுதிய திருமுகம் 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Pavlova poslanica Rimljanima 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("אגרת פולוס השליח אל-הרומיים 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Uromarukku Elutiya Nirupam 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Uromarukku Eḻutiya Nirupam 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Urōmarukku Elutiya Nirupam 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Urōmarukku Eḻutiya Nirupam 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("List sw. Pawła do Rzymian 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("List św. Pawła do Rzymian 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("உரோமருக்கு எழுதிய நிருபம் 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("List sw Pawła do Rzymian 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("List św Pawła do Rzymian 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Paulus' Brev til Romerne 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Paulus’ Brev til Romerne 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Paulus’ brev til romerne 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Bref Pals til Romverja 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Bref Pals til Rómverja 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Bref Páls til Romverja 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Bref Páls til Rómverja 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Bréf Pals til Romverja 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Bréf Pals til Rómverja 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Bréf Páls til Romverja 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Bréf Páls til Rómverja 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Послание към римляните 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("रोमीहरूलाई पावलको पत्र 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("rōmiyōṅ ke nām kā ḫaṭ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("الرسالة إلى أهل رومية 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Poslanica Rimljanima 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("पौलाचे रोमकरांस पत्र 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Epistula ad Romanos 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Kirje roomalaisille 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Sulat sa mga Romano 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Послание к Римлянам 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Посланица Римљанима 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("رومیوں کے نام کا خط 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ରୋମୀୟଙ୍କ ପ୍ରତି ପତ୍ର 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Layang Paulus Roma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Послання до римлян 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Lettera ai Romani 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Waraka kwa Waroma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Waraka kwa Warumi 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romiharulai patra 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romiharulaī patra 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romiharulāi patra 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romiharulāī patra 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romiharūlai patra 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romiharūlaī patra 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romiharūlāi patra 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romiharūlāī patra 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romīharulai patra 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romīharulaī patra 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romīharulāi patra 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romīharulāī patra 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romīharūlai patra 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romīharūlaī patra 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romīharūlāi patra 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romīharūlāī patra 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romīāṃ nū̃ pattrī 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("האיגרת אל הרומאים 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ਰੋਮੀਆਂ ਨੂੰ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Barua kwa Waroma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("List do Rzymian 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romkarams patra 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romkaraṃs patra 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romkarāms patra 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romkarāṃs patra 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("रोमीहरूलाई पत्र 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Mga Taga- Roma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romverjabrefið 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romverjabréfið 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Roomalaiskirje 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rómverjabrefið 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rómverjabréfið 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("로마 신자들에게 보낸 서간 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Mga Taga Roma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Mga Taga-Roma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romeinenbrief 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Roomalaisille 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Προς Ρωμαίους 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Προς Ρωμαιους 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("रोमकरांस पत्र 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("List Rimanom 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("List Rimanum 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("List Rimanům 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("List Rímanum 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("List Rímanům 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("List Řimanum 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("List Řimanům 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("List Římanum 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("List Římanům 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rhufeiniaid 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romarbrevet 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romerbrevet 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romiharulai 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romiharulaī 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romiharulāi 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romiharulāī 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romiharūlai 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romiharūlaī 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romiharūlāi 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romiharūlāī 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romīharulai 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romīharulaī 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romīharulāi 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romīharulāī 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romīharūlai 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romīharūlaī 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romīharūlāi 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romīharūlāī 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rimljanima 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romaiakhoz 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rómaiakhoz 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Taga- Roma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Uromarukku 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Urōmarukku 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ad Romanos 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("К Римлянам 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("אל הרומאים 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("رسالة روما 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("रोमीहरूलाई 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ਰੋਮੀਆਂ ਨੂੰ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ローマの信徒への手紙 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Taga Roma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romkarams 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romkaraṃs 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romkarāms 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romkarāṃs 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("До римлян 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Римјаните 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Римљанима 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("римляните 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("אל הרומים 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romakeve 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romakëve 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romeinen 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Ρωμαίους 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Ρωμαιους 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Римлянам 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("رُومِیوں 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("रोमकंरास 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("रोमकरांस 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ରୋମୀୟଙ୍କ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("உரோமையர் 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ローマ人への手紙 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rimanom 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rimanum 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rimanům 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rimskym 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romains 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romands 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romanos 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romerne 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romiyon 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rzymian 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rímanum 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rímanům 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rímskym 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Řimanum 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Řimanům 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Římanum 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Římanům 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Римляни 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Римјани 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("रोमियों 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Roamns 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Roemer 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romani 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romano 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romans 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romasn 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rpmans 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Waroma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Warumi 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("romīāṃ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Римлян 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("رومیوں 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("रोमियो 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ਰੋਮੀਆਂ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("《羅爾瑪書》 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ロマ人への書 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("La-mã 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Roman 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romen 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Romer 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rooma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rô-ma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Römer 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ரோமர் 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("《罗马书》 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("《羅爾瑪書 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("《羅馬書》 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("羅爾瑪書》 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ﺭﻭﻣﻴﺔ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rhuf 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rmns 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Roma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Roms 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Room 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rzym 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Róma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rôma 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Римл 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("रोमी 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("《罗马书 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("《羅馬書 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ローマ書 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("罗马书》 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("羅爾瑪書 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("羅馬書》 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rim 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rmn 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rms 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rom 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Ros 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rum 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rím 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Ròm 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Róm 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Röm 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Řim 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Řím 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Ρωμ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Рим 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("روم 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("உரோ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("โรม 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("῾Ρω 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("《罗》 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("《羅》 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ローマ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("罗马书 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("羅馬書 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("로마서 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rm 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Ro 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Rz 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("رو 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("รม 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("《罗 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("《羅 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("罗》 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("羅》 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("로마 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("R 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Ř 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("罗 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("羅 1:1").osis()).toEqual("Rom.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО РИМ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО РИМЛЯН 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ. АП. ПАВЛА ДО РИМЛЯНИ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО РИМЛЯН 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("POSLANNJA APOSTOLA PAVLA DO RYMLJAN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ АП. ПАВЛА ДО РИМЛЯНИ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ. АП ПАВЛА ДО РИМЛЯНИ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ АП ПАВЛА ДО РИМЛЯНИ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО РИМЛЯН 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("رسالة بولس الرسول إلى أهل رومية 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ரோமாபுரியாருக்கு எழுதிய கடிதம் 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("رومیوں کے نام پولس رسول کا خط 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("உரோமையருக்கு எழுதிய திருமுகம் 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("PAVLOVA POSLANICA RIMLJANIMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("אגרת פולוס השליח אל-הרומיים 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("UROMARUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("UROMARUKKU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("URŌMARUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("URŌMARUKKU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("LIST SW. PAWŁA DO RZYMIAN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("LIST ŚW. PAWŁA DO RZYMIAN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("உரோமருக்கு எழுதிய நிருபம் 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("LIST SW PAWŁA DO RZYMIAN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("LIST ŚW PAWŁA DO RZYMIAN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("PAULUS' BREV TIL ROMERNE 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("PAULUS’ BREV TIL ROMERNE 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("PAULUS’ BREV TIL ROMERNE 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("BREF PALS TIL ROMVERJA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("BREF PALS TIL RÓMVERJA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("BREF PÁLS TIL ROMVERJA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("BREF PÁLS TIL RÓMVERJA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("BRÉF PALS TIL ROMVERJA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("BRÉF PALS TIL RÓMVERJA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("BRÉF PÁLS TIL ROMVERJA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("BRÉF PÁLS TIL RÓMVERJA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ПОСЛАНИЕ КЪМ РИМЛЯНИТЕ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("रोमीहरूलाई पावलको पत्र 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RŌMIYŌṄ KE NĀM KĀ ḪAṬ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("الرسالة إلى أهل رومية 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("POSLANICA RIMLJANIMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("पौलाचे रोमकरांस पत्र 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("EPISTULA AD ROMANOS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("KIRJE ROOMALAISILLE 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("SULAT SA MGA ROMANO 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ПОСЛАНИЕ К РИМЛЯНАМ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ПОСЛАНИЦА РИМЉАНИМА 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("رومیوں کے نام کا خط 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ରୋମୀୟଙ୍କ ପ୍ରତି ପତ୍ର 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("LAYANG PAULUS ROMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ПОСЛАННЯ ДО РИМЛЯН 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("LETTERA AI ROMANI 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("WARAKA KWA WAROMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("WARAKA KWA WARUMI 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMIHARULAI PATRA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMIHARULAĪ PATRA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMIHARULĀI PATRA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMIHARULĀĪ PATRA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMIHARŪLAI PATRA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMIHARŪLAĪ PATRA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMIHARŪLĀI PATRA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMIHARŪLĀĪ PATRA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMĪHARULAI PATRA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMĪHARULAĪ PATRA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMĪHARULĀI PATRA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMĪHARULĀĪ PATRA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMĪHARŪLAI PATRA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMĪHARŪLAĪ PATRA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMĪHARŪLĀI PATRA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMĪHARŪLĀĪ PATRA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMĪĀṂ NŪ̃ PATTRĪ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("האיגרת אל הרומאים 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ਰੋਮੀਆਂ ਨੂੰ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("BARUA KWA WAROMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("LIST DO RZYMIAN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMKARAMS PATRA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMKARAṂS PATRA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMKARĀMS PATRA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMKARĀṂS PATRA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("रोमीहरूलाई पत्र 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("MGA TAGA- ROMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMVERJABREFIÐ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMVERJABRÉFIÐ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROOMALAISKIRJE 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RÓMVERJABREFIÐ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RÓMVERJABRÉFIÐ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("로마 신자들에게 보낸 서간 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("MGA TAGA ROMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("MGA TAGA-ROMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMEINENBRIEF 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROOMALAISILLE 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ΠΡΟΣ ΡΩΜΑΊΟΥΣ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ΠΡΟΣ ΡΩΜΑΙΟΥΣ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("रोमकरांस पत्र 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("LIST RIMANOM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("LIST RIMANUM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("LIST RIMANŮM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("LIST RÍMANUM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("LIST RÍMANŮM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("LIST ŘIMANUM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("LIST ŘIMANŮM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("LIST ŘÍMANUM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("LIST ŘÍMANŮM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RHUFEINIAID 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMARBREVET 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMERBREVET 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMIHARULAI 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMIHARULAĪ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMIHARULĀI 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMIHARULĀĪ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMIHARŪLAI 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMIHARŪLAĪ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMIHARŪLĀI 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMIHARŪLĀĪ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMĪHARULAI 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMĪHARULAĪ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMĪHARULĀI 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMĪHARULĀĪ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMĪHARŪLAI 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMĪHARŪLAĪ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMĪHARŪLĀI 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMĪHARŪLĀĪ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RIMLJANIMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMAIAKHOZ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RÓMAIAKHOZ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("TAGA- ROMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("UROMARUKKU 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("URŌMARUKKU 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("AD ROMANOS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("К РИМЛЯНАМ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("אל הרומאים 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("رسالة روما 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("रोमीहरूलाई 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ਰੋਮੀਆਂ ਨੂੰ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ローマの信徒への手紙 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("TAGA ROMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMKARAMS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMKARAṂS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMKARĀMS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMKARĀṂS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ДО РИМЛЯН 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("РИМЈАНИТЕ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("РИМЉАНИМА 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("РИМЛЯНИТЕ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("אל הרומים 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMAKEVE 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMAKËVE 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMEINEN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ΡΩΜΑΊΟΥΣ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ΡΩΜΑΙΟΥΣ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("РИМЛЯНАМ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("رُومِیوں 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("रोमकंरास 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("रोमकरांस 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ରୋମୀୟଙ୍କ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("உரோமையர் 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ローマ人への手紙 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RIMANOM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RIMANUM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RIMANŮM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RIMSKYM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMAINS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMANDS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMANOS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMERNE 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMIYON 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RZYMIAN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RÍMANUM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RÍMANŮM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RÍMSKYM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ŘIMANUM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ŘIMANŮM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ŘÍMANUM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ŘÍMANŮM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("РИМЛЯНИ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("РИМЈАНИ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("रोमियों 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROAMNS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROEMER 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMANI 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMANO 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMANS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMASN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RPMANS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("WAROMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("WARUMI 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMĪĀṂ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("РИМЛЯН 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("رومیوں 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("रोमियो 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ਰੋਮੀਆਂ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("《羅爾瑪書》 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ロマ人への書 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("LA-MÃ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMAN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMEN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMER 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROOMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RÔ-MA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RÖMER 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ரோமர் 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("《罗马书》 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("《羅爾瑪書 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("《羅馬書》 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("羅爾瑪書》 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ﺭﻭﻣﻴﺔ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RHUF 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RMNS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROMS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROOM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RZYM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RÓMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RÔMA 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("РИМЛ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("रोमी 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("《罗马书 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("《羅馬書 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ローマ書 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("罗马书》 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("羅爾瑪書 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("羅馬書》 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RIM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RMN 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RMS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ROS 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RUM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RÍM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RÒM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RÓM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RÖM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ŘIM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ŘÍM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ΡΩΜ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("РИМ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("روم 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("உரோ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("โรม 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("῾ΡΩ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("《罗》 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("《羅》 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("ローマ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("罗马书 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("羅馬書 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("로마서 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RM 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RO 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("RZ 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("رو 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("รม 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("《罗 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("《羅 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("罗》 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("羅》 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("로마 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("R 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("Ř 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("罗 1:1").osis()).toEqual("Rom.1.1")
		expect(p.parse("羅 1:1").osis()).toEqual("Rom.1.1")
		`
		true
describe "Localized book Song (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Song (full)", ->
		`
		expect(p.parse("Книга Песен на Песните, от Соломона 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Книга Пісні Пісень Соломона 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Пісня над піснями Соломона 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("El Cantar de los Cantares 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("சாலொமோனின் உன்னதப்பாட்டு 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantare de los Cantares 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantar de los Cantares 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantique des Cantiques 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantique des cantiques 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Canticos dos Canticos 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Canticos dos Cânticos 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cânticos dos Canticos 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cânticos dos Cânticos 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Salomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Salomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Solomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Solomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Песнь песнеи Соломона 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Песнь песней Соломона 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Ang Awit ng mga Awit 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantarea lui Solomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantico dos Canticos 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantico dos Cânticos 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cântarea lui Solomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cântico dos Canticos 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cântico dos Cânticos 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Salomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Salomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Solomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Solomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Saloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Salomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Soloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Solomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Velpiesen Salamunova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Velpiesen Salamúnova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Velpiesen Šalamunova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Velpiesen Šalamúnova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Velpieseň Salamunova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Velpieseň Salamúnova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Velpieseň Šalamunova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Velpieseň Šalamúnova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Veľpiesen Salamunova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Veľpiesen Salamúnova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Veľpiesen Šalamunova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Veľpiesen Šalamúnova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Veľpieseň Salamunova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Veľpieseň Salamúnova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Veľpieseň Šalamunova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Veľpieseň Šalamúnova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemanko srestʰagit 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemanko srestʰagīt 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemanko sresṭʰagit 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemanko sresṭʰagīt 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemanko sreṣtʰagit 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemanko sreṣtʰagīt 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemanko sreṣṭʰagit 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemanko sreṣṭʰagīt 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemanko šrestʰagit 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemanko šrestʰagīt 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemanko šresṭʰagit 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemanko šresṭʰagīt 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemanko šreṣtʰagit 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemanko šreṣtʰagīt 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemanko šreṣṭʰagit 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemanko šreṣṭʰagīt 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemānko srestʰagit 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemānko srestʰagīt 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemānko sresṭʰagit 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemānko sresṭʰagīt 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemānko sreṣtʰagit 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemānko sreṣtʰagīt 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemānko sreṣṭʰagit 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemānko sreṣṭʰagīt 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemānko šrestʰagit 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemānko šrestʰagīt 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemānko šresṭʰagit 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemānko šresṭʰagīt 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemānko šreṣtʰagit 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemānko šreṣtʰagīt 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemānko šreṣṭʰagit 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("sulemānko šreṣṭʰagīt 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("सुलेमानको श्रेष्ठगीत 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Ang Awit ni Salomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Ang Awit ni Salomón 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Ang Awit ni Solomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Ang Awit ni Solomón 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantarea Cantarilor 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantarea Cantărilor 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantarea Cântarilor 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantarea Cântărilor 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantarea cantarilor 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantares de Salomao 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantares de Salomão 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantico Superlativo 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantico dei Cantici 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantico dei cantici 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantico di Salomone 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Canticum Canticorum 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Canticum canticorum 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cântarea Cantarilor 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cântarea Cantărilor 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cântarea Cântarilor 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cântarea Cântărilor 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cântico Superlativo 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Kantiku i Kantikeve 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Kantiku i Kantikëve 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Musthikaning Kidung 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piesn nad Piesniami 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piesn nad Pieśniami 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piesń nad Piesniami 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piesń nad Pieśniami 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pieśn nad Piesniami 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pieśn nad Pieśniami 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pieśń nad Piesniami 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pieśń nad Pieśniami 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pisnja nad pisnjamy 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pjesma nad pjesmama 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Saloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Salomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Soloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Solomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Песната над песните 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantico de Salomao 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantico de Salomão 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cântico de Salomao 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cântico de Salomão 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Gabaygii Sulaymaan 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hohelied Salomonis 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Songs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Песната на Соломон 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hoheslied Salomos 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piesen Salamunova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piesen Salamúnova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piesen Šalamunova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piesen Šalamúnova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pieseň Salamunova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pieseň Salamúnova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pieseň Šalamunova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pieseň Šalamúnova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pisen Salamounova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pisen Šalamounova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piseň Salamounova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piseň Šalamounova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Písen Salamounova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Písen Šalamounova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Píseň Salamounova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Píseň Šalamounova 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Salomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Salomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Solomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Solomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Songs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Songs of Song 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Песма над песмама 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Песна над песните 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Пісня над піснями 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Awit ng mga Awit 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Awit sa mga Awit 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Kantid de Kantik 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Salomons Højsang 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Salomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Salomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Solomans 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Solomons 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Saloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Salomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Soloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Solomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("The Song of Song 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ġazalu l-ġazalāt 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Песен на песните 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Песма Соломонова 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("سفر نشيد الأنشاد 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Awit ni Salomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Awit ni Salomón 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Awit ni Solomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Awit ni Solomón 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pi bèl Chante a 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Salomos Høisang 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Salomos høysang 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Saloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Salomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Soloman 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Solomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Wimbo Ulio Bora 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Песнь Сулеимана 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Песнь Сулеймана 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("இனிமைமிகு பாடல் 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Caniad Solomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Chante Salomon 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Laulujen laulu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piesn Salomona 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piesń Salomona 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pieśn Salomona 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pieśń Salomona 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Songs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("salemān dā gīt 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("உன்னத சங்கீதம் 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piesen piesni 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piesen piesní 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pieseň piesni 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pieseň piesní 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Salamon eneke 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Salamon éneke 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Songs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Songs of Song 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Црковни химни 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("نشيد الأناشيد 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ਸਲੇਮਾਨ ਦਾ ਗੀਤ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("உன்னதப்பாட்டு 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cant. Cantic 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Enekek eneke 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Enekek éneke 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Kidung Agung 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Korkea veisu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song of Song 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Unnatappattu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Unnatappatṭu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Unnatappaṭtu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Unnatappaṭṭu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Unnatappāttu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Unnatappātṭu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Unnatappāṭtu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Unnatappāṭṭu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Unṉatappattu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Unṉatappatṭu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Unṉatappaṭtu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Unṉatappaṭṭu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Unṉatappāttu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Unṉatappātṭu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Unṉatappāṭtu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Unṉatappāṭṭu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Uṉnatappattu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Uṉnatappatṭu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Uṉnatappaṭtu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Uṉnatappaṭṭu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Uṉnatappāttu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Uṉnatappātṭu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Uṉnatappāṭtu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Uṉnatappāṭṭu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Uṉṉatappattu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Uṉṉatappatṭu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Uṉṉatappaṭtu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Uṉṉatappaṭṭu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Uṉṉatappāttu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Uṉṉatappātṭu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Uṉṉatappāṭtu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Uṉṉatappāṭṭu 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Énekek eneke 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Énekek éneke 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Άσμα Ασμάτων 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Άσμα Ασματων 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Ασμα Ασμάτων 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Ασμα Ασματων 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Песни Песнеи 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Песни Песней 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Пісня Піснеи 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Пісня Пісней 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Пісні Пісень 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("غزلُ الغزلات 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("உன்னத பாட்டு 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cant Cantic 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Ljoðaljoðin 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Ljoðaljóðin 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Ljóðaljoðin 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Ljóðaljóðin 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pisen pisni 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pisen pisní 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pisen písni 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pisen písní 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piseň pisni 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piseň pisní 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piseň písni 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piseň písní 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Písen pisni 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Písen pisní 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Písen písni 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Písen písní 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Píseň pisni 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Píseň pisní 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Píseň písni 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Píseň písní 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Reshthageet 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("غزل الغزلات 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("स्रेस्ट गीत 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("เพลงซาโลมอน 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("เพลงโซโลมอน 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hoga visan 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hohes Lied 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Höga Visan 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Höga visan 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Wimbo Bora 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("שיר השירים 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("श्रेष्ठगीत 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ﻧﺸﻴﺪ ﺍﻷﻧﺸﺎ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantiques 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hoheslied 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Højsangen 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Høysangen 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Kantikulo 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Velpiesen 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Velpieseň 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Veľpiesen 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Veľpieseň 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("שירי שלמה 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Caniadau 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantares 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Canticos 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantique 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cânticos 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Gabaygii 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hohelied 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hooglied 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("gitratna 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("gītratna 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Aw ni S 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantari 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantico 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cantări 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cântari 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cântări 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Diễm ca 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Kantiko 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Laul. l 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Tình ca 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("गीतरत्न 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("श्रेष्ठ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Chante 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hoga V 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hoga v 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Höga V 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Laul l 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Nhã ca 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piesen 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pieseň 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("S of S 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ପରମଗୀତ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hogav 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hoogl 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Högav 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pisen 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Piseň 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Písen 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Píseň 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Песнь 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("பாடல் 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cant 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cânt 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hoga 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hojs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Höga 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Højs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Høys 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Kant 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pies 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Sngs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Song 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Tình 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Velp 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Veľp 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("П. П 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Песн 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Пісн 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("உன்ன 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("《雅歌》 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("諸歌の歌 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Can 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Cnt 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Gab 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hld 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Ljl 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PNP 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pis 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pnp 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pís 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Sgs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Sng 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SoS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Sol 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Son 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Vlp 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Vľp 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Wim 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("П П 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Пес 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Пнп 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("இபா 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("พซม 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("《歌》 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("《雅歌 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("雅歌》 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Ct 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Hl 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Pj 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PŠ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Sg 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("So 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Én 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Ασ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("نش 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("Ἆσ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("《歌 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("歌》 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("雅歌 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("아가 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("아 1:1").osis()).toEqual("Song.1.1")
		p.include_apocrypha(false)
		expect(p.parse("КНИГА ПЕСЕН НА ПЕСНИТЕ, ОТ СОЛОМОНА 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("КНИГА ПІСНІ ПІСЕНЬ СОЛОМОНА 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ПІСНЯ НАД ПІСНЯМИ СОЛОМОНА 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("EL CANTAR DE LOS CANTARES 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("சாலொமோனின் உன்னதப்பாட்டு 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTARE DE LOS CANTARES 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTAR DE LOS CANTARES 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTIQUE DES CANTIQUES 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTIQUE DES CANTIQUES 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICOS DOS CANTICOS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICOS DOS CÂNTICOS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CÂNTICOS DOS CANTICOS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CÂNTICOS DOS CÂNTICOS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SALOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SALOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SOLOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SOLOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ПЕСНЬ ПЕСНЕИ СОЛОМОНА 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ПЕСНЬ ПЕСНЕЙ СОЛОМОНА 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ANG AWIT NG MGA AWIT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTAREA LUI SOLOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICO DOS CANTICOS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICO DOS CÂNTICOS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CÂNTAREA LUI SOLOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CÂNTICO DOS CANTICOS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CÂNTICO DOS CÂNTICOS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SALOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SALOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SOLOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SOLOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SALOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SALOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SOLOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SOLOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VELPIESEN SALAMUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VELPIESEN SALAMÚNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VELPIESEN ŠALAMUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VELPIESEN ŠALAMÚNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VELPIESEŇ SALAMUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VELPIESEŇ SALAMÚNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VELPIESEŇ ŠALAMUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VELPIESEŇ ŠALAMÚNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VEĽPIESEN SALAMUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VEĽPIESEN SALAMÚNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VEĽPIESEN ŠALAMUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VEĽPIESEN ŠALAMÚNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VEĽPIESEŇ SALAMUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VEĽPIESEŇ SALAMÚNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VEĽPIESEŇ ŠALAMUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VEĽPIESEŇ ŠALAMÚNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMANKO SRESTʰAGIT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMANKO SRESTʰAGĪT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMANKO SRESṬʰAGIT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMANKO SRESṬʰAGĪT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMANKO SREṢTʰAGIT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMANKO SREṢTʰAGĪT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMANKO SREṢṬʰAGIT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMANKO SREṢṬʰAGĪT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMANKO ŠRESTʰAGIT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMANKO ŠRESTʰAGĪT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMANKO ŠRESṬʰAGIT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMANKO ŠRESṬʰAGĪT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMANKO ŠREṢTʰAGIT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMANKO ŠREṢTʰAGĪT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMANKO ŠREṢṬʰAGIT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMANKO ŠREṢṬʰAGĪT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMĀNKO SRESTʰAGIT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMĀNKO SRESTʰAGĪT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMĀNKO SRESṬʰAGIT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMĀNKO SRESṬʰAGĪT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMĀNKO SREṢTʰAGIT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMĀNKO SREṢTʰAGĪT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMĀNKO SREṢṬʰAGIT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMĀNKO SREṢṬʰAGĪT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMĀNKO ŠRESTʰAGIT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMĀNKO ŠRESTʰAGĪT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMĀNKO ŠRESṬʰAGIT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMĀNKO ŠRESṬʰAGĪT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMĀNKO ŠREṢTʰAGIT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMĀNKO ŠREṢTʰAGĪT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMĀNKO ŠREṢṬʰAGIT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SULEMĀNKO ŠREṢṬʰAGĪT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("सुलेमानको श्रेष्ठगीत 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ANG AWIT NI SALOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ANG AWIT NI SALOMÓN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ANG AWIT NI SOLOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ANG AWIT NI SOLOMÓN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTAREA CANTARILOR 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTAREA CANTĂRILOR 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTAREA CÂNTARILOR 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTAREA CÂNTĂRILOR 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTAREA CANTARILOR 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTARES DE SALOMAO 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTARES DE SALOMÃO 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICO SUPERLATIVO 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICO DEI CANTICI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICO DEI CANTICI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICO DI SALOMONE 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICUM CANTICORUM 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICUM CANTICORUM 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CÂNTAREA CANTARILOR 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CÂNTAREA CANTĂRILOR 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CÂNTAREA CÂNTARILOR 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CÂNTAREA CÂNTĂRILOR 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CÂNTICO SUPERLATIVO 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("KANTIKU I KANTIKEVE 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("KANTIKU I KANTIKËVE 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("MUSTHIKANING KIDUNG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESN NAD PIESNIAMI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESN NAD PIEŚNIAMI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESŃ NAD PIESNIAMI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESŃ NAD PIEŚNIAMI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIEŚN NAD PIESNIAMI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIEŚN NAD PIEŚNIAMI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIEŚŃ NAD PIESNIAMI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIEŚŃ NAD PIEŚNIAMI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PISNJA NAD PISNJAMY 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PJESMA NAD PJESMAMA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SALOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SALOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SOLOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SOLOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ПЕСНАТА НАД ПЕСНИТЕ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICO DE SALOMAO 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICO DE SALOMÃO 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CÂNTICO DE SALOMAO 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CÂNTICO DE SALOMÃO 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("GABAYGII SULAYMAAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOHELIED SALOMONIS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SONGS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ПЕСНАТА НА СОЛОМОН 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOHESLIED SALOMOS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESEN SALAMUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESEN SALAMÚNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESEN ŠALAMUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESEN ŠALAMÚNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESEŇ SALAMUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESEŇ SALAMÚNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESEŇ ŠALAMUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESEŇ ŠALAMÚNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PISEN SALAMOUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PISEN ŠALAMOUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PISEŇ SALAMOUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PISEŇ ŠALAMOUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PÍSEN SALAMOUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PÍSEN ŠALAMOUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PÍSEŇ SALAMOUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PÍSEŇ ŠALAMOUNOVA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SALOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SALOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SOLOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SOLOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SONGS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONGS OF SONG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ПЕСМА НАД ПЕСМАМА 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ПЕСНА НАД ПЕСНИТЕ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ПІСНЯ НАД ПІСНЯМИ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("AWIT NG MGA AWIT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("AWIT SA MGA AWIT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("KANTID DE KANTIK 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SALOMONS HØJSANG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SALOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SALOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SOLOMANS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SOLOMONS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SALOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SALOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SOLOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SOLOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("THE SONG OF SONG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ĠAZALU L-ĠAZALĀT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ПЕСЕН НА ПЕСНИТЕ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ПЕСМА СОЛОМОНОВА 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("سفر نشيد الأنشاد 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("AWIT NI SALOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("AWIT NI SALOMÓN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("AWIT NI SOLOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("AWIT NI SOLOMÓN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PI BÈL CHANTE A 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SALOMOS HØISANG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SALOMOS HØYSANG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SALOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SALOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SOLOMAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SOLOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("WIMBO ULIO BORA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ПЕСНЬ СУЛЕИМАНА 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ПЕСНЬ СУЛЕЙМАНА 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("இனிமைமிகு பாடல் 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANIAD SOLOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CHANTE SALOMON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("LAULUJEN LAULU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESN SALOMONA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESŃ SALOMONA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIEŚN SALOMONA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIEŚŃ SALOMONA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SONGS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SALEMĀN DĀ GĪT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("உன்னத சங்கீதம் 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESEN PIESNI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESEN PIESNÍ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESEŇ PIESNI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESEŇ PIESNÍ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SALAMON ENEKE 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SALAMON ÉNEKE 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SONGS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONGS OF SONG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ЦРКОВНИ ХИМНИ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("نشيد الأناشيد 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ਸਲੇਮਾਨ ਦਾ ਗੀਤ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("உன்னதப்பாட்டு 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANT. CANTIC 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ENEKEK ENEKE 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ENEKEK ÉNEKE 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("KIDUNG AGUNG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("KORKEA VEISU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG OF SONG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UNNATAPPATTU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UNNATAPPATṬU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UNNATAPPAṬTU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UNNATAPPAṬṬU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UNNATAPPĀTTU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UNNATAPPĀTṬU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UNNATAPPĀṬTU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UNNATAPPĀṬṬU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UNṈATAPPATTU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UNṈATAPPATṬU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UNṈATAPPAṬTU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UNṈATAPPAṬṬU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UNṈATAPPĀTTU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UNṈATAPPĀTṬU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UNṈATAPPĀṬTU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UNṈATAPPĀṬṬU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UṈNATAPPATTU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UṈNATAPPATṬU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UṈNATAPPAṬTU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UṈNATAPPAṬṬU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UṈNATAPPĀTTU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UṈNATAPPĀTṬU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UṈNATAPPĀṬTU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UṈNATAPPĀṬṬU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UṈṈATAPPATTU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UṈṈATAPPATṬU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UṈṈATAPPAṬTU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UṈṈATAPPAṬṬU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UṈṈATAPPĀTTU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UṈṈATAPPĀTṬU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UṈṈATAPPĀṬTU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("UṈṈATAPPĀṬṬU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ÉNEKEK ENEKE 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ÉNEKEK ÉNEKE 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ΆΣΜΑ ΑΣΜΆΤΩΝ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ΆΣΜΑ ΑΣΜΑΤΩΝ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ΑΣΜΑ ΑΣΜΆΤΩΝ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ΑΣΜΑ ΑΣΜΑΤΩΝ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ПЕСНИ ПЕСНЕИ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ПЕСНИ ПЕСНЕЙ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ПІСНЯ ПІСНЕИ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ПІСНЯ ПІСНЕЙ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ПІСНІ ПІСЕНЬ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("غزلُ الغزلات 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("உன்னத பாட்டு 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANT CANTIC 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("LJOÐALJOÐIN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("LJOÐALJÓÐIN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("LJÓÐALJOÐIN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("LJÓÐALJÓÐIN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PISEN PISNI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PISEN PISNÍ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PISEN PÍSNI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PISEN PÍSNÍ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PISEŇ PISNI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PISEŇ PISNÍ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PISEŇ PÍSNI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PISEŇ PÍSNÍ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PÍSEN PISNI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PÍSEN PISNÍ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PÍSEN PÍSNI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PÍSEN PÍSNÍ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PÍSEŇ PISNI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PÍSEŇ PISNÍ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PÍSEŇ PÍSNI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PÍSEŇ PÍSNÍ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("RESHTHAGEET 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("غزل الغزلات 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("स्रेस्ट गीत 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("เพลงซาโลมอน 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("เพลงโซโลมอน 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOGA VISAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOHES LIED 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HÖGA VISAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HÖGA VISAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("WIMBO BORA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("שיר השירים 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("श्रेष्ठगीत 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ﻧﺸﻴﺪ ﺍﻷﻧﺸﺎ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTIQUES 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOHESLIED 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HØJSANGEN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HØYSANGEN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("KANTIKULO 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VELPIESEN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VELPIESEŇ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VEĽPIESEN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VEĽPIESEŇ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("שירי שלמה 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANIADAU 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTARES 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICOS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTIQUE 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CÂNTICOS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("GABAYGII 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOHELIED 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOOGLIED 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("GITRATNA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("GĪTRATNA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("AW NI S 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTARI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTICO 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANTĂRI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CÂNTARI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CÂNTĂRI 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("DIỄM CA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("KANTIKO 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("LAUL. L 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("TÌNH CA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("गीतरत्न 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("श्रेष्ठ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CHANTE 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOGA V 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOGA V 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HÖGA V 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("LAUL L 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("NHÃ CA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESEN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIESEŇ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("S OF S 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ପରମଗୀତ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOGAV 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOOGL 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HÖGAV 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PISEN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PISEŇ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PÍSEN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PÍSEŇ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ПЕСНЬ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("பாடல் 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CANT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CÂNT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOGA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HOJS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HÖGA 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HØJS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HØYS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("KANT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIES 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SNGS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SONG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("TÌNH 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VELP 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VEĽP 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("П. П 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ПЕСН 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ПІСН 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("உன்ன 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("《雅歌》 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("諸歌の歌 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CAN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CNT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("GAB 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HLD 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("LJL 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PNP 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PIS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PNP 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PÍS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SGS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SNG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SOS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SOL 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SON 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VLP 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("VĽP 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("WIM 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("П П 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ПЕС 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ПНП 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("இபா 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("พซม 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("《歌》 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("《雅歌 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("雅歌》 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("CT 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("HL 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PJ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("PŠ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SG 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("SO 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ÉN 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ΑΣ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("نش 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("ἎΣ 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("《歌 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("歌》 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("雅歌 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("아가 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("아 1:1").osis()).toEqual("Song.1.1")
		`
		true
describe "Localized book Prov (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Prov (full)", ->
		`
		expect(p.parse("Книга Приповістеи Соломонових 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Книга Приповістей Соломонових 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ksiega Przypowiesci Salomona 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ksiega Przypowieści Salomona 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ksiegi Przypowiesci Salomona 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ksiegi Przypowieści Salomona 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Księga Przypowiesci Salomona 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Księga Przypowieści Salomona 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Księgi Przypowiesci Salomona 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Księgi Przypowieści Salomona 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Книга Приказок Соломонових 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ks. Przypowiesci Salomona 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ks. Przypowieści Salomona 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Przypowiesci Salomonowych 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Przypowieści Salomonowych 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Книга притчеи Соломоновых 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Книга притчей Соломоновых 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ks Przypowiesci Salomona 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ks Przypowieści Salomona 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Книга Притчи Соломонови 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Приповістеи соломонових 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Приповістей соломонових 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proverbele lui Solomon 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prislovi Salomounova 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prislovi Šalomounova 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prisloví Salomounova 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prisloví Šalomounova 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Príslovi Salomounova 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Príslovi Šalomounova 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prísloví Salomounova 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prísloví Šalomounova 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Přislovi Salomounova 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Přislovi Šalomounova 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Přisloví Salomounova 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Přisloví Šalomounova 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Příslovi Salomounova 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Příslovi Šalomounova 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Přísloví Salomounova 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Přísloví Šalomounova 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Pildele lui Solomon 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Sananlaskujen kirja 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Liber Proverbiorum 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("hitopadesko pustak 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("hitopadeško pustak 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Притчи Соломонови 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("हितोपदेशको पुस्तक 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ordsprogenes Bog 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Salomos Ordsprak 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Salomos Ordsprog 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Salomos Ordspråk 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Мудрые изречения 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Приче Соломонове 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Приче Соломунове 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ksiega Przysłow 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ksiega Przysłów 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ksiegi Przysłow 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ksiegi Przysłów 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Księga Przysłow 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Księga Przysłów 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Księgi Przysłow 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Księgi Przysłów 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Притчі Соломона 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Kniha prislovi 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Kniha prisloví 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Kniha príslovi 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Kniha prísloví 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Mga Panultihon 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ordspraksboken 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ordspråksboken 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Wulang Bebasan 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Fjalet e urta 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Fjalët e urta 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Liv Pwoveb yo 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Liv Pwovèb yo 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Maahmaahyadii 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Orðskviðirnir 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Peldabeszedek 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Peldabeszédek 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Példabeszedek 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Példabeszédek 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Sananlaskujen 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ks. Przysłow 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ks. Przysłów 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Mga Kawikaan 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Mudre izreke 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Sprichworter 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Sprichwörter 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("பழமொழி ஆகமம் 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("K. prislovi 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("K. prisloví 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("K. príslovi 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("K. prísloví 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ks Przysłow 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ks Przysłów 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Neetivachan 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Nitimolikal 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Nitimolikaḷ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Nitimoḻikal 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Nitimoḻikaḷ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Nītimolikal 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Nītimolikaḷ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Nītimoḻikal 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Nītimoḻikaḷ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ordsprakene 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ordsprogene 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ordspråkene 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Probverbios 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Sananlaskut 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("hitopadesko 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("hitopadeško 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Приповістеи 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Приповістей 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("سفر الأمثال 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("नीतिसूत्रें 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("நீதிமொழிகள் 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Diarhebion 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("K prislovi 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("K prisloví 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("K príslovi 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("K prísloví 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Panultihon 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Porverbios 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Preverbios 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proberbios 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proverbele 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proverbios 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Provérbios 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prypovisti 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Приповідок 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Приповісті 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("नीतिसूत्रे 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("हितोपदेशको 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Châm ngôn 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Diarebion 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Poslovice 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Poverbios 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Preverbio 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prislovia 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Probverbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Provebios 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proverbes 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proverbia 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proverbio 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prverbios 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Príslovia 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("nitisutre 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("nitisūtre 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("nītisutre 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("nītisūtre 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Παροιμίαι 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Παροιμίες 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Παροιμιαι 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Παροιμιες 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Пословици 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Kawikaan 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Oroverbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Porverbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Preverbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prislovi 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prisloví 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proberbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proverbe 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proverbi 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proverbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prverbio 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Príslovi 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prísloví 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Přislovi 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Přisloví 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Příslovi 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Přísloví 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Spreuken 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Sprueche 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("kahāutāṃ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Приказки 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Приказок 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("नीति वचन 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("हितोपदेश 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ହିତୋପଦେଶ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Methali 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Mithali 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Poverbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Preverb 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Provebs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Proverb 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prverbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Spruche 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Sprüche 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("الأمثال 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("नीतिबचन 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("नीतिवचन 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ਕਹਾਉਂਤਾ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ਕਹਾਉਤਾਂ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("สุภาษิต 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prvbos 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prverb 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Pwoveb 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Pwovèb 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Sananl 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ams̱āl 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Изреке 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Изреки 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Притчи 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Притчі 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("פתגמים 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("اَمثال 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ordsp 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prvbo 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prvbs 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Przyp 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Притч 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("משלים 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("أمثال 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("امثال 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ﺃﻣﺜﺎﻝ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Châm 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Diar 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Maah 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Meth 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Mith 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Ords 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Peld 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Pris 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prov 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prvb 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Przy 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prís 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Péld 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Přis 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Přís 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Мудр 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Прит 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("משלי 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("नीति 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("நீதி 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("நீமொ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("《箴言》 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("格言の書 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Izr 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Kaw 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Mit 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Okv 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Pro 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prv 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Prz 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Snl 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Spr 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Πρμ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("مثل 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("สภษ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("《箴》 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("《箴言 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("箴言》 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Pr 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Pv 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Pw 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Př 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("Пр 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ام 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("《箴 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("箴》 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("箴言 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("잠언 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("格 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("箴 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("잠 1:1").osis()).toEqual("Prov.1.1")
		p.include_apocrypha(false)
		expect(p.parse("КНИГА ПРИПОВІСТЕИ СОЛОМОНОВИХ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("КНИГА ПРИПОВІСТЕЙ СОЛОМОНОВИХ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KSIEGA PRZYPOWIESCI SALOMONA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KSIEGA PRZYPOWIEŚCI SALOMONA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KSIEGI PRZYPOWIESCI SALOMONA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KSIEGI PRZYPOWIEŚCI SALOMONA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KSIĘGA PRZYPOWIESCI SALOMONA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KSIĘGA PRZYPOWIEŚCI SALOMONA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KSIĘGI PRZYPOWIESCI SALOMONA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KSIĘGI PRZYPOWIEŚCI SALOMONA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("КНИГА ПРИКАЗОК СОЛОМОНОВИХ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KS. PRZYPOWIESCI SALOMONA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KS. PRZYPOWIEŚCI SALOMONA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRZYPOWIESCI SALOMONOWYCH 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRZYPOWIEŚCI SALOMONOWYCH 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("КНИГА ПРИТЧЕИ СОЛОМОНОВЫХ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("КНИГА ПРИТЧЕЙ СОЛОМОНОВЫХ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KS PRZYPOWIESCI SALOMONA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KS PRZYPOWIEŚCI SALOMONA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("КНИГА ПРИТЧИ СОЛОМОНОВИ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ПРИПОВІСТЕИ СОЛОМОНОВИХ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ПРИПОВІСТЕЙ СОЛОМОНОВИХ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVERBELE LUI SOLOMON 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRISLOVI SALOMOUNOVA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRISLOVI ŠALOMOUNOVA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRISLOVÍ SALOMOUNOVA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRISLOVÍ ŠALOMOUNOVA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRÍSLOVI SALOMOUNOVA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRÍSLOVI ŠALOMOUNOVA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRÍSLOVÍ SALOMOUNOVA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRÍSLOVÍ ŠALOMOUNOVA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PŘISLOVI SALOMOUNOVA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PŘISLOVI ŠALOMOUNOVA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PŘISLOVÍ SALOMOUNOVA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PŘISLOVÍ ŠALOMOUNOVA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PŘÍSLOVI SALOMOUNOVA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PŘÍSLOVI ŠALOMOUNOVA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PŘÍSLOVÍ SALOMOUNOVA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PŘÍSLOVÍ ŠALOMOUNOVA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PILDELE LUI SOLOMON 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SANANLASKUJEN KIRJA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("LIBER PROVERBIORUM 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("HITOPADESKO PUSTAK 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("HITOPADEŠKO PUSTAK 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ПРИТЧИ СОЛОМОНОВИ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("हितोपदेशको पुस्तक 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ORDSPROGENES BOG 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SALOMOS ORDSPRAK 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SALOMOS ORDSPROG 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SALOMOS ORDSPRÅK 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("МУДРЫЕ ИЗРЕЧЕНИЯ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ПРИЧЕ СОЛОМОНОВЕ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ПРИЧЕ СОЛОМУНОВЕ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KSIEGA PRZYSŁOW 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KSIEGA PRZYSŁÓW 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KSIEGI PRZYSŁOW 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KSIEGI PRZYSŁÓW 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KSIĘGA PRZYSŁOW 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KSIĘGA PRZYSŁÓW 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KSIĘGI PRZYSŁOW 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KSIĘGI PRZYSŁÓW 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ПРИТЧІ СОЛОМОНА 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KNIHA PRISLOVI 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KNIHA PRISLOVÍ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KNIHA PRÍSLOVI 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KNIHA PRÍSLOVÍ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("MGA PANULTIHON 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ORDSPRAKSBOKEN 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ORDSPRÅKSBOKEN 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("WULANG BEBASAN 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("FJALET E URTA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("FJALËT E URTA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("LIV PWOVEB YO 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("LIV PWOVÈB YO 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("MAAHMAAHYADII 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ORÐSKVIÐIRNIR 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PELDABESZEDEK 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PELDABESZÉDEK 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PÉLDABESZEDEK 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PÉLDABESZÉDEK 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SANANLASKUJEN 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KS. PRZYSŁOW 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KS. PRZYSŁÓW 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("MGA KAWIKAAN 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("MUDRE IZREKE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SPRICHWORTER 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SPRICHWÖRTER 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("பழமொழி ஆகமம் 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("K. PRISLOVI 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("K. PRISLOVÍ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("K. PRÍSLOVI 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("K. PRÍSLOVÍ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KS PRZYSŁOW 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KS PRZYSŁÓW 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("NEETIVACHAN 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("NITIMOLIKAL 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("NITIMOLIKAḶ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("NITIMOḺIKAL 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("NITIMOḺIKAḶ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("NĪTIMOLIKAL 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("NĪTIMOLIKAḶ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("NĪTIMOḺIKAL 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("NĪTIMOḺIKAḶ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ORDSPRAKENE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ORDSPROGENE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ORDSPRÅKENE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROBVERBIOS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SANANLASKUT 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("HITOPADESKO 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("HITOPADEŠKO 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ПРИПОВІСТЕИ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ПРИПОВІСТЕЙ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("سفر الأمثال 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("नीतिसूत्रें 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("நீதிமொழிகள் 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("DIARHEBION 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("K PRISLOVI 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("K PRISLOVÍ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("K PRÍSLOVI 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("K PRÍSLOVÍ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PANULTIHON 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PORVERBIOS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PREVERBIOS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROBERBIOS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVERBELE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVERBIOS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVÉRBIOS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRYPOVISTI 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ПРИПОВІДОК 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ПРИПОВІСТІ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("नीतिसूत्रे 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("हितोपदेशको 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("CHÂM NGÔN 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("DIAREBION 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("POSLOVICE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("POVERBIOS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PREVERBIO 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRISLOVIA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROBVERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVEBIOS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVERBES 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVERBIA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVERBIO 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRVERBIOS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRÍSLOVIA 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("NITISUTRE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("NITISŪTRE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("NĪTISUTRE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("NĪTISŪTRE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ΠΑΡΟΙΜΊΑΙ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ΠΑΡΟΙΜΊΕΣ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ΠΑΡΟΙΜΙΑΙ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ΠΑΡΟΙΜΙΕΣ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ПОСЛОВИЦИ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KAWIKAAN 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("OROVERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PORVERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PREVERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRISLOVI 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRISLOVÍ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROBERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVERBE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVERBI 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRVERBIO 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRÍSLOVI 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRÍSLOVÍ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PŘISLOVI 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PŘISLOVÍ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PŘÍSLOVI 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PŘÍSLOVÍ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SPREUKEN 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SPRUECHE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KAHĀUTĀṂ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ПРИКАЗКИ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ПРИКАЗОК 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("नीति वचन 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("हितोपदेश 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ହିତୋପଦେଶ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("METHALI 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("MITHALI 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("POVERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PREVERB 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVEBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROVERB 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRVERBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SPRUCHE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SPRÜCHE 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("الأمثال 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("नीतिबचन 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("नीतिवचन 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ਕਹਾਉਂਤਾ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ਕਹਾਉਤਾਂ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("สุภาษิต 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRVBOS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRVERB 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PWOVEB 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PWOVÈB 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SANANL 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("AMS̱ĀL 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ИЗРЕКЕ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ИЗРЕКИ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ПРИТЧИ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ПРИТЧІ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("פתגמים 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("اَمثال 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ORDSP 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRVBO 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRVBS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRZYP 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ПРИТЧ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("משלים 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("أمثال 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("امثال 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ﺃﻣﺜﺎﻝ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("CHÂM 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("DIAR 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("MAAH 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("METH 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("MITH 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ORDS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PELD 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRIS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PROV 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRVB 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRZY 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRÍS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PÉLD 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PŘIS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PŘÍS 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("МУДР 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ПРИТ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("משלי 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("नीति 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("நீதி 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("நீமொ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("《箴言》 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("格言の書 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("IZR 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("KAW 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("MIT 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("OKV 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRO 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRV 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PRZ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SNL 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("SPR 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ΠΡΜ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("مثل 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("สภษ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("《箴》 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("《箴言 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("箴言》 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PR 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PV 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PW 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("PŘ 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ПР 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("ام 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("《箴 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("箴》 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("箴言 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("잠언 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("格 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("箴 1:1").osis()).toEqual("Prov.1.1")
		expect(p.parse("잠 1:1").osis()).toEqual("Prov.1.1")
		`
		true
describe "Localized book Wis (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Wis (full)", ->
		`
		expect(p.parse("Cartea intelepciunii lui Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Cartea inţelepciunii lui Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Cartea întelepciunii lui Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Cartea înţelepciunii lui Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Книга Премъдрост Соломонова 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Книга Премудрості Соломона 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ang Karunungan ni Salomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ang Karunungan ni Salomón 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ang Karunungan ni Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ang Karunungan ni Solomón 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Intelepciunea lui Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ințelepciunea lui Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Întelepciunea lui Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Înțelepciunea lui Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Книга Мудрост Соломонова 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("De wijsheid van Salomo 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Премудорсти Соломонове 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Het boek der wijsheid 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Karunungan ni Salomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Karunungan ni Salomón 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Karunungan ni Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Karunungan ni Solomón 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("The Wisdom of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Премъдрост Соломонова 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Cartea Intelepciunii 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Cartea Ințelepciunii 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Cartea Întelepciunii 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Cartea Înțelepciunii 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Moudrost Salomounova 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Moudrost Šalomounova 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sabedoria de Salomao 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sabedoria de Salomão 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sapienza di Salomone 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("The Wisom of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Премудрости Соломона 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Премудрість Соломона 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Kawicaksanan Salomo 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Salamon bolcsessege 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Salamon bolcsessége 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Salamon bölcsessege 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Salamon bölcsessége 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sapientia Salomonis 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("The Wisd of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wijsheid van Salomo 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Мудрости Соломонове 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Hekima ya Solomoni 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sagesse de Salomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("The Wis of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Книга на мъдростта 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Doethineb Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wisdom of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Liber Sapientiae 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Madrosc Salomona 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Madrosć Salomona 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Madrośc Salomona 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Madrość Salomona 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Mądrosc Salomona 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Mądrosć Salomona 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Mądrośc Salomona 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Mądrość Salomona 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Weisheit Salomos 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wisom of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Σοφία Σαλωμωντος 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Σοφία Σαλωμώντος 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Σοφία Σολομωντος 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Σοφία Σολομώντος 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Σοφια Σαλωμωντος 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Σοφια Σαλωμώντος 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Σοφια Σολομωντος 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Σοφια Σολομώντος 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Kniha Moudrosti 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Kniha moudrosti 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Kniha moudrostí 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Knjiga Mudrosti 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ksiega Madrosci 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ksiega Madrości 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ksiega Mądrosci 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ksiega Mądrości 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ksiegi Madrosci 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ksiegi Madrości 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ksiegi Mądrosci 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ksiegi Mądrości 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Księga Madrosci 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Księga Madrości 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Księga Mądrosci 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Księga Mądrości 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Księgi Madrosci 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Księgi Madrości 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Księgi Mądrosci 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Księgi Mądrości 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Salomon viisaus 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Viisauden kirja 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wisd of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("சாலமோனின் ஞானம் 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Salomos Visdom 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Salomos vishet 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Speki Salomons 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Speki Salómons 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Visdommens Bog 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Visdommens bok 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wis of Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Книга Мудрости 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Vishetens bok 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Kawicaksanan 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ks. Madrosci 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ks. Madrości 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ks. Mądrosci 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ks. Mądrości 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ks Madrosci 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ks Madrości 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ks Mądrosci 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Ks Mądrości 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("حكمة سليمان 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Bolcsesseg 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Bolcsesség 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Bölcsesseg 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Bölcsesség 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Karunungan 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Khôn Ngoan 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Премъдрост 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("سفر الحكمة 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sabedoria 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sabiduria 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sabiduría 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sapientia 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Visdommen 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Σοφία Σολ 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Σοφια Σολ 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("חכמת שלמה 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Moudrost 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Mudrosti 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Múdrosti 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sapienza 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Visheten 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Weisheit 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wijsheid 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Мудрости 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Прем Сол 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("ஞானாகமம் 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("ปรีชาญาณ 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("ソロモンの知恵書 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Mudrost 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Mudrosť 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Múdrost 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Múdrosť 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sagesse 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Salomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Salomón 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sapient 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Solomon 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Solomón 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("ソロモンの智慧 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Hekima 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wisdom 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("الحكمة 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Bolcs 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Bölcs 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Weish 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Σοφία 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Σοφια 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("《智慧篇》 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Madr 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Mudr 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Mądr 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("SSal 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Viis 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Visd 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Vish 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wisd 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Прем 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("சாஞா 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("《智慧篇 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("智慧篇》 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("知恵の書 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Hek 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Kar 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Mdr 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Mud 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Múd 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sab 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sap 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Wis 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Σοφ 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Муд 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("智慧篇 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("지혜서 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("Sb 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("حك 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("知恵 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("지혜 1:1").osis()).toEqual("Wis.1.1")
		expect(p.parse("知 1:1").osis()).toEqual("Wis.1.1")
		`
		true
describe "Localized book Joel (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Joel (full)", ->
		`
		expect(p.parse("ଯୋୟେଲ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Книга на пророк Иоиля 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Книга на пророк Иоил 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Книга пророка Иоиля 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Книга пророка Иоіла 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Книга пророка Йоіла 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Proroctwo Ioelowe 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Prophetia Ioel 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("योएलको पुस्तक 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joelin kirja 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Ksiega Joela 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Ksiegi Joela 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Księga Joela 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Księgi Joela 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Liv Jowel la 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Liv Jowèl la 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Книга Иоіла 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Книга Йоіла 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joels Bog 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joels bok 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Ks. Joela 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("سفر يوئيل 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Ks Joela 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Yoo'eel 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Yoo’eel 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Gioele 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Giô-ên 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joelin 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("یُوایل 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("யோவேல் 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joela 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joeli 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Jowel 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Jowèl 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Yoael 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Yoeli 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Yovel 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Yovēl 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Yōvel 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Yōvēl 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("yōʾīl 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Иоиль 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Иоиля 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Иоіла 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Йоіла 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("يوئيل 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("یوایل 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ଯୋୟେଲ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("โยเอล 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("《岳厄爾》 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("《約珥書》 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("《约珥书》 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("《约饵书》 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("よえるしょ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Gioe 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Ioel 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Ioil 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joel 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joil 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joél 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joël 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joïl 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Jóel 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Jóél 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Yoel 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Yole 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Yool 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("yoel 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Ιωήλ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Ιωηλ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Јоел 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Јоил 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Јоиљ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Иоил 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Иоіл 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Иоін 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Иоїл 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Иоїн 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Йоил 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Йоіл 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Йоін 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Йоїл 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Йоїн 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("יואל 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("योएल 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ਜੋਏਲ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ਯੋਏਲ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("யோவே 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("《岳厄爾 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("《約珥書 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("《约珥书 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("《约饵书 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ヨエル書 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("岳厄爾》 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("約珥書》 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("约珥书》 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("约饵书》 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joe 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Joë 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Yoe 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("يوء 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ยอล 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("《珥》 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ヨエル 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("岳厄爾 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("約珥書 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("约珥书 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("约饵书 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("요엘서 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Jl 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Ιλ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("Ἰλ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("《珥 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("珥》 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("요엘 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("珥 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("욜 1:1").osis()).toEqual("Joel.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ଯୋୟେଲ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("КНИГА НА ПРОРОК ИОИЛЯ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("КНИГА НА ПРОРОК ИОИЛ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("КНИГА ПРОРОКА ИОИЛЯ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("КНИГА ПРОРОКА ИОІЛА 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("КНИГА ПРОРОКА ЙОІЛА 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("PROROCTWO IOELOWE 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("PROPHETIA IOEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("योएलको पुस्तक 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOELIN KIRJA 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("KSIEGA JOELA 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("KSIEGI JOELA 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("KSIĘGA JOELA 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("KSIĘGI JOELA 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("LIV JOWEL LA 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("LIV JOWÈL LA 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("КНИГА ИОІЛА 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("КНИГА ЙОІЛА 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOELS BOG 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOELS BOK 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("KS. JOELA 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("سفر يوئيل 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("KS JOELA 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YOO'EEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YOO’EEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("GIOELE 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("GIÔ-ÊN 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOELIN 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("یُوایل 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("யோவேல் 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOELA 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOELI 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOWEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOWÈL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YOAEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YOELI 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YOVEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YOVĒL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YŌVEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YŌVĒL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YŌʾĪL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ИОИЛЬ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ИОИЛЯ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ИОІЛА 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ЙОІЛА 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("يوئيل 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("یوایل 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ଯୋୟେଲ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("โยเอล 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("《岳厄爾》 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("《約珥書》 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("《约珥书》 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("《约饵书》 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("よえるしょ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("GIOE 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("IOEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("IOIL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOIL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOÉL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOËL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOÏL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JÓEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JÓÉL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YOEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YOLE 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YOOL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YOEL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ΙΩΉΛ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ΙΩΗΛ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ЈОЕЛ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ЈОИЛ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ЈОИЉ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ИОИЛ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ИОІЛ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ИОІН 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ИОЇЛ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ИОЇН 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ЙОИЛ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ЙОІЛ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ЙОІН 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ЙОЇЛ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ЙОЇН 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("יואל 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("योएल 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ਜੋਏਲ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ਯੋਏਲ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("யோவே 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("《岳厄爾 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("《約珥書 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("《约珥书 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("《约饵书 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ヨエル書 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("岳厄爾》 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("約珥書》 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("约珥书》 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("约饵书》 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOE 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JOË 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("YOE 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("يوء 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ยอล 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("《珥》 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ヨエル 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("岳厄爾 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("約珥書 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("约珥书 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("约饵书 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("요엘서 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("JL 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ΙΛ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("ἸΛ 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("《珥 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("珥》 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("요엘 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("珥 1:1").osis()).toEqual("Joel.1.1")
		expect(p.parse("욜 1:1").osis()).toEqual("Joel.1.1")
		`
		true
describe "Localized book Jonah (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Jonah (full)", ->
		`
		expect(p.parse("ଯୂନସ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Книга на пророк Иона 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Proroctwo Ionaszowe 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Книга пророка Иони 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Книга пророка Ионы 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Книга пророка Йони 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Prophetia Ionae 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Ksiega Jonasza 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Ksiegi Jonasza 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Księga Jonasza 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Księgi Jonasza 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("योनाको पुस्तक 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Joonan kirja 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Liv Jonas la 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Ks. Jonasza 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jonas' Bog 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jonas’ Bog 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Ks Jonasza 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jonas bok 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("سفر يونان 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jona bok 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jonasza 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Giô-na 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Joonan 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Yoonis 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("یُوناہ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("โยนาห์ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Giona 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Ionas 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jonah 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jonas 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jonaš 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jonáh 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jonás 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jonáš 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Joona 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jónas 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jónás 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Yunus 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("yūnas 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("yūnāh 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Ιωνάς 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Ιωνας 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("يونان 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ਯੂਨਾਹ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("《約拿書》 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("《约拿书》 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Iona 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jona 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Joná 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Yona 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Yonā 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Yoon 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Yoṉa 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Yoṉā 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Yōna 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Yōnā 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Yōṉa 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Yōṉā 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("yona 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("yonā 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Јона 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Иона 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Иони 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Ионы 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Йона 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Йони 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Юнус 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("יונה 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("یونس 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("योना 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ଯୂନସ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("யோனா 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("《約拿書 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("《約納》 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("《约拿书 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ヨナしょ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("約拿書》 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("约拿书》 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Gio 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jnh 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jns 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jon 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Jón 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Yon 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Ион 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Йон 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("يون 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ยนา 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("《拿》 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("《約納 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ヨナ書 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("約拿書 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("約納》 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("约拿书 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("요나서 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Ιν 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("Ἰν 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("《拿 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ヨナ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("拿》 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("約納 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("요나 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("拿 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("욘 1:1").osis()).toEqual("Jonah.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ଯୂନସ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("КНИГА НА ПРОРОК ИОНА 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("PROROCTWO IONASZOWE 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("КНИГА ПРОРОКА ИОНИ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("КНИГА ПРОРОКА ИОНЫ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("КНИГА ПРОРОКА ЙОНИ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("PROPHETIA IONAE 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("KSIEGA JONASZA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("KSIEGI JONASZA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("KSIĘGA JONASZA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("KSIĘGI JONASZA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("योनाको पुस्तक 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JOONAN KIRJA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("LIV JONAS LA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("KS. JONASZA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JONAS' BOG 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JONAS’ BOG 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("KS JONASZA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JONAS BOK 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("سفر يونان 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JONA BOK 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JONASZA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("GIÔ-NA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JOONAN 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("YOONIS 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("یُوناہ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("โยนาห์ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("GIONA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("IONAS 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JONAH 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JONAS 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JONAŠ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JONÁH 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JONÁS 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JONÁŠ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JOONA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JÓNAS 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JÓNÁS 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("YUNUS 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("YŪNAS 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("YŪNĀH 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ΙΩΝΆΣ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ΙΩΝΑΣ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("يونان 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ਯੂਨਾਹ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("《約拿書》 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("《约拿书》 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("IONA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JONA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JONÁ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("YONA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("YONĀ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("YOON 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("YOṈA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("YOṈĀ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("YŌNA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("YŌNĀ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("YŌṈA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("YŌṈĀ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("YONA 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("YONĀ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ЈОНА 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ИОНА 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ИОНИ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ИОНЫ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ЙОНА 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ЙОНИ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ЮНУС 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("יונה 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("یونس 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("योना 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ଯୂନସ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("யோனா 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("《約拿書 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("《約納》 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("《约拿书 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ヨナしょ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("約拿書》 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("约拿书》 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("GIO 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JNH 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JNS 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JON 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("JÓN 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("YON 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ИОН 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ЙОН 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("يون 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ยนา 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("《拿》 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("《約納 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ヨナ書 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("約拿書 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("約納》 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("约拿书 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("요나서 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ΙΝ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ἸΝ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("《拿 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("ヨナ 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("拿》 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("約納 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("요나 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("拿 1:1").osis()).toEqual("Jonah.1.1")
		expect(p.parse("욘 1:1").osis()).toEqual("Jonah.1.1")
		`
		true
describe "Localized book Nah (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Nah (full)", ->
		`
		expect(p.parse("ନାହୂମ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Книга на пророк Наума 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Книга на пророк Наум 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Книга пророка Наума 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Proroctwo Nahumowe 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Prophetia Nahum 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Liv Nawoum lan 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Ksiega Nahuma 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Ksiegi Nahuma 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Księga Nahuma 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Księgi Nahuma 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahumin kirja 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("नहूमको पुस्तक 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Ks. Nahuma 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahums Bog 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahums bok 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Ks Nahuma 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("سفر ناحوم 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahumin 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("نا حُوم 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Na-hum 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Na-hâm 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahoom 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahuma 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahumi 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahumu 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nawoum 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nawoun 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Naxuum 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("ناحُوم 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("நாகூம் 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahum 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahúm 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nakum 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nakūm 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Náhum 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nākum 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nākūm 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("nahum 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("nahūm 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("nāḥūm 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Ναουμ 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Ναούμ 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Наума 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("ناحوم 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("ନାହୂମ 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("นาฮูม 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《那鴻书》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《那鴻書》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《那鸿书》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("ナホムしょ 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nach 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahu 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nahú 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Naum 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Наум 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("נחום 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("نحوم 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("नहूम 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("ਨਹੂਮ 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("நாகூ 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《納鴻》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《那鴻书 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《那鴻書 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《那鸿书 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("ナホム書 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("那鴻书》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("那鴻書》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("那鸿书》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nah 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Naw 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nax 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Náh 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("نحو 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("นฮม 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《納鴻 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《鴻》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《鸿》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("ナホム 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("納鴻》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("那鴻书 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("那鴻書 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("那鸿书 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("나훔서 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Na 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Nh 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("Να 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("نا 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《鴻 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《鸿 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("納鴻 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("鴻》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("鸿》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("나훔 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("鴻 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("鸿 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("나 1:1").osis()).toEqual("Nah.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ନାହୂମ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("КНИГА НА ПРОРОК НАУМА 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("КНИГА НА ПРОРОК НАУМ 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("КНИГА ПРОРОКА НАУМА 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("PROROCTWO NAHUMOWE 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("PROPHETIA NAHUM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("LIV NAWOUM LAN 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("KSIEGA NAHUMA 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("KSIEGI NAHUMA 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("KSIĘGA NAHUMA 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("KSIĘGI NAHUMA 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHUMIN KIRJA 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("नहूमको पुस्तक 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("KS. NAHUMA 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHUMS BOG 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHUMS BOK 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("KS NAHUMA 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("سفر ناحوم 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHUMIN 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("نا حُوم 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NA-HUM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NA-HÂM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHOOM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHUMA 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHUMI 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHUMU 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAWOUM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAWOUN 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAXUUM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("ناحُوم 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("நாகூம் 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHUM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHÚM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAKUM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAKŪM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NÁHUM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NĀKUM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NĀKŪM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHUM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHŪM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NĀḤŪM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("ΝΑΟΥΜ 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("ΝΑΟΎΜ 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("НАУМА 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("ناحوم 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("ନାହୂମ 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("นาฮูม 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《那鴻书》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《那鴻書》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《那鸿书》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("ナホムしょ 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NACH 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHU 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAHÚ 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAUM 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("НАУМ 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("נחום 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("نحوم 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("नहूम 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("ਨਹੂਮ 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("நாகூ 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《納鴻》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《那鴻书 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《那鴻書 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《那鸿书 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("ナホム書 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("那鴻书》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("那鴻書》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("那鸿书》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAH 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAW 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NAX 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NÁH 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("نحو 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("นฮม 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《納鴻 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《鴻》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《鸿》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("ナホム 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("納鴻》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("那鴻书 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("那鴻書 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("那鸿书 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("나훔서 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NA 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("NH 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("ΝΑ 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("نا 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《鴻 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("《鸿 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("納鴻 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("鴻》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("鸿》 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("나훔 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("鴻 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("鸿 1:1").osis()).toEqual("Nah.1.1")
		expect(p.parse("나 1:1").osis()).toEqual("Nah.1.1")
		`
		true
describe "Localized book 1John (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1John (full)", ->
		`
		expect(p.parse("Първо съборно послание на св. ап. Иоана Богослова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Първо съборно послание на св ап. Иоана Богослова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Първо съборно послание на св. ап Иоана Богослова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Първо съборно послание на св ап Иоана Богослова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перша соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перше соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше. соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перша соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перше соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а. соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е. соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta bref Johannesar hið almenna 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta bref Jóhannesar hið almenna 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta bréf Johannesar hið almenna 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta bréf Jóhannesar hið almenna 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yovan Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yovan Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yovan Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yovan Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yovaṉ Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yovaṉ Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yōvan Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yōvan Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yōvan Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yōvan Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Perse poslannja apostola Ivana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Perše poslannja apostola Ivana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Прва послание на апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Прво послание на апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше. послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ensimmainen Johanneksen kirje 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ensimmäinen Johanneksen kirje 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перша послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перше послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("யோவன் எழுதிய முதலாவது நிருபம் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("யோவான் எழுதிய முதல் திருமுகம் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а. послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е. послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. послание на апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. послание на апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("யோவான் எழுதிய முதலாம் கடிதம் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 послание на апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I послание на апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Прва писмо од апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Прво писмо од апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("אגרתו הראשונה של יוחנן השלי 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Waraka wa Kwanza wa Yohane 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. писмо од апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Barua ya Kwanza ya Yohane 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. писмо од апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prima lettera di Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("رسالة القديس يوحنا الأولى 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 писмо од апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I писмо од апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yūḥannā kā pahlā ʿām ḫaṭ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ensimmainen Johanneksen 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ensimmäinen Johanneksen 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yūhãnā dī pahilī pattrī 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Прва посланица Јованова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta bref Johannesar 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta bref Jóhannesar 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta bréf Johannesar 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta bréf Jóhannesar 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsza List sw. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsza List św. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsze List sw. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsze List św. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwszy List sw. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwszy List św. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prva Ivanova Poslanica 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prva Ivanova poslanica 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yohanacem pahile patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yohanaceṃ pahile patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yohanācem pahile patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yohanāceṃ pahile patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yohānacem pahile patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yohānaceṃ pahile patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yohānācem pahile patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yohānāceṃ pahile patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yuhannako pahilo patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yuhannāko pahilo patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yūhannako pahilo patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yūhannāko pahilo patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Първо послание на Иоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Първо послание на Йоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("یُوحنّا کا پہلا عام خط 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ਯੂਹੰਨਾ ਦੀ ਪਹਿਲੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("யோவான் முதல் திருமுகம் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. посланица Јованова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Forsta Johannesbrevet 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta Johannesarbref 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta Johannesarbréf 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta Jóhannesarbref 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta Jóhannesarbréf 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Första Johannesbrevet 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. посланица Јованова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes' Første Brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes’ Første Brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes’ første brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsza List sw Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsza List św Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsze List sw Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsze List św Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwszy List sw Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwszy List św Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("یوحنّا کا پہلا عام خط 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 посланица Јованова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е. послание Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше. Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-я. послание Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Ivanova Poslanica 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Johanneksen kirje 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I посланица Јованова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Ivanova Poslanica 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Johanneksen kirje 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes forsta brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes första brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перша Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перше Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("یوحنا کا پہلا عام خط 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("यूहन्नाको पहिलो पत्र 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("योहानाचें पहिले पत्र 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Ivanova Poslanica 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Johanneksen kirje 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а. Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е послание Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е. Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-я послание Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1е. послание Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1я. послание Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Første Johannesbrev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Ivanova Poslanica 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Johanneksen kirje 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("איגרת יוחנן הראשונה 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. послание Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1е послание Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1я послание Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Epistula I Ioannis 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Epistula Ioannis I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsza List Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsze List Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwszy List Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("رسالة يوحنا الأولى 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ଯୋହନଙ୍କ ପ୍ରଥମ ପତ୍ର 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 послание Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Johannesbrevet 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes' 1. Brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes’ 1. Brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Mutalavatu யோவான் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Mutalāvatu யோவான் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Johannesbrevet 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. List sw. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. List św. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. List sw. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. List św. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes' 1 Brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes’ 1 Brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prva kniha Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prva kniha Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvni list Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvni list Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("První list Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("První list Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvá kniha Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvá kniha Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 List sw. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 List św. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Johannesbrev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. List sw Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. List św Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Eerste Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Første Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I List sw. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I List św. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. List sw Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. List św Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvy Janov list 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvy Jánov list 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvy list Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvy list Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvý Janov list 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvý Jánov list 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvý list Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvý list Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yooxanaa Kowaad 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("முதலாவது யோவான் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Johannesbrev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 List sw Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 List św Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Johanneksen 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Erste Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I List sw Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I List św Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Johanneksen 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Premieres Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Premières Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prima Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primo Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Johanneksen 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше. Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше. Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. list Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. list Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Johanneksen 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. list Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. list Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Kwanza Yohana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Kwanza Yohane 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsza Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsze Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwszy Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Premiere Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Premiers Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Première Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primeira Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primeira João 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primeiro Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primeiro João 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перша Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перша Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перше Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перше Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Прва Јованова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Прва Јованово 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Прво Јованово 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Първа Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Първа Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("رسالة يوحنا 1 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 list Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 list Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а. Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а. Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е. Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е. Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше. Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. List Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. yuhannako 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. yuhannāko 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. yūhannako 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. yūhannāko 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. यूहन्नाको 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1e. Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1°. Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I list Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I list Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. List Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Premier Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prva Ivanova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvni Janova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("První Janova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перша Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перше Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("اوّل یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("اوّل-یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("يوحنا الأولى 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 List Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 e. Gjonit 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 i. Gjonit 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yohanacem 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yohanaceṃ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yohanācem 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yohanāceṃ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yohānacem 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yohānaceṃ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yohānācem 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yohānāceṃ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yuhannako 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yuhannāko 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yūhannako 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yūhannāko 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 यूहन्नाको 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 அருளப்பர் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а. Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е. Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е. Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е. Иохана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше. Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-я. Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-я. Иохана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yoohanna 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yooxanaa 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Јованова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Јованово 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1e Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1° Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I List Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Yooxanaa 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Јованова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Јованово 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvni Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvni Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("První Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("První Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перша Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перше Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("اوّل یوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ପ୍ରଥମ ଯୋହନଙ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yoohanna 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yooxanaa 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 e Gjonit 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 i Gjonit 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 k. Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 k. Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Јованова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Јованово 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а. Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е Иохана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е. Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-я Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-я Иохана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Ioannis 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Ivanova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yohanes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yokanan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. युहत्रा 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. यूहन्ना 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.-یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ere. Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ère. Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1е. Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1е. Иохана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1я. Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1я. Иохана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Eerste Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Elso Janos 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Elso János 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Első Janos 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Első János 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Første Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Yooxanaa 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Јованова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Јованово 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Ioannis 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Ivanova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Yohanes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Yokanan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Kwanza Yoh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Premye Jan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prva Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prva Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvy Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvy Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvá Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvá Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvý Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvý Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Unang Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ιωάννου Α' 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ιωάννου Αʹ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ιωάννου Αʹ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ιωάννου Α΄ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ιωάννου Α’ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ιωαννου Α' 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ιωαννου Αʹ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ιωαννου Αʹ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ιωαννου Α΄ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ιωαννου Α’ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Прва Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Прво Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Първа Иоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Първа Йоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("اوّل۔یوحنا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ﻳﻮﺣﻨﺎ ﺍﻻﻭﻝ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Ioannis 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Ivanova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yohanes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yokanan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 k Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 k Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 युहत्रा 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 यूहन्ना 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 योहानाच 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Gjonit 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Janova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yohana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yohane 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Иохана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. یوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. யோவான் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1er. Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ere Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1re. Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ère Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1е Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1е Иохана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1я Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1я Иохана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Ioannis 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Ivanova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Yohanes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Yokanan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Janova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Yohana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Yohane 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ioannis I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvni Jan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("První Jan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α' Ιωάννη 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α' Ιωαννη 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ Ιωάννη 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ Ιωαννη 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ Ιωάννη 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ Ιωαννη 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α΄ Ιωάννη 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α΄ Ιωαννη 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α’ Ιωάννη 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α’ Ιωαννη 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("۱ یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("۱-یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ヨハネの第一の手紙 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("요한의 첫째 서간 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Gjonit 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Janova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yohana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yohane 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yūhãnā 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Иохана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 یوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ਯੂਹੰਨਾ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 யோவான் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Gioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Giăng 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Janos 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. János 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ଯୋହନଙ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ยอห์น 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.۔یوحنا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1a. Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1a. João 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1er Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. João 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1re Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Janova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Yohana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Yohane 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Gioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Giăng 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Janos 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. János 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Una Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yohane I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("۱ یوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ヨハネの第一の書 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Gioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Giăng 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Janos 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 János 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yovan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yovaṉ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yōvan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yōvaṉ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 योहान 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ଯୋହନଙ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ยอห์น 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Ioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. João 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yoox 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Иоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Йоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1a Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1a João 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1e. Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o João 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1۔یوحنا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Elso Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Első Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Gioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Giăng 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Janos 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I János 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Ioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. João 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Yoox 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Иоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Йоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Janos I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("János I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvni J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("První J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("۱۔یوحنا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ヨハネの手紙一 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Ioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 João 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yoox 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Иоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Йоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 யோவா 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jóh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yoh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1e Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Ioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I João 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Yoox 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Иоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Йоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jóh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Yoh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α' ᾿Ιω 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ ᾿Ιω 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ ᾿Ιω 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α΄ ᾿Ιω 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α’ ᾿Ιω 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《伊望第一》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《約翰一書》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《約翰壹書》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《约翰一书》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《约翰壹书》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《若望一書》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jóh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yoh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Gi 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. In 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jóh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Yoh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Gi 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. In 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α' Ιω 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ Ιω 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ Ιω 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α΄ Ιω 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α’ Ιω 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《伊望第一 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《約翰一書 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《約翰壹書 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《约翰一书 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《约翰壹书 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《若望一書 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ヨハネ 1 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("伊望第一》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("約翰一書》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("約翰壹書》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("约翰一书》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("约翰壹书》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("若望一書》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Gi 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Gj 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Gv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 In 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Iv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Ів 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Јн 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Ин 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 يو 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 யோ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ยน 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Gi 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I In 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《約壹》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《约壹》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("一ヨハネ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("伊望第一 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("約翰一書 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("約翰壹書 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("约翰一书 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("约翰壹书 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("若望一書 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("요한1서 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("요한일서 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1요한 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《約壹 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《约壹 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("約壹》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("约壹》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("約壹 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("约壹 1:1").osis()).toEqual("1John.1.1")
		`
		true
	it "should handle non-Latin digits in book: 1John (full)", ->
		p.set_options non_latin_digits_strategy: "replace"
		`
		expect(p.parse("Първо съборно послание на св. ап. Иоана Богослова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Първо съборно послание на св ап. Иоана Богослова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Първо съборно послание на св. ап Иоана Богослова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Първо съборно послание на св ап Иоана Богослова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перша соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перше соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше. соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перша соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перше соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а. соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е. соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I соборне послання св. апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I соборне послання св апостола Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta bref Johannesar hið almenna 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta bref Jóhannesar hið almenna 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta bréf Johannesar hið almenna 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta bréf Jóhannesar hið almenna 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yovan Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yovan Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yovan Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yovan Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yovaṉ Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yovaṉ Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yōvan Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yōvan Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yōvan Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yōvan Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Perse poslannja apostola Ivana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Perše poslannja apostola Ivana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Прва послание на апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Прво послание на апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше. послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ensimmainen Johanneksen kirje 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ensimmäinen Johanneksen kirje 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перша послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перше послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("யோவன் எழுதிய முதலாவது நிருபம் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("யோவான் எழுதிய முதல் திருமுகம் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а. послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е. послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. послание на апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. послание на апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("யோவான் எழுதிய முதலாம் கடிதம் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 послание на апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I послание на апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Прва писмо од апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Прво писмо од апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("אגרתו הראשונה של יוחנן השלי 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Waraka wa Kwanza wa Yohane 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. писмо од апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Barua ya Kwanza ya Yohane 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I послання апостола Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. писмо од апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prima lettera di Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("رسالة القديس يوحنا الأولى 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 писмо од апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I писмо од апостол Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yūḥannā kā pahlā ʿām ḫaṭ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ensimmainen Johanneksen 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ensimmäinen Johanneksen 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yūhãnā dī pahilī pattrī 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Прва посланица Јованова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta bref Johannesar 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta bref Jóhannesar 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta bréf Johannesar 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta bréf Jóhannesar 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsza List sw. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsza List św. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsze List sw. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsze List św. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwszy List sw. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwszy List św. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prva Ivanova Poslanica 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prva Ivanova poslanica 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yohanacem pahile patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yohanaceṃ pahile patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yohanācem pahile patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yohanāceṃ pahile patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yohānacem pahile patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yohānaceṃ pahile patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yohānācem pahile patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yohānāceṃ pahile patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yuhannako pahilo patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yuhannāko pahilo patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yūhannako pahilo patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("yūhannāko pahilo patra 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Първо послание на Иоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Първо послание на Йоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("یُوحنّا کا پہلا عام خط 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ਯੂਹੰਨਾ ਦੀ ਪਹਿਲੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("யோவான் முதல் திருமுகம் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. посланица Јованова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Forsta Johannesbrevet 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta Johannesarbref 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta Johannesarbréf 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta Jóhannesarbref 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Fyrsta Jóhannesarbréf 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Första Johannesbrevet 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. посланица Јованова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes' Første Brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes’ Første Brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes’ første brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsza List sw Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsza List św Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsze List sw Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsze List św Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwszy List sw Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwszy List św Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("یوحنّا کا پہلا عام خط 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 посланица Јованова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е. послание Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше. Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-я. послание Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Ivanova Poslanica 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Johanneksen kirje 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I посланица Јованова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Ivanova Poslanica 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Johanneksen kirje 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes forsta brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes första brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перша Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перше Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("یوحنا کا پہلا عام خط 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("यूहन्नाको पहिलो पत्र 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("योहानाचें पहिले पत्र 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Ivanova Poslanica 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Johanneksen kirje 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а. Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е послание Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е. Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-я послание Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1е. послание Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1я. послание Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Første Johannesbrev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Ivanova Poslanica 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Johanneksen kirje 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("איגרת יוחנן הראשונה 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. послание Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1е послание Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1я послание Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Epistula I Ioannis 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Epistula Ioannis I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsza List Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsze List Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwszy List Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("رسالة يوحنا الأولى 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ଯୋହନଙ୍କ ପ୍ରଥମ ପତ୍ର 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 послание Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Johannesbrevet 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes' 1. Brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes’ 1. Brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Mutalavatu யோவான் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Mutalāvatu யோவான் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Johannesbrevet 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. List sw. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. List św. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Послання Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. List sw. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. List św. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes' 1 Brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Johannes’ 1 Brev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prva kniha Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prva kniha Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvni list Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvni list Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("První list Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("První list Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvá kniha Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvá kniha Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 List sw. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 List św. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Johannesbrev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. List sw Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. List św Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Eerste Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Første Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I List sw. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I List św. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. List sw Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. List św Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvy Janov list 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvy Jánov list 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvy list Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvy list Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvý Janov list 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvý Jánov list 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvý list Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvý list Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yooxanaa Kowaad 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("முதலாவது யோவான் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Johannesbrev 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 List sw Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 List św Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Johanneksen 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Erste Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I List sw Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I List św Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Johanneksen 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Premieres Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Premières Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prima Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primo Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Johanneksen 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше. Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше. Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. list Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. list Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Johanneksen 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. list Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. list Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Kwanza Yohana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Kwanza Yohane 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsza Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwsze Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Pierwszy Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Premiere Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Premiers Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Première Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primeira Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primeira João 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primeiro Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primeiro João 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перша Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перша Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перше Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перше Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Прва Јованова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Прва Јованово 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Прво Јованово 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Първа Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Първа Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("رسالة يوحنا 1 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 list Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 list Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а. Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а. Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е. Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е. Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше. Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. List Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. yuhannako 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. yuhannāko 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. yūhannako 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. yūhannāko 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. यूहन्नाको 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1e. Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1°. Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I list Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I list Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. List Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Premier Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primero Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prva Ivanova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvni Janova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("První Janova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перша Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перше Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("اوّل یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("اوّل-یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("يوحنا الأولى 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 List Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 e. Gjonit 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 i. Gjonit 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yohanacem 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yohanaceṃ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yohanācem 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yohanāceṃ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yohānacem 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yohānaceṃ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yohānācem 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yohānāceṃ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yuhannako 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yuhannāko 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yūhannako 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yūhannāko 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 यूहन्नाको 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 அருளப்பர் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а. Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е. Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е. Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е. Иохана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше. Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-я. Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-я. Иохана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yoohanna 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yooxanaa 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Јованова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Јованово 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1e Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1° Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I List Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Yooxanaa 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Јованова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Јованово 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Primer Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvni Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvni Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("První Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("První Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перша Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Перше Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("اوّل یوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ପ୍ରଥମ ଯୋହନଙ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yoohanna 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yooxanaa 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 e Gjonit 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 i Gjonit 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 k. Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 k. Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Јованова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Јованово 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а. Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е Иохана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е. Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ше Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-я Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-я Иохана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Ioannis 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Ivanova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yohanes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yokanan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. युहत्रा 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. यूहन्ना 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.-یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ere. Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ère. Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1е. Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1е. Иохана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1я. Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1я. Иохана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Eerste Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Elso Janos 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Elso János 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Első Janos 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Első János 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Første Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Giovanni 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Johannes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I San Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I San Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I San Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I San Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Yooxanaa 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Јованова 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Јованово 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Ioannis 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Ivanova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Yohanes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Yokanan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Kwanza Yoh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Premye Jan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prva Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prva Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvy Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvy Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvá Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvá Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvý Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvý Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Unang Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ιωάννου Α' 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ιωάννου Αʹ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ιωάννου Αʹ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ιωάννου Α΄ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ιωάννου Α’ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ιωαννου Α' 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ιωαννου Αʹ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ιωαννου Αʹ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ιωαννου Α΄ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ιωαννου Α’ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Прва Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Прво Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Първа Иоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Първа Йоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("اوّل۔یوحنا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ﻳﻮﺣﻨﺎ ﺍﻻﻭﻝ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Ioannis 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Ivanova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yohanes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yokanan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 k Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 k Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 युहत्रा 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 यूहन्ना 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 योहानाच 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-а Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-е Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Gjonit 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Janova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yohana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yohane 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Иохана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. یوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. யோவான் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o. Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1er. Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ere Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1re. Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ère Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1е Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1е Иохана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1я Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1я Иохана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Ioannis 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Ivanova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Yohanes 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Yokanan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Иоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Йоаново 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Janova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Yohana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Yohane 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Ioannis I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvni Jan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("První Jan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α' Ιωάννη 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α' Ιωαννη 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ Ιωάννη 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ Ιωαννη 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ Ιωάννη 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ Ιωαννη 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α΄ Ιωάννη 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α΄ Ιωαννη 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α’ Ιωάννη 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α’ Ιωαννη 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("۱ یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("۱-یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ヨハネの第一の手紙 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("요한의 첫째 서간 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Gjonit 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Janova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yohana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yohane 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 yūhãnā 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Иоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Иохана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 یوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ਯੂਹੰਨਾ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 யோவான் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Gioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Giăng 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Janos 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. János 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ଯୋହନଙ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ยอห์น 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.o Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.۔یوحنا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1a. Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1a. João 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1er Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. João 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o. Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1re Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("First Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Janova 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Yohana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Yohane 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Іоанна 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Gioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Giăng 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Janos 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. János 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Una Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Yohane I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("۱ یوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ヨハネの第一の書 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Gioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Giăng 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Janos 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 János 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yovan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yovaṉ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yōvan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yōvaṉ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 योहान 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ଯୋହନଙ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ยอห์น 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Ioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. João 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yoox 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Иоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Йоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1a Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1a João 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1e. Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o João 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1o Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st. Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1۔یوحنا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Elso Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Első Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Gioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Giăng 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Janos 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Janov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Januv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Janův 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jophn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I János 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jánov 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Івана 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Јован 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Ioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. João 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Yoox 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Иоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Йоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Janos I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("János I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Prvni J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("První J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("۱۔یوحنا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ヨハネの手紙一 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Ioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 João 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yoox 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Иоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Йоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 யோவா 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jóh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Yoh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1e Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1st Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Ioan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jaan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jana 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jaun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jean 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jhhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jhon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Joao 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Johm 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jonh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Joon 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I João 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jphn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Juan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Juun 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Yoox 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Иоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Йоан 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jóh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Yoh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α' ᾿Ιω 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ ᾿Ιω 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ ᾿Ιω 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α΄ ᾿Ιω 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α’ ᾿Ιω 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《伊望第一》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《約翰一書》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《約翰壹書》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《约翰一书》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《约翰壹书》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《若望一書》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jóh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Yoh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Gi 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. In 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1John 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jan 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jhn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Joh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jóh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Yoh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Gi 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. In 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α' Ιω 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ Ιω 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ Ιω 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α΄ Ιω 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α’ Ιω 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《伊望第一 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《約翰一書 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《約翰壹書 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《约翰一书 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《约翰壹书 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《若望一書 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ヨハネ 1 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("伊望第一》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("約翰一書》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("約翰壹書》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("约翰一书》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("约翰壹书》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("若望一書》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Gi 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Gj 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Gv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 In 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Iv 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Ів 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Јн 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 Ин 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 يو 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 யோ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ยน 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Gi 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I In 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jh 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jn 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I Jo 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《約壹》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《约壹》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("一ヨハネ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("伊望第一 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("約翰一書 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("約翰壹書 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("约翰一书 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("约翰壹书 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("若望一書 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("요한1서 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("요한일서 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1요한 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《約壹 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《约壹 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("約壹》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("约壹》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("約壹 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("约壹 1:1").osis()).toEqual("1John.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ПЪРВО СЪБОРНО ПОСЛАНИЕ НА СВ. АП. ИОАНА БОГОСЛОВА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЪРВО СЪБОРНО ПОСЛАНИЕ НА СВ АП. ИОАНА БОГОСЛОВА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЪРВО СЪБОРНО ПОСЛАНИЕ НА СВ. АП ИОАНА БОГОСЛОВА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЪРВО СЪБОРНО ПОСЛАНИЕ НА СВ АП ИОАНА БОГОСЛОВА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ШЕ. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЕРША СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЕРШЕ СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-А. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Е. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ШЕ СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ШЕ. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЕРША СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЕРШЕ СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-А СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-А. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Е СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Е. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ШЕ СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-А СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Е СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FYRSTA BREF JOHANNESAR HIÐ ALMENNA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FYRSTA BREF JÓHANNESAR HIÐ ALMENNA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FYRSTA BRÉF JOHANNESAR HIÐ ALMENNA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FYRSTA BRÉF JÓHANNESAR HIÐ ALMENNA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YOVAN ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YOVAN ELUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YOVAN EḺUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YOVAN EḺUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YŌVAN ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YŌVAN ELUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PERSE POSLANNJA APOSTOLA IVANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PERŠE POSLANNJA APOSTOLA IVANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПРВА ПОСЛАНИЕ НА АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПРВО ПОСЛАНИЕ НА АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ШЕ. ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ENSIMMAINEN JOHANNEKSEN KIRJE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ENSIMMÄINEN JOHANNEKSEN KIRJE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЕРША ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЕРШЕ ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("யோவன் எழுதிய முதலாவது நிருபம் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("யோவான் எழுதிய முதல் திருமுகம் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-А. ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Е. ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ШЕ ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ПОСЛАНИЕ НА АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. ПОСЛАНИЕ НА АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("யோவான் எழுதிய முதலாம் கடிதம் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ПОСЛАНИЕ НА АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-А ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Е ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I ПОСЛАНИЕ НА АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПРВА ПИСМО ОД АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПРВО ПИСМО ОД АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("אגרתו הראשונה של יוחנן השלי 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("WARAKA WA KWANZA WA YOHANE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ПИСМО ОД АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("BARUA YA KWANZA YA YOHANE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. ПИСМО ОД АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMA LETTERA DI GIOVANNI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("رسالة القديس يوحنا الأولى 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ПИСМО ОД АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I ПИСМО ОД АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YŪḤANNĀ KĀ PAHLĀ ʿĀM ḪAṬ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ENSIMMAINEN JOHANNEKSEN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ENSIMMÄINEN JOHANNEKSEN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YŪHÃNĀ DĪ PAHILĪ PATTRĪ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПРВА ПОСЛАНИЦА ЈОВАНОВА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FYRSTA BREF JOHANNESAR 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FYRSTA BREF JÓHANNESAR 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FYRSTA BRÉF JOHANNESAR 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FYRSTA BRÉF JÓHANNESAR 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZA LIST SW. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZA LIST ŚW. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZE LIST SW. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZE LIST ŚW. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZY LIST SW. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZY LIST ŚW. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVA IVANOVA POSLANICA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVA IVANOVA POSLANICA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YOHANACEM PAHILE PATRA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YOHANACEṂ PAHILE PATRA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YOHANĀCEM PAHILE PATRA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YOHANĀCEṂ PAHILE PATRA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YOHĀNACEM PAHILE PATRA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YOHĀNACEṂ PAHILE PATRA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YOHĀNĀCEM PAHILE PATRA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YOHĀNĀCEṂ PAHILE PATRA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YUHANNAKO PAHILO PATRA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YUHANNĀKO PAHILO PATRA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YŪHANNAKO PAHILO PATRA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YŪHANNĀKO PAHILO PATRA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЪРВО ПОСЛАНИЕ НА ИОАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЪРВО ПОСЛАНИЕ НА ЙОАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("یُوحنّا کا پہلا عام خط 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ਯੂਹੰਨਾ ਦੀ ਪਹਿਲੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("யோவான் முதல் திருமுகம் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ПОСЛАНИЦА ЈОВАНОВА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FORSTA JOHANNESBREVET 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FYRSTA JOHANNESARBREF 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FYRSTA JOHANNESARBRÉF 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FYRSTA JÓHANNESARBREF 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FYRSTA JÓHANNESARBRÉF 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FÖRSTA JOHANNESBREVET 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. ПОСЛАНИЦА ЈОВАНОВА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("JOHANNES' FØRSTE BREV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("JOHANNES’ FØRSTE BREV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("JOHANNES’ FØRSTE BREV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZA LIST SW JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZA LIST ŚW JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZE LIST SW JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZE LIST ŚW JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZY LIST SW JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZY LIST ŚW JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("یوحنّا کا پہلا عام خط 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ПОСЛАНИЦА ЈОВАНОВА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Е. ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ШЕ. ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Я. ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. IVANOVA POSLANICA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOHANNEKSEN KIRJE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I ПОСЛАНИЦА ЈОВАНОВА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. IVANOVA POSLANICA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOHANNEKSEN KIRJE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("JOHANNES FORSTA BREV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("JOHANNES FÖRSTA BREV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЕРША ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЕРШЕ ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("یوحنا کا پہلا عام خط 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("यूहन्नाको पहिलो पत्र 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("योहानाचें पहिले पत्र 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 IVANOVA POSLANICA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOHANNEKSEN KIRJE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-А. ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Е ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Е. ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ШЕ ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Я ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1Е. ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1Я. ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FØRSTE JOHANNESBREV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I IVANOVA POSLANICA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOHANNEKSEN KIRJE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("איגרת יוחנן הראשונה 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-А ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Е ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1Е ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1Я ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("EPISTULA I IOANNIS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("EPISTULA IOANNIS I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZA LIST JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZE LIST JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZY LIST JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("رسالة يوحنا الأولى 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ଯୋହନଙ୍କ ପ୍ରଥମ ପତ୍ର 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOHANNESBREVET 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("JOHANNES' 1. BREV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("JOHANNES’ 1. BREV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("MUTALAVATU யோவான் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("MUTALĀVATU யோவான் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOHANNESBREVET 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. LIST SW. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. LIST ŚW. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. LIST SW. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. LIST ŚW. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("JOHANNES' 1 BREV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("JOHANNES’ 1 BREV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMERO SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMERO SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMERO SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMERO SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVA KNIHA JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVA KNIHA JÁNOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVNI LIST JANUV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVNI LIST JANŮV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVNÍ LIST JANUV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVNÍ LIST JANŮV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVÁ KNIHA JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVÁ KNIHA JÁNOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 LIST SW. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 LIST ŚW. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOHANNESBREV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. LIST SW JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. LIST ŚW JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("EERSTE JOHANNES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FØRSTE JOHANNES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I LIST SW. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I LIST ŚW. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. LIST SW JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. LIST ŚW JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMER SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMER SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMER SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMER SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVY JANOV LIST 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVY JÁNOV LIST 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVY LIST JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVY LIST JÁNOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVÝ JANOV LIST 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVÝ JÁNOV LIST 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVÝ LIST JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVÝ LIST JÁNOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YOOXANAA KOWAAD 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("முதலாவது யோவான் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOHANNESBREV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 LIST SW JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 LIST ŚW JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOHANNEKSEN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ERSTE JOHANNES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I LIST SW JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I LIST ŚW JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOHANNEKSEN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PREMIERES JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PREMIÈRES JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMA GIOVANNI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMO GIOVANNI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOHANNEKSEN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ШЕ. ИОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ШЕ. ЙОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. LIST JANUV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. LIST JANŮV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O. SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O. SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O. SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O. SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOHANNEKSEN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. LIST JANUV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. LIST JANŮV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("KWANZA YOHANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("KWANZA YOHANE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZA JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZE JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PIERWSZY JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PREMIERE JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PREMIERS JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PREMIÈRE JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMEIRA JOAO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMEIRA JOÃO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMEIRO JOAO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMEIRO JOÃO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЕРША ИОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЕРША ЙОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЕРШЕ ИОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЕРШЕ ЙОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПРВА ЈОВАНОВА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПРВА ЈОВАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПРВО ЈОВАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЪРВА ИОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЪРВА ЙОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("رسالة يوحنا 1 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 LIST JANUV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 LIST JANŮV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-А. ИОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-А. ЙОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Е. ИОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Е. ЙОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ШЕ ИОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ШЕ ЙОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ШЕ. ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. LIST JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. YUHANNAKO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. YUHANNĀKO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. YŪHANNAKO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. YŪHANNĀKO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. यूहन्नाको 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1E. JOHANNES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O. SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O. SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O. SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O. SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1°. GIOVANNI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I LIST JANUV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I LIST JANŮV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. LIST JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PREMIER JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMERO JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMERO JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMERO JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMERO JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVA IVANOVA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVNI JANOVA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVNÍ JANOVA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЕРША ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЕРШЕ ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("اوّل یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("اوّل-یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("يوحنا الأولى 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 LIST JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 E. GJONIT 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 I. GJONIT 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOHANACEM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOHANACEṂ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOHANĀCEM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOHANĀCEṂ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOHĀNACEM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOHĀNACEṂ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOHĀNĀCEM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOHĀNĀCEṂ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YUHANNAKO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YUHANNĀKO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YŪHANNAKO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YŪHANNĀKO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 यूहन्नाको 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 அருளப்பர் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-А ИОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-А ЙОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-А. ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Е ИОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Е ЙОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Е. ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Е. ИОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Е. ИОХАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ШЕ ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ШЕ. ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Я. ИОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Я. ИОХАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. GIOVANNI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOHANNES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. YOOHANNA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. YOOXANAA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ЈОВАНОВА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ЈОВАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1E JOHANNES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1° GIOVANNI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JOPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I LIST JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. GIOVANNI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOHANNES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. YOOXANAA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. ЈОВАНОВА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. ЈОВАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMER JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMER JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMER JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRIMER JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVNI JANUV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVNI JANŮV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVNÍ JANUV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVNÍ JANŮV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЕРША ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЕРШЕ ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("اوّل یوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ପ୍ରଥମ ଯୋହନଙ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 GIOVANNI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOHANNES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOOHANNA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOOXANAA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 E GJONIT 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 I GJONIT 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 K. JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 K. JÁNOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ЈОВАНОВА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ЈОВАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-А ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-А. ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Е ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Е ИОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Е ИОХАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Е. ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-ШЕ ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Я ИОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Я ИОХАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. IOANNIS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. IVANOVA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. YOHANES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. YOKANAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ИОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ЙОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. युहत्रा 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. यूहन्ना 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.-یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ERE. JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JOPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ÈRE. JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1Е. ИОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1Е. ИОХАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1Я. ИОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1Я. ИОХАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("EERSTE JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ELSO JANOS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ELSO JÁNOS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ELSŐ JANOS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ELSŐ JÁNOS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JHHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JHON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JOHM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JONH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JOON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FØRSTE JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I GIOVANNI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOHANNES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I SAN JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I SAN JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I SAN JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I SAN JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I YOOXANAA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I ЈОВАНОВА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I ЈОВАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. IOANNIS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. IVANOVA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. YOHANES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. YOKANAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. ИОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. ЙОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("KWANZA YOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PREMYE JAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVA JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVA JÁNOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVY JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVY JÁNOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVÁ JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVÁ JÁNOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVÝ JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVÝ JÁNOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("UNANG JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ΙΩΆΝΝΟΥ Α' 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ΙΩΆΝΝΟΥ Αʹ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ΙΩΆΝΝΟΥ Αʹ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ΙΩΆΝΝΟΥ Α΄ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ΙΩΆΝΝΟΥ Α’ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ΙΩΑΝΝΟΥ Α' 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ΙΩΑΝΝΟΥ Αʹ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ΙΩΑΝΝΟΥ Αʹ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ΙΩΑΝΝΟΥ Α΄ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ΙΩΑΝΝΟΥ Α’ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПРВА ЈОВАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПРВО ЈОВАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЪРВА ИОАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ПЪРВА ЙОАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("اوّل۔یوحنا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ﻳﻮﺣﻨﺎ ﺍﻻﻭﻝ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 IOANNIS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 IVANOVA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOHANES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOKANAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 K JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 K JÁNOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ИОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ЙОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 युहत्रा 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 यूहन्ना 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 योहानाच 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-А ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-Е ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1-یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. GJONIT 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JANOVA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. YOHANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. YOHANE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ИОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ИОХАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. یوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. யோவான் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O. JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O. JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O. JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O. JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º. JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ER. JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ERE JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1RE. JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JOPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JHHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JHON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JOHM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JONH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JOON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ÈRE JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1Е ИОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1Е ИОХАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1Я ИОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1Я ИОХАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I IOANNIS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I IVANOVA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I YOHANES 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I YOKANAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I ИОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I ЙОАНОВО 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JANOVA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. YOHANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. YOHANE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("IOANNIS I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVNI JAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVNÍ JAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α' ΙΩΆΝΝΗ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α' ΙΩΑΝΝΗ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ ΙΩΆΝΝΗ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ ΙΩΑΝΝΗ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ ΙΩΆΝΝΗ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ ΙΩΑΝΝΗ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α΄ ΙΩΆΝΝΗ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α΄ ΙΩΑΝΝΗ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α’ ΙΩΆΝΝΗ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α’ ΙΩΑΝΝΗ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("۱ یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("۱-یُوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ヨハネの第一の手紙 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("요한의 첫째 서간 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 GJONIT 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JANOVA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOHANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOHANE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YŪHÃNĀ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ИОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ИОХАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 یوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ਯੂਹੰਨਾ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 யோவான் 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. GIOAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. GIĂNG 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JANOS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JANUV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JANŮV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JÁNOS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JÁNOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ЈОВАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ଯୋହନଙ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ยอห์น 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.O JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.º JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1.۔یوحنا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1A. JOAO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1A. JOÃO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ER JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O. JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O. JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O. JOAO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O. JOÃO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O. JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O. JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1RE JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JHHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JHON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JOHM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JONH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JOON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º. JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("FIRST JO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JANOVA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I YOHANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I YOHANE 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I ІОАННА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. GIOAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. GIĂNG 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JANOS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JANUV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JANŮV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JÁNOS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JÁNOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. ЈОВАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("UNA JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("YOHANE I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("۱ یوحنّا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ヨハネの第一の書 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 GIOAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 GIĂNG 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JANOS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JANUV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JANŮV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JÁNOS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JÁNOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOVAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOVAṈ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YŌVAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YŌVAṈ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ЈОВАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 योहान 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ଯୋହନଙ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ยอห์น 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. IOAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JHHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JHON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOAO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOHM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JONH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOÃO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. YOOX 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ИОАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. ЙОАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1A JOAO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1A JOÃO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1E. JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O JOAO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O JOÃO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1O JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST. JO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1º JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1۔یوحنا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ELSO JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ELSŐ JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I GIOAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I GIĂNG 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JANOS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JANOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JANUV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JANŮV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JÁNOS 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JÁNOV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I ІВАНА 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I ЈОВАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. IOAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JHHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JHON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOAO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOHM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JONH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOÃO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. YOOX 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. ИОАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. ЙОАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("JANOS I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("JÁNOS I 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVNI J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("PRVNÍ J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("۱۔یوحنا 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ヨハネの手紙一 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 IOAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JHHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JHON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOAO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOHM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JONH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOÃO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOOX 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ИОАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ЙОАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 யோவா 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JÓH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. YOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1E JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1ST JO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I IOAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JAAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JANA 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JAUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JEAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JHHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JHON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOAO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOHM 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JONH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOON 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOÃO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JPHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JUAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JUUN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I YOOX 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I ИОАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I ЙОАН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JÓH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. YOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α' ᾿ΙΩ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ ᾿ΙΩ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ ᾿ΙΩ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α΄ ᾿ΙΩ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α’ ᾿ΙΩ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《伊望第一》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《約翰一書》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《約翰壹書》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《约翰一书》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《约翰壹书》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《若望一書》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JÓH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 YOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. GI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. IN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. JO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1JOHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JAN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JHN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JÓH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I YOH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. GI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. IN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. JO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α' ΙΩ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ ΙΩ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Αʹ ΙΩ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α΄ ΙΩ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("Α’ ΙΩ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《伊望第一 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《約翰一書 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《約翰壹書 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《约翰一书 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《约翰壹书 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《若望一書 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("ヨハネ 1 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("伊望第一》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("約翰一書》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("約翰壹書》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("约翰一书》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("约翰壹书》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("若望一書》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 GI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 GJ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 GV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 IN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 IV 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 JO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ІВ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ЈН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ИН 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 يو 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 யோ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 ยน 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1. J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I GI 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I IN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JH 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JN 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I JO 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I. J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《約壹》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《约壹》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("一ヨハネ 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("伊望第一 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("約翰一書 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("約翰壹書 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("约翰一书 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("约翰壹书 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("若望一書 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("요한1서 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("요한일서 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1 J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("1요한 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("I J 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《約壹 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("《约壹 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("約壹》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("约壹》 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("約壹 1:1").osis()).toEqual("1John.1.1")
		expect(p.parse("约壹 1:1").osis()).toEqual("1John.1.1")
		`
		true
describe "Localized book 2John (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2John (full)", ->
		`
		expect(p.parse("Второ съборно послание на св. ап. Иоана Богослова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Второ съборно послание на св ап. Иоана Богослова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Второ съборно послание на св. ап Иоана Богослова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Второ съборно послание на св ап Иоана Богослова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друга соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друге соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге. соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друга соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друге соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а. соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е. соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("யோவான் எழுதிய இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Втора послание на апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Второ послание на апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhe poslannja apostola Ivana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("யோவன் எழுதிய இரண்டாவது நிருபம் 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге. послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. послание на апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друга послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друге послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("யோவான் எழுதிய இரண்டாம் கடிதம் 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а. послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е. послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. послание на апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II послание на апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Втора писмо од апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Второ писмо од апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 послание на апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Seconda lettera di Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("אגרתו השנייה של יוחנן השליח 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. писмо од апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("رسالة القديس يوحنا الثانية 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. писмо од апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II писмо од апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("யோவான் இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 писмо од апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Toinen Johanneksen kirje 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Waraka wa Pili wa Yohane 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yūḥannā kā dūsrā ʿām ḫaṭ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друга посланица Јованова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Barua ya Pili ya Yohane 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga Ivanova Poslanica 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga Ivanova poslanica 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("یُوحنّا کا دوسرا عام خط 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("यूहन्नाको दोस्त्रो पत्र 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. посланица Јованова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yuhannako dostro patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yuhannāko dostro patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yūhannako dostro patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yūhannāko dostro patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Второ послание на Иоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Второ послание на Йоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. посланица Јованова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Annað bref Johannesar 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Annað bref Jóhannesar 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Annað bréf Johannesar 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Annað bréf Jóhannesar 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II посланица Јованова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Ivanova Poslanica 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Johanneksen kirje 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yohanacem dusre patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yohanaceṃ dusre patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yohanācem dusre patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yohanāceṃ dusre patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yohānacem dusre patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yohānaceṃ dusre patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yohānācem dusre patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yohānāceṃ dusre patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yūhãnā dī dūjī pattrī 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("یوحنا کا دوسرا عام خط 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("यूहन्नाको दोस्रो पत्र 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ਯੂਹੰਨਾ ਦੀ ਦੂਜੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 посланица Јованова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге. Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е. послание Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-я. послание Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Ivanova Poslanica 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Johanneksen kirje 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Andra Johannesbrevet 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Annað Johannesarbref 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Annað Johannesarbréf 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Annað Jóhannesarbref 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Annað Jóhannesarbréf 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Ivanova Poslanica 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Johanneksen kirje 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Johannes' Andet Brev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Johannes’ Andet Brev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Johannes’ andre brev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друга Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друге Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("योहानाचें दुसरे पत्र 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ଯୋହନଙ୍କ ଦ୍ୱିତୀୟ ପତ୍ର 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Ivanova Poslanica 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Johanneksen kirje 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а. Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е послание Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е. Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-я послание Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2е. послание Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2я. послание Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga List sw. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga List św. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Drugi List sw. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Drugi List św. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Epistula II Ioannis 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Epistula Ioannis II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Johannes andra brev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("رسالة يوحنا الثانية 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. послание Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2е послание Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2я послание Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Anden Johannesbrev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Andet Johannesbrev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga List sw Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga List św Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Drugi List sw Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Drugi List św Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Toinen Johanneksen 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("איגרת יוחנן השנייה 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("یوحنّا کا دوسرا خط 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 послание Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Johannesbrevet 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha kniha Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha kniha Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhá kniha Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhá kniha Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. List sw. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. List św. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Johannesbrevet 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. List sw. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. List św. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha list Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha list Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy Janov list 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy Jánov list 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy list Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy list Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy list Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy list Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhá list Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhá list Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý Janov list 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý Jánov list 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý list Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý list Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý list Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý list Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II List sw. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II List św. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. List sw Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. List św Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Seconda Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Secondo Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Послання до Тита 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 List sw. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 List św. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Johannesbrev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. List sw Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. List św Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga List Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Drugi List Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II List sw Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II List św Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Johanneksen 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Tweede Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yooxanaa Labaad 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Zweite Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Johannesbrev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 List sw Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 List św Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Johanneksen 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Anden Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Andre Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Deuxiemes Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Deuxièmes Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Johanneksen 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. list Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. list Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ikalawang Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Втора Јованово 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Второ Јованово 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друга Јованова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Johanneksen 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге. Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге. Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. list Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. list Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Deuxieme Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Deuxième Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga Ivanova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II list Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II list Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. List Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Masodik Janos 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Masodik János 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Második Janos 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Második János 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Втора Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Втора Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друга Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друга Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друге Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друге Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("رسالة يوحنا 2 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("يوحنا الثانية 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ଯୋହନଙ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 list Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 list Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а. Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а. Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге. Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е. Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е. Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. List Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. yuhannako 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. yuhannāko 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. yūhannako 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. yūhannāko 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. यूहन्नाको 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2e. Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2°. Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha Janova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy Janova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhá Janova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý Janova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II List Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Yooxanaa 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Јованова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Јованово 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segunda Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segunda João 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo João 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друга Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друге Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 List Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 e. Gjonit 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 i. Gjonit 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yohanacem 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yohanaceṃ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yohanācem 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yohanāceṃ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yohānacem 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yohānaceṃ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yohānācem 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yohānāceṃ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yuhannako 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yuhannāko 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yūhannako 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yūhannāko 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 यूहन्नाको 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 அருளப்பர் 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а. Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге. Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е. Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е. Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е. Иохана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-я. Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-я. Иохана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yoohanna 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yooxanaa 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Јованова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Јованово 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2e Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2° Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhá Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhá Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhá Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhá Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Yooxanaa 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Јованова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Јованово 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Ioannis 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Ivanova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Yohanes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Yokanan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Pili Yohana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Pili Yohane 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Втора Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Второ Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друга Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друге Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("دوم یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("دوم-یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yoohanna 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yooxanaa 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 e Gjonit 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 i Gjonit 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 k. Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 k. Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Јованова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Јованово 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а. Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е Иохана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е. Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-я Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-я Иохана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Ioannis 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Ivanova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yohanes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yokanan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. युहत्रा 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. यूहन्ना 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.-یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2eme. Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ème. Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2е. Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2е. Иохана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2я. Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2я. Иохана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Dezyem Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Dezyèm Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Drugi Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Ioannis 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Ivanova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Yohanes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Yokanan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Janova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Yohana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Yohane 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ioannis II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Masodik Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Második Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Toinen Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Tweede Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ιωάννου Β' 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ιωάννου Βʹ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ιωάννου Βʹ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ιωάννου Β΄ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ιωάννου Β’ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ιωαννου Β' 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ιωαννου Βʹ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ιωαννου Βʹ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ιωαννου Β΄ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ιωαννου Β’ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Втора Иоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Втора Йоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("دوم یوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Ioannis 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Ivanova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yohanes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yokanan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 k Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 k Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 युहत्रा 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 यूहन्ना 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 योहानाच 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Gjonit 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Janova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yohana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yohane 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Иохана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. یوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2de. Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2eme Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ème Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2е Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2е Иохана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2я Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2я Иохана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Anden Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Andre Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhá Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Janova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Yohana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Yohane 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Gioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Giăng 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Janos 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. János 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yohane II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β' Ιωάννη 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β' Ιωαννη 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ Ιωάννη 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ Ιωαννη 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ Ιωάννη 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ Ιωαννη 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β΄ Ιωάννη 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β΄ Ιωαννη 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β’ Ιωάννη 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β’ Ιωαννη 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("دوم۔یوحنا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("۲ یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("۲-یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ヨハネの第二の手紙 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("요한의 둘째 서간 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Gjonit 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Janova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yohana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yohane 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yūhãnā 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Иохана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 یوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ਯੂਹੰਨਾ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 யோவான் 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Gioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Giăng 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Janos 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. János 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ଯୋହନଙ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ยอห์น 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.۔یوحنا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2a. Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2a. João 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2d. Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2de Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2e. Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. João 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Gioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Giăng 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Janos 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II János 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Ioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. João 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Yoox 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Иоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Йоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Janos II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("János II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Pili Yoh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("۲ یوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ヨハネの第二の書 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Gioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Giăng 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Janos 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 János 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yovan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yovaṉ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yōvan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yōvaṉ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 योहान 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ଯୋହନଙ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ยอห์น 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Ioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. João 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yoox 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Иоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Йоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2a Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2a João 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2d Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2e Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2e. Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o João 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2۔یوحنا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhá J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Ioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II João 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Yoox 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Иоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Йоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jóh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Yoh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("۲۔یوحنا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ヨハネの手紙二 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Ioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 João 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yoox 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Иоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Йоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 யோவா 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jóh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yoh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2e Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jóh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Yoh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Gi 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. In 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β' ᾿Ιω 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ ᾿Ιω 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ ᾿Ιω 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β΄ ᾿Ιω 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β’ ᾿Ιω 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《伊望第二》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《約翰二書》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《約翰貳書》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《约翰二书》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《约翰贰书》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《若望二書》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jóh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yoh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Gi 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. In 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Gi 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II In 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β' Ιω 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ Ιω 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ Ιω 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β΄ Ιω 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β’ Ιω 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《伊望第二 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《約翰二書 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《約翰貳書 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《约翰二书 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《约翰贰书 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《若望二書 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ヨハネ 2 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("伊望第二》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("約翰二書》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("約翰貳書》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("约翰二书》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("约翰贰书》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("若望二書》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Gi 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Gj 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Gv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 In 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Iv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Ів 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Јн 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Ин 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 يو 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 யோ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ยน 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《約貳》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《约贰》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("二ヨハネ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("伊望第二 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("約翰二書 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("約翰貳書 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("约翰二书 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("约翰贰书 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("若望二書 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("요한2서 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("요한이서 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2요한 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《約貳 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《约贰 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("約貳》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("约贰》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("約貳 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("约贰 1:1").osis()).toEqual("2John.1.1")
		`
		true
	it "should handle non-Latin digits in book: 2John (full)", ->
		p.set_options non_latin_digits_strategy: "replace"
		`
		expect(p.parse("Второ съборно послание на св. ап. Иоана Богослова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Второ съборно послание на св ап. Иоана Богослова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Второ съборно послание на св. ап Иоана Богослова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Второ съборно послание на св ап Иоана Богослова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друга соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друге соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге. соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друга соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друге соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а. соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е. соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 соборне послання св. апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 соборне послання св апостола Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovan Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvan Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("யோவான் எழுதிய இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Втора послание на апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Второ послание на апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhe poslannja apostola Ivana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("யோவன் எழுதிய இரண்டாவது நிருபம் 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге. послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. послание на апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друга послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друге послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("யோவான் எழுதிய இரண்டாம் கடிதம் 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а. послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е. послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. послание на апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II послание на апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Втора писмо од апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Второ писмо од апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 послание на апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Seconda lettera di Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("אגרתו השנייה של יוחנן השליח 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. писмо од апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("رسالة القديس يوحنا الثانية 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 послання апостола Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. писмо од апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II писмо од апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("யோவான் இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 писмо од апостол Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Toinen Johanneksen kirje 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Waraka wa Pili wa Yohane 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yūḥannā kā dūsrā ʿām ḫaṭ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друга посланица Јованова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Barua ya Pili ya Yohane 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga Ivanova Poslanica 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga Ivanova poslanica 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("یُوحنّا کا دوسرا عام خط 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("यूहन्नाको दोस्त्रो पत्र 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. посланица Јованова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yuhannako dostro patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yuhannāko dostro patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yūhannako dostro patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yūhannāko dostro patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Второ послание на Иоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Второ послание на Йоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. посланица Јованова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Annað bref Johannesar 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Annað bref Jóhannesar 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Annað bréf Johannesar 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Annað bréf Jóhannesar 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II посланица Јованова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Ivanova Poslanica 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Johanneksen kirje 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yohanacem dusre patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yohanaceṃ dusre patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yohanācem dusre patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yohanāceṃ dusre patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yohānacem dusre patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yohānaceṃ dusre patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yohānācem dusre patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yohānāceṃ dusre patra 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("yūhãnā dī dūjī pattrī 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("یوحنا کا دوسرا عام خط 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("यूहन्नाको दोस्रो पत्र 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ਯੂਹੰਨਾ ਦੀ ਦੂਜੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 посланица Јованова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге. Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е. послание Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-я. послание Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Ivanova Poslanica 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Johanneksen kirje 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Andra Johannesbrevet 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Annað Johannesarbref 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Annað Johannesarbréf 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Annað Jóhannesarbref 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Annað Jóhannesarbréf 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Ivanova Poslanica 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Johanneksen kirje 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Johannes' Andet Brev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Johannes’ Andet Brev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Johannes’ andre brev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друга Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друге Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("योहानाचें दुसरे पत्र 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ଯୋହନଙ୍କ ଦ୍ୱିତୀୟ ପତ୍ର 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Ivanova Poslanica 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Johanneksen kirje 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а. Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е послание Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е. Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-я послание Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2е. послание Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2я. послание Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga List sw. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga List św. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Drugi List sw. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Drugi List św. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Epistula II Ioannis 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Epistula Ioannis II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Johannes andra brev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("رسالة يوحنا الثانية 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. послание Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2е послание Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2я послание Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Anden Johannesbrev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Andet Johannesbrev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga List sw Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga List św Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Drugi List sw Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Drugi List św Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Toinen Johanneksen 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("איגרת יוחנן השנייה 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("یوحنّا کا دوسرا خط 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 послание Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Johannesbrevet 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha kniha Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha kniha Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhá kniha Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhá kniha Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. List sw. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. List św. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Johannesbrevet 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Послання Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. List sw. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. List św. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha list Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha list Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy Janov list 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy Jánov list 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy list Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy list Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy list Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy list Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhá list Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhá list Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý Janov list 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý Jánov list 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý list Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý list Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý list Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý list Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II List sw. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II List św. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. List sw Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. List św Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Seconda Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Secondo Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Послання до Тита 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 List sw. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 List św. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Johannesbrev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. List sw Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. List św Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga List Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Drugi List Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II List sw Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II List św Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Johanneksen 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Tweede Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yooxanaa Labaad 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Zweite Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Johannesbrev 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 List sw Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 List św Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Johanneksen 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Anden Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Andre Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Deuxiemes Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Deuxièmes Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Johanneksen 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. list Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. list Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ikalawang Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Втора Јованово 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Второ Јованово 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друга Јованова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Johanneksen 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге. Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге. Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. list Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. list Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Deuxieme Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Deuxième Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga Ivanova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II list Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II list Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. List Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Masodik Janos 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Masodik János 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Második Janos 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Második János 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Втора Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Втора Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друга Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друга Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друге Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друге Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("رسالة يوحنا 2 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("يوحنا الثانية 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ଯୋହନଙ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 list Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 list Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а. Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а. Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге. Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е. Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е. Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. List Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. yuhannako 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. yuhannāko 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. yūhannako 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. yūhannāko 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. यूहन्नाको 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2e. Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2°. Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha Janova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy Janova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhá Janova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý Janova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II List Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Yooxanaa 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Јованова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Јованово 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segunda Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segunda João 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo João 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Segundo Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друга Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друге Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 List Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 e. Gjonit 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 i. Gjonit 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yohanacem 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yohanaceṃ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yohanācem 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yohanāceṃ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yohānacem 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yohānaceṃ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yohānācem 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yohānāceṃ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yuhannako 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yuhannāko 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yūhannako 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yūhannāko 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 यूहन्नाको 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 அருளப்பர் 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а. Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге. Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е. Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е. Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е. Иохана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-я. Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-я. Иохана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yoohanna 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yooxanaa 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Јованова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Јованово 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2e Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2° Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhá Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhá Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhá Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhá Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Yooxanaa 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Јованова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Јованово 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Ioannis 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Ivanova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Yohanes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Yokanan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Pili Yohana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Pili Yohane 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Втора Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Второ Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друга Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Друге Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("دوم یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("دوم-یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Giovanni 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Johannes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 San Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 San Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 San Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 San Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yoohanna 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yooxanaa 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 e Gjonit 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 i Gjonit 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 k. Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 k. Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Јованова 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Јованово 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а. Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ге Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е Иохана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е. Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-я Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-я Иохана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Ioannis 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Ivanova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yohanes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yokanan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. युहत्रा 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. यूहन्ना 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.-یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2eme. Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ème. Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2е. Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2е. Иохана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2я. Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2я. Иохана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Dezyem Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Dezyèm Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druga Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Drugi Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Ioannis 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Ivanova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Yohanes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Yokanan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Janova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Yohana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Yohane 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ioannis II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Masodik Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Második Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Toinen Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Tweede Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ιωάννου Β' 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ιωάννου Βʹ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ιωάννου Βʹ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ιωάννου Β΄ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ιωάννου Β’ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ιωαννου Β' 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ιωαννου Βʹ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ιωαννου Βʹ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ιωαννου Β΄ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Ιωαννου Β’ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Втора Иоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Втора Йоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("دوم یوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Ioannis 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Ivanova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yohanes 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yokanan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 k Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 k Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Иоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Йоаново 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 युहत्रा 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 यूहन्ना 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 योहानाच 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-а Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-е Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Gjonit 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Janova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yohana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yohane 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Иохана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. یوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o. Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2de. Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2eme Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ème Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2е Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2е Иохана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2я Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2я Иохана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Anden Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Andre Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhá Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Janova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Yohana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Yohane 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Gioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Giăng 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Janos 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. János 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Second Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Yohane II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β' Ιωάννη 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β' Ιωαννη 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ Ιωάννη 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ Ιωαννη 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ Ιωάννη 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ Ιωαννη 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β΄ Ιωάννη 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β΄ Ιωαννη 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β’ Ιωάννη 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β’ Ιωαννη 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("دوم۔یوحنا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("۲ یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("۲-یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ヨハネの第二の手紙 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("요한의 둘째 서간 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Gjonit 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Janova 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yohana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yohane 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 yūhãnā 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Іоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Иоанна 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Иохана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 یوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ਯੂਹੰਨਾ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 யோவான் 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Gioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Giăng 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Janos 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. János 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ଯୋହନଙ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ยอห์น 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.o Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.۔یوحنا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2a. Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2a. João 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2d. Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2de Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2e. Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. João 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o. Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Gioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Giăng 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Janos 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II János 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Ioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. João 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Yoox 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Иоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Йоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Janos II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("János II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Pili Yoh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("۲ یوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ヨハネの第二の書 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Gioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Giăng 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Janos 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Janov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Januv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Janův 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jophn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 János 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jánov 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yovan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yovaṉ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yōvan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yōvaṉ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Івана 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Јован 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 योहान 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ଯୋହନଙ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ยอห์น 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Ioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. João 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yoox 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Иоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Йоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2a Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2a João 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2d Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2e Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2e. Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd. Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o João 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2o Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2۔یوحنا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druha J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhy J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhá J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Druhý J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Ioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II João 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Yoox 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Иоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Йоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jóh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Yoh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("۲۔یوحنا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ヨハネの手紙二 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Ioan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jaan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jana 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jaun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jean 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jhhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jhon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Joao 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Johm 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jonh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Joon 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 João 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jphn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Juan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Juun 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yoox 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Иоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Йоан 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 யோவா 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jóh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Yoh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2e Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2nd Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jóh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Yoh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Gi 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. In 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β' ᾿Ιω 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ ᾿Ιω 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ ᾿Ιω 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β΄ ᾿Ιω 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β’ ᾿Ιω 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《伊望第二》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《約翰二書》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《約翰貳書》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《约翰二书》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《约翰贰书》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《若望二書》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jan 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jhn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Joh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jóh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Yoh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Gi 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. In 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2John 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Gi 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II In 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β' Ιω 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ Ιω 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ Ιω 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β΄ Ιω 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β’ Ιω 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《伊望第二 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《約翰二書 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《約翰貳書 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《约翰二书 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《约翰贰书 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《若望二書 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ヨハネ 2 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("伊望第二》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("約翰二書》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("約翰貳書》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("约翰二书》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("约翰贰书》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("若望二書》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Gi 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Gj 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Gv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 In 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Iv 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jh 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jn 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Jo 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Ів 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Јн 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 Ин 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 يو 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 யோ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ยน 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《約貳》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《约贰》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("二ヨハネ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("伊望第二 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("約翰二書 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("約翰貳書 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("约翰二书 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("约翰贰书 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("若望二書 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("요한2서 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("요한이서 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2요한 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《約貳 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《约贰 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("約貳》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("约贰》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("約貳 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("约贰 1:1").osis()).toEqual("2John.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ВТОРО СЪБОРНО ПОСЛАНИЕ НА СВ. АП. ИОАНА БОГОСЛОВА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ВТОРО СЪБОРНО ПОСЛАНИЕ НА СВ АП. ИОАНА БОГОСЛОВА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ВТОРО СЪБОРНО ПОСЛАНИЕ НА СВ. АП ИОАНА БОГОСЛОВА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ВТОРО СЪБОРНО ПОСЛАНИЕ НА СВ АП ИОАНА БОГОСЛОВА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ГЕ. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ДРУГА СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ДРУГЕ СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-А. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ГЕ СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ГЕ. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Е. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ДРУГА СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ДРУГЕ СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-А СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-А. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ГЕ СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Е СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Е. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-А СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Е СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAN ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAN ELUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAN ELUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAN ELUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAN ELUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAN ELUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAN ELUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAN ELUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAN EḺUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAN EḺUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAN EḺUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAN EḺUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAN EḺUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAN EḺUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAN EḺUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAN EḺUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAN ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAN ELUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAN ELUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAN ELUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAN ELUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAN ELUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAN ELUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAN ELUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("யோவான் எழுதிய இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ВТОРА ПОСЛАНИЕ НА АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ВТОРО ПОСЛАНИЕ НА АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHE POSLANNJA APOSTOLA IVANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("யோவன் எழுதிய இரண்டாவது நிருபம் 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ГЕ. ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. ПОСЛАНИЕ НА АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ДРУГА ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ДРУГЕ ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("யோவான் எழுதிய இரண்டாம் கடிதம் 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-А. ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ГЕ ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Е. ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ПОСЛАНИЕ НА АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II ПОСЛАНИЕ НА АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ВТОРА ПИСМО ОД АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ВТОРО ПИСМО ОД АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ПОСЛАНИЕ НА АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-А ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Е ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECONDA LETTERA DI GIOVANNI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("אגרתו השנייה של יוחנן השליח 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. ПИСМО ОД АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("رسالة القديس يوحنا الثانية 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ПИСМО ОД АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II ПИСМО ОД АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("யோவான் இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ПИСМО ОД АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("TOINEN JOHANNEKSEN KIRJE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("WARAKA WA PILI WA YOHANE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŪḤANNĀ KĀ DŪSRĀ ʿĀM ḪAṬ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ДРУГА ПОСЛАНИЦА ЈОВАНОВА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("BARUA YA PILI YA YOHANE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGA IVANOVA POSLANICA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGA IVANOVA POSLANICA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("یُوحنّا کا دوسرا عام خط 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("यूहन्नाको दोस्त्रो पत्र 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. ПОСЛАНИЦА ЈОВАНОВА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YUHANNAKO DOSTRO PATRA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YUHANNĀKO DOSTRO PATRA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŪHANNAKO DOSTRO PATRA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŪHANNĀKO DOSTRO PATRA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ВТОРО ПОСЛАНИЕ НА ИОАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ВТОРО ПОСЛАНИЕ НА ЙОАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ПОСЛАНИЦА ЈОВАНОВА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ANNAÐ BREF JOHANNESAR 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ANNAÐ BREF JÓHANNESAR 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ANNAÐ BRÉF JOHANNESAR 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ANNAÐ BRÉF JÓHANNESAR 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II ПОСЛАНИЦА ЈОВАНОВА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. IVANOVA POSLANICA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOHANNEKSEN KIRJE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOHANACEM DUSRE PATRA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOHANACEṂ DUSRE PATRA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOHANĀCEM DUSRE PATRA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOHANĀCEṂ DUSRE PATRA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOHĀNACEM DUSRE PATRA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOHĀNACEṂ DUSRE PATRA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOHĀNĀCEM DUSRE PATRA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOHĀNĀCEṂ DUSRE PATRA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YŪHÃNĀ DĪ DŪJĪ PATTRĪ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("یوحنا کا دوسرا عام خط 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("यूहन्नाको दोस्रो पत्र 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ਯੂਹੰਨਾ ਦੀ ਦੂਜੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ПОСЛАНИЦА ЈОВАНОВА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ГЕ. ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Е. ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Я. ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. IVANOVA POSLANICA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOHANNEKSEN KIRJE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ANDRA JOHANNESBREVET 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ANNAÐ JOHANNESARBREF 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ANNAÐ JOHANNESARBRÉF 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ANNAÐ JÓHANNESARBREF 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ANNAÐ JÓHANNESARBRÉF 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II IVANOVA POSLANICA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOHANNEKSEN KIRJE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("JOHANNES' ANDET BREV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("JOHANNES’ ANDET BREV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("JOHANNES’ ANDRE BREV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ДРУГА ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ДРУГЕ ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("योहानाचें दुसरे पत्र 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ଯୋହନଙ୍କ ଦ୍ୱିତୀୟ ପତ୍ର 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 IVANOVA POSLANICA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOHANNEKSEN KIRJE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-А. ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ГЕ ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Е ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Е. ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Я ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2Е. ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2Я. ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGA LIST SW. JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGA LIST ŚW. JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGI LIST SW. JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGI LIST ŚW. JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("EPISTULA II IOANNIS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("EPISTULA IOANNIS II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("JOHANNES ANDRA BREV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("رسالة يوحنا الثانية 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-А ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Е ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2Е ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2Я ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ANDEN JOHANNESBREV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ANDET JOHANNESBREV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGA LIST SW JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGA LIST ŚW JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGI LIST SW JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGI LIST ŚW JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("TOINEN JOHANNEKSEN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("איגרת יוחנן השנייה 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("یوحنّا کا دوسرا خط 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOHANNESBREVET 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHA KNIHA JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHA KNIHA JÁNOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÁ KNIHA JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÁ KNIHA JÁNOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. LIST SW. JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. LIST ŚW. JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOHANNESBREVET 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. LIST SW. JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. LIST ŚW. JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHA LIST JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHA LIST JANŮV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHY JANOV LIST 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHY JÁNOV LIST 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHY LIST JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHY LIST JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHY LIST JANŮV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHY LIST JÁNOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÁ LIST JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÁ LIST JANŮV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÝ JANOV LIST 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÝ JÁNOV LIST 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÝ LIST JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÝ LIST JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÝ LIST JANŮV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÝ LIST JÁNOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II LIST SW. JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II LIST ŚW. JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. LIST SW JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. LIST ŚW JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECONDA GIOVANNI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECONDO GIOVANNI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SEGUNDO SAN JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SEGUNDO SAN JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SEGUNDO SAN JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SEGUNDO SAN JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ПОСЛАННЯ ДО ТИТА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 LIST SW. JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 LIST ŚW. JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOHANNESBREV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. LIST SW JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. LIST ŚW JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGA LIST JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGI LIST JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II LIST SW JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II LIST ŚW JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOHANNEKSEN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("TWEEDE JOHANNES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOOXANAA LABAAD 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ZWEITE JOHANNES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOHANNESBREV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 LIST SW JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 LIST ŚW JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOHANNEKSEN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ANDEN JOHANNES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ANDRE JOHANNES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DEUXIEMES JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DEUXIÈMES JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOHANNEKSEN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. LIST JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. LIST JANŮV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("IKALAWANG JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ВТОРА ЈОВАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ВТОРО ЈОВАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ДРУГА ЈОВАНОВА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOHANNEKSEN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ГЕ. ИОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ГЕ. ЙОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. LIST JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. LIST JANŮV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O. SAN JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O. SAN JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O. SAN JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O. SAN JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. SAN JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. SAN JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. SAN JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. SAN JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DEUXIEME JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DEUXIÈME JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGA IVANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II LIST JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II LIST JANŮV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. LIST JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("MASODIK JANOS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("MASODIK JÁNOS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("MÁSODIK JANOS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("MÁSODIK JÁNOS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ВТОРА ИОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ВТОРА ЙОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ДРУГА ИОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ДРУГА ЙОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ДРУГЕ ИОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ДРУГЕ ЙОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("رسالة يوحنا 2 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("يوحنا الثانية 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ଯୋହନଙ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 LIST JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 LIST JANŮV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-А. ИОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-А. ЙОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ГЕ ИОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ГЕ ЙОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ГЕ. ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Е. ИОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Е. ЙОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. LIST JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. YUHANNAKO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. YUHANNĀKO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. YŪHANNAKO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. YŪHANNĀKO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. यूहन्नाको 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O SAN JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O SAN JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O SAN JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O SAN JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º SAN JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º SAN JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º SAN JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º SAN JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2E. JOHANNES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O. SAN JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O. SAN JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O. SAN JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O. SAN JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2°. GIOVANNI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. SAN JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. SAN JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. SAN JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. SAN JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHA JANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHY JANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÁ JANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÝ JANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II LIST JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. GIOVANNI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOHANNES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. SAN JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. SAN JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. SAN JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. SAN JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. YOOXANAA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. ЈОВАНОВА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. ЈОВАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JOPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SEGUNDA JOAO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SEGUNDA JOÃO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SEGUNDO JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SEGUNDO JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SEGUNDO JOAO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SEGUNDO JOÃO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SEGUNDO JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SEGUNDO JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ДРУГА ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ДРУГЕ ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 LIST JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 E. GJONIT 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 I. GJONIT 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOHANACEM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOHANACEṂ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOHANĀCEM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOHANĀCEṂ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOHĀNACEM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOHĀNACEṂ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOHĀNĀCEM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOHĀNĀCEṂ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YUHANNAKO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YUHANNĀKO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YŪHANNAKO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YŪHANNĀKO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 यूहन्नाको 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 அருளப்பர் 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-А ИОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-А ЙОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-А. ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ГЕ ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ГЕ. ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Е ИОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Е ЙОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Е. ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Е. ИОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Е. ИОХАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Я. ИОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Я. ИОХАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. GIOVANNI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOHANNES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. SAN JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. SAN JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. SAN JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. SAN JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. YOOHANNA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. YOOXANAA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ЈОВАНОВА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ЈОВАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2E JOHANNES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O SAN JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O SAN JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O SAN JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O SAN JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2° GIOVANNI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º SAN JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º SAN JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º SAN JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º SAN JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHA JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHA JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHA JANŮV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHA JÁNOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHY JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHY JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHY JANŮV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHY JÁNOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÁ JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÁ JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÁ JANŮV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÁ JÁNOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÝ JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÝ JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÝ JANŮV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÝ JÁNOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II GIOVANNI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOHANNES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II SAN JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II SAN JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II SAN JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II SAN JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II YOOXANAA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II ЈОВАНОВА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II ЈОВАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. IOANNIS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. IVANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. YOHANES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. YOKANAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. ИОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. ЙОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("PILI YOHANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("PILI YOHANE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JHHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JHON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JOHM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JONH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JOON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ВТОРА ЈОВАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ВТОРО ЈОВАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ДРУГА ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ДРУГЕ ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("دوم یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("دوم-یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 GIOVANNI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOHANNES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 SAN JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 SAN JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 SAN JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 SAN JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOOHANNA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOOXANAA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 E GJONIT 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 I GJONIT 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 K. JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 K. JÁNOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ЈОВАНОВА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ЈОВАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-А ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-А. ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-ГЕ ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Е ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Е ИОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Е ИОХАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Е. ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Я ИОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Я ИОХАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. IOANNIS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. IVANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. YOHANES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. YOKANAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ИОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ЙОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. युहत्रा 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. यूहन्ना 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.-یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2EME. JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JOPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ÈME. JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2Е. ИОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2Е. ИОХАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2Я. ИОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2Я. ИОХАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DEZYEM JAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DEZYÈM JAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGA JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUGI JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II IOANNIS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II IVANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II YOHANES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II YOKANAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II ИОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II ЙОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. YOHANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. YOHANE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("IOANNIS II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("MASODIK JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("MÁSODIK JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("TOINEN JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("TWEEDE JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ΙΩΆΝΝΟΥ Β' 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ΙΩΆΝΝΟΥ Βʹ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ΙΩΆΝΝΟΥ Βʹ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ΙΩΆΝΝΟΥ Β΄ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ΙΩΆΝΝΟΥ Β’ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ΙΩΑΝΝΟΥ Β' 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ΙΩΑΝΝΟΥ Βʹ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ΙΩΑΝΝΟΥ Βʹ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ΙΩΑΝΝΟΥ Β΄ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ΙΩΑΝΝΟΥ Β’ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ВТОРА ИОАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ВТОРА ЙОАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("دوم یوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 IOANNIS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 IVANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOHANES 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOKANAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 K JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 K JÁNOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ИОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ЙОАНОВО 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 युहत्रा 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 यूहन्ना 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 योहानाच 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-А ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-Е ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2-یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. GJONIT 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. YOHANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. YOHANE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ИОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ИОХАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. یوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O. JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O. JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O. JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O. JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º. JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2DE. JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2EME JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JOPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JHHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JHON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JOHM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JONH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JOON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ÈME JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2Е ИОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2Е ИОХАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2Я ИОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2Я ИОХАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ANDEN JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ANDRE JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHA JAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHY JAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÁ JAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÝ JAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II YOHANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II YOHANE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. GIOAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. GIĂNG 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JANOS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JANŮV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JÁNOS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JÁNOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. ЈОВАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("SECOND JO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("YOHANE II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β' ΙΩΆΝΝΗ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β' ΙΩΑΝΝΗ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ ΙΩΆΝΝΗ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ ΙΩΑΝΝΗ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ ΙΩΆΝΝΗ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ ΙΩΑΝΝΗ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β΄ ΙΩΆΝΝΗ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β΄ ΙΩΑΝΝΗ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β’ ΙΩΆΝΝΗ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β’ ΙΩΑΝΝΗ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("دوم۔یوحنا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("۲ یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("۲-یُوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ヨハネの第二の手紙 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("요한의 둘째 서간 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 GJONIT 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JANOVA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOHANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOHANE 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YŪHÃNĀ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ІОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ИОАННА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ИОХАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 یوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ਯੂਹੰਨਾ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 யோவான் 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. GIOAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. GIĂNG 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JANOS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JANŮV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JÁNOS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JÁNOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ЈОВАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ଯୋହନଙ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ยอห์น 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.O JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.º JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2.۔یوحنا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2A. JOAO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2A. JOÃO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2D. JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2DE JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2E. JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JHHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JHON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JOHM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JONH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JOON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O. JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O. JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O. JOAO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O. JOÃO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O. JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O. JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º. JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II GIOAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II GIĂNG 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JANOS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JANŮV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JÁNOS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JÁNOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II ЈОВАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. IOAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JHHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JHON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOAO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOHM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JONH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOÃO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. YOOX 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. ИОАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. ЙОАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("JANOS II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("JÁNOS II 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("PILI YOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("۲ یوحنّا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ヨハネの第二の書 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 GIOAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 GIĂNG 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JANOS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JANOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JANUV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JANŮV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JÁNOS 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JÁNOV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOVAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOVAṈ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YŌVAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YŌVAṈ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ІВАНА 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ЈОВАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 योहान 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ଯୋହନଙ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ยอห์น 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. IOAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JHHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JHON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOAO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOHM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JONH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOÃO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. YOOX 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ИОАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. ЙОАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2A JOAO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2A JOÃO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2D JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2E JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2E. JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND. JO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O JOAO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O JOÃO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2O JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2º JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2۔یوحنا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHA J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHY J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÁ J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("DRUHÝ J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II IOAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JHHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JHON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOAO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOHM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JONH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOÃO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II YOOX 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II ИОАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II ЙОАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JÓH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. YOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("۲۔یوحنا 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ヨハネの手紙二 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 IOAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JAAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JANA 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JAUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JEAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JHHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JHON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOAO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOHM 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JONH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOON 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOÃO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JPHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JUAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JUUN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOOX 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ИОАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ЙОАН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 யோவா 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JÓH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. YOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2E JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2ND JO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JÓH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II YOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. GI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. IN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. JO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β' ᾿ΙΩ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ ᾿ΙΩ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ ᾿ΙΩ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β΄ ᾿ΙΩ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β’ ᾿ΙΩ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《伊望第二》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《約翰二書》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《約翰貳書》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《约翰二书》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《约翰贰书》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《若望二書》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JAN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JÓH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 YOH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. GI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. IN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. JO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2JOHN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II GI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II IN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II JO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II. J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β' ΙΩ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ ΙΩ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Βʹ ΙΩ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β΄ ΙΩ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("Β’ ΙΩ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《伊望第二 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《約翰二書 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《約翰貳書 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《约翰二书 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《约翰贰书 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《若望二書 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("ヨハネ 2 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("伊望第二》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("約翰二書》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("約翰貳書》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("约翰二书》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("约翰贰书》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("若望二書》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 GI 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 GJ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 GV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 IN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 IV 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JH 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JN 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 JO 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ІВ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ЈН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ИН 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 يو 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 யோ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 ยน 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2. J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("II J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《約貳》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《约贰》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("二ヨハネ 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("伊望第二 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("約翰二書 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("約翰貳書 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("约翰二书 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("约翰贰书 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("若望二書 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("요한2서 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("요한이서 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2 J 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("2요한 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《約貳 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("《约贰 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("約貳》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("约贰》 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("約貳 1:1").osis()).toEqual("2John.1.1")
		expect(p.parse("约贰 1:1").osis()).toEqual("2John.1.1")
		`
		true
describe "Localized book 3John (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 3John (full)", ->
		`
		expect(p.parse("Трето съборно послание на св. ап. Иоана Богослова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето съборно послание на св ап. Иоана Богослова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето съборно послание на св. ап Иоана Богослова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето съборно послание на св ап Иоана Богослова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третя соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третє соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє. соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третя соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третє соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а. соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е. соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("யோவான் எழுதிய முன்றாம் திருமுகம் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretje poslannja apostola Ivana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Munravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Munrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Munṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Munṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Muṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Muṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Muṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Muṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Mūnravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Mūnrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Mūnṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Mūnṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Mūṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Mūṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Mūṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Mūṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Munravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Munrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Munṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Munṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Muṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Muṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Muṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Muṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Mūnravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Mūnrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Mūnṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Mūnṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Mūṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Mūṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Mūṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Mūṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Munravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Munrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Munṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Munṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Muṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Muṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Muṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Muṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Mūnravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Mūnrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Mūnṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Mūnṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Mūṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Mūṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Mūṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Mūṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Munravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Munrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Munṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Munṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Muṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Muṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Muṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Muṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Mūnravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Mūnrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Mūnṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Mūnṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Mūṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Mūṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Mūṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Mūṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Munravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Munrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Munṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Munṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Muṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Muṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Muṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Muṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Mūnravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Mūnrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Mūnṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Mūnṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Mūṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Mūṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Mūṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Mūṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Munravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Munrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Munṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Munṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Muṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Muṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Muṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Muṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Mūnravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Mūnrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Mūnṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Mūnṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Mūṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Mūṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Mūṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Mūṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Munravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Munrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Munṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Munṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Muṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Muṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Muṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Muṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Mūnravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Mūnrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Mūnṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Mūnṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Mūṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Mūṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Mūṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Mūṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Munravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Munrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Munṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Munṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Muṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Muṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Muṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Muṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Mūnravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Mūnrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Mūnṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Mūnṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Mūṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Mūṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Mūṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Mūṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трета послание на апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето послание на апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. послание на апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("யோவன் எழுதிய மூன்றாவது நிருபம் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє. послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III послание на апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третя послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третє послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("யோவான் எழுதிய மூன்றாம் கடிதம் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а. послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е. послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. послание на апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трета писмо од апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето писмо од апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 послание на апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. писмо од апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("אגרתו השלישית של יוחנן השלי 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III писмо од апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("رسالة القديس يوحنا الثالثة 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. писмо од апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Terza lettera di Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трећом посланица Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("யோவான் மூன்றாம் திருமுகம் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 писмо од апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Kolmas Johanneksen kirje 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Waraka wa Tatu wa Yohane 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yūḥannā kā tīsrā ʿām ḫaṭ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трећа посланица Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Barua ya Tatu ya Yohane 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. посланица Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treca Ivanova Poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treca Ivanova poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treæa Ivanova Poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treæa Ivanova poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treća Ivanova Poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treća Ivanova poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("یُوحنّا کا تیسرا عام خط 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("यूहन्नाको तेस्त्रो पत्र 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III посланица Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Ivanova Poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Johanneksen kirje 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yuhannako testro patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yuhannāko testro patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yūhannako testro patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yūhannāko testro patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Þriðja bref Johannesar 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Þriðja bref Jóhannesar 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Þriðja bréf Johannesar 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Þriðja bréf Jóhannesar 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето послание на Иоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето послание на Йоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. посланица Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Ivanova Poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Johanneksen kirje 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes' Tredje Brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes’ Tredje Brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes’ tredje brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tredje Johannesbrevet 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzecia List sw. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzecia List św. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yohanacem tisre patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yohanaceṃ tisre patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yohanācem tisre patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yohanāceṃ tisre patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yohānacem tisre patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yohānaceṃ tisre patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yohānācem tisre patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yohānāceṃ tisre patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yūhãnā dī tījī pattrī 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Þriðja Johannesarbref 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Þriðja Johannesarbréf 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Þriðja Jóhannesarbref 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Þriðja Jóhannesarbréf 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("یوحنا کا تیسرا عام خط 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("यूहन्नाको तेस्रो पत्र 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ਯੂਹੰਨਾ ਦੀ ਤੀਜੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 посланица Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е. послание Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє. Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-я. послание Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Ivanova Poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Johanneksen kirje 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Epistula III Ioannis 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Epistula Ioannis III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes tredje brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzeci List sw. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzeci List św. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzecia List sw Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzecia List św Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третя Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третє Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("योहानाचें तिसरे पत्र 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Ivanova Poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Johanneksen kirje 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а. Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е послание Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е. Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-я послание Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3е. послание Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3я. послание Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tredje Johannesbrev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzeci List sw Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzeci List św Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("איגרת יוחנן השלישית 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("رسالة يوحنا الثالثة 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. послание Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e. Johannesbrevet 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3е послание Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3я послание Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. List sw. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. List św. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Kolmas Johanneksen 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretia kniha Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretia kniha Jánov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yooxanaa Saddexaad 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("یوحنّا کا تیسرا خط 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ଯୋହନଙ୍କ ତୃତୀୟ ପତ୍ର 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 послание Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Johannesbrevet 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e Johannesbrevet 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III List sw. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III List św. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. List sw Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. List św Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes' 3. Brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes’ 3. Brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzecia List Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Johannesbrevet 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. List sw. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. List św. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III List sw Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III List św Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Johanneksen 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes' 3 Brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes’ 3 Brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Munravatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Munrāvatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Munṛavatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Munṛāvatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Muṉravatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Muṉrāvatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Muṉṛavatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Muṉṛāvatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Mūnravatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Mūnrāvatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Mūnṛavatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Mūnṛāvatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Mūṉravatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Mūṉrāvatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Mūṉṛavatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Mūṉṛāvatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti Janov list 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti Jánov list 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti list Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti list Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretí Janov list 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretí Jánov list 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretí list Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretí list Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzeci List Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třeti list Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třeti list Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třetí list Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třetí list Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("மூன்றாவது யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 List sw. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 List św. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Johannesbrev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. List sw Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. List św Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Dritte Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Johanneksen 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. list Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. list Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tredje Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Troisiemes Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Troisièmes Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трећом Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("یوحنّا کا 3. خط 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("முன்றாம் யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Johannesbrev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 List sw Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 List św Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Johanneksen 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Derde Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Harmadik Janos 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Harmadik János 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III list Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III list Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. List Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Terza Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Terzo Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Troisieme Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Troisième Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трета Јованово 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето Јованово 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трећа Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("یوحنّا کا 3 خط 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("یوحنّا کا ۳ خط 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Johanneksen 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє. Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє. Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. list Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. list Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III List Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Yooxanaa 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Јованово 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ikatlong Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Terceira Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Terceira João 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Terceiro Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Terceiro João 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treca Ivanova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treæa Ivanova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treća Ivanova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третя Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третя Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третє Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третє Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("تیسرا یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("تیسرا-یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("رسالة يوحنا 3 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("يوحنا الثالثة 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 list Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 list Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а. Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а. Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е. Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е. Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє. Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. List Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. yuhannako 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. yuhannāko 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. yūhannako 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. yūhannāko 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. यूहन्नाको 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e. Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3°. Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Yooxanaa 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Јованово 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Ioannis 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Ivanova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Yohanes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Yokanan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti Janova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretia Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretia Jánov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretí Janova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzecia Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třeti Janova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třetí Janova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третя Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третє Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("تیسرا یوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 List Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 e. Gjonit 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 i. Gjonit 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yohanacem 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yohanaceṃ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yohanācem 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yohanāceṃ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yohānacem 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yohānaceṃ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yohānācem 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yohānāceṃ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yuhannako 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yuhannāko 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yūhannako 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yūhannāko 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 यूहन्नाको 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 அருளப்பர் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а. Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е. Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е. Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е. Иохана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє. Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-я. Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-я. Иохана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yoohanna 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yooxanaa 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Јованово 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3° Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Harmadik Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Ioannis 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Ivanova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Yohanes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Yokanan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Janova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Yohana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Yohane 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ioannis III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tatu Yohana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tatu Yohane 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti Jánov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretí Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretí Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretí Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretí Jánov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzeci Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třeti Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třeti Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třetí Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třetí Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трета Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третя Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третє Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("تیسرا۔یوحنا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ତୃତୀୟ ଯୋହନଙ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yoohanna 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yooxanaa 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 e Gjonit 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 i Gjonit 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 k. Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 k. Jánov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Јованово 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а. Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е Иохана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е. Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-я Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-я Иохана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Ioannis 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Ivanova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yohanes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yokanan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. युहत्रा 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. यूहन्ना 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.-یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3eme. Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3ème. Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3е. Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3е. Иохана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3я. Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3я. Иохана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Janova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Yohana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Yohane 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Gioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Giăng 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Janos 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. János 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jánov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tredje Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yohane III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ιωάννου Γ' 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ιωάννου Γʹ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ιωάννου Γʹ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ιωάννου Γ΄ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ιωάννου Γ’ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ιωαννου Γ' 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ιωαννου Γʹ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ιωαννου Γʹ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ιωαννου Γ΄ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ιωαννου Γ’ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето Иоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето Йоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Ioannis 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Ivanova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yohanes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yokanan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 k Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 k Jánov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 युहत्रा 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 यूहन्ना 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 योहानाच 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Gjonit 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Janova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yohana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yohane 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Иохана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. یوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3eme Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3ème Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3е Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3е Иохана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3я Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3я Иохана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Derde Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Gioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Giăng 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Janos 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III János 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jánov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Ioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. João 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Yoox 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Иоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Йоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Janos III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("János III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti Jan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretí Jan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třeti Jan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třetí Jan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ' Ιωάννη 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ' Ιωαννη 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ Ιωάννη 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ Ιωαννη 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ Ιωάννη 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ Ιωαννη 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ΄ Ιωάννη 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ΄ Ιωαννη 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ’ Ιωάννη 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ’ Ιωαννη 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("۳ یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("۳-یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ヨハネの第三の手紙 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("요한의 셋째 서간 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Gjonit 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Janova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yohana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yohane 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yūhãnā 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Иохана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 یوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ਯੂਹੰਨਾ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Gioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Giăng 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Janos 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. János 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jánov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ଯୋହନଙ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ยอห์น 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.۔یوحنا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3a. Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3a. João 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e. Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. João 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Ioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III João 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Yoox 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Иоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Йоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jóh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Yoh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tatu Yoh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("۳ یوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ヨハネの第三の書 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Gioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Giăng 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Janos 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 János 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jánov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yovan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yovaṉ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yōvan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yōvaṉ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 योहान 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ଯୋହନଙ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ยอห์น 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Ioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. João 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yoox 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Иоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Йоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3a Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3a João 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e. Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o João 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3۔یوحنا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jóh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Yoh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Gi 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. In 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretí J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třeti J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třetí J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("۳۔یوحنا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ヨハネの手紙三 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Ioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 João 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yoox 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Иоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Йоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 யோவா 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jóh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yoh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Gi 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III In 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ' ᾿Ιω 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ ᾿Ιω 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ ᾿Ιω 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ΄ ᾿Ιω 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ’ ᾿Ιω 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《伊望第三》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《約翰三書》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《約翰參書》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《约翰三书》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《约翰叁书》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《若望三書》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jóh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yoh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Gi 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. In 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ' Ιω 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ Ιω 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ Ιω 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ΄ Ιω 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ’ Ιω 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《伊望第三 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《約翰三書 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《約翰參書 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《约翰三书 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《约翰叁书 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《若望三書 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ヨハネ 3 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("伊望第三》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("約翰三書》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("約翰參書》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("约翰三书》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("约翰叁书》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("若望三書》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Gi 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Gj 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Gv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 In 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Iv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Ів 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Јн 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Ин 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 يو 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 யோ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ยน 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《約三》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《约三》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("三ヨハネ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("伊望第三 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("約翰三書 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("約翰參書 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("约翰三书 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("约翰叁书 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("若望三書 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("요한3서 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("요한삼서 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3요한 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《約三 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《约三 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("約三》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("约三》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("約三 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("约三 1:1").osis()).toEqual("3John.1.1")
		`
		true
	it "should handle non-Latin digits in book: 3John (full)", ->
		p.set_options non_latin_digits_strategy: "replace"
		`
		expect(p.parse("Трето съборно послание на св. ап. Иоана Богослова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето съборно послание на св ап. Иоана Богослова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето съборно послание на св. ап Иоана Богослова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето съборно послание на св ап Иоана Богослова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третя соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третє соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє. соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третя соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третє соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а. соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е. соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 соборне послання св. апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 соборне послання св апостола Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("யோவான் எழுதிய முன்றாம் திருமுகம் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretje poslannja apostola Ivana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Munravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Munrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Munṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Munṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Muṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Muṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Muṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Muṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Mūnravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Mūnrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Mūnṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Mūnṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Mūṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Mūṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Mūṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Elutiya Mūṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Munravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Munrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Munṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Munṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Muṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Muṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Muṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Muṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Mūnravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Mūnrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Mūnṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Mūnṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Mūṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Mūṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Mūṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovan Eḻutiya Mūṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Munravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Munrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Munṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Munṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Muṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Muṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Muṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Muṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Mūnravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Mūnrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Mūnṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Mūnṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Mūṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Mūṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Mūṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Elutiya Mūṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Munravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Munrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Munṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Munṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Muṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Muṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Muṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Muṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Mūnravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Mūnrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Mūnṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Mūnṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Mūṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Mūṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Mūṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yovaṉ Eḻutiya Mūṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Munravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Munrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Munṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Munṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Muṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Muṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Muṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Muṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Mūnravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Mūnrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Mūnṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Mūnṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Mūṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Mūṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Mūṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Elutiya Mūṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Munravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Munrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Munṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Munṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Muṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Muṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Muṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Muṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Mūnravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Mūnrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Mūnṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Mūnṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Mūṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Mūṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Mūṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvan Eḻutiya Mūṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Munravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Munrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Munṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Munṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Muṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Muṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Muṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Muṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Mūnravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Mūnrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Mūnṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Mūnṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Mūṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Mūṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Mūṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Elutiya Mūṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Munravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Munrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Munṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Munṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Muṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Muṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Muṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Muṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Mūnravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Mūnrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Mūnṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Mūnṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Mūṉravatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Mūṉrāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Mūṉṛavatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yōvaṉ Eḻutiya Mūṉṛāvatu Nirupam 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трета послание на апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето послание на апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. послание на апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("யோவன் எழுதிய மூன்றாவது நிருபம் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє. послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III послание на апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третя послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третє послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("யோவான் எழுதிய மூன்றாம் கடிதம் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а. послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е. послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. послание на апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трета писмо од апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето писмо од апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 послание на апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. писмо од апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("אגרתו השלישית של יוחנן השלי 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III писмо од апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("رسالة القديس يوحنا الثالثة 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 послання апостола Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. писмо од апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Terza lettera di Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трећом посланица Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("யோவான் மூன்றாம் திருமுகம் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 писмо од апостол Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Kolmas Johanneksen kirje 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Waraka wa Tatu wa Yohane 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yūḥannā kā tīsrā ʿām ḫaṭ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трећа посланица Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Barua ya Tatu ya Yohane 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. посланица Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treca Ivanova Poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treca Ivanova poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treæa Ivanova Poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treæa Ivanova poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treća Ivanova Poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treća Ivanova poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("یُوحنّا کا تیسرا عام خط 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("यूहन्नाको तेस्त्रो पत्र 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III посланица Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Ivanova Poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Johanneksen kirje 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yuhannako testro patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yuhannāko testro patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yūhannako testro patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yūhannāko testro patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Þriðja bref Johannesar 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Þriðja bref Jóhannesar 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Þriðja bréf Johannesar 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Þriðja bréf Jóhannesar 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето послание на Иоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето послание на Йоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. посланица Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Ivanova Poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Johanneksen kirje 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes' Tredje Brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes’ Tredje Brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes’ tredje brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tredje Johannesbrevet 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzecia List sw. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzecia List św. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yohanacem tisre patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yohanaceṃ tisre patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yohanācem tisre patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yohanāceṃ tisre patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yohānacem tisre patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yohānaceṃ tisre patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yohānācem tisre patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yohānāceṃ tisre patra 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("yūhãnā dī tījī pattrī 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Þriðja Johannesarbref 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Þriðja Johannesarbréf 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Þriðja Jóhannesarbref 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Þriðja Jóhannesarbréf 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("یوحنا کا تیسرا عام خط 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("यूहन्नाको तेस्रो पत्र 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ਯੂਹੰਨਾ ਦੀ ਤੀਜੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 посланица Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е. послание Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє. Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-я. послание Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Ivanova Poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Johanneksen kirje 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Epistula III Ioannis 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Epistula Ioannis III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes tredje brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzeci List sw. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzeci List św. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzecia List sw Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzecia List św Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третя Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третє Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("योहानाचें तिसरे पत्र 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Ivanova Poslanica 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Johanneksen kirje 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а. Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е послание Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е. Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-я послание Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3е. послание Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3я. послание Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tredje Johannesbrev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzeci List sw Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzeci List św Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("איגרת יוחנן השלישית 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("رسالة يوحنا الثالثة 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. послание Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e. Johannesbrevet 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3е послание Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3я послание Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. List sw. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. List św. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Kolmas Johanneksen 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretia kniha Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretia kniha Jánov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yooxanaa Saddexaad 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("یوحنّا کا تیسرا خط 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ଯୋହନଙ୍କ ତୃତୀୟ ପତ୍ର 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 послание Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Johannesbrevet 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e Johannesbrevet 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III List sw. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III List św. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. List sw Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. List św Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes' 3. Brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes’ 3. Brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzecia List Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Johannesbrevet 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Послання Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. List sw. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. List św. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III List sw Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III List św Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Johanneksen 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes' 3 Brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Johannes’ 3 Brev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Munravatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Munrāvatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Munṛavatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Munṛāvatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Muṉravatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Muṉrāvatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Muṉṛavatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Muṉṛāvatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Mūnravatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Mūnrāvatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Mūnṛavatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Mūnṛāvatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Mūṉravatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Mūṉrāvatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Mūṉṛavatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Mūṉṛāvatu யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti Janov list 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti Jánov list 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti list Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti list Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretí Janov list 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretí Jánov list 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretí list Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretí list Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzeci List Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třeti list Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třeti list Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třetí list Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třetí list Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("மூன்றாவது யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 List sw. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 List św. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Johannesbrev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. List sw Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. List św Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Dritte Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Johanneksen 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. list Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. list Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tredje Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Troisiemes Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Troisièmes Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трећом Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("یوحنّا کا 3. خط 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("முன்றாம் யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Johannesbrev 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 List sw Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 List św Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Johanneksen 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Derde Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Harmadik Janos 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Harmadik János 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III list Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III list Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. List Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Terza Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Terzo Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Troisieme Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Troisième Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трета Јованово 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето Јованово 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трећа Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("یوحنّا کا 3 خط 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("یوحنّا کا ۳ خط 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Johanneksen 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє. Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє. Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. list Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. list Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III List Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Yooxanaa 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Јованово 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ikatlong Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Terceira Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Terceira João 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Terceiro Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Terceiro João 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treca Ivanova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treæa Ivanova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treća Ivanova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третя Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третя Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третє Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третє Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("تیسرا یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("تیسرا-یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("رسالة يوحنا 3 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("يوحنا الثالثة 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 list Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 list Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а. Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а. Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е. Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е. Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє. Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. List Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. yuhannako 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. yuhannāko 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. yūhannako 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. yūhannāko 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. यूहन्नाको 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e. Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3°. Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Yooxanaa 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Јованово 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Ioannis 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Ivanova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Yohanes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Yokanan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercero Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti Janova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretia Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretia Jánov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretí Janova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzecia Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třeti Janova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třetí Janova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третя Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третє Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("تیسرا یوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 List Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 e. Gjonit 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 i. Gjonit 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yohanacem 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yohanaceṃ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yohanācem 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yohanāceṃ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yohānacem 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yohānaceṃ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yohānācem 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yohānāceṃ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yuhannako 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yuhannāko 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yūhannako 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yūhannāko 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 यूहन्नाको 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 அருளப்பர் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а. Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е. Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е. Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е. Иохана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє. Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-я. Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-я. Иохана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yoohanna 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yooxanaa 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Јованово 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3° Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Harmadik Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Ioannis 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Ivanova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Yohanes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Yokanan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Janova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Yohana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Yohane 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ioannis III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tatu Yohana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tatu Yohane 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tercer Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti Jánov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretí Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretí Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretí Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretí Jánov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Trzeci Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třeti Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třeti Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třetí Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třetí Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трета Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третя Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Третє Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("تیسرا۔یوحنا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ତୃତୀୟ ଯୋହନଙ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Giovanni 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Johannes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 San Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 San Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 San Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 San Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yoohanna 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yooxanaa 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 e Gjonit 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 i Gjonit 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 k. Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 k. Jánov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Јованова 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Јованово 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а. Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е Иохана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е. Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-тє Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-я Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-я Иохана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Ioannis 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Ivanova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yohanes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yokanan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. युहत्रा 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. यूहन्ना 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.-یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3eme. Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3ème. Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3е. Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3е. Иохана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3я. Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3я. Иохана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Janova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Yohana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Yohane 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Gioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Giăng 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Janos 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. János 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jánov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tredje Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Yohane III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ιωάννου Γ' 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ιωάννου Γʹ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ιωάννου Γʹ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ιωάννου Γ΄ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ιωάννου Γ’ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ιωαννου Γ' 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ιωαννου Γʹ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ιωαννου Γʹ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ιωαννου Γ΄ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Ιωαννου Γ’ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето Иоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Трето Йоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Ioannis 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Ivanova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yohanes 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yokanan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 k Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 k Jánov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Иоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Йоаново 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 युहत्रा 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 यूहन्ना 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 योहानाच 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-а Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-е Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Gjonit 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Janova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yohana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yohane 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Иохана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. یوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o. Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3eme Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3ème Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3е Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3е Иохана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3я Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3я Иохана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Derde Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Gioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Giăng 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Janos 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III János 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jánov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Ioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. João 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Yoox 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Иоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Йоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Janos III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("János III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti Jan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretí Jan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třeti Jan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třetí Jan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ' Ιωάννη 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ' Ιωαννη 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ Ιωάννη 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ Ιωαννη 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ Ιωάννη 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ Ιωαννη 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ΄ Ιωάννη 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ΄ Ιωαννη 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ’ Ιωάννη 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ’ Ιωαννη 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("۳ یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("۳-یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ヨハネの第三の手紙 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("요한의 셋째 서간 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Gjonit 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Janova 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yohana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yohane 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 yūhãnā 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Іоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Иоанна 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Иохана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 یوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ਯੂਹੰਨਾ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Gioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Giăng 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Janos 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. János 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jánov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ଯୋହନଙ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ยอห์น 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.o Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.۔یوحنا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3a. Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3a. João 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e. Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. João 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o. Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Ioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III João 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Yoox 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Иоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Йоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jóh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Yoh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tatu Yoh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Third Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("۳ یوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ヨハネの第三の書 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Gioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Giăng 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Janos 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Janov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Januv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Janův 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jophn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 János 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jánov 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yovan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yovaṉ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yōvan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yōvaṉ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Івана 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Јован 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 योहान 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ଯୋହନଙ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ยอห์น 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Ioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. João 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yoox 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Иоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Йоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3a Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3a João 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e. Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o João 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3o Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd. Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3۔یوحنا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jóh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Yoh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Gi 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. In 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Treti J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Tretí J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třeti J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Třetí J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("۳۔یوحنا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ヨハネの手紙三 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Ioan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jaan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jana 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jaun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jean 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jhhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jhon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Joao 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Johm 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jonh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Joon 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 João 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jphn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Juan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Juun 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yoox 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Иоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Йоан 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 யோவா 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jóh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Yoh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3e Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3rd Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Gi 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III In 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ' ᾿Ιω 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ ᾿Ιω 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ ᾿Ιω 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ΄ ᾿Ιω 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ’ ᾿Ιω 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《伊望第三》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《約翰三書》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《約翰參書》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《约翰三书》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《约翰叁书》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《若望三書》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jan 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jhn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Joh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jóh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Yoh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Gi 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. In 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3John 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ' Ιω 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ Ιω 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ Ιω 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ΄ Ιω 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ’ Ιω 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《伊望第三 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《約翰三書 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《約翰參書 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《约翰三书 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《约翰叁书 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《若望三書 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ヨハネ 3 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("伊望第三》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("約翰三書》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("約翰參書》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("约翰三书》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("约翰叁书》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("若望三書》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Gi 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Gj 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Gv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 In 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Iv 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jh 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jn 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Jo 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Ів 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Јн 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 Ин 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 يو 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 யோ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ยน 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《約三》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《约三》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("三ヨハネ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("伊望第三 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("約翰三書 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("約翰參書 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("约翰三书 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("约翰叁书 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("若望三書 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("요한3서 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("요한삼서 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3요한 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《約三 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《约三 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("約三》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("约三》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("約三 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("约三 1:1").osis()).toEqual("3John.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ТРЕТО СЪБОРНО ПОСЛАНИЕ НА СВ. АП. ИОАНА БОГОСЛОВА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТО СЪБОРНО ПОСЛАНИЕ НА СВ АП. ИОАНА БОГОСЛОВА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТО СЪБОРНО ПОСЛАНИЕ НА СВ. АП ИОАНА БОГОСЛОВА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТО СЪБОРНО ПОСЛАНИЕ НА СВ АП ИОАНА БОГОСЛОВА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-ТЄ. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТЯ СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТЄ СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-А. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Е. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-ТЄ СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-ТЄ. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТЯ СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТЄ СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-А СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-А. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Е СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Е. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-ТЄ СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-А СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Е СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("யோவான் எழுதிய முன்றாம் திருமுகம் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETJE POSLANNJA APOSTOLA IVANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN ELUTIYA MUNRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN ELUTIYA MUNRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN ELUTIYA MUNṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN ELUTIYA MUNṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN ELUTIYA MUṈRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN ELUTIYA MUṈRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN ELUTIYA MUṈṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN ELUTIYA MUṈṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN ELUTIYA MŪNRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN ELUTIYA MŪNRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN ELUTIYA MŪNṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN ELUTIYA MŪNṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN ELUTIYA MŪṈRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN ELUTIYA MŪṈRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN ELUTIYA MŪṈṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN ELUTIYA MŪṈṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN EḺUTIYA MUNRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN EḺUTIYA MUNRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN EḺUTIYA MUNṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN EḺUTIYA MUNṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN EḺUTIYA MUṈRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN EḺUTIYA MUṈRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN EḺUTIYA MUṈṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN EḺUTIYA MUṈṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN EḺUTIYA MŪNRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN EḺUTIYA MŪNRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN EḺUTIYA MŪNṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN EḺUTIYA MŪNṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN EḺUTIYA MŪṈRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN EḺUTIYA MŪṈRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN EḺUTIYA MŪṈṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAN EḺUTIYA MŪṈṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA MUNRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA MUNRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA MUNṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA MUNṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA MUṈRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA MUṈRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA MUṈṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA MUṈṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA MŪNRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA MŪNRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA MŪNṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA MŪNṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA MŪṈRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA MŪṈRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA MŪṈṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ ELUTIYA MŪṈṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA MUNRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA MUNRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA MUNṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA MUNṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA MUṈRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA MUṈRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA MUṈṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA MUṈṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA MŪNRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA MŪNRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA MŪNṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA MŪNṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA MŪṈRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA MŪṈRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA MŪṈṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOVAṈ EḺUTIYA MŪṈṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN ELUTIYA MUNRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN ELUTIYA MUNRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN ELUTIYA MUNṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN ELUTIYA MUNṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN ELUTIYA MUṈRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN ELUTIYA MUṈRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN ELUTIYA MUṈṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN ELUTIYA MUṈṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN ELUTIYA MŪNRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN ELUTIYA MŪNRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN ELUTIYA MŪNṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN ELUTIYA MŪNṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN ELUTIYA MŪṈRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN ELUTIYA MŪṈRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN ELUTIYA MŪṈṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN ELUTIYA MŪṈṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA MUNRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA MUNRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA MUNṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA MUNṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA MUṈRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA MUṈRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA MUṈṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA MUṈṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA MŪNRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA MŪNRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA MŪNṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA MŪNṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA MŪṈRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA MŪṈRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA MŪṈṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAN EḺUTIYA MŪṈṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA MUNRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA MUNRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA MUNṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA MUNṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA MUṈRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA MUṈRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA MUṈṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA MUṈṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA MŪNRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA MŪNRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA MŪNṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA MŪNṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA MŪṈRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA MŪṈRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA MŪṈṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ ELUTIYA MŪṈṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA MUNRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA MUNRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA MUNṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA MUNṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA MUṈRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA MUṈRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA MUṈṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA MUṈṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA MŪNRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA MŪNRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA MŪNṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA MŪNṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA MŪṈRAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA MŪṈRĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA MŪṈṚAVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŌVAṈ EḺUTIYA MŪṈṚĀVATU NIRUPAM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТА ПОСЛАНИЕ НА АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТО ПОСЛАНИЕ НА АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. ПОСЛАНИЕ НА АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("யோவன் எழுதிய மூன்றாவது நிருபம் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-ТЄ. ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III ПОСЛАНИЕ НА АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТЯ ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТЄ ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("யோவான் எழுதிய மூன்றாம் கடிதம் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-А. ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Е. ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-ТЄ ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ПОСЛАНИЕ НА АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТА ПИСМО ОД АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТО ПИСМО ОД АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ПОСЛАНИЕ НА АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-А ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Е ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. ПИСМО ОД АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("אגרתו השלישית של יוחנן השלי 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III ПИСМО ОД АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("رسالة القديس يوحنا الثالثة 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ПОСЛАННЯ АПОСТОЛА ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ПИСМО ОД АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERZA LETTERA DI GIOVANNI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕЋОМ ПОСЛАНИЦА ЈОВАНОВА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("யோவான் மூன்றாம் திருமுகம் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ПИСМО ОД АПОСТОЛ ЈОВАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("KOLMAS JOHANNEKSEN KIRJE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("WARAKA WA TATU WA YOHANE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŪḤANNĀ KĀ TĪSRĀ ʿĀM ḪAṬ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕЋА ПОСЛАНИЦА ЈОВАНОВА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("BARUA YA TATU YA YOHANE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. ПОСЛАНИЦА ЈОВАНОВА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRECA IVANOVA POSLANICA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRECA IVANOVA POSLANICA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TREÆA IVANOVA POSLANICA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TREÆA IVANOVA POSLANICA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TREĆA IVANOVA POSLANICA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TREĆA IVANOVA POSLANICA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("یُوحنّا کا تیسرا عام خط 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("यूहन्नाको तेस्त्रो पत्र 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III ПОСЛАНИЦА ЈОВАНОВА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. IVANOVA POSLANICA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOHANNEKSEN KIRJE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YUHANNAKO TESTRO PATRA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YUHANNĀKO TESTRO PATRA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŪHANNAKO TESTRO PATRA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŪHANNĀKO TESTRO PATRA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ÞRIÐJA BREF JOHANNESAR 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ÞRIÐJA BREF JÓHANNESAR 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ÞRIÐJA BRÉF JOHANNESAR 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ÞRIÐJA BRÉF JÓHANNESAR 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТО ПОСЛАНИЕ НА ИОАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТО ПОСЛАНИЕ НА ЙОАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ПОСЛАНИЦА ЈОВАНОВА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III IVANOVA POSLANICA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOHANNEKSEN KIRJE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("JOHANNES' TREDJE BREV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("JOHANNES’ TREDJE BREV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("JOHANNES’ TREDJE BREV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TREDJE JOHANNESBREVET 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRZECIA LIST SW. JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRZECIA LIST ŚW. JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOHANACEM TISRE PATRA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOHANACEṂ TISRE PATRA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOHANĀCEM TISRE PATRA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOHANĀCEṂ TISRE PATRA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOHĀNACEM TISRE PATRA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOHĀNACEṂ TISRE PATRA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOHĀNĀCEM TISRE PATRA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOHĀNĀCEṂ TISRE PATRA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YŪHÃNĀ DĪ TĪJĪ PATTRĪ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ÞRIÐJA JOHANNESARBREF 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ÞRIÐJA JOHANNESARBRÉF 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ÞRIÐJA JÓHANNESARBREF 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ÞRIÐJA JÓHANNESARBRÉF 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("یوحنا کا تیسرا عام خط 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("यूहन्नाको तेस्रो पत्र 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ਯੂਹੰਨਾ ਦੀ ਤੀਜੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ПОСЛАНИЦА ЈОВАНОВА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Е. ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-ТЄ. ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Я. ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. IVANOVA POSLANICA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOHANNEKSEN KIRJE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("EPISTULA III IOANNIS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("EPISTULA IOANNIS III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("JOHANNES TREDJE BREV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRZECI LIST SW. JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRZECI LIST ŚW. JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRZECIA LIST SW JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRZECIA LIST ŚW JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТЯ ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТЄ ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("योहानाचें तिसरे पत्र 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 IVANOVA POSLANICA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOHANNEKSEN KIRJE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-А. ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Е ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Е. ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-ТЄ ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Я ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3Е. ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3Я. ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TREDJE JOHANNESBREV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRZECI LIST SW JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRZECI LIST ŚW JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("איגרת יוחנן השלישית 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("رسالة يوحنا الثالثة 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-А ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Е ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3E. JOHANNESBREVET 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3Е ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3Я ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. LIST SW. JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. LIST ŚW. JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("KOLMAS JOHANNEKSEN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETIA KNIHA JANOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETIA KNIHA JÁNOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOOXANAA SADDEXAAD 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("یوحنّا کا تیسرا خط 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ଯୋହନଙ୍କ ତୃତୀୟ ପତ୍ର 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ПОСЛАНИЕ ИОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOHANNESBREVET 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3E JOHANNESBREVET 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III LIST SW. JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III LIST ŚW. JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. LIST SW JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. LIST ŚW JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("JOHANNES' 3. BREV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("JOHANNES’ 3. BREV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRZECIA LIST JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOHANNESBREVET 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ПОСЛАННЯ ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. LIST SW. JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. LIST ŚW. JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III LIST SW JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III LIST ŚW JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOHANNEKSEN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("JOHANNES' 3 BREV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("JOHANNES’ 3 BREV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("MUNRAVATU யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("MUNRĀVATU யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("MUNṚAVATU யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("MUNṚĀVATU யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("MUṈRAVATU யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("MUṈRĀVATU யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("MUṈṚAVATU யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("MUṈṚĀVATU யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("MŪNRAVATU யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("MŪNRĀVATU யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("MŪNṚAVATU யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("MŪNṚĀVATU யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("MŪṈRAVATU யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("MŪṈRĀVATU யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("MŪṈṚAVATU யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("MŪṈṚĀVATU யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCERO SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCERO SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCERO SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCERO SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETI JANOV LIST 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETI JÁNOV LIST 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETI LIST JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETI LIST JANŮV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETÍ JANOV LIST 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETÍ JÁNOV LIST 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETÍ LIST JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETÍ LIST JANŮV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRZECI LIST JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TŘETI LIST JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TŘETI LIST JANŮV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TŘETÍ LIST JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TŘETÍ LIST JANŮV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("மூன்றாவது யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 LIST SW. JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 LIST ŚW. JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOHANNESBREV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. LIST SW JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. LIST ŚW JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("DRITTE JOHANNES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOHANNEKSEN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. LIST JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. LIST JANŮV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCER SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCER SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCER SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCER SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TREDJE JOHANNES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TROISIEMES JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TROISIÈMES JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕЋОМ ЈОВАНОВА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("یوحنّا کا 3. خط 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("முன்றாம் யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOHANNESBREV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 LIST SW JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 LIST ŚW JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOHANNEKSEN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("DERDE JOHANNES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("HARMADIK JANOS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("HARMADIK JÁNOS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III LIST JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III LIST JANŮV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. LIST JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERZA GIOVANNI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERZO GIOVANNI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TROISIEME JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TROISIÈME JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТА ЈОВАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТО ЈОВАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕЋА ЈОВАНОВА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("یوحنّا کا 3 خط 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("یوحنّا کا ۳ خط 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOHANNEKSEN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-ТЄ. ИОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-ТЄ. ЙОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. LIST JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. LIST JANŮV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O. SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O. SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O. SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O. SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III LIST JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. GIOVANNI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOHANNES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. YOOXANAA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. ЈОВАНОВА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. ЈОВАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("IKATLONG JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCEIRA JOAO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCEIRA JOÃO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCEIRO JOAO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCEIRO JOÃO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRECA IVANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TREÆA IVANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TREĆA IVANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТО ИОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТО ЙОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТЯ ИОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТЯ ЙОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТЄ ИОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТЄ ЙОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("تیسرا یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("تیسرا-یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("رسالة يوحنا 3 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("يوحنا الثالثة 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 LIST JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 LIST JANŮV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-А. ИОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-А. ЙОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Е. ИОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Е. ЙОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-ТЄ ИОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-ТЄ ЙОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-ТЄ. ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. LIST JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. YUHANNAKO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. YUHANNĀKO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. YŪHANNAKO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. YŪHANNĀKO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. यूहन्नाको 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3E. JOHANNES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O. SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O. SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O. SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O. SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3°. GIOVANNI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III GIOVANNI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOHANNES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III YOOXANAA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III ЈОВАНОВА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III ЈОВАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. IOANNIS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. IVANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. YOHANES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. YOKANAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. ИОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. ЙОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCERO JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCERO JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCERO JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCERO JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETI JANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETIA JANOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETIA JÁNOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETÍ JANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRZECIA JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TŘETI JANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TŘETÍ JANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТЯ ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТЄ ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("تیسرا یوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 LIST JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 E. GJONIT 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 I. GJONIT 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOHANACEM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOHANACEṂ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOHANĀCEM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOHANĀCEṂ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOHĀNACEM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOHĀNACEṂ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOHĀNĀCEM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOHĀNĀCEṂ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YUHANNAKO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YUHANNĀKO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YŪHANNAKO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YŪHANNĀKO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 यूहन्नाको 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 அருளப்பர் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-А ИОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-А ЙОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-А. ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Е ИОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Е ЙОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Е. ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Е. ИОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Е. ИОХАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-ТЄ ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-ТЄ. ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Я. ИОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Я. ИОХАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. GIOVANNI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOHANNES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. YOOHANNA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. YOOXANAA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ЈОВАНОВА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ЈОВАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3E JOHANNES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3° GIOVANNI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("HARMADIK JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III IOANNIS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III IVANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III YOHANES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III YOKANAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III ИОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III ЙОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. YOHANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. YOHANE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("IOANNIS III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TATU YOHANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TATU YOHANE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCER JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCER JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCER JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TERCER JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JOPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETI JANOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETI JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETI JANŮV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETI JÁNOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETÍ JANOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETÍ JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETÍ JANŮV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETÍ JÁNOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRZECI JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TŘETI JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TŘETI JANŮV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TŘETÍ JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TŘETÍ JANŮV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТА ЈОВАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТО ЈОВАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТЯ ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТЄ ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("تیسرا۔یوحنا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ତୃତୀୟ ଯୋହନଙ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 GIOVANNI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOHANNES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 SAN JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 SAN JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 SAN JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 SAN JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOOHANNA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOOXANAA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 E GJONIT 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 I GJONIT 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 K. JANOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 K. JÁNOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ЈОВАНОВА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ЈОВАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-А ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-А. ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Е ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Е ИОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Е ИОХАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Е. ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-ТЄ ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Я ИОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Я ИОХАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. IOANNIS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. IVANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. YOHANES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. YOKANAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ИОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ЙОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. युहत्रा 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. यूहन्ना 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.-یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3EME. JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JOPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3ÈME. JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3Е. ИОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3Е. ИОХАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3Я. ИОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3Я. ИОХАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III YOHANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III YOHANE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. GIOAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. GIĂNG 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JANOS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JANOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JANŮV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JÁNOS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JÁNOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. ЈОВАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JHHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JHON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JOHM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JONH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JOON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TREDJE JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("YOHANE III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ΙΩΆΝΝΟΥ Γ' 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ΙΩΆΝΝΟΥ Γʹ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ΙΩΆΝΝΟΥ Γʹ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ΙΩΆΝΝΟΥ Γ΄ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ΙΩΆΝΝΟΥ Γ’ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ΙΩΑΝΝΟΥ Γ' 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ΙΩΑΝΝΟΥ Γʹ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ΙΩΑΝΝΟΥ Γʹ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ΙΩΑΝΝΟΥ Γ΄ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ΙΩΑΝΝΟΥ Γ’ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТО ИОАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ТРЕТО ЙОАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 IOANNIS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 IVANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOHANES 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOKANAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 K JANOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 K JÁNOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ИОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ЙОАНОВО 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 युहत्रा 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 यूहन्ना 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 योहानाच 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-А ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-Е ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3-یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. GJONIT 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. YOHANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. YOHANE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ИОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ИОХАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. یوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O. JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O. JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O. JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O. JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º. JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3EME JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JOPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JHHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JHON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JOHM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JONH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JOON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3ÈME JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3Е ИОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3Е ИОХАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3Я ИОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3Я ИОХАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("DERDE JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III GIOAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III GIĂNG 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JANOS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JANOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JANŮV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JÁNOS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JÁNOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III ЈОВАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. IOAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JHHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JHON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOAO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOHM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JONH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOÃO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. YOOX 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. ИОАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. ЙОАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("JANOS III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("JÁNOS III 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETI JAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETÍ JAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TŘETI JAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TŘETÍ JAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ' ΙΩΆΝΝΗ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ' ΙΩΑΝΝΗ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ ΙΩΆΝΝΗ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ ΙΩΑΝΝΗ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ ΙΩΆΝΝΗ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ ΙΩΑΝΝΗ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ΄ ΙΩΆΝΝΗ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ΄ ΙΩΑΝΝΗ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ’ ΙΩΆΝΝΗ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ’ ΙΩΑΝΝΗ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("۳ یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("۳-یُوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ヨハネの第三の手紙 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("요한의 셋째 서간 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 GJONIT 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JANOVA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOHANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOHANE 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YŪHÃNĀ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ІОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ИОАННА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ИОХАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 یوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ਯੂਹੰਨਾ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 யோவான் 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. GIOAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. GIĂNG 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JANOS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JANOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JANŮV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JÁNOS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JÁNOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ЈОВАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ଯୋହନଙ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ยอห์น 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.O JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.º JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3.۔یوحنا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3A. JOAO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3A. JOÃO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3E. JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O. JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O. JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O. JOAO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O. JOÃO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O. JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O. JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JHHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JHON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JOHM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JONH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JOON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º. JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III IOAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JHHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JHON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOAO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOHM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JONH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOÃO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III YOOX 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III ИОАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III ЙОАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JÓH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. YOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TATU YOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("THIRD JO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("۳ یوحنّا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ヨハネの第三の書 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 GIOAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 GIĂNG 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JANOS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JANOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JANUV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JANŮV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JÁNOS 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JÁNOV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOVAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOVAṈ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YŌVAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YŌVAṈ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ІВАНА 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ЈОВАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 योहान 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ଯୋହନଙ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ยอห์น 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. IOAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JHHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JHON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOAO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOHM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JONH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOÃO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. YOOX 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ИОАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. ЙОАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3A JOAO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3A JOÃO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3E JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3E. JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O JOAO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O JOÃO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3O JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD. JO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3º JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3۔یوحنا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JÓH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III YOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. GI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. IN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. JO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETI J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TRETÍ J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TŘETI J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("TŘETÍ J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("۳۔یوحنا 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ヨハネの手紙三 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 IOAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JAAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JANA 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JAUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JEAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JHHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JHON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOAO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOHM 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JONH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOON 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOÃO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JPHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JUAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JUUN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOOX 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ИОАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ЙОАН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 யோவா 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JÓH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. YOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3E JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3RD JO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III GI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III IN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III JO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III. J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ' ᾿ΙΩ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ ᾿ΙΩ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ ᾿ΙΩ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ΄ ᾿ΙΩ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ’ ᾿ΙΩ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《伊望第三》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《約翰三書》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《約翰參書》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《约翰三书》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《约翰叁书》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《若望三書》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JAN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JÓH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 YOH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. GI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. IN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. JO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3JOHN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("III J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ' ΙΩ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ ΙΩ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γʹ ΙΩ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ΄ ΙΩ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("Γ’ ΙΩ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《伊望第三 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《約翰三書 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《約翰參書 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《约翰三书 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《约翰叁书 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《若望三書 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("ヨハネ 3 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("伊望第三》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("約翰三書》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("約翰參書》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("约翰三书》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("约翰叁书》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("若望三書》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 GI 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 GJ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 GV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 IN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 IV 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JH 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JN 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 JO 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ІВ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ЈН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ИН 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 يو 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 யோ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 ยน 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3. J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《約三》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《约三》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("三ヨハネ 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("伊望第三 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("約翰三書 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("約翰參書 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("约翰三书 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("约翰叁书 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("若望三書 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("요한3서 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("요한삼서 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3 J 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("3요한 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《約三 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("《约三 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("約三》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("约三》 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("約三 1:1").osis()).toEqual("3John.1.1")
		expect(p.parse("约三 1:1").osis()).toEqual("3John.1.1")
		`
		true
describe "Localized book John (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: John (full)", ->
		`
		expect(p.parse("The Gospel according to Saint Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Mabuting Balita ayon kay San Juan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Saint Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yohanane lihilele subʰavartaman 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yohanane lihilele subʰavartamān 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yohanane lihilele ŝubʰavartaman 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yohanane lihilele ŝubʰavartamān 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yohanāne lihilele subʰavartaman 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yohanāne lihilele subʰavartamān 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yohanāne lihilele ŝubʰavartaman 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yohanāne lihilele ŝubʰavartamān 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yohānane lihilele subʰavartaman 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yohānane lihilele subʰavartamān 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yohānane lihilele ŝubʰavartaman 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yohānane lihilele ŝubʰavartamān 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yohānāne lihilele subʰavartaman 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yohānāne lihilele subʰavartamān 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yohānāne lihilele ŝubʰavartaman 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yohānāne lihilele ŝubʰavartamān 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Evankeliumi Johanneksen mukaan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St. Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Mabuting Balita ayon kay Juan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to St Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ebanghelyo ayon kay San Juan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Saint Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("योहानाने लिहिलेले शुभवर्तमान 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Evangelium secundum Ioannem 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Evangelie volgens Johannes 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St. Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel according to Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yuhannale lekʰeko susmacar 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yuhannale lekʰeko susmacār 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yuhannale lekʰeko susmācar 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yuhannale lekʰeko susmācār 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yuhannāle lekʰeko susmacar 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yuhannāle lekʰeko susmacār 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yuhannāle lekʰeko susmācar 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yuhannāle lekʰeko susmācār 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yūhannale lekʰeko susmacar 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yūhannale lekʰeko susmacār 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yūhannale lekʰeko susmācar 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yūhannale lekʰeko susmācār 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yūhannāle lekʰeko susmacar 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yūhannāle lekʰeko susmacār 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yūhannāle lekʰeko susmācar 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yūhannāle lekʰeko susmācār 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Evangeliet etter Johannes 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ewangelia według sw. Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ewangelia według św. Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to St Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("यूहन्नाले लेखेको सुसमाचार 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ebanghelyo ayon kay Juan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ewangelia według sw Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ewangelia według św Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Евангелието според Јован 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("От Иоана свето Евангелие 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Johanneksen evankeliumi 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Vangelo di San Giovanni 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Євангелія від св. Івана 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Євангеліє від св. Иоана 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Євангеліє від св. Йоана 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("யோவான் எழுதிய சுவிசேஷம் 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("யோவான் எழுதிய நற்செய்தி 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ebanghelyo ni San Juan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel according to Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Saint Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Євангелія від св Івана 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Євангеліє від св Иоана 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Євангеліє від св Йоана 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Евангелие според Јован 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Evangelium podle Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Evanjelium Podla Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Evanjelium Podla Jána 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Evanjelium Podľa Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Evanjelium Podľa Jána 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ewangelia wg sw. Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ewangelia wg św. Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jevanhelije vid Ivana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("El Evangelio de Jaan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("El Evangelio de Jaun 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("El Evangelio de Juan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("El Evangelio de Juun 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ewangelia wg sw Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ewangelia wg św Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St. Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ଯୋହନ ଲିଖିତ ସୁସମାଗ୍ଭର 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jevanđelje po Ivanu 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Johannesarguðspjall 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Johannis evangelium 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jóhannesarguðspjall 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of St Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Vangelo di Giovanni 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Євангелія від Івана 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Євангеліє від Івана 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Јеванђеље по Јовану 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Евангелие от Иоанна 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("அருளப்பர் நற்செய்தி 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("พระวรสารนักบุญจอห์น 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Evanðelje po Ivanu 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Evanđelje po Ivanu 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Saint Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Johannesevangeliet 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Еванђеље по Јовану 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("הבשורה על פי יוחנן 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("הבשורה על-פי יוחנן 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("यूहन्नाको सुसमाचार 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Janovo evangelium 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Sulat ni San Juan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ungjilli i Gjonit 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Евангелие от Иоан 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Евангелие от Йоан 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St. Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Injili ya Yohana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Injili ya Yohane 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("The Gospel of Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yūḥannā kī injīl 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("یُوحنّا کی انجیل 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("யோவான் நற்செய்தி 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of St Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ਯੂਹੰਨਾ ਦੀ ਇੰਜੀਲ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ewangelia Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yovan Narceyti 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yovan Naṛceyti 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yovaṉ Narceyti 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yovaṉ Naṛceyti 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yovān Narceyti 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yovān Naṛceyti 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yovāṉ Narceyti 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yovāṉ Naṛceyti 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yōvan Narceyti 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yōvan Naṛceyti 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yōvaṉ Narceyti 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yōvaṉ Naṛceyti 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yōvān Narceyti 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yōvān Naṛceyti 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yōvāṉ Narceyti 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yōvāṉ Naṛceyti 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yūhãnā dī ĩjīl 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("یوحنا کی انجیل 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Injil Yohanes 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gospel of Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Κατά Ιωάννην 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Κατά Ιωαννην 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Κατα Ιωάννην 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Κατα Ιωαννην 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Johanneksen 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("إنجيل يوحنا 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yuhannale 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yuhannāle 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yūhannale 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yūhannāle 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Від Івана 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("От Иоанна 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("यूहन्नाले 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ヨハネによる福音書 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ew. Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Giovanni 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Johannes 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Saint Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("San Juan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yooxanaa 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yohanane 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yohanāne 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yohānane 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yohānāne 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("От Иоана 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("यूहान्ना 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("योहानाने 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ew Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ioannes 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yohanes 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yokanan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yuhanna 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ιωάννης 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ιωαννης 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("یُوحنّا 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("यहून्ना 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("युहत्रा 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("युहन्ना 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("यूहन्ना 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ਯੂਹਾਂਨਾ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ヨハネ傳福音書 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ew Jan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St. Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yohana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yohane 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("yūhãnā 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ਯੂਹੰਨਾ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("யோவான் 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《約翰福音》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《约翰福音》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《若望福音》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ヨハネ福音書 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("요한 복음서 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gioan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Giăng 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gjoni 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Janos 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jophn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("János 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("St Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yovan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yovaṉ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yovān 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yovāṉ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yōvan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yōvaṉ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yōvān 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yōvāṉ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Івана 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Јован 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Иоана 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Иохан 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Йоана 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("يوحنا 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("یوحنا 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("यूहना 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("योहान 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ยอห์น 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《約翰福音 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《约翰福音 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《若望福音 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("約翰福音》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("约翰福音》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("若望福音》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("요한 복음 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("요한복음서 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ioan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ivan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jaan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jana 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jaun 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jean 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jhhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jhon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Joao 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Johm 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("John 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jonh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Joon 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("João 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jphn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Juan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Juun 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jána 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yoox 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ιωάν 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ιωαν 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Иоан 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Йоан 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ଯୋହନ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("யோவா 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《伊望》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ヨハネ伝 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("約翰福音 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("约翰福音 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("若望福音 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("요한복음 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gjo 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jhn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Joh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ján 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jóh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Yoh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《伊望 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《約》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《约》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("伊望》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gg 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gi 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Gv 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jh 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Jn 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ιω 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ів 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ін 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Јн 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ин 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("يو 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ยน 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ยฮ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("Ἰω 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《約 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《约 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("伊望 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("約》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("约》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("요한 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("约 1:1").osis()).toEqual("John.1.1")
		p.include_apocrypha(false)
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("MABUTING BALITA AYON KAY SAN JUAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHANANE LIHILELE SUBʰAVARTAMAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHANANE LIHILELE SUBʰAVARTAMĀN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHANANE LIHILELE ŜUBʰAVARTAMAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHANANE LIHILELE ŜUBʰAVARTAMĀN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHANĀNE LIHILELE SUBʰAVARTAMAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHANĀNE LIHILELE SUBʰAVARTAMĀN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHANĀNE LIHILELE ŜUBʰAVARTAMAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHANĀNE LIHILELE ŜUBʰAVARTAMĀN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHĀNANE LIHILELE SUBʰAVARTAMAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHĀNANE LIHILELE SUBʰAVARTAMĀN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHĀNANE LIHILELE ŜUBʰAVARTAMAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHĀNANE LIHILELE ŜUBʰAVARTAMĀN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHĀNĀNE LIHILELE SUBʰAVARTAMAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHĀNĀNE LIHILELE SUBʰAVARTAMĀN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHĀNĀNE LIHILELE ŜUBʰAVARTAMAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHĀNĀNE LIHILELE ŜUBʰAVARTAMĀN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EVANKELIUMI JOHANNEKSEN MUKAAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("MABUTING BALITA AYON KAY JUAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EBANGHELYO AYON KAY SAN JUAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("योहानाने लिहिलेले शुभवर्तमान 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EVANGELIUM SECUNDUM IOANNEM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EVANGELIE VOLGENS JOHANNES 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YUHANNALE LEKʰEKO SUSMACAR 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YUHANNALE LEKʰEKO SUSMACĀR 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YUHANNALE LEKʰEKO SUSMĀCAR 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YUHANNALE LEKʰEKO SUSMĀCĀR 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YUHANNĀLE LEKʰEKO SUSMACAR 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YUHANNĀLE LEKʰEKO SUSMACĀR 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YUHANNĀLE LEKʰEKO SUSMĀCAR 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YUHANNĀLE LEKʰEKO SUSMĀCĀR 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŪHANNALE LEKʰEKO SUSMACAR 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŪHANNALE LEKʰEKO SUSMACĀR 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŪHANNALE LEKʰEKO SUSMĀCAR 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŪHANNALE LEKʰEKO SUSMĀCĀR 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŪHANNĀLE LEKʰEKO SUSMACAR 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŪHANNĀLE LEKʰEKO SUSMACĀR 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŪHANNĀLE LEKʰEKO SUSMĀCAR 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŪHANNĀLE LEKʰEKO SUSMĀCĀR 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EVANGELIET ETTER JOHANNES 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EWANGELIA WEDŁUG SW. JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EWANGELIA WEDŁUG ŚW. JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("यूहन्नाले लेखेको सुसमाचार 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EBANGHELYO AYON KAY JUAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EWANGELIA WEDŁUG SW JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EWANGELIA WEDŁUG ŚW JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ЕВАНГЕЛИЕТО СПОРЕД ЈОВАН 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ОТ ИОАНА СВЕТО ЕВАНГЕЛИЕ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOHANNEKSEN EVANKELIUMI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("VANGELO DI SAN GIOVANNI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ЄВАНГЕЛІЯ ВІД СВ. ІВАНА 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ЄВАНГЕЛІЄ ВІД СВ. ИОАНА 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ЄВАНГЕЛІЄ ВІД СВ. ЙОАНА 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("யோவான் எழுதிய சுவிசேஷம் 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("யோவான் எழுதிய நற்செய்தி 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EBANGHELYO NI SAN JUAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL ACCORDING TO JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF SAINT JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ЄВАНГЕЛІЯ ВІД СВ ІВАНА 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ЄВАНГЕЛІЄ ВІД СВ ИОАНА 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ЄВАНГЕЛІЄ ВІД СВ ЙОАНА 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ЕВАНГЕЛИЕ СПОРЕД ЈОВАН 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EVANGELIUM PODLE JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EVANJELIUM PODLA JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EVANJELIUM PODLA JÁNA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EVANJELIUM PODĽA JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EVANJELIUM PODĽA JÁNA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EWANGELIA WG SW. JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EWANGELIA WG ŚW. JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JEVANHELIJE VID IVANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EL EVANGELIO DE JAAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EL EVANGELIO DE JAUN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EL EVANGELIO DE JUAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EL EVANGELIO DE JUUN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EWANGELIA WG SW JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EWANGELIA WG ŚW JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST. JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ଯୋହନ ଲିଖିତ ସୁସମାଗ୍ଭର 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JEVANĐELJE PO IVANU 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOHANNESARGUÐSPJALL 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOHANNIS EVANGELIUM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JÓHANNESARGUÐSPJALL 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF ST JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("VANGELO DI GIOVANNI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ЄВАНГЕЛІЯ ВІД ІВАНА 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ЄВАНГЕЛІЄ ВІД ІВАНА 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ЈЕВАНЂЕЉЕ ПО ЈОВАНУ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ЕВАНГЕЛИЕ ОТ ИОАННА 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("அருளப்பர் நற்செய்தி 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("พระวรสารนักบุญจอห์น 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EVANÐELJE PO IVANU 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EVANĐELJE PO IVANU 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF SAINT JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOHANNESEVANGELIET 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ЕВАНЂЕЉЕ ПО ЈОВАНУ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("הבשורה על פי יוחנן 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("הבשורה על-פי יוחנן 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("यूहन्नाको सुसमाचार 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JANOVO EVANGELIUM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SULAT NI SAN JUAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("UNGJILLI I GJONIT 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ЕВАНГЕЛИЕ ОТ ИОАН 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ЕВАНГЕЛИЕ ОТ ЙОАН 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST. JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("INJILI YA YOHANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("INJILI YA YOHANE 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("THE GOSPEL OF JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŪḤANNĀ KĪ INJĪL 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("یُوحنّا کی انجیل 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("யோவான் நற்செய்தி 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF ST JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ਯੂਹੰਨਾ ਦੀ ਇੰਜੀਲ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EWANGELIA JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOVAN NARCEYTI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOVAN NAṚCEYTI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOVAṈ NARCEYTI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOVAṈ NAṚCEYTI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOVĀN NARCEYTI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOVĀN NAṚCEYTI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOVĀṈ NARCEYTI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOVĀṈ NAṚCEYTI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŌVAN NARCEYTI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŌVAN NAṚCEYTI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŌVAṈ NARCEYTI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŌVAṈ NAṚCEYTI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŌVĀN NARCEYTI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŌVĀN NAṚCEYTI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŌVĀṈ NARCEYTI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŌVĀṈ NAṚCEYTI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŪHÃNĀ DĪ ĨJĪL 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("یوحنا کی انجیل 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("INJIL YOHANES 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GOSPEL OF JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ΚΑΤΆ ΙΩΆΝΝΗΝ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ΚΑΤΆ ΙΩΑΝΝΗΝ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ΚΑΤΑ ΙΩΆΝΝΗΝ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ΚΑΤΑ ΙΩΑΝΝΗΝ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOHANNEKSEN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("إنجيل يوحنا 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YUHANNALE 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YUHANNĀLE 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŪHANNALE 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŪHANNĀLE 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ВІД ІВАНА 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ОТ ИОАННА 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("यूहन्नाले 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ヨハネによる福音書 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EW. JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GIOVANNI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOHANNES 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAINT JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("SAN JUAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOOXANAA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHANANE 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHANĀNE 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHĀNANE 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHĀNĀNE 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ОТ ИОАНА 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("यूहान्ना 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("योहानाने 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EW JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("IOANNES 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHANES 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOKANAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YUHANNA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ΙΩΆΝΝΗΣ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ΙΩΑΝΝΗΣ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("یُوحنّا 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("यहून्ना 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("युहत्रा 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("युहन्ना 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("यूहन्ना 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ਯੂਹਾਂਨਾ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ヨハネ傳福音書 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("EW JAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST. JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOHANE 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŪHÃNĀ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ਯੂਹੰਨਾ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("யோவான் 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《約翰福音》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《约翰福音》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《若望福音》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ヨハネ福音書 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("요한 복음서 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GIOAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GIĂNG 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GJONI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JANOS 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JÁNOS 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ST JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOVAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOVAṈ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOVĀN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOVĀṈ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŌVAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŌVAṈ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŌVĀN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YŌVĀṈ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ІВАНА 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ЈОВАН 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ИОАНА 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ИОХАН 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ЙОАНА 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("يوحنا 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("یوحنا 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("यूहना 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("योहान 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ยอห์น 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《約翰福音 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《约翰福音 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《若望福音 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("約翰福音》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("约翰福音》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("若望福音》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("요한 복음 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("요한복음서 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("IOAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("IVAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JAAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JANA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JAUN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JEAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JHHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JHON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOAO 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOHM 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JONH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOON 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOÃO 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JPHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JUAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JUUN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JÁNA 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOOX 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ΙΩΆΝ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ΙΩΑΝ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ИОАН 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ЙОАН 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ଯୋହନ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("யோவா 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《伊望》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ヨハネ伝 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("約翰福音 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("约翰福音 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("若望福音 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("요한복음 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GJO 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JHN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JÁN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JÓH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("YOH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《伊望 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《約》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《约》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("伊望》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GG 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GI 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("GV 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JH 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("JN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ΙΩ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ІВ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ІН 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ЈН 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ИН 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("يو 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ยน 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ยฮ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("ἸΩ 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《約 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("《约 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("伊望 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("約》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("约》 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("요한 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("约 1:1").osis()).toEqual("John.1.1")
		`
		true
describe "Localized book Josh (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Josh (full)", ->
		`
		expect(p.parse("Книга на Исус Навиев 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Книга Иисуса Навина 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Книга на Исус Невин 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("யோசுவாவின் புத்தகம் 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Книга Ісуса Навина 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ଯିହୋଶୂୟଙ୍କର ପୁସ୍ତକ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Книга Иисус Навин 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("yahosuko pustak 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("yahosūko pustak 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("yahošuko pustak 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("yahošūko pustak 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ιησους του Ναυή 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ιησους του Ναυη 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ιησούς του Ναυή 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ιησούς του Ναυη 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ksiega Jozuego 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ksiegi Jozuego 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Księga Jozuego 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Księgi Jozuego 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("यहोशूको पुस्तक 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Joosuan kirja 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Иисуса Навина 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ісуса Навина 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Книга Єгошуі 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Книга Єгошуї 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ks. Jozuego 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Liber Iosue 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Liv Jozye a 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Иисус Навин 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Исус Навиев 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ଯିହୋଶୂୟଙ୍କର 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Iosua Navi 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Isus Navyn 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josvabogen 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josvas Bog 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josvas bok 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ks Jozuego 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ісус Навин 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Исус Навин 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josuabok 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josuabók 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josvabog 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josúabok 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josúabók 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jósuabok 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jósuabók 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jósúabok 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jósúabók 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Yahoshoo 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Yashuuca 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("yahosawa 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("yahosawā 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("yahosuko 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("yahosūko 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("yahoŝawa 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("yahoŝawā 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("yahošuko 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("yahošūko 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ιησ Ναυή 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ιησ Ναυη 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("سفر يشوع 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Giô-sua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Giô-suê 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Joosuan 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josuova 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Joushua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jozuego 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jozuova 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jošuova 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Józuova 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("yahošuā 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ιησ Ναυ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ис. Нав 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("यहोशूको 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ਯਹੋਸ਼ੁਆ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Giosue 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Giosuè 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Giosué 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Joshua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josuah 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josvas 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jousua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jozsue 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jozsué 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jozueu 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Józsue 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Józsué 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Yocuva 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Yocuvā 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Yoshua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Yōcuva 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Yōcuvā 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Єгошуі 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Єгошуї 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("І. Нав 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ис Нав 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("यहोशवा 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("யோசுவா 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("โยชูวา 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("《約書亞記》 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("《约书亚记》 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("《若蘇厄書》 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Iosua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Iosue 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josue 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josué 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josva 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jozua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jozue 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jozye 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jošua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Józua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Yosua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Yusak 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("yašūʿ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("І Нав 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Јешуа 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Јошуа 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Иешуа 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("יהושע 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("یشُوع 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("यहोशु 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("यहोशू 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("《約書亞記 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("《约书亚记 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("《若蘇厄書 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ヨシュア記 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("約書亞記》 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("约书亚记》 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("若蘇厄書》 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("여호수아기 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Giôs 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Gsua 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Joos 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Josh 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jozs 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Józs 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Yash 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("И. Н 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ИНав 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("يشوع 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("یشوع 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("யோசு 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ヨシュア 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("約書亞記 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("约书亚记 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("若蘇厄書 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("여호수아 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Giô 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ios 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jos 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Joz 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jsh 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jós 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Yos 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("И Н 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Иеш 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Нав 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ยชว 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("《书》 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("《書》 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Gs 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Js 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Jš 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ιη 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Єг 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("يش 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("Ἰη 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("《书 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("《書 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("书》 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("書》 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("여호 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("书 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("수 1:1").osis()).toEqual("Josh.1.1")
		p.include_apocrypha(false)
		expect(p.parse("КНИГА НА ИСУС НАВИЕВ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("КНИГА ИИСУСА НАВИНА 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("КНИГА НА ИСУС НЕВИН 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("யோசுவாவின் புத்தகம் 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("КНИГА ІСУСА НАВИНА 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ଯିହୋଶୂୟଙ୍କର ପୁସ୍ତକ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("КНИГА ИИСУС НАВИН 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YAHOSUKO PUSTAK 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YAHOSŪKO PUSTAK 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YAHOŠUKO PUSTAK 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YAHOŠŪKO PUSTAK 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ΙΗΣΟΥΣ ΤΟΥ ΝΑΥΉ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ΙΗΣΟΥΣ ΤΟΥ ΝΑΥΗ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ΙΗΣΟΎΣ ΤΟΥ ΝΑΥΉ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ΙΗΣΟΎΣ ΤΟΥ ΝΑΥΗ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("KSIEGA JOZUEGO 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("KSIEGI JOZUEGO 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("KSIĘGA JOZUEGO 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("KSIĘGI JOZUEGO 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("यहोशूको पुस्तक 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOOSUAN KIRJA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ИИСУСА НАВИНА 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ІСУСА НАВИНА 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("КНИГА ЄГОШУІ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("КНИГА ЄГОШУЇ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("KS. JOZUEGO 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("LIBER IOSUE 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("LIV JOZYE A 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ИИСУС НАВИН 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ИСУС НАВИЕВ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ଯିହୋଶୂୟଙ୍କର 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("IOSUA NAVI 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ISUS NAVYN 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSVABOGEN 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSVAS BOG 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSVAS BOK 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("KS JOZUEGO 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ІСУС НАВИН 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ИСУС НАВИН 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSUABOK 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSUABÓK 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSVABOG 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSÚABOK 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSÚABÓK 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JÓSUABOK 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JÓSUABÓK 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JÓSÚABOK 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JÓSÚABÓK 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YAHOSHOO 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YASHUUCA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YAHOSAWA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YAHOSAWĀ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YAHOSUKO 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YAHOSŪKO 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YAHOŜAWA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YAHOŜAWĀ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YAHOŠUKO 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YAHOŠŪKO 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ΙΗΣ ΝΑΥΉ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ΙΗΣ ΝΑΥΗ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("سفر يشوع 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("GIÔ-SUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("GIÔ-SUÊ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOOSUAN 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSUOVA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOUSHUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOZUEGO 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOZUOVA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOŠUOVA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JÓZUOVA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YAHOŠUĀ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ΙΗΣ ΝΑΥ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ИС. НАВ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("यहोशूको 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ਯਹੋਸ਼ੁਆ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("GIOSUE 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("GIOSUÈ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("GIOSUÉ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSHUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSUAH 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSVAS 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOUSUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOZSUE 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOZSUÉ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOZUEU 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JÓZSUE 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JÓZSUÉ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YOCUVA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YOCUVĀ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YOSHUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YŌCUVA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YŌCUVĀ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ЄГОШУІ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ЄГОШУЇ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("І. НАВ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ИС НАВ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("यहोशवा 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("யோசுவா 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("โยชูวา 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("《約書亞記》 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("《约书亚记》 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("《若蘇厄書》 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("IOSUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("IOSUE 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSUE 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSUÉ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSVA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOZUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOZUE 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOZYE 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOŠUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JÓZUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YOSUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YUSAK 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YAŠŪʿ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("І НАВ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ЈЕШУА 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ЈОШУА 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ИЕШУА 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("יהושע 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("یشُوع 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("यहोशु 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("यहोशू 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("《約書亞記 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("《约书亚记 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("《若蘇厄書 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ヨシュア記 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("約書亞記》 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("约书亚记》 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("若蘇厄書》 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("여호수아기 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("GIÔS 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("GSUA 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOOS 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOSH 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOZS 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JÓZS 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YASH 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("И. Н 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ИНАВ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("يشوع 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("یشوع 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("யோசு 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ヨシュア 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("約書亞記 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("约书亚记 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("若蘇厄書 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("여호수아 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("GIÔ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("IOS 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOS 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JOZ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JSH 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JÓS 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("YOS 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("И Н 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ИЕШ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("НАВ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ยชว 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("《书》 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("《書》 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("GS 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JS 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("JŠ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ΙΗ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ЄГ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("يش 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("ἸΗ 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("《书 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("《書 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("书》 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("書》 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("여호 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("书 1:1").osis()).toEqual("Josh.1.1")
		expect(p.parse("수 1:1").osis()).toEqual("Josh.1.1")
		`
		true
describe "Localized book Judg (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Judg (full)", ->
		`
		expect(p.parse("ବିଗ୍ଭରକର୍ତ୍ତାମାନଙ୍କ ବିବରଣ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("நியாயாதிபதிகளின் புத்தகம் 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("nyayakarttaharuko pustak 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("nyayakarttaharūko pustak 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("nyayakarttāharuko pustak 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("nyayakarttāharūko pustak 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("nyāyakarttaharuko pustak 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("nyāyakarttaharūko pustak 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("nyāyakarttāharuko pustak 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("nyāyakarttāharūko pustak 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Книга на израелеви судии 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("न्यायकर्त्ताहरूको पुस्तक 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Книга Судеи Израилевых 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Книга Судей Израилевых 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("न्यायकर्ताहरूको पुस्तक 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Книга Съдии Израилеви 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("न्यायिय का विर्तान्त 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("நியாயாதிபதிகள் ஆகமம் 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("nyayakarttaharuko 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("nyayakarttaharūko 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("nyayakarttāharuko 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("nyayakarttāharūko 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("nyāyakarttaharuko 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("nyāyakarttaharūko 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("nyāyakarttāharuko 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("nyāyakarttāharūko 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("न्यायकर्त्ताहरूको 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Книга на съдиите 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("நீதித் தலைவர்கள் 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Knjiga o Sucima 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Niyayatipatikal 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Niyayatipatikaḷ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Niyayātipatikal 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Niyayātipatikaḷ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Niyāyatipatikal 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Niyāyatipatikaḷ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Niyāyātipatikal 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Niyāyātipatikaḷ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Tuomarien kirja 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("niāīāṃ dī potʰī 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Съдии Израилеви 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("ਨਿਆਂਈਆਂ ਦੀ ਪੋਥੀ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Ksiega Sedziow 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Ksiega Sedziów 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Ksiega Sędziow 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Ksiega Sędziów 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Ksiegi Sedziow 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Ksiegi Sedziów 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Ksiegi Sędziow 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Ksiegi Sędziów 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Księga Sedziow 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Księga Sedziów 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Księga Sędziow 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Księga Sędziów 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Księgi Sedziow 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Księgi Sedziów 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Księgi Sędziow 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Księgi Sędziów 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Mga Maghuhukom 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("ਨਿਆਈਆਂ ਦੀ ਪੋਥੀ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("நியாயாதிபதிகள் 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Dommernes bok 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Liber Iudicum 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Các Thủ lãnh 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Các quan xét 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Knyha Suddiv 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Книга Суддів 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Domarabokin 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Domarabókin 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Dommerbogen 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Dómarabokin 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Dómarabókin 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Judecatorii 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Ks. Sedziow 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Ks. Sedziów 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Ks. Sędziow 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Ks. Sędziów 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Liv Chef yo 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Liv Chèf yo 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Книга Судеи 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Книга Судей 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("ผู้วินิจฉัย 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Domarboken 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Judecatori 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Judecători 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Ks Sedziow 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Ks Sedziów 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Ks Sędziow 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Ks Sędziów 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Maghuhukom 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Para Hakim 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Xaakinnada 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("سفر القضاة 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("न्यायकर्ता 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("நீதிபதிகள் 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Domarabok 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Domarabók 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Dommernes 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Dómarabok 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Dómarabók 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Gjyqtaret 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Gjyqtarët 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("K. sudcov 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Mga Hukom 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Richteren 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Thẩm phán 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Tuomarien 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("न्यायियों 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Dommerne 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("K sudcov 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Nyayiyon 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Rechters 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Richtere 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Sudcovia 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Thủ lãnh 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Barnwyr 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Giudici 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Iudicum 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Quan án 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Richter 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Sedziow 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Sedziów 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Sędziow 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Sędziów 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Waamuzi 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Dommer 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Judges 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jueces 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Juizes 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Juízes 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Soudcu 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Soudců 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Sudcov 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("niāīāṃ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Κριτές 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Κριταί 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Κριται 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Κριτες 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Суддів 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Судија 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Судије 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("שופטים 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("القضاة 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("शास्ते 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Birak 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Birák 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Bírak 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Bírák 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Hukom 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Juges 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Recht 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Richt 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("qużāh 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("saste 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("sāste 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("ŝaste 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("ŝāste 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Судеи 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Судей 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Судии 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Судьи 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Съдии 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("قُضاۃ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("《士师记》 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("《士師記》 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("《民長紀》 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Barn 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jdgs 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Judg 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Juec 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Juiz 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Juíz 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Quan 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Sedz 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Suci 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Sędz 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Tuom 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Waam 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Xaak 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Κριτ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("قضاة 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("قضاہ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("قضاۃ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("நியா 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("《士师记 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("《士師記 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("《民長紀 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("士师记》 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("士師記》 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("民長紀》 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Amu 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Bir 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Bír 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Dom 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Dóm 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Gdc 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Gjy 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Huk 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Iud 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jdg 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jgs 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jij 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jue 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jug 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Sdc 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Sdz 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Sud 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Thủ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Суд 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Съд 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("நீத 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("วนฉ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("《士》 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("士师记 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("士師記 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("民長紀 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("사사기 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("판관기 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jc 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jg 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Jz 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Sd 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("Κρ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("قض 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("《士 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("士》 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("士師 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("판관 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("士 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("삿 1:1").osis()).toEqual("Judg.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ବିଗ୍ଭରକର୍ତ୍ତାମାନଙ୍କ ବିବରଣ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("நியாயாதிபதிகளின் புத்தகம் 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NYAYAKARTTAHARUKO PUSTAK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NYAYAKARTTAHARŪKO PUSTAK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NYAYAKARTTĀHARUKO PUSTAK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NYAYAKARTTĀHARŪKO PUSTAK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NYĀYAKARTTAHARUKO PUSTAK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NYĀYAKARTTAHARŪKO PUSTAK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NYĀYAKARTTĀHARUKO PUSTAK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NYĀYAKARTTĀHARŪKO PUSTAK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("КНИГА НА ИЗРАЕЛЕВИ СУДИИ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("न्यायकर्त्ताहरूको पुस्तक 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("КНИГА СУДЕИ ИЗРАИЛЕВЫХ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("КНИГА СУДЕЙ ИЗРАИЛЕВЫХ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("न्यायकर्ताहरूको पुस्तक 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("КНИГА СЪДИИ ИЗРАИЛЕВИ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("न्यायिय का विर्तान्त 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("நியாயாதிபதிகள் ஆகமம் 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NYAYAKARTTAHARUKO 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NYAYAKARTTAHARŪKO 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NYAYAKARTTĀHARUKO 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NYAYAKARTTĀHARŪKO 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NYĀYAKARTTAHARUKO 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NYĀYAKARTTAHARŪKO 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NYĀYAKARTTĀHARUKO 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NYĀYAKARTTĀHARŪKO 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("न्यायकर्त्ताहरूको 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("КНИГА НА СЪДИИТЕ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("நீதித் தலைவர்கள் 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KNJIGA O SUCIMA 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NIYAYATIPATIKAL 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NIYAYATIPATIKAḶ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NIYAYĀTIPATIKAL 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NIYAYĀTIPATIKAḶ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NIYĀYATIPATIKAL 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NIYĀYATIPATIKAḶ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NIYĀYĀTIPATIKAL 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NIYĀYĀTIPATIKAḶ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("TUOMARIEN KIRJA 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NIĀĪĀṂ DĪ POTʰĪ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("СЪДИИ ИЗРАИЛЕВИ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("ਨਿਆਂਈਆਂ ਦੀ ਪੋਥੀ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KSIEGA SEDZIOW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KSIEGA SEDZIÓW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KSIEGA SĘDZIOW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KSIEGA SĘDZIÓW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KSIEGI SEDZIOW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KSIEGI SEDZIÓW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KSIEGI SĘDZIOW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KSIEGI SĘDZIÓW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KSIĘGA SEDZIOW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KSIĘGA SEDZIÓW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KSIĘGA SĘDZIOW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KSIĘGA SĘDZIÓW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KSIĘGI SEDZIOW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KSIĘGI SEDZIÓW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KSIĘGI SĘDZIOW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KSIĘGI SĘDZIÓW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("MGA MAGHUHUKOM 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("ਨਿਆਈਆਂ ਦੀ ਪੋਥੀ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("நியாயாதிபதிகள் 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DOMMERNES BOK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("LIBER IUDICUM 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("CÁC THỦ LÃNH 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("CÁC QUAN XÉT 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KNYHA SUDDIV 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("КНИГА СУДДІВ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DOMARABOKIN 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DOMARABÓKIN 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DOMMERBOGEN 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DÓMARABOKIN 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DÓMARABÓKIN 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUDECATORII 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KS. SEDZIOW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KS. SEDZIÓW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KS. SĘDZIOW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KS. SĘDZIÓW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("LIV CHEF YO 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("LIV CHÈF YO 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("КНИГА СУДЕИ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("КНИГА СУДЕЙ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("ผู้วินิจฉัย 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DOMARBOKEN 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUDECATORI 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUDECĂTORI 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KS SEDZIOW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KS SEDZIÓW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KS SĘDZIOW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("KS SĘDZIÓW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("MAGHUHUKOM 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("PARA HAKIM 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("XAAKINNADA 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("سفر القضاة 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("न्यायकर्ता 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("நீதிபதிகள் 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DOMARABOK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DOMARABÓK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DOMMERNES 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DÓMARABOK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DÓMARABÓK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("GJYQTARET 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("GJYQTARËT 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("K. SUDCOV 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("MGA HUKOM 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("RICHTEREN 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("THẨM PHÁN 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("TUOMARIEN 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("न्यायियों 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DOMMERNE 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("K SUDCOV 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NYAYIYON 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("RECHTERS 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("RICHTERE 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SUDCOVIA 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("THỦ LÃNH 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("BARNWYR 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("GIUDICI 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("IUDICUM 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("QUAN ÁN 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("RICHTER 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SEDZIOW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SEDZIÓW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SĘDZIOW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SĘDZIÓW 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("WAAMUZI 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DOMMER 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUDGES 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUECES 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUIZES 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUÍZES 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SOUDCU 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SOUDCŮ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SUDCOV 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("NIĀĪĀṂ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("ΚΡΙΤΈΣ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("ΚΡΙΤΑΊ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("ΚΡΙΤΑΙ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("ΚΡΙΤΕΣ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("СУДДІВ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("СУДИЈА 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("СУДИЈЕ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("שופטים 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("القضاة 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("शास्ते 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("BIRAK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("BIRÁK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("BÍRAK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("BÍRÁK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("HUKOM 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUGES 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("RECHT 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("RICHT 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("QUŻĀH 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SASTE 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SĀSTE 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("ŜASTE 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("ŜĀSTE 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("СУДЕИ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("СУДЕЙ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("СУДИИ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("СУДЬИ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("СЪДИИ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("قُضاۃ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("《士师记》 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("《士師記》 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("《民長紀》 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("BARN 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JDGS 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUDG 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUEC 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUIZ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUÍZ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("QUAN 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SEDZ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SUCI 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SĘDZ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("TUOM 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("WAAM 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("XAAK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("ΚΡΙΤ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("قضاة 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("قضاہ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("قضاۃ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("நியா 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("《士师记 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("《士師記 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("《民長紀 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("士师记》 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("士師記》 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("民長紀》 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("AMU 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("BIR 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("BÍR 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DOM 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("DÓM 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("GDC 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("GJY 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("HUK 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("IUD 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JDG 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JGS 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JIJ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUE 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JUG 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SDC 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SDZ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SUD 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("THỦ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("СУД 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("СЪД 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("நீத 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("วนฉ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("《士》 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("士师记 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("士師記 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("民長紀 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("사사기 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("판관기 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JC 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JG 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("JZ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("SD 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("ΚΡ 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("قض 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("《士 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("士》 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("士師 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("판관 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("士 1:1").osis()).toEqual("Judg.1.1")
		expect(p.parse("삿 1:1").osis()).toEqual("Judg.1.1")
		`
		true
describe "Localized book 1Esd (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Esd (full)", ->
		`
		expect(p.parse("Kitabu cha Kwanza cha Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsza Ksiega Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsza Ksiegi Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsza Księga Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsza Księgi Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsze Ksiega Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsze Ksiegi Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsze Księga Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsze Księgi Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwszy Ksiega Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwszy Ksiegi Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwszy Księga Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwszy Księgi Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsza Ks. Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsze Ks. Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwszy Ks. Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsza Ks Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsze Ks Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwszy Ks Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prva kniha Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prva kniha Ezdrašova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prva kniha Ezdrásova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prva kniha Ezdrášova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvá kniha Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvá kniha Ezdrašova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvá kniha Ezdrásova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvá kniha Ezdrášova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Първа книга на Ездра 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvy list Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvy list Ezdrašova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvy list Ezdrásova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvy list Ezdrášova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvý list Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvý list Ezdrašova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvý list Ezdrásova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvý list Ezdrášova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ksiega Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ksiegi Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Księga Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Księgi Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ksiega Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ksiegi Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Księga Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Księgi Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ksiega Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ksiegi Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Księga Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Księgi Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ksiega Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ksiegi Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Księga Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Księgi Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsza Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwsze Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Pierwszy Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prva kniha Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prva kniha Ezdraš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prva kniha Ezdrás 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prva kniha Ezdráš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvá kniha Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvá kniha Ezdraš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvá kniha Ezdrás 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvá kniha Ezdráš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Ensimmainen Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Ensimmäinen Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Første Esdrasbog 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Premieres Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Premières Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvy list Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvy list Ezdraš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvy list Ezdrás 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvy list Ezdráš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvý list Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvý list Ezdraš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvý list Ezdrás 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvý list Ezdráš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Tredje Esdrasbog 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ks. Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ks. Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Premiere Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Premiers Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Première Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Primeira Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Primeiro Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ks. Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 k. Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 k. Ezdrašova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 k. Ezdrásova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 k. Ezdrášova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ks Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ks. Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ks Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Liber Esdrae I 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Liber I Esdrae 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Premier Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Primero Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prva Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prva Ezdrašova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prva Ezdrásova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prva Ezdrášova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvy Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvy Ezdrašova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvy Ezdrásova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvy Ezdrášova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvá Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvá Ezdrašova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvá Ezdrásova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvá Ezdrášova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvý Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvý Ezdrašova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvý Ezdrásova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvý Ezdrášova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ks Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 k Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 k Ezdrašova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 k Ezdrásova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 k Ezdrášova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Eerste Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Første Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ks Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Primer Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Прва Јездрина 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Esdrasbog 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ezdrašova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ezdrásova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ezdrášova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1ere. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1ère. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3. Esdrasbog 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Derde Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("First Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ezdrašova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ezdrásova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ezdrášova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prima Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prima Ésdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Primo Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Primo Ésdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvni Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvni Ezdraš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvni Ezdrás 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvni Ezdráš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("První Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("První Ezdraš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("První Ezdrás 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("První Ezdráš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Unang Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Прва Ездрина 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("إسدراس الأول 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Esdrasbog 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ezdrašova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ezdrásova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ezdrášova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 k. Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 k. Ezdraš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 k. Ezdrás 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 k. Ezdráš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 எஸ்திராஸ் 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1-ше. Ездра 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1-ше. Ездри 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Јездрина 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1.o. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1.º. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1er. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1ere Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1re. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1st. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1ère Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3 Esdrasbog 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Eerste Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Elso Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Elso Ezdrás 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Első Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Első Ezdrás 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Esdra greco 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Forsta Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Första Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Første Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ezdrasova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ezdrašova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ezdrásova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ezdrášova 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Јездрина 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("III. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Kwanza Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prima Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Primo Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prva Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prva Ezdraš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prva Ezdrás 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prva Ezdráš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvy Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvy Ezdraš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvy Ezdrás 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvy Ezdráš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvá Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvá Ezdraš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvá Ezdrás 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvá Ezdráš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvý Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvý Ezdraš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvý Ezdrás 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Prvý Ezdráš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Terza Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Terzo Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Tredje Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Перша Ездра 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Перша Ездри 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Перше Ездра 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Перше Ездри 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Първа Ездра 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 k Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 k Ezdraš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 k Ezdrás 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 k Ezdráš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Јездрина 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1-а. Ездра 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1-а. Ездри 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1-е. Ездра 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1-е. Ездри 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1-ше Ездра 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1-ше Ездри 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ездрина 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1.o Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1.º Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1a. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1e. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1er Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1o. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1re Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1st Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1°. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1°. Ésdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1º. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("2-е. Ездры 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("2-я. Ездры 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3e. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Derde Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Erste Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("First Esdr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ezdrasza 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Јездрина 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ездрина 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("III Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("III. Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("III. Ezdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Una Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Unang Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ездрина 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1-а Ездра 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1-а Ездри 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1-е Ездра 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1-е Ездри 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Esdrae 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ezdraš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ezdrás 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ezdráš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ésdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1a Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1e Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1o Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1st. Esdr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1° Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1° Ésdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1°. Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1º Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("2-е Ездры 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("2-я Ездры 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("2е. Ездры 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("2я. Ездры 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3e Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3°. Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("First Esd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ездрина 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Esdrae 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ezdraš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ezdrás 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ezdráš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ésdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("III Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("III Ezdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("III. Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Έσδρας Α' 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Έσδρας Αʹ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Έσδρας Αʹ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Έσδρας Α΄ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Έσδρας Α’ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Α' Έσδρας 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Α' Εσδρας 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Αʹ Έσδρας 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Αʹ Εσδρας 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Αʹ Έσδρας 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Αʹ Εσδρας 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Α΄ Έσδρας 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Α΄ Εσδρας 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Α’ Έσδρας 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Α’ Εσδρας 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Εσδρας Α' 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Εσδρας Αʹ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Εσδρας Αʹ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Εσδρας Α΄ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Εσδρας Α’ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("חזון עזרא 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Esdrae 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ezdraš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ezdrás 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ezdráš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ésdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ezdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ездра 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ездри 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1e. Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1st Esdr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1st. Esd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1° Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("2. Ездры 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("2е Ездры 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("2я Ездры 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3 Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3. Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3. Ezdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3e. Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3e. Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3° Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Elso Ezd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Első Ezd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Ezdras I 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Ezdrás I 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Esdrae 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Esdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ezdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ezdraš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ezdrás 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ezdráš 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ésdras 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ezdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ездра 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ездри 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("III Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Una Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ezdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ездра 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ездри 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Esdr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1e Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1st Esd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("2 Ездры 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3 Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3 Ezdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3. Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3. Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3e Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3e Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Esdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ezdra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ездра 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ездри 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Esdr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Α' Έσδρ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Α' Εσδρ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Αʹ Έσδρ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Αʹ Εσδρ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Αʹ Έσδρ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Αʹ Εσδρ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Α΄ Έσδρ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Α΄ Εσδρ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Α’ Έσδρ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Α’ Εσδρ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("エストラ第一巻 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("エスドラ第一巻 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("エズトラ第一巻 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("エズドラ第一巻 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("에스드라 1서 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Esdr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Esd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Esr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Ezd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3 Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("3 Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Esdr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Esra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ezra 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Esd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I. Ezd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Α' Έσδ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Α' Εσδ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Αʹ Έσδ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Αʹ Εσδ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Αʹ Έσδ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Αʹ Εσδ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Α΄ Έσδ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Α΄ Εσδ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Α’ Έσδ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("Α’ Εσδ 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("《1Esd》 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("エスラ第一書 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("エズラ第一書 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Esd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Esr 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Ezd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Јез 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1. Es 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1Esd》 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("2 Езд 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Esd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("I Ezd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("《1Esd 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1 Es 1:1").osis()).toEqual("1Esd.1.1")
		expect(p.parse("1Esd 1:1").osis()).toEqual("1Esd.1.1")
		`
		true
describe "Localized book 2Esd (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Esd (full)", ->
		`
		expect(p.parse("Kitabu cha Pili cha Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druga Ksiega Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druga Ksiegi Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druga Księga Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druga Księgi Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Drugi Ksiega Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Drugi Ksiegi Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Drugi Księga Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Drugi Księgi Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druha kniha Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druha kniha Ezdrašova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druha kniha Ezdrásova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druha kniha Ezdrášova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhá kniha Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhá kniha Ezdrašova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhá kniha Ezdrásova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhá kniha Ezdrášova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhy list Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhy list Ezdrašova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhy list Ezdrásova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhy list Ezdrášova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhý list Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhý list Ezdrašova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhý list Ezdrásova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhý list Ezdrášova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Втора книга на Ездра 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ksiega Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ksiegi Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Księga Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Księgi Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ksiega Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ksiegi Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Księga Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Księgi Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druga Ks. Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Drugi Ks. Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druha kniha Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druha kniha Ezdraš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druha kniha Ezdrás 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druha kniha Ezdráš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhá kniha Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhá kniha Ezdraš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhá kniha Ezdrás 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhá kniha Ezdráš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ksiega Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ksiegi Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Księga Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Księgi Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ksiega Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ksiegi Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Księga Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Księgi Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2-ге. книга Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druga Ks Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Drugi Ks Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhy list Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhy list Ezdraš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhy list Ezdrás 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhy list Ezdráš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhý list Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhý list Ezdraš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhý list Ezdrás 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhý list Ezdráš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Друга книга Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Друге книга Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2-а. книга Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2-ге книга Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2-е. книга Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Deuxiemes Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Deuxièmes Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Fjerde Esdrasbog 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ks. Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Ikalawang Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2-а книга Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2-е книга Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ks. Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Anden Esdrasbog 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Deuxieme Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Deuxième Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druha Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druha Ezdrašova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druha Ezdrásova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druha Ezdrášova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhy Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhy Ezdrašova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhy Ezdrásova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhy Ezdrášova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhá Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhá Ezdrašova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhá Ezdrásova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhá Ezdrášova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhý Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhý Ezdrašova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhý Ezdrásova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhý Ezdrášova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ks. Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ks Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. книга Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Liber Esdrae II 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Liber II Esdrae 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ks. Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 k. Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 k. Ezdrašova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 k. Ezdrásova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 k. Ezdrášova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ks Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. книга Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druga Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Drugi Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ks Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II книга Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Ikalawang Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Masodik Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Masodik Ezdrás 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Második Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Második Ezdrás 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Seconda Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Seconda Ésdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Secondo Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Secondo Ésdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Segunda Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Segundo Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Друга Јездрина 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ks Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 k Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 k Ezdrašova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 k Ezdrásova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 k Ezdrášova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 книга Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ezdrašova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ezdrásova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ezdrášova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Second Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Seconda Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Secondo Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Tweede Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Vierde Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Друга Ездрина 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("إسدراس الثاني 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Esdrasbog 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ezdrašova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ezdrásova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ezdrášova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2eme. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2ème. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4. Esdrasbog 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Andre Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druha Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druha Ezdraš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druha Ezdrás 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druha Ezdráš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhy Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhy Ezdraš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhy Ezdrás 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhy Ezdráš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhá Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhá Ezdraš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhá Ezdrás 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhá Ezdráš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhý Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhý Ezdraš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhý Ezdrás 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Druhý Ezdráš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ezdrašova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ezdrásova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ezdrášova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Јездрина 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Quarta Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Quarto Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("עזרא החיצוני 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Esdrasbog 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ezdrasova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ezdrašova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ezdrásova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ezdrášova 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 k. Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 k. Ezdraš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 k. Ezdrás 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 k. Ezdráš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 எஸ்திராஸ் 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2-ге. Ездра 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2-ге. Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Јездрина 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2.o. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2.º. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2de. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2eme Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2nd. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2ème Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4 Esdrasbog 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Fjarde Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Fjerde Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Fjärde Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Јездрина 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ездрина 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Masodik Ezd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Második Ezd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Second Esdr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Toinen Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Tweede Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Vierde Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Zweite Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Втора Ездра 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Друга Ездра 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Друга Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Друге Ездра 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Друге Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ezdrasza 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 k Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 k Ezdraš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 k Ezdrás 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 k Ezdráš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Јездрина 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2-а. Ездра 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2-а. Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2-ге Ездра 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2-ге Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2-е. Ездра 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2-е. Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ездрина 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2.o Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2.º Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2a. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2d. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2de Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2e. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2nd Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2o. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2°. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2°. Ésdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2º. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("3-е. Ездры 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("3-я. Ездры 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Andra Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Andre Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ездрина 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Esdrae 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ezdraš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ezdrás 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ezdráš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ésdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("IV. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Second Esd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ездрина 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2-а Ездра 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2-а Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2-е Ездра 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2-е Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Esdrae 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ezdraš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ezdrás 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ezdráš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ésdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2a Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2d Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2e Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2nd. Esdr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2o Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2° Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2° Ésdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2°. Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2º Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("3-е Ездры 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("3-я Ездры 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("3е. Ездры 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("3я. Ездры 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4. Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4°. Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Ezdras II 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Ezdrás II 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Esdrae 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ezdraš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ezdrás 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ezdráš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ésdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ezdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ездра 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("IV Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("IV. Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("IV. Ezdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Pili Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Έσδρας Β' 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Έσδρας Βʹ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Έσδρας Βʹ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Έσδρας Β΄ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Έσδρας Β’ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Β' Έσδρας 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Β' Εσδρας 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Βʹ Έσδρας 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Βʹ Εσδρας 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Βʹ Έσδρας 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Βʹ Εσδρας 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Β΄ Έσδρας 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Β΄ Εσδρας 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Β’ Έσδρας 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Β’ Εσδρας 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Εσδρας Β' 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Εσδρας Βʹ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Εσδρας Βʹ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Εσδρας Β΄ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Εσδρας Β’ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Esdrae 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ezdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ezdraš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ezdrás 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ezdráš 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ésdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ezdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ездра 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2e. Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2nd Esdr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2nd. Esd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2° Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("3. Ездры 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("3е Ездры 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("3я Ездры 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4 Esdras 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4. Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4. Ezdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4° Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ezdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ездра 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Esdr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("IV Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("IV Ezdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("IV. Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ezdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ездра 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ездри 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Esdr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2e Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2nd Esd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("3 Ездры 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4 Esdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4 Ezdra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4. Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4. Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Esdr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Esd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II. Ezd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("IV Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Β' Έσδρ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Β' Εσδρ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Βʹ Έσδρ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Βʹ Εσδρ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Βʹ Έσδρ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Βʹ Εσδρ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Β΄ Έσδρ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Β΄ Εσδρ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Β’ Έσδρ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Β’ Εσδρ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("エストラ第二巻 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("エスドラ第二巻 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("エズトラ第二巻 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("エズドラ第二巻 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("에스드라 2서 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Esdr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Esd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Esr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Ezd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4 Esra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("4 Ezra 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Esd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("II Ezd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Β' Έσδ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Β' Εσδ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Βʹ Έσδ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Βʹ Εσδ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Βʹ Έσδ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Βʹ Εσδ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Β΄ Έσδ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Β΄ Εσδ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Β’ Έσδ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("Β’ Εσδ 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("《2Esd》 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("エスラ第二書 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("エズラ第二書 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Esd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Esr 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Ezd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Јез 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2. Es 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2Esd》 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("3 Езд 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("《2Esd 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2 Es 1:1").osis()).toEqual("2Esd.1.1")
		expect(p.parse("2Esd 1:1").osis()).toEqual("2Esd.1.1")
		`
		true
describe "Localized book Isa (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Isa (full)", ->
		`
		expect(p.parse("ଯିଶାଇୟ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କର ପୁସ୍ତକ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ஏசாயா தீர்க்கதரிசியின் புத்தகம் 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Книга на пророк Исаия 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Книга пророка Исаии 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Книга пророка Ісаі 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Книга пророка Ісаї 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("yasəiyako pustak 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("yasəiyāko pustak 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("yašəiyako pustak 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("yašəiyāko pustak 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ksiega Izajasza 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ksiegi Izajasza 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Księga Izajasza 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Księgi Izajasza 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("यशैयाको पुस्तक 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Jesajan kirja 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ks. Izajasza 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Liber Isaiae 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Esaias' bok 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Esaias’ bok 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Esajas' Bog 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Esajas’ Bog 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Jesajaboken 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Jesajas bok 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ks Izajasza 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Liv Ezayi a 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Книга Ісаиі 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Книга Ісаиї 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Книга Ісайі 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Книга Ісайї 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Jesajaboka 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("yashaayaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("سفر إشعياء 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ishacyaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("yasəiyako 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("yasəiyāko 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("yašəiyako 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("yašəiyāko 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("I-sa-gia 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaaaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaaiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaiaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaiiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiaaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiaiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiiaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiiiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaaaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaaiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaiaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaiiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiaaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiaiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiiaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiiiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Izajasza 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("yasaʿyāh 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("إشَعْياء 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ezsaias 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ezsaiás 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("I-sai-a 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaaih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaiah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaiih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiaih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiiah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiiih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaisha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaaih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaiah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaiih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiaih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiiah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiiih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Jesajan 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("yasāyāh 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ézsaias 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ézsaiás 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ΗΣΑΪ́ΑΣ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("यशैयाको 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ਯਾਸਾਯਾਹ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("อิสยาห์ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Esaias 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Esaiás 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Esajas 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaaih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaias 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaiih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaish 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaíah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaías 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiaih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiiih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Izaias 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Izaiaš 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Izaija 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Izaiás 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Izaiáš 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Izajas 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Izajaš 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Izajás 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Izajáš 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Jesaia 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Jesaja 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Yesaya 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Yésaya 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("yasaya 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("yasayā 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("yaŝaya 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("yaŝayā 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ésaias 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ésaiás 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ΗΣΑΊΑΣ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ΗΣΑΙΑΣ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ησαΐας 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ησαιας 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Исаија 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ישעיהו 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("یسعیاہ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("یعسیاہ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("यशायाह 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("येशैया 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ਯਸਾਯਾਹ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ଯାଶାଇୟ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ଯିଶାଇୟ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ଯୀଶାଇୟ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《以賽亚书》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《以賽亞書》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《以赛亚书》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《依撒意亞》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ﺃﺷﻌﻴﺎء 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ecaya 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ecayā 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ecāya 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ecāyā 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Esaie 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Esaïe 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Eseia 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ezayi 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaia 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaie 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaja 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaya 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaía 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isaïe 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiha 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isiih 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Issah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ésaie 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ésaïe 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ê-sai 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Исаии 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Исаия 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Исаја 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ישעיה 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("إشعيا 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("यशाया 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("यशैया 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ୟଶାଇୟ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ୟିଶାୟ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("எசாயா 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ஏசாயா 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《以賽亚书 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《以賽亞書 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《以赛亚书 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《依撒意亞 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("以賽亚书》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("以賽亞書》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("以赛亚书》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("依撒意亞》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Esai 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("I-sa 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isah 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isai 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ісая 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ісаі 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ісаї 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Исаи 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Исая 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ישעה 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("यशया 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("यशाय 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("イサヤ書 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("イザヤ書 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("以賽亚书 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("以賽亞書 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("以赛亚书 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("依撒意亞 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("이사야서 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Esa 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ezs 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Isa 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ish 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Jes 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ésa 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ézs 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("यशा 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ਯਸਾ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("எசா 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ஏசா 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("อสย 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《賽》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《赛》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("イサヤ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("イザヤ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("이사야 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ia 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Is 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Iz 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("És 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ησ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Іс 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ис 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("اش 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ἠσ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《賽 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《赛 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("賽》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("赛》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("이사 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("賽 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("赛 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("사 1:1").osis()).toEqual("Isa.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ଯିଶାଇୟ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କର ପୁସ୍ତକ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ஏசாயா தீர்க்கதரிசியின் புத்தகம் 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("КНИГА НА ПРОРОК ИСАИЯ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("КНИГА ПРОРОКА ИСАИИ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("КНИГА ПРОРОКА ІСАІ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("КНИГА ПРОРОКА ІСАЇ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("YASƏIYAKO PUSTAK 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("YASƏIYĀKO PUSTAK 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("YAŠƏIYAKO PUSTAK 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("YAŠƏIYĀKO PUSTAK 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("KSIEGA IZAJASZA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("KSIEGI IZAJASZA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("KSIĘGA IZAJASZA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("KSIĘGI IZAJASZA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("यशैयाको पुस्तक 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("JESAJAN KIRJA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("KS. IZAJASZA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("LIBER ISAIAE 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ESAIAS' BOK 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ESAIAS’ BOK 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ESAJAS' BOG 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ESAJAS’ BOG 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("JESAJABOKEN 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("JESAJAS BOK 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("KS IZAJASZA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("LIV EZAYI A 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("КНИГА ІСАИІ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("КНИГА ІСАИЇ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("КНИГА ІСАЙІ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("КНИГА ІСАЙЇ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("JESAJABOKA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("YASHAAYAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("سفر إشعياء 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISHACYAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("YASƏIYAKO 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("YASƏIYĀKO 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("YAŠƏIYAKO 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("YAŠƏIYĀKO 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("I-SA-GIA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAAAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAAIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAIAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAIIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIAAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIAIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIIAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIIIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAAAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAAIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAIAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAIIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIAAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIAIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIIAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIIIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("IZAJASZA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("YASAʿYĀH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("إشَعْياء 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("EZSAIAS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("EZSAIÁS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("I-SAI-A 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAAIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAIAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAIIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIAIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIIAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIIIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAISHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAAIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAIAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAIIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIAIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIIAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIIIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("JESAJAN 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("YASĀYĀH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ÉZSAIAS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ÉZSAIÁS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ΗΣΑΪ́ΑΣ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("यशैयाको 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ਯਾਸਾਯਾਹ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("อิสยาห์ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ESAIAS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ESAIÁS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ESAJAS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIAS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAISH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAÍAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAÍAS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("IZAIAS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("IZAIAŠ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("IZAIJA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("IZAIÁS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("IZAIÁŠ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("IZAJAS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("IZAJAŠ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("IZAJÁS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("IZAJÁŠ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("JESAIA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("JESAJA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("YESAYA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("YÉSAYA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("YASAYA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("YASAYĀ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("YAŜAYA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("YAŜAYĀ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ÉSAIAS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ÉSAIÁS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ΗΣΑΊΑΣ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ΗΣΑΙΑΣ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ΗΣΑΪ́ΑΣ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ΗΣΑΙΑΣ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ИСАИЈА 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ישעיהו 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("یسعیاہ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("یعسیاہ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("यशायाह 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("येशैया 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ਯਸਾਯਾਹ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ଯାଶାଇୟ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ଯିଶାଇୟ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ଯୀଶାଇୟ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《以賽亚书》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《以賽亞書》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《以赛亚书》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《依撒意亞》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ﺃﺷﻌﻴﺎء 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ECAYA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ECAYĀ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ECĀYA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ECĀYĀ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ESAIE 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ESAÏE 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ESEIA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("EZAYI 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIE 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAJA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAYA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAÍA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAÏE 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIHA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISIIH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISSAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ÉSAIE 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ÉSAÏE 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("Ê-SAI 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ИСАИИ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ИСАИЯ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ИСАЈА 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ישעיה 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("إشعيا 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("यशाया 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("यशैया 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ୟଶାଇୟ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ୟିଶାୟ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("எசாயா 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ஏசாயா 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《以賽亚书 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《以賽亞書 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《以赛亚书 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《依撒意亞 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("以賽亚书》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("以賽亞書》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("以赛亚书》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("依撒意亞》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ESAI 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("I-SA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISAI 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ІСАЯ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ІСАІ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ІСАЇ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ИСАИ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ИСАЯ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ישעה 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("यशया 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("यशाय 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("イサヤ書 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("イザヤ書 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("以賽亚书 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("以賽亞書 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("以赛亚书 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("依撒意亞 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("이사야서 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ESA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("EZS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ISH 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("JES 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ÉSA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ÉZS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("यशा 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ਯਸਾ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("எசா 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ஏசா 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("อสย 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《賽》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《赛》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("イサヤ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("イザヤ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("이사야 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("IA 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("IS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("IZ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ÉS 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ΗΣ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ІС 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ИС 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("اش 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("ἨΣ 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《賽 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("《赛 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("賽》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("赛》 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("이사 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("賽 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("赛 1:1").osis()).toEqual("Isa.1.1")
		expect(p.parse("사 1:1").osis()).toEqual("Isa.1.1")
		`
		true
describe "Localized book 2Sam (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Sam (full)", ->
		`
		expect(p.parse("சாமுவேலின் இரண்டாம் புத்தகம் 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Kitabu cha Pili cha Samueli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ଶାମୁୟେଲଙ୍କ ଦ୍ୱିତୀୟ ପୁସ୍ତକ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Anden Kongerigernes Bog 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Cartea a doua a Regilor 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Cartea II a lui Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ksiega Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ksiegi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Księga Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Księgi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Samuelova knjiga 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga knjiga o Samuelu 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ksiega Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ksiegi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Księga Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Księgi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге. книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге. книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druha kniha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhy kniha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhá kniha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhý kniha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Toinen Samuelin kirja 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Втора Книга на царете 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Втора книга Самоилова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Втора книга на Самуил 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Второ книга Самоилова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друга книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друга книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друге книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друге книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("शमूएलको दोस्रो पुस्तक 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а. книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а. книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е. книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е. книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Kongerigernes Bog 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Dezyem liv Samyel la 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Dezyem liv Samyèl la 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Dezyèm liv Samyel la 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Dezyèm liv Samyèl la 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ksiega Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ksiegi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Księga Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Księgi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ksiega Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ksiegi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Księga Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Księgi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhy list Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhý list Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ksiega Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ksiegi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Księga Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Księgi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("samūel dī dūjī potʰī 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("शमुऐयल की 2री पुस्तक 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("शमुऐयल की २री पुस्तक 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Kongerigernes Bog 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ksiega Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ksiegi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Księga Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Księgi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Cartea II a Regilor 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ks. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ks. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ksiega Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ksiegi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Księga Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Księgi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. kniha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Книга на царете 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. книга Самоилова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Втора книга Царства 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ksiega Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ksiegi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Księga Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Księgi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. kniha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Книга на царете 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. книга Самоилова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Andra Samuelsboken 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ks Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ks Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II kniha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Книга на царете 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II книга Самоилова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ksiega Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ksiegi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Księga Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Księgi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuelin kirja 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικος Σαμουήλ Β' 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικος Σαμουήλ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικος Σαμουήλ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικος Σαμουήλ Β΄ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικος Σαμουήλ Β’ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικος Σαμουηλ Β' 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικος Σαμουηλ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικος Σαμουηλ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικος Σαμουηλ Β΄ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικος Σαμουηλ Β’ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικός Σαμουήλ Β' 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικός Σαμουήλ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικός Σαμουήλ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικός Σαμουήλ Β΄ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικός Σαμουήλ Β’ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικός Σαμουηλ Β' 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικός Σαμουηλ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικός Σαμουηλ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικός Σαμουηλ Β΄ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικός Σαμουηλ Β’ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ਸਮੂਏਲ ਦੀ ਦੂਜੀ ਪੋਥੀ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 kniha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Книга на царете 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 книга Самоилова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е. Книга Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-я. Книга Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ksiega Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ksiegi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Księga Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Księgi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelin kirja 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ks. Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ks. Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ksiega Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ksiegi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Księga Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Księgi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuelin kirja 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ks. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Liber II Samuelis 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Siðari Samuelsbok 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Siðari Samuelsbók 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Siðari Samúelsbok 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Siðari Samúelsbók 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Síðari Samuelsbok 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Síðari Samuelsbók 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Síðari Samúelsbok 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Síðari Samúelsbók 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("سفر صموئيل الثاني 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ksiega Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ksiegi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Księga Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Księgi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelin kirja 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е Книга Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-я Книга Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ks. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2е. Книга Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2я. Книга Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Anden Samuelsbog 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Andre Samuelsbok 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Deuxiemes Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Deuxièmes Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ks Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ks Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ks. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ks Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Ikalawang Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Samuu'eel Labaad 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Samuu’eel Labaad 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ଶାମୁୟେଲଙ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ks. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге. Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге. Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ks Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelsboken 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Книга Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2е Книга Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2я Книга Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Deuxieme Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Deuxième Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhy Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhá Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhý Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ks Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ks. Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Seconda Samuele 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Secondo Samuele 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Toinen Samuelin 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друга Самуилова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друга краљевима 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друге Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друге Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ଶାମୁୟେଲ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ks Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelsboken 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 k. Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Книга Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а. Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а. Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е. Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е. Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ks. Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ks. Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ks Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Masodik Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Masodik Sámuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Második Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Második Sámuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Segunda Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Segunda Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Segundo Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Segundo Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("الممالك الثاني 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("صموئيل الثّاني 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ks. Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 e. Samuelit 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 i. Samuelit 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 k Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ks Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelsbog 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelsbok 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Dezyem Samyel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Dezyem Samyèl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Dezyèm Samyel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Dezyèm Samyèl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ks Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuu'eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuu’eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Самуилова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. краљевима 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Tweede Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Tweede Samuël 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Zweite Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Втора Царства 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("صموئيل الثاني 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ks Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelsbog 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelsbok 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 e Samuelit 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 i Samuelit 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге. Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге. Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге. Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге. Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е. Самуила 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-я. Самуила 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuu'eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuu’eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Shamooael 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Самуилова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. краљевима 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2eme. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ème. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Anden Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Andre Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druha Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhy Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhá Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhý Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuu'eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuu’eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Самуилова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II краљевима 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Regnorum 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Sa-mu-ên 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuelin 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuelis 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Pili Samueli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Pili Samweli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βασιλειων Β' 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βασιλειων Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βασιλειων Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βασιλειων Β΄ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βασιλειων Β’ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βασιλειών Β' 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βασιλειών Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βασιλειών Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βασιλειών Β΄ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βασιλειών Β’ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Втора Самуил 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Второ Самуил 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друга Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друга Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друга Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друга Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друге Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друге Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друге Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друге Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("दुसरे शमुवेल 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuu'eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuu’eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Shamooael 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Самуилова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 краљевима 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а. Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а. Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а. Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а. Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е Самуила 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е. Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е. Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е. Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е. Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е. Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-я Самуила 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-я. Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Regnorum 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Sa-mu-ên 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelin 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelis 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelit 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. samuelko 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. samūelko 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. šamuelko 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. šamūelko 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. ଶାମୁୟେଲଙ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2.o. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2.º. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2de. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2eme Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2°. Samuele 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ème Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2е. Самуила 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2я. Самуила 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Regnorum 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Sa-mu-ên 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuelin 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuelis 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Regilor 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuele 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samueli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samweli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Царства 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Masodik Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Masodik Sám 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Második Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Második Sám 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Samuelis II 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Regnorum 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Sa-mu-ên 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelin 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelis 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelit 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 samuelko 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 samūelko 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 šamuelko 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 šamūelko 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ଶାମୁୟେଲଙ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 சாமுவேல் 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-я Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Regilor 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuele 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samueli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samweli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Самуила 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Царства 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. शमूएलको 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. ଶାମୁୟେଲ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. ซามูเอล 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2.o Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2.º Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2a. Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2a. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2d. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2de Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2e. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2e. Samuël 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2o. Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2o. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2° Samuele 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2º. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2е Самуила 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2е. Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2я Самуила 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2я. Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Regilor 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuele 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samueli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samweli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Царства 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuël 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samyel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samyèl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Sámuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Самуил 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Samueli II 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Tweede Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β' Σαμουήλ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β' Σαμουηλ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βʹ Σαμουήλ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βʹ Σαμουηλ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βʹ Σαμουήλ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βʹ Σαμουηλ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β΄ Σαμουήλ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β΄ Σαμουηλ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β’ Σαμουήλ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β’ Σαμουηλ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Втора Царе 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("دوم سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("دوم-سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("دوم۔سموایل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Camuvel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Camuvēl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Cāmuvel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Cāmuvēl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Regilor 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuele 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samueli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samweli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 samuwel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 samūʾīl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ŝamuwel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Самуила 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Царства 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 शमूएलको 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ଶାମୁୟେଲ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 அரசுகள் 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ซามูเอล 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuël 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samyel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samyèl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Sámuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Самуил 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. शामुएल 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2.-سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2.۔سموایل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2a Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2a Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2d Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2e Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2e Samuël 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2o Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2o Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2º Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2е Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2я Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Anden Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Andre Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druha Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhy Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhá Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhý Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuël 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samyel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samyèl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Sámuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Самуил 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Samuel II 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Sámuel II 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuël 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samyel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samyèl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Sámuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 samūel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Самуил 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 صموئيل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 शमुवेल 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 शामुएल 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. शमूएल 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2۔سموایل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Царе 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Pili Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("שמואל ב' 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("שמואל ב’ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("۲ سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("۲-سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("۲۔سموایل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 शमूएल 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ਸਮੂਏਲ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Царе 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2e. Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druha S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhy S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhá S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhý S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Царе 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Sám 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("שמואל ב 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒慕爾紀下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒母耳記下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒母耳记下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("사무엘기 하권 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Царе 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 சாமு 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Sám 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. शमू 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. ซมอ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2e Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Sám 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β' Σαμ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βʹ Σαμ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βʹ Σαμ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β΄ Σαμ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β’ Σαμ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒慕爾紀下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒母耳記下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒母耳记下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("サムエル 2 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("サムエル後書 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("サムエル記下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("列王記第二巻 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒慕爾紀下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒母耳記下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒母耳记下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Sám 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Сам 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Цар 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 शमू 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ซมอ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("サムエル下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒慕爾紀下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒母耳記下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒母耳记下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("사무엘 하 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("사무엘기하 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 صم 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("사무엘하 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ц 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2사무 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("삼하 1:1").osis()).toEqual("2Sam.1.1")
		`
		true
	it "should handle non-Latin digits in book: 2Sam (full)", ->
		p.set_options non_latin_digits_strategy: "replace"
		`
		expect(p.parse("சாமுவேலின் இரண்டாம் புத்தகம் 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Kitabu cha Pili cha Samueli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ଶାମୁୟେଲଙ୍କ ଦ୍ୱିତୀୟ ପୁସ୍ତକ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Anden Kongerigernes Bog 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Cartea a doua a Regilor 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Cartea II a lui Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ksiega Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ksiegi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Księga Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Księgi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Samuelova knjiga 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga knjiga o Samuelu 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ksiega Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ksiegi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Księga Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Księgi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге. книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге. книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druha kniha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhy kniha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhá kniha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhý kniha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Toinen Samuelin kirja 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Втора Книга на царете 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Втора книга Самоилова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Втора книга на Самуил 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Второ книга Самоилова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друга книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друга книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друге книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друге книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("शमूएलको दोस्रो पुस्तक 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а. книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а. книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е. книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е. книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Kongerigernes Bog 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Dezyem liv Samyel la 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Dezyem liv Samyèl la 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Dezyèm liv Samyel la 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Dezyèm liv Samyèl la 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ksiega Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ksiegi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Księga Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Księgi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ksiega Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ksiegi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Księga Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Księgi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhy list Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhý list Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ksiega Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ksiegi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Księga Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Księgi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("samūel dī dūjī potʰī 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("शमुऐयल की 2री पुस्तक 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("शमुऐयल की २री पुस्तक 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Kongerigernes Bog 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ksiega Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ksiegi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Księga Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Księgi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Cartea II a Regilor 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ks. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ks. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ksiega Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ksiegi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Księga Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Księgi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. kniha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Книга на царете 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. книга Самоилова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Втора книга Царства 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ksiega Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ksiegi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Księga Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Księgi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. kniha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Книга на царете 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. книга Самоилова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Andra Samuelsboken 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ks Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ks Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II kniha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Книга на царете 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II книга Самоилова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ksiega Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ksiegi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Księga Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Księgi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuelin kirja 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικος Σαμουήλ Β' 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικος Σαμουήλ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικος Σαμουήλ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικος Σαμουήλ Β΄ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικος Σαμουήλ Β’ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικος Σαμουηλ Β' 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικος Σαμουηλ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικος Σαμουηλ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικος Σαμουηλ Β΄ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικος Σαμουηλ Β’ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικός Σαμουήλ Β' 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικός Σαμουήλ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικός Σαμουήλ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικός Σαμουήλ Β΄ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικός Σαμουήλ Β’ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικός Σαμουηλ Β' 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικός Σαμουηλ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικός Σαμουηλ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικός Σαμουηλ Β΄ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("δυτικός Σαμουηλ Β’ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ਸਮੂਏਲ ਦੀ ਦੂਜੀ ਪੋਥੀ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 kniha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Книга на царете 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 книга Самоилова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 книга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 книга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е. Книга Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-я. Книга Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ksiega Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ksiegi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Księga Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Księgi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelin kirja 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ks. Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ks. Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ksiega Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ksiegi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Księga Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Księgi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuelin kirja 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ks. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Liber II Samuelis 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Siðari Samuelsbok 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Siðari Samuelsbók 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Siðari Samúelsbok 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Siðari Samúelsbók 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Síðari Samuelsbok 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Síðari Samuelsbók 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Síðari Samúelsbok 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Síðari Samúelsbók 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("سفر صموئيل الثاني 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ksiega Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ksiegi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Księga Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Księgi Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelin kirja 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е Книга Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-я Книга Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ks. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2е. Книга Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2я. Книга Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Anden Samuelsbog 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Andre Samuelsbok 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Deuxiemes Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Deuxièmes Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Ks Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Ks Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ks. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ks Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Ikalawang Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Samuu'eel Labaad 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Samuu’eel Labaad 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ଶାମୁୟେଲଙ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ks. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге. Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге. Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ks Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelsboken 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Книга Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2е Книга Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2я Книга Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Deuxieme Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Deuxième Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druga Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Drugi Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druha Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhy Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhá Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhý Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ks Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ks. Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Seconda Samuele 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Secondo Samuele 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Toinen Samuelin 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друга Самуилова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друга Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друга Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друга краљевима 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друге Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друге Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ଶାମୁୟେଲ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ks Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelsboken 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 k. Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Книга Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а. Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а. Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е. Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е. Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ks. Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ks. Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Ks Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Masodik Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Masodik Sámuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Második Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Második Sámuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Segunda Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Segunda Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Segundo Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Segundo Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("الممالك الثاني 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("صموئيل الثّاني 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ks. Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 e. Samuelit 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 i. Samuelit 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 k Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Ks Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelsbog 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelsbok 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Dezyem Samyel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Dezyem Samyèl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Dezyèm Samyel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Dezyèm Samyèl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Ks Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuu'eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuu’eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Самуилова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. краљевима 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Tweede Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Tweede Samuël 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Zweite Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Втора Царства 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("صموئيل الثاني 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ks Samuela 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelsbog 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelsbok 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 e Samuelit 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 i Samuelit 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге. Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге. Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге. Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге. Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е. Самуила 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-я. Самуила 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuu'eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuu’eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Shamooael 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Самуилова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. краљевима 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2eme. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ème. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Anden Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Andre Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druha Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhy Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhá Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhý Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuu'eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuu’eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Самуилова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II краљевима 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Regnorum 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Sa-mu-ên 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuelin 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuelis 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Pili Samueli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Pili Samweli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βασιλειων Β' 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βασιλειων Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βασιλειων Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βασιλειων Β΄ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βασιλειων Β’ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βασιλειών Β' 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βασιλειών Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βασιλειών Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βασιλειών Β΄ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βασιλειών Β’ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Втора Самуил 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Второ Самуил 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друга Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друга Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друга Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друга Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друге Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друге Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друге Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Друге Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("दुसरे शमुवेल 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelova 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelowa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuu'eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuu’eel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Shamooael 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Самуилова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Самуілова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Самуїлова 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 краљевима 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а. Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а. Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а. Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а. Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ге Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е Самуила 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е. Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е. Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е. Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е. Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е. Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-я Самуила 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-я. Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Regnorum 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Sa-mu-ên 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelin 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelis 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuelit 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. samuelko 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. samūelko 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. šamuelko 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. šamūelko 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. ଶାମୁୟେଲଙ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2.o. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2.º. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2de. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2eme Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2°. Samuele 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ème Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2е. Самуила 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2я. Самуила 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Regnorum 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Sa-mu-ên 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuelin 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuelis 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Regilor 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuele 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samueli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samweli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Царства 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Masodik Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Masodik Sám 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Második Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Második Sám 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Samuelis II 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Kingdoms 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Regnorum 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Sa-mu-ên 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelin 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelis 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuelit 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 samuelko 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 samūelko 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 šamuelko 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 šamūelko 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ଶାମୁୟେଲଙ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 சாமுவேல் 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-а Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-е Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-я Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Regilor 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuele 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samueli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samweli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Самуила 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Царства 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. शमूएलको 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. ଶାମୁୟେଲ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. ซามูเอล 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2.o Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2.º Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2a. Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2a. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2d. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2de Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2e. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2e. Samuël 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2o. Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2o. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2° Samuele 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2º. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2е Самуила 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2е. Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2я Самуила 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2я. Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Regilor 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuele 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samueli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samweli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Царства 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuël 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samyel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Samyèl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Sámuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Самуил 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Samueli II 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Tweede Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β' Σαμουήλ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β' Σαμουηλ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βʹ Σαμουήλ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βʹ Σαμουηλ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βʹ Σαμουήλ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βʹ Σαμουηλ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β΄ Σαμουήλ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β΄ Σαμουηλ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β’ Σαμουήλ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β’ Σαμουηλ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Втора Царе 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("دوم سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("دوم-سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("دوم۔سموایل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Camuvel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Camuvēl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Cāmuvel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Cāmuvēl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Regilor 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuall 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuals 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuele 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samueli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuell 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuels 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samweli 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 samuwel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 samūʾīl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ŝamuwel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Самуила 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Царства 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 शमूएलको 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ଶାମୁୟେଲ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 அரசுகள் 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ซามูเอล 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuël 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samyel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Samyèl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Sámuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Самуил 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. शामुएल 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2.-سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2.۔سموایل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2a Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2a Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2d Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2e Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2e Samuël 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2o Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2o Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2º Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2е Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2я Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Anden Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Andre Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druha Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhy Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhá Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhý Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuël 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samyel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Samyèl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Sámuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Самуил 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Samuel II 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Second Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Sámuel II 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Reinos 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samual 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuil 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuël 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samuïl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samyel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Samyèl 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Sámuel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 samūel 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Самуил 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Самуіл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Самуїл 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Царств 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 صموئيل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 शमुवेल 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 शामुएल 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. शमूएल 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2۔سموایل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Царе 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Pili Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("שמואל ב' 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("שמואל ב’ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("۲ سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("۲-سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("۲۔سموایل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 शमूएल 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ਸਮੂਏਲ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Царе 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2e. Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd. Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druha S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhy S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhá S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Druhý S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Царе 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Sám 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("שמואל ב 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒慕爾紀下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒母耳記下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒母耳记下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("사무엘기 하권 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Царе 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 சாமு 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Sám 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. शमू 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. ซมอ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2e Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2nd Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Sám 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β' Σαμ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βʹ Σαμ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βʹ Σαμ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β΄ Σαμ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β’ Σαμ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒慕爾紀下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒母耳記下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒母耳记下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("サムエル 2 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("サムエル後書 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("サムエル記下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("列王記第二巻 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒慕爾紀下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒母耳記下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒母耳记下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Sma 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Sám 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Сам 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Цар 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 शमू 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ซมอ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("サムエル下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒慕爾紀下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒母耳記下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒母耳记下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("사무엘 하 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("사무엘기하 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Sa 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Sm 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 صم 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2Sam 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("사무엘하 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ц 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2사무 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("삼하 1:1").osis()).toEqual("2Sam.1.1")
		p.include_apocrypha(false)
		expect(p.parse("சாமுவேலின் இரண்டாம் புத்தகம் 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("KITABU CHA PILI CHA SAMUELI 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ଶାମୁୟେଲଙ୍କ ଦ୍ୱିତୀୟ ପୁସ୍ତକ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ANDEN KONGERIGERNES BOG 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("CARTEA A DOUA A REGILOR 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("CARTEA II A LUI SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA KSIEGA SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA KSIEGI SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA KSIĘGA SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA KSIĘGI SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA SAMUELOVA KNJIGA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA KNJIGA O SAMUELU 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGI KSIEGA SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGI KSIEGI SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGI KSIĘGA SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGI KSIĘGI SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ГЕ. КНИГА САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ГЕ. КНИГА САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHA KNIHA SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHY KNIHA SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHÁ KNIHA SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHÝ KNIHA SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("TOINEN SAMUELIN KIRJA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ВТОРА КНИГА НА ЦАРЕТЕ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ВТОРА КНИГА САМОИЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ВТОРА КНИГА НА САМУИЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ВТОРО КНИГА САМОИЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ДРУГА КНИГА САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ДРУГА КНИГА САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ДРУГЕ КНИГА САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ДРУГЕ КНИГА САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("शमूएलको दोस्रो पुस्तक 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-А. КНИГА САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-А. КНИГА САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ГЕ КНИГА САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ГЕ КНИГА САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Е. КНИГА САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Е. КНИГА САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KONGERIGERNES BOG 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DEZYEM LIV SAMYEL LA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DEZYEM LIV SAMYÈL LA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DEZYÈM LIV SAMYEL LA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DEZYÈM LIV SAMYÈL LA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA KSIEGA SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA KSIEGI SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA KSIĘGA SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA KSIĘGI SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGI KSIEGA SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGI KSIEGI SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGI KSIĘGA SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGI KSIĘGI SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHY LIST SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHÝ LIST SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KSIEGA SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KSIEGI SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KSIĘGA SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KSIĘGI SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SAMŪEL DĪ DŪJĪ POTʰĪ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("शमुऐयल की 2री पुस्तक 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("शमुऐयल की २री पुस्तक 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KONGERIGERNES BOG 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-А КНИГА САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-А КНИГА САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Е КНИГА САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Е КНИГА САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KSIEGA SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KSIEGI SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KSIĘGA SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KSIĘGI SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("CARTEA II A REGILOR 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA KS. SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGI KS. SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KSIEGA SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KSIEGI SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KSIĘGA SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KSIĘGI SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KNIHA SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. КНИГА НА ЦАРЕТЕ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. КНИГА САМОИЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. КНИГА САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. КНИГА САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ВТОРА КНИГА ЦАРСТВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KSIEGA SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KSIEGI SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KSIĘGA SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KSIĘGI SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KNIHA SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. КНИГА НА ЦАРЕТЕ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. КНИГА САМОИЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. КНИГА САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. КНИГА САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ANDRA SAMUELSBOKEN 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA KS SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGI KS SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KNIHA SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II КНИГА НА ЦАРЕТЕ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II КНИГА САМОИЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II КНИГА САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II КНИГА САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KSIEGA SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KSIEGI SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KSIĘGA SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KSIĘGI SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUELIN KIRJA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΣΑΜΟΥΉΛ Β' 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΣΑΜΟΥΉΛ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΣΑΜΟΥΉΛ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΣΑΜΟΥΉΛ Β΄ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΣΑΜΟΥΉΛ Β’ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΣΑΜΟΥΗΛ Β' 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΣΑΜΟΥΗΛ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΣΑΜΟΥΗΛ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΣΑΜΟΥΗΛ Β΄ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΣΑΜΟΥΗΛ Β’ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΣΑΜΟΥΉΛ Β' 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΣΑΜΟΥΉΛ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΣΑΜΟΥΉΛ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΣΑΜΟΥΉΛ Β΄ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΣΑΜΟΥΉΛ Β’ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΣΑΜΟΥΗΛ Β' 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΣΑΜΟΥΗΛ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΣΑΜΟΥΗΛ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΣΑΜΟΥΗΛ Β΄ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΣΑΜΟΥΗΛ Β’ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ਸਮੂਏਲ ਦੀ ਦੂਜੀ ਪੋਥੀ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KNIHA SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 КНИГА НА ЦАРЕТЕ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 КНИГА САМОИЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 КНИГА САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 КНИГА САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Е. КНИГА ЦАРСТВ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Я. КНИГА ЦАРСТВ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KSIEGA SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KSIEGI SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KSIĘGA SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KSIĘGI SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELIN KIRJA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA KS. SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGI KS. SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KSIEGA SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KSIEGI SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KSIĘGA SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KSIĘGI SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUELIN KIRJA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KS. SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("LIBER II SAMUELIS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SIÐARI SAMUELSBOK 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SIÐARI SAMUELSBÓK 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SIÐARI SAMÚELSBOK 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SIÐARI SAMÚELSBÓK 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SÍÐARI SAMUELSBOK 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SÍÐARI SAMUELSBÓK 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SÍÐARI SAMÚELSBOK 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SÍÐARI SAMÚELSBÓK 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("سفر صموئيل الثاني 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KSIEGA SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KSIEGI SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KSIĘGA SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KSIĘGI SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELIN KIRJA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Е КНИГА ЦАРСТВ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Я КНИГА ЦАРСТВ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KS. SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2Е. КНИГА ЦАРСТВ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2Я. КНИГА ЦАРСТВ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ANDEN SAMUELSBOG 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ANDRE SAMUELSBOK 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DEUXIEMES SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DEUXIÈMES SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA KS SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGI KS SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KS. SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KS SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("IKALAWANG SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SAMUU'EEL LABAAD 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SAMUU’EEL LABAAD 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ଶାମୁୟେଲଙ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KS. SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ГЕ. САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ГЕ. САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KS SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELSBOKEN 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. КНИГА ЦАРСТВ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2Е КНИГА ЦАРСТВ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2Я КНИГА ЦАРСТВ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DEUXIEME SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DEUXIÈME SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGA SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUGI SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHA SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHY SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHÁ SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHÝ SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KS SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KS. SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND KINGDOMS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECONDA SAMUELE 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECONDO SAMUELE 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("TOINEN SAMUELIN 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ДРУГА САМУИЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ДРУГА САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ДРУГА САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ДРУГА КРАЉЕВИМА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ДРУГЕ САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ДРУГЕ САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ଶାମୁୟେଲ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KS SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELSBOKEN 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 K. SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 КНИГА ЦАРСТВ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-А. САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-А. САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ГЕ САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ГЕ САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Е. САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Е. САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KS. SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KS. SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KS SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("MASODIK SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("MASODIK SÁMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("MÁSODIK SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("MÁSODIK SÁMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SAMUALL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SAMUALS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SAMUELL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SAMUELS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SEGUNDA REINOS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SEGUNDA SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SEGUNDO REINOS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SEGUNDO SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("الممالك الثاني 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("صموئيل الثّاني 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KS. SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 E. SAMUELIT 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 I. SAMUELIT 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 K SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-А САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-А САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Е САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Е САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KS SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELSBOG 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELSBOK 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. KINGDOMS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DEZYEM SAMYEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DEZYEM SAMYÈL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DEZYÈM SAMYEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DEZYÈM SAMYÈL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KS SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUU'EEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUU’EEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. САМУИЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. КРАЉЕВИМА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SAMUAL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("TWEEDE SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("TWEEDE SAMUËL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ZWEITE SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ВТОРА ЦАРСТВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("صموئيل الثاني 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KS SAMUELA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELSBOG 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELSBOK 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 E SAMUELIT 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 I SAMUELIT 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ГЕ. SAMUIL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ГЕ. SAMUÏL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ГЕ. САМУІЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ГЕ. САМУЇЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Е. САМУИЛА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Я. САМУИЛА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUU'EEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUU’EEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SHAMOOAEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. САМУИЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. КРАЉЕВИМА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2EME. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND KINGDOMS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SAMUALL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SAMUALS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SAMUELL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SAMUELS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ÈME. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ANDEN SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ANDRE SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHA SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHY SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHÁ SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHÝ SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUU'EEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUU’EEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II САМУИЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II КРАЉЕВИМА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. KINGDOMS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. REGNORUM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SA-MU-ÊN 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUELIN 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUELIS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("PILI SAMUELI 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("PILI SAMWELI 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΩΝ Β' 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΩΝ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΩΝ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΩΝ Β΄ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΩΝ Β’ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΏΝ Β' 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΏΝ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΏΝ Βʹ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΏΝ Β΄ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΏΝ Β’ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ВТОРА САМУИЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ВТОРО САМУИЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ДРУГА SAMUIL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ДРУГА SAMUÏL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ДРУГА САМУІЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ДРУГА САМУЇЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ДРУГЕ SAMUIL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ДРУГЕ SAMUÏL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ДРУГЕ САМУІЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ДРУГЕ САМУЇЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("दुसरे शमुवेल 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELOVA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELOWA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUU'EEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUU’EEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SHAMOOAEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 САМУИЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 САМУІЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 САМУЇЛОВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 КРАЉЕВИМА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-А. SAMUIL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-А. SAMUÏL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-А. САМУІЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-А. САМУЇЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ГЕ SAMUIL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ГЕ SAMUÏL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ГЕ САМУІЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-ГЕ САМУЇЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Е САМУИЛА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Е. SAMUIL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Е. SAMUÏL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Е. САМУІЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Е. САМУЇЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Е. ЦАРСТВ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Я САМУИЛА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Я. ЦАРСТВ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. KINGDOMS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. REGNORUM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SA-MU-ÊN 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELIN 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELIS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELIT 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELKO 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMŪELKO 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. ŠAMUELKO 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. ŠAMŪELKO 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. ଶାମୁୟେଲଙ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2.O. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2.º. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2DE. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2EME SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SAMUALL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SAMUALS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SAMUELL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SAMUELS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SAMUAL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2°. SAMUELE 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ÈME SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2Е. САМУИЛА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2Я. САМУИЛА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II KINGDOMS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II REGNORUM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SA-MU-ÊN 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUELIN 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUELIS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. REGILOR 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUALL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUALS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUELE 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUELI 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUELL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUELS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMWELI 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. ЦАРСТВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("MASODIK SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("MASODIK SÁM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("MÁSODIK SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("MÁSODIK SÁM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SAMUELIS II 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 KINGDOMS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 REGNORUM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SA-MU-ÊN 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELIN 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELIS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELIT 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELKO 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMŪELKO 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ŠAMUELKO 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ŠAMŪELKO 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ଶାମୁୟେଲଙ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 சாமுவேல் 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-А SAMUIL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-А SAMUÏL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-А САМУІЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-А САМУЇЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Е SAMUIL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Е SAMUÏL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Е САМУІЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Е САМУЇЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Е ЦАРСТВ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-Я ЦАРСТВ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. REGILOR 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUALL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUALS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELE 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELI 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUELS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMWELI 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. САМУИЛА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. ЦАРСТВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. शमूएलको 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. ଶାମୁୟେଲ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. ซามูเอล 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2.O SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2.º SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2A. REINOS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2A. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2D. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2DE SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2E. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2E. SAMUËL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SAMUAL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2O. REINOS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2O. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2° SAMUELE 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2º. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2Е САМУИЛА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2Е. ЦАРСТВ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2Я САМУИЛА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2Я. ЦАРСТВ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II REGILOR 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUALL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUALS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUELE 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUELI 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUELL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUELS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMWELI 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II ЦАРСТВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. REINOS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUAL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUIL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUËL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMUÏL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMYEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAMYÈL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SÁMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. САМУИЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. САМУІЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. САМУЇЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SAMUELI II 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SMA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("TWEEDE SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β' ΣΑΜΟΥΉΛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β' ΣΑΜΟΥΗΛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βʹ ΣΑΜΟΥΉΛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βʹ ΣΑΜΟΥΗΛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βʹ ΣΑΜΟΥΉΛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βʹ ΣΑΜΟΥΗΛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β΄ ΣΑΜΟΥΉΛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β΄ ΣΑΜΟΥΗΛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β’ ΣΑΜΟΥΉΛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β’ ΣΑΜΟΥΗΛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ВТОРА ЦАРЕ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("دوم سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("دوم-سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("دوم۔سموایل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 CAMUVEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 CAMUVĒL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 CĀMUVEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 CĀMUVĒL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 REGILOR 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUALL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUALS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELE 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELI 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUELS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMWELI 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUWEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMŪʾĪL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ŜAMUWEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 САМУИЛА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ЦАРСТВА 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 शमूएलको 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ଶାମୁୟେଲ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 அரசுகள் 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ซามูเอล 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. REINOS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUAL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUIL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUËL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMUÏL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMYEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAMYÈL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SÁMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. САМУИЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. САМУІЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. САМУЇЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. ЦАРСТВ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. शामुएल 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2.-سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2.۔سموایل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2A REINOS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2A SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2D SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2E SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2E SAMUËL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2O REINOS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2O SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2º SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2Е ЦАРСТВ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2Я ЦАРСТВ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ANDEN SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("ANDRE SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHA SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHY SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHÁ SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHÝ SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II REINOS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUAL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUIL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUËL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMUÏL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMYEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAMYÈL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SÁMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II САМУИЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II САМУІЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II САМУЇЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SAMUEL II 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SECOND SM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("SÁMUEL II 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 REINOS 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUAL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUIL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUËL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMUÏL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMYEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMYÈL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SÁMUEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAMŪEL 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 САМУИЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 САМУІЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 САМУЇЛ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ЦАРСТВ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 صموئيل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 शमुवेल 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 शामुएल 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2-سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. शमूएल 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SMA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2۔سموایل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. ЦАРЕ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("PILI SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("שמואל ב' 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("שמואל ב’ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("۲ سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("۲-سموئیل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("۲۔سموایل 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 शमूएल 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ਸਮੂਏਲ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. ЦАРЕ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2E. SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SMA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND. SM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHA S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHY S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHÁ S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("DRUHÝ S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II ЦАРЕ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SMA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SÁM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("שמואל ב 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒慕爾紀下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒母耳記下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒母耳记下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("사무엘기 하권 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ЦАРЕ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 சாமு 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SMA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SÁM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. शमू 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. ซมอ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2E SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2ND SM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SMA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SÁM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. SM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β' ΣΑΜ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βʹ ΣΑΜ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Βʹ ΣΑΜ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β΄ ΣΑΜ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("Β’ ΣΑΜ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒慕爾紀下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒母耳記下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒母耳记下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("サムエル 2 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("サムエル後書 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("サムエル記下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("列王記第二巻 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒慕爾紀下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒母耳記下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒母耳记下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SMA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SÁM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 САМ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ЦАР 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 शमू 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 ซมอ 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. SM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II SM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II. S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("サムエル下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒慕爾紀下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒母耳記下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒母耳记下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("사무엘 하 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("사무엘기하 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SA 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 SM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 صم 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2. S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2SAM 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("II S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("사무엘하 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 S 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2 Ц 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("2사무 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("《撒下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒下》 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("撒下 1:1").osis()).toEqual("2Sam.1.1")
		expect(p.parse("삼하 1:1").osis()).toEqual("2Sam.1.1")
		`
		true
describe "Localized book 1Sam (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Sam (full)", ->
		`
		expect(p.parse("Kitabu cha Kwanza cha Samueli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("சாமுவேலின் முதலாம் புத்தகம் 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Ensimmainen Samuelin kirja 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Ensimmäinen Samuelin kirja 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ksiega Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ksiegi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Księga Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Księgi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ksiega Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ksiegi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Księga Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Księgi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ksiega Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ksiegi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Księga Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Księgi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Første Kongerigernes Bog 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ksiega Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ksiegi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Księga Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Księgi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ksiega Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ksiegi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Księga Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Księgi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ksiega Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ksiegi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Księga Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Księgi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ଶାମୁୟେଲଙ୍କ ପ୍ରଥମ ପୁସ୍ତକ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Cartea intai a Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Cartea intâi a Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Cartea întai a Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Cartea întâi a Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ks. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ks. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ks. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("samūel dī pahilī potʰī 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше. книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше. книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Cartea I a lui Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ks Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ks Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ks Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prva Samuelova knjiga 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prva knjiga o Samuelu 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvni kniha Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("První kniha Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перша книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перша книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перше книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перше книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Първа Книга на царете 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Първа книга на Самуил 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а. книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а. книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е. книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е. книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Kongerigernes Bog 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Ensimmainen Samuelin 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Ensimmäinen Samuelin 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ks. Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ks. Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ks. Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premye liv Samyel la 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premye liv Samyèl la 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prva kniha Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvá kniha Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Прва книга Самоилова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Прво книга Самоилова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("शमूएलको पहिलो पुस्तक 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Kongerigernes Bog 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ksiega Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ksiegi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Księga Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Księgi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Forsta Samuelsboken 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Första Samuelsboken 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ksiega Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ksiegi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Księga Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Księgi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ks Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ks Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ks Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvy list Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvý list Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Първа книга Царства 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("शमुऐल की 1ली पुस्तक 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("शमुऐल की १ली पुस्तक 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ਸਮੂਏਲ ਦੀ ਪਹਿਲੀ ਪੋਥੀ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ksiega Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ksiegi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Księga Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Księgi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. kniha Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Книга на царете 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. книга Самоилова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Cartea I a Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ksiega Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ksiegi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Księga Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Księgi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. kniha Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Книга на царете 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. книга Самоилова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικος Σαμουήλ Α' 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικος Σαμουήλ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικος Σαμουήλ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικος Σαμουήλ Α΄ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικος Σαμουήλ Α’ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικος Σαμουηλ Α' 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικος Σαμουηλ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικος Σαμουηλ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικος Σαμουηλ Α΄ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικος Σαμουηλ Α’ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικός Σαμουήλ Α' 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικός Σαμουήλ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικός Σαμουήλ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικός Σαμουήλ Α΄ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικός Σαμουήλ Α’ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικός Σαμουηλ Α' 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικός Σαμουηλ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικός Σαμουηλ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικός Σαμουηλ Α΄ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικός Σαμουηλ Α’ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 kniha Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Книга на царете 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 книга Самоилова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е. Книга Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-я. Книга Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ksiega Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ksiegi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Księga Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Księgi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelin kirja 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Første Samuelsbog 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Første Samuelsbok 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I kniha Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Книга на царете 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I книга Самоилова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ksiega Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ksiegi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Księga Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Księgi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuelin kirja 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ksiega Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ksiegi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Księga Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Księgi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelin kirja 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е Книга Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-я Книга Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ks. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1е. Книга Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1я. Книга Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Fyrri Samuelsbok 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Fyrri Samuelsbók 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Fyrri Samúelsbok 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Fyrri Samúelsbók 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ksiega Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ksiegi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Księga Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Księgi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuelin kirja 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ks. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Liber I Samuelis 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premieres Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premières Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuu'eel Kowaad 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuu’eel Kowaad 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("سفر صموئيل الأول 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ks. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше. Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше. Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ks Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelsboken 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Книга Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1е Книга Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1я Книга Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ks. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ks Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premiere Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premiers Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Première Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Primeira Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Primeira Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Primeiro Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Primeiro Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvni Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("První Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("samuelko pustak 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("samūelko pustak 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("šamuelko pustak 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("šamūelko pustak 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перша Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перша Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перше Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перше Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ks Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelsboken 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 k. Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Книга Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а. Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а. Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е. Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е. Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ks. Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Første Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ks Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ks. Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Kwanza Samueli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Kwanza Samweli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premier Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Primero Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prva Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvy Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvá Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvý Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Прва Самуилова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Прва краљевима 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ପ୍ରଥମ ଶାମୁୟେଲଙ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ks. Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 e. Samuelit 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 i. Samuelit 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 k Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ks Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelsbog 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelsbok 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Eerste Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Eerste Samuël 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Første Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ks. Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ks Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premye Samyel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premye Samyèl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prima Samuele 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Primer Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Primo Samuele 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Първа Царства 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("الممالك الأول 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ପ୍ରଥମ ଶାମୁୟେଲ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ks Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelsbog 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelsbok 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 e Samuelit 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 i Samuelit 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е. Самуила 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше. Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше. Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше. Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше. Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-я. Самуила 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuu'eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuu’eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Shamooael 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Самуилова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. краљевима 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ere. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ère. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Erste Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ks Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuu'eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuu’eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Самуилова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. краљевима 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvni Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("První Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Unang Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Βασιλειων Α' 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Βασιλειων Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Βασιλειων Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Βασιλειων Α΄ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Βασιλειων Α’ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Βασιλειών Α' 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Βασιλειών Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Βασιλειών Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Βασιλειών Α΄ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Βασιλειών Α’ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перша Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перша Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перша Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перша Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перше Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перше Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перше Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перше Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Първа Самуил 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("صموئيل الأول 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("पहिले शमुवेल 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuu'eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuu’eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Shamooael 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Самуилова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 краљевима 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а. Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а. Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а. Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а. Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е Самуила 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е. Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е. Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е. Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е. Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е. Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-я Самуила 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-я. Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Regnorum 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Sa-mu-ên 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelin 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelis 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelit 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. samuelko 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. samūelko 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. šamuelko 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. šamūelko 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. ଶାମୁୟେଲଙ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1.o. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1.º. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1er. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ere Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1re. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1°. Samuele 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ère Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1е. Самуила 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1я. Самуила 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Elso Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Elso Sámuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Első Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Első Sámuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuu'eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuu’eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Самуилова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I краљевима 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Regnorum 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Sa-mu-ên 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuelin 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuelis 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Прва Самуил 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Прво Самуил 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("اوّل سموئيل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("اوّل سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("اوّل-سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("اوّل۔سموایل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ﺻﻤﻮﺋﻴﻞ ﺍﻷﻭﻝ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Regnorum 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Sa-mu-ên 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelin 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelis 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelit 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 samuelko 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 samūelko 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 šamuelko 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 šamūelko 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ଶାମୁୟେଲଙ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 சாமுவேல் 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-я Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuele 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samueli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samweli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Самуила 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Царства 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. शमूएलको 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. ଶାମୁୟେଲ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. ซามูเอล 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1.o Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1.º Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1a. Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1a. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1e. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1e. Samuël 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1er Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1o. Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1o. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1re Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1° Samuele 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1º. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1е Самуила 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1е. Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1я Самуила 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1я. Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Eerste Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Første Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Regnorum 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Sa-mu-ên 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuelin 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuelis 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuele 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samueli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samweli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Царства 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Kwanza Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuelis I 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Una Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α' Σαμουήλ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α' Σαμουηλ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Αʹ Σαμουήλ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Αʹ Σαμουηλ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Αʹ Σαμουήλ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Αʹ Σαμουηλ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α΄ Σαμουήλ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α΄ Σαμουηλ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α’ Σαμουήλ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α’ Σαμουηλ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Първа Царе 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Camuvel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Camuvēl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Cāmuvel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Cāmuvēl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuele 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samueli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samweli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 samuwel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 samūʾīl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ŝamuwel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Самуила 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Царства 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 शमूएलको 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ଶାମୁୟେଲ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 அரசுகள் 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ซามูเอล 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuël 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samyel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samyèl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Sámuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Самуил 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. سموئيل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. शामुएल 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1.-سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1.۔سموایل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1a Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1a Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1e Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1e Samuël 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1o Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1o Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1º Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1е Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1я Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuele 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samueli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samweli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Царства 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuël 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samyel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samyèl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Sámuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Самуил 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvni Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("První Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samueli I 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuël 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samyel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samyèl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Sámuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 samūel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Самуил 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 سموئيل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 صموئيل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 शमुवेल 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 शामुएल 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. शमूएल 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1۔سموایل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Elso Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Elso Sám 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Első Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Első Sám 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuël 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samyel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samyèl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Sámuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Самуил 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuel I 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Sámuel I 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("שמואל א' 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("שמואל א’ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("۱ سموئيل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("۱ سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("۱-سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("۱۔سموایل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 शमूएल 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ਸਮੂਏਲ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Царе 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1e. Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Царе 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvni S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("První S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("שמואל א 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒慕爾紀上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒母耳記上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒母耳记上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("사무엘기 상권 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Царе 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 சாமு 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Sám 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. शमू 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. ซมอ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1e Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Царе 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Sám 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α' Σαμ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Αʹ Σαμ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Αʹ Σαμ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α΄ Σαμ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α’ Σαμ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒慕爾紀上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒母耳記上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒母耳记上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("サムエル 1 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("サムエル前書 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("サムエル記上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("列王記第一巻 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒慕爾紀上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒母耳記上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒母耳记上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Sám 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Сам 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Цар 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 शमू 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ซมอ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Sám 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("サムエル上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒慕爾紀上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒母耳記上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒母耳记上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("사무엘 상 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("사무엘기상 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 صم 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("사무엘상 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ц 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1사무 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("삼상 1:1").osis()).toEqual("1Sam.1.1")
		`
		true
	it "should handle non-Latin digits in book: 1Sam (full)", ->
		p.set_options non_latin_digits_strategy: "replace"
		`
		expect(p.parse("Kitabu cha Kwanza cha Samueli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("சாமுவேலின் முதலாம் புத்தகம் 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Ensimmainen Samuelin kirja 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Ensimmäinen Samuelin kirja 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ksiega Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ksiegi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Księga Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Księgi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ksiega Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ksiegi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Księga Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Księgi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ksiega Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ksiegi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Księga Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Księgi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Første Kongerigernes Bog 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ksiega Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ksiegi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Księga Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Księgi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ksiega Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ksiegi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Księga Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Księgi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ksiega Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ksiegi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Księga Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Księgi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ଶାମୁୟେଲଙ୍କ ପ୍ରଥମ ପୁସ୍ତକ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Cartea intai a Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Cartea intâi a Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Cartea întai a Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Cartea întâi a Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ks. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ks. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ks. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("samūel dī pahilī potʰī 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше. книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше. книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Cartea I a lui Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ks Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ks Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ks Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prva Samuelova knjiga 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prva knjiga o Samuelu 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvni kniha Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("První kniha Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перша книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перша книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перше книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перше книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Първа Книга на царете 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Първа книга на Самуил 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а. книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а. книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е. книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е. книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Kongerigernes Bog 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Ensimmainen Samuelin 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Ensimmäinen Samuelin 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ks. Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ks. Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ks. Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premye liv Samyel la 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premye liv Samyèl la 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prva kniha Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvá kniha Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Прва книга Самоилова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Прво книга Самоилова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("शमूएलको पहिलो पुस्तक 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Kongerigernes Bog 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ksiega Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ksiegi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Księga Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Księgi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Forsta Samuelsboken 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Första Samuelsboken 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ksiega Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ksiegi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Księga Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Księgi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Ks Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Ks Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Ks Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvy list Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvý list Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Първа книга Царства 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("शमुऐल की 1ली पुस्तक 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("शमुऐल की १ली पुस्तक 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ਸਮੂਏਲ ਦੀ ਪਹਿਲੀ ਪੋਥੀ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ksiega Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ksiegi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Księga Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Księgi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. kniha Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Книга на царете 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. книга Самоилова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Cartea I a Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ksiega Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ksiegi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Księga Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Księgi Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. kniha Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Книга на царете 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. книга Самоилова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsza Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwsze Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Pierwszy Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικος Σαμουήλ Α' 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικος Σαμουήλ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικος Σαμουήλ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικος Σαμουήλ Α΄ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικος Σαμουήλ Α’ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικος Σαμουηλ Α' 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικος Σαμουηλ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικος Σαμουηλ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικος Σαμουηλ Α΄ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικος Σαμουηλ Α’ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικός Σαμουήλ Α' 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικός Σαμουήλ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικός Σαμουήλ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικός Σαμουήλ Α΄ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικός Σαμουήλ Α’ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικός Σαμουηλ Α' 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικός Σαμουηλ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικός Σαμουηλ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικός Σαμουηλ Α΄ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("δυτικός Σαμουηλ Α’ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 kniha Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Книга на царете 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 книга Самоилова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е. Книга Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-я. Книга Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ksiega Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ksiegi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Księga Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Księgi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelin kirja 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Første Samuelsbog 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Første Samuelsbok 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I kniha Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Книга на царете 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I книга Самоилова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I книга Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I книга Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ksiega Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ksiegi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Księga Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Księgi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuelin kirja 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ksiega Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ksiegi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Księga Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Księgi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelin kirja 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е Книга Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-я Книга Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ks. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1е. Книга Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1я. Книга Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Fyrri Samuelsbok 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Fyrri Samuelsbók 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Fyrri Samúelsbok 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Fyrri Samúelsbók 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ksiega Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ksiegi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Księga Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Księgi Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuelin kirja 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ks. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Liber I Samuelis 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premieres Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premières Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuu'eel Kowaad 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuu’eel Kowaad 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("سفر صموئيل الأول 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ks. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше. Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше. Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ks Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelsboken 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Книга Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1е Книга Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1я Книга Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ks. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ks Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premiere Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premiers Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Première Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Primeira Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Primeira Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Primeiro Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Primeiro Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvni Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("První Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("samuelko pustak 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("samūelko pustak 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("šamuelko pustak 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("šamūelko pustak 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перша Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перша Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перше Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перше Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ks Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelsboken 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 k. Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Книга Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а. Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а. Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е. Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е. Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ks. Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Første Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ks Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ks. Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Kwanza Samueli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Kwanza Samweli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premier Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Primero Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prva Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvy Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvá Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvý Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Прва Самуилова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Прва краљевима 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ପ୍ରଥମ ଶାମୁୟେଲଙ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ks. Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 e. Samuelit 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 i. Samuelit 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 k Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Ks Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelsbog 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelsbok 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Eerste Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Eerste Samuël 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Første Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ks. Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Ks Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premye Samyel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Premye Samyèl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prima Samuele 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Primer Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Primo Samuele 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Първа Царства 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("الممالك الأول 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ପ୍ରଥମ ଶାମୁୟେଲ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ks Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelsbog 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelsbok 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 e Samuelit 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 i Samuelit 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е. Самуила 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше. Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше. Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше. Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше. Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-я. Самуила 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuu'eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuu’eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Shamooael 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Самуилова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. краљевима 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ere. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ère. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Erste Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Ks Samuela 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuu'eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuu’eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Самуилова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. краљевима 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvni Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("První Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Unang Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Βασιλειων Α' 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Βασιλειων Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Βασιλειων Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Βασιλειων Α΄ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Βασιλειων Α’ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Βασιλειών Α' 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Βασιλειών Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Βασιλειών Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Βασιλειών Α΄ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Βασιλειών Α’ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перша Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перша Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перша Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перша Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перше Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перше Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перше Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Перше Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Първа Самуил 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("صموئيل الأول 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("पहिले शमुवेल 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuu'eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuu’eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Shamooael 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Самуилова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 краљевима 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а. Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а. Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а. Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а. Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е Самуила 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е. Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е. Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е. Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е. Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е. Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ше Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-я Самуила 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-я. Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Regnorum 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Sa-mu-ên 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelin 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelis 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuelit 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. samuelko 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. samūelko 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. šamuelko 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. šamūelko 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. ଶାମୁୟେଲଙ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1.o. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1.º. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1er. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ere Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1re. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1°. Samuele 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ère Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1е. Самуила 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1я. Самуила 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Elso Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Elso Sámuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Első Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Első Sámuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuelova 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuelowa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuu'eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuu’eel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Самуилова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Самуілова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Самуїлова 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I краљевима 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Regnorum 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Sa-mu-ên 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuelin 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuelis 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Прва Самуил 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Прво Самуил 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("اوّل سموئيل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("اوّل سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("اوّل-سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("اوّل۔سموایل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ﺻﻤﻮﺋﻴﻞ ﺍﻷﻭﻝ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Regnorum 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Sa-mu-ên 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelin 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelis 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuelit 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 samuelko 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 samūelko 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 šamuelko 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 šamūelko 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ଶାମୁୟେଲଙ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 சாமுவேல் 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-а Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-е Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-я Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuele 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samueli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samweli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Самуила 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Царства 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. शमूएलको 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. ଶାମୁୟେଲ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. ซามูเอล 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1.o Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1.º Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1a. Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1a. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1e. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1e. Samuël 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1er Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1o. Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1o. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1re Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1° Samuele 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1º. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1е Самуила 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1е. Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1я Самуила 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1я. Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Eerste Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Første Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Kingdoms 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Regnorum 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Sa-mu-ên 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuelin 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuelis 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuele 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samueli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samweli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Царства 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Kwanza Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuelis I 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Una Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α' Σαμουήλ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α' Σαμουηλ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Αʹ Σαμουήλ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Αʹ Σαμουηλ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Αʹ Σαμουήλ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Αʹ Σαμουηλ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α΄ Σαμουήλ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α΄ Σαμουηλ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α’ Σαμουήλ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α’ Σαμουηλ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Първа Царе 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Camuvel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Camuvēl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Cāmuvel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Cāmuvēl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuele 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samueli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samweli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 samuwel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 samūʾīl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ŝamuwel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Самуила 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Царства 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 शमूएलको 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ଶାମୁୟେଲ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 அரசுகள் 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ซามูเอล 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuël 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samyel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Samyèl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Sámuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Самуил 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. سموئيل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. शामुएल 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1.-سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1.۔سموایل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1a Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1a Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1e Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1e Samuël 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1o Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1o Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1º Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1е Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1я Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Regilor 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuele 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samueli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samweli 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Царства 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuël 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samyel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Samyèl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Sámuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Самуил 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvni Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("První Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samueli I 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuël 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samyel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Samyèl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Sámuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 samūel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Самуил 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Царств 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 سموئيل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 صموئيل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 शमुवेल 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 शामुएल 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. शमूएल 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1۔سموایل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Elso Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Elso Sám 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Első Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Első Sám 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("First Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Reinos 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuil 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuël 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samuïl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samyel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Samyèl 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Sámuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Самуил 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Самуіл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Самуїл 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuel I 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Sámuel I 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("שמואל א' 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("שמואל א’ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("۱ سموئيل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("۱ سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("۱-سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("۱۔سموایل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 शमूएल 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ਸਮੂਏਲ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Царе 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1e. Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st. Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Царе 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Prvni S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("První S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuall 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuals 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuell 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuels 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("שמואל א 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒慕爾紀上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒母耳記上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒母耳记上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("사무엘기 상권 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Царе 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 சாமு 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Sám 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. शमू 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. ซมอ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1e Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1st Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Царе 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Sám 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samual 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Samuel 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α' Σαμ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Αʹ Σαμ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Αʹ Σαμ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α΄ Σαμ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α’ Σαμ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒慕爾紀上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒母耳記上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒母耳记上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("サムエル 1 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("サムエル前書 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("サムエル記上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("列王記第一巻 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒慕爾紀上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒母耳記上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒母耳记上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Sám 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Сам 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Цар 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 शमू 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ซมอ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Sma 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Sám 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("サムエル上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒慕爾紀上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒母耳記上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒母耳记上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("사무엘 상 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("사무엘기상 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 صم 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1Sam 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Sa 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I Sm 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("사무엘상 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ц 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1사무 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("삼상 1:1").osis()).toEqual("1Sam.1.1")
		p.include_apocrypha(false)
		expect(p.parse("KITABU CHA KWANZA CHA SAMUELI 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("சாமுவேலின் முதலாம் புத்தகம் 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ENSIMMAINEN SAMUELIN KIRJA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ENSIMMÄINEN SAMUELIN KIRJA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZA KSIEGA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZA KSIEGI SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZA KSIĘGA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZA KSIĘGI SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZE KSIEGA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZE KSIEGI SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZE KSIĘGA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZE KSIĘGI SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZY KSIEGA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZY KSIEGI SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZY KSIĘGA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZY KSIĘGI SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FØRSTE KONGERIGERNES BOG 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZA KSIEGA SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZA KSIEGI SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZA KSIĘGA SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZA KSIĘGI SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZE KSIEGA SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZE KSIEGI SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZE KSIĘGA SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZE KSIĘGI SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZY KSIEGA SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZY KSIEGI SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZY KSIĘGA SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZY KSIĘGI SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ଶାମୁୟେଲଙ୍କ ପ୍ରଥମ ପୁସ୍ତକ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("CARTEA INTAI A REGILOR 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("CARTEA INTÂI A REGILOR 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("CARTEA ÎNTAI A REGILOR 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("CARTEA ÎNTÂI A REGILOR 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZA KS. SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZE KS. SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZY KS. SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMŪEL DĪ PAHILĪ POTʰĪ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ШЕ. КНИГА САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ШЕ. КНИГА САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("CARTEA I A LUI SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZA KS SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZE KS SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZY KS SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVA SAMUELOVA KNJIGA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVA KNJIGA O SAMUELU 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVNI KNIHA SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVNÍ KNIHA SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПЕРША КНИГА САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПЕРША КНИГА САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПЕРШЕ КНИГА САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПЕРШЕ КНИГА САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПЪРВА КНИГА НА ЦАРЕТЕ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПЪРВА КНИГА НА САМУИЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-А. КНИГА САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-А. КНИГА САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Е. КНИГА САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Е. КНИГА САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ШЕ КНИГА САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ШЕ КНИГА САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KONGERIGERNES BOG 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ENSIMMAINEN SAMUELIN 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ENSIMMÄINEN SAMUELIN 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZA KS. SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZE KS. SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZY KS. SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PREMYE LIV SAMYEL LA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PREMYE LIV SAMYÈL LA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVA KNIHA SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVÁ KNIHA SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПРВА КНИГА САМОИЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПРВО КНИГА САМОИЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("शमूएलको पहिलो पुस्तक 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KONGERIGERNES BOG 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-А КНИГА САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-А КНИГА САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Е КНИГА САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Е КНИГА САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KSIEGA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KSIEGI SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KSIĘGA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KSIĘGI SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FORSTA SAMUELSBOKEN 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FÖRSTA SAMUELSBOKEN 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KSIEGA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KSIEGI SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KSIĘGA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KSIĘGI SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZA KS SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZE KS SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZY KS SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVY LIST SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVÝ LIST SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПЪРВА КНИГА ЦАРСТВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("शमुऐल की 1ली पुस्तक 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("शमुऐल की १ली पुस्तक 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ਸਮੂਏਲ ਦੀ ਪਹਿਲੀ ਪੋਥੀ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KSIEGA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KSIEGI SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KSIĘGA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KSIĘGI SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KNIHA SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. КНИГА НА ЦАРЕТЕ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. КНИГА САМОИЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. КНИГА САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. КНИГА САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("CARTEA I A REGILOR 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KSIEGA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KSIEGI SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KSIĘGA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KSIĘGI SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KNIHA SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. КНИГА НА ЦАРЕТЕ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. КНИГА САМОИЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. КНИГА САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. КНИГА САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZA SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZE SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PIERWSZY SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΣΑΜΟΥΉΛ Α' 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΣΑΜΟΥΉΛ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΣΑΜΟΥΉΛ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΣΑΜΟΥΉΛ Α΄ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΣΑΜΟΥΉΛ Α’ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΣΑΜΟΥΗΛ Α' 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΣΑΜΟΥΗΛ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΣΑΜΟΥΗΛ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΣΑΜΟΥΗΛ Α΄ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΣΑΜΟΥΗΛ Α’ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΣΑΜΟΥΉΛ Α' 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΣΑΜΟΥΉΛ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΣΑΜΟΥΉΛ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΣΑΜΟΥΉΛ Α΄ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΣΑΜΟΥΉΛ Α’ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΣΑΜΟΥΗΛ Α' 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΣΑΜΟΥΗΛ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΣΑΜΟΥΗΛ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΣΑΜΟΥΗΛ Α΄ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΣΑΜΟΥΗΛ Α’ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KNIHA SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 КНИГА НА ЦАРЕТЕ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 КНИГА САМОИЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 КНИГА САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 КНИГА САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Е. КНИГА ЦАРСТВ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Я. КНИГА ЦАРСТВ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KSIEGA SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KSIEGI SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KSIĘGA SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KSIĘGI SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELIN KIRJA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FØRSTE SAMUELSBOG 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FØRSTE SAMUELSBOK 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KNIHA SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I КНИГА НА ЦАРЕТЕ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I КНИГА САМОИЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I КНИГА САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I КНИГА САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KSIEGA SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KSIEGI SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KSIĘGA SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KSIĘGI SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUELIN KIRJA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KSIEGA SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KSIEGI SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KSIĘGA SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KSIĘGI SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELIN KIRJA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Е КНИГА ЦАРСТВ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Я КНИГА ЦАРСТВ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KS. SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1Е. КНИГА ЦАРСТВ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1Я. КНИГА ЦАРСТВ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FYRRI SAMUELSBOK 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FYRRI SAMUELSBÓK 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FYRRI SAMÚELSBOK 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FYRRI SAMÚELSBÓK 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KSIEGA SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KSIEGI SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KSIĘGA SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KSIĘGI SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUELIN KIRJA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KS. SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("LIBER I SAMUELIS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PREMIERES SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PREMIÈRES SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUU'EEL KOWAAD 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUU’EEL KOWAAD 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("سفر صموئيل الأول 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KS. SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ШЕ. САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ШЕ. САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KS SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELSBOKEN 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. КНИГА ЦАРСТВ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1Е КНИГА ЦАРСТВ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1Я КНИГА ЦАРСТВ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KS. SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KS SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PREMIERE SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PREMIERS SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PREMIÈRE SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRIMEIRA REINOS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRIMEIRA SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRIMEIRO REINOS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRIMEIRO SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVNI SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVNÍ SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUELKO PUSTAK 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMŪELKO PUSTAK 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ŠAMUELKO PUSTAK 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ŠAMŪELKO PUSTAK 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПЕРША САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПЕРША САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПЕРШЕ САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПЕРШЕ САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KS SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELSBOKEN 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 K. SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 КНИГА ЦАРСТВ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-А. САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-А. САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Е. САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Е. САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ШЕ САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ШЕ САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KS. SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST KINGDOMS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FØRSTE SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KS SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KS. SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("KWANZA SAMUELI 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("KWANZA SAMWELI 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PREMIER SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRIMERO SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVA SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVY SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVÁ SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVÝ SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПРВА САМУИЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПРВА КРАЉЕВИМА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ପ୍ରଥମ ଶାମୁୟେଲଙ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KS. SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 E. SAMUELIT 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 I. SAMUELIT 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 K SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-А САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-А САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Е САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Е САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KS SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELSBOG 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELSBOK 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. KINGDOMS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("EERSTE SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("EERSTE SAMUËL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FØRSTE SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KS. SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KS SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PREMYE SAMYEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PREMYE SAMYÈL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRIMA SAMUELE 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRIMER SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRIMO SAMUELE 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПЪРВА ЦАРСТВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("الممالك الأول 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ପ୍ରଥମ ଶାମୁୟେଲ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KS SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELSBOG 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELSBOK 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 E SAMUELIT 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 I SAMUELIT 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Е. САМУИЛА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ШЕ. SAMUIL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ШЕ. SAMUÏL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ШЕ. САМУІЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ШЕ. САМУЇЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Я. САМУИЛА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUU'EEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUU’EEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SHAMOOAEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. САМУИЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. КРАЉЕВИМА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ERE. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST KINGDOMS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ÈRE. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ERSTE SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KS SAMUELA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUU'EEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUU’EEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. САМУИЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. КРАЉЕВИМА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVNI SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVNÍ SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("UNANG SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΩΝ Α' 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΩΝ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΩΝ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΩΝ Α΄ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΩΝ Α’ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΏΝ Α' 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΏΝ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΏΝ Αʹ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΏΝ Α΄ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ΒΑΣΙΛΕΙΏΝ Α’ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПЕРША SAMUIL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПЕРША SAMUÏL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПЕРША САМУІЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПЕРША САМУЇЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПЕРШЕ SAMUIL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПЕРШЕ SAMUÏL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПЕРШЕ САМУІЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПЕРШЕ САМУЇЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПЪРВА САМУИЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("صموئيل الأول 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("पहिले शमुवेल 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUU'EEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUU’EEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SHAMOOAEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 САМУИЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 КРАЉЕВИМА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-А. SAMUIL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-А. SAMUÏL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-А. САМУІЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-А. САМУЇЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Е САМУИЛА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Е. SAMUIL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Е. SAMUÏL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Е. САМУІЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Е. САМУЇЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Е. ЦАРСТВ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ШЕ SAMUIL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ШЕ SAMUÏL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ШЕ САМУІЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-ШЕ САМУЇЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Я САМУИЛА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Я. ЦАРСТВ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. KINGDOMS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. REGNORUM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SA-MU-ÊN 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELIN 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELIS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELIT 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELKO 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMŪELKO 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. ŠAMUELKO 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. ŠAMŪELKO 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. ଶାମୁୟେଲଙ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1.O. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1.º. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ER. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ERE SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1RE. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1°. SAMUELE 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ÈRE SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1Е. САМУИЛА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1Я. САМУИЛА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ELSO SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ELSO SÁMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ELSŐ SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ELSŐ SÁMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUELOVA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUELOWA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUU'EEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUU’EEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I САМУИЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I САМУІЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I САМУЇЛОВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I КРАЉЕВИМА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. KINGDOMS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. REGNORUM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SA-MU-ÊN 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUELIN 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUELIS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПРВА САМУИЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПРВО САМУИЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("اوّل سموئيل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("اوّل سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("اوّل-سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("اوّل۔سموایل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ﺻﻤﻮﺋﻴﻞ ﺍﻷﻭﻝ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 KINGDOMS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 REGNORUM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SA-MU-ÊN 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELIN 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELIS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELIT 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELKO 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMŪELKO 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ŠAMUELKO 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ŠAMŪELKO 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ଶାମୁୟେଲଙ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 சாமுவேல் 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-А SAMUIL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-А SAMUÏL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-А САМУІЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-А САМУЇЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Е SAMUIL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Е SAMUÏL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Е САМУІЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Е САМУЇЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Е ЦАРСТВ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-Я ЦАРСТВ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. REGILOR 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELE 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELI 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMWELI 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. САМУИЛА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. ЦАРСТВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. शमूएलको 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. ଶାମୁୟେଲ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. ซามูเอล 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1.O SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1.º SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1A. REINOS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1A. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1E. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1E. SAMUËL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ER SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1O. REINOS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1O. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1RE SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1° SAMUELE 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1º. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1Е САМУИЛА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1Е. ЦАРСТВ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1Я САМУИЛА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1Я. ЦАРСТВ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("EERSTE SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FØRSTE SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I KINGDOMS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I REGNORUM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SA-MU-ÊN 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUELIN 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUELIS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. REGILOR 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUELE 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUELI 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMWELI 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. ЦАРСТВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("KWANZA SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUELIS I 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("UNA SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α' ΣΑΜΟΥΉΛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α' ΣΑΜΟΥΗΛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Αʹ ΣΑΜΟΥΉΛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Αʹ ΣΑΜΟΥΗΛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Αʹ ΣΑΜΟΥΉΛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Αʹ ΣΑΜΟΥΗΛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α΄ ΣΑΜΟΥΉΛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α΄ ΣΑΜΟΥΗΛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α’ ΣΑΜΟΥΉΛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α’ ΣΑΜΟΥΗΛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ПЪРВА ЦАРЕ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 CAMUVEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 CAMUVĒL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 CĀMUVEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 CĀMUVĒL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 REGILOR 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELE 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELI 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMWELI 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUWEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMŪʾĪL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ŜAMUWEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 САМУИЛА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ЦАРСТВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 शमूएलको 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ଶାମୁୟେଲ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 அரசுகள் 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ซามูเอล 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. REINOS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUIL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUËL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMUÏL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMYEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAMYÈL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SÁMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. САМУИЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. САМУІЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. САМУЇЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. ЦАРСТВ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. سموئيل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. शामुएल 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1.-سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1.۔سموایل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1A REINOS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1A SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1E SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1E SAMUËL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1O REINOS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1O SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1º SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1Е ЦАРСТВ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1Я ЦАРСТВ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SMA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I REGILOR 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUELE 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUELI 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMWELI 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I ЦАРСТВА 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. REINOS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUIL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUËL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMUÏL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMYEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAMYÈL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SÁMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. САМУИЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. САМУІЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. САМУЇЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVNI SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVNÍ SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUELI I 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 REINOS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUIL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUËL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMUÏL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMYEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMYÈL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SÁMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAMŪEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 САМУИЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 САМУІЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 САМУЇЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ЦАРСТВ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 سموئيل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 صموئيل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 शमुवेल 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 शामुएल 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1-سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. शमूएल 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SMA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1۔سموایل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ELSO SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ELSO SÁM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ELSŐ SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("ELSŐ SÁM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("FIRST SM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I REINOS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUIL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUËL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMUÏL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMYEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAMYÈL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SÁMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I САМУИЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I САМУІЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I САМУЇЛ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUEL I 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SÁMUEL I 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("שמואל א' 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("שמואל א’ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("۱ سموئيل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("۱ سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("۱-سموئیل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("۱۔سموایل 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 शमूएल 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ਸਮੂਏਲ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. ЦАРЕ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1E. SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SMA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST. SM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. ЦАРЕ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVNI S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("PRVNÍ S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUALL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUALS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUELL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUELS 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("שמואל א 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒慕爾紀上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒母耳記上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒母耳记上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("사무엘기 상권 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ЦАРЕ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 சாமு 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SMA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SÁM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. शमू 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. ซมอ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1E SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1ST SM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I ЦАРЕ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SMA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SÁM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUAL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("SAMUEL 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α' ΣΑΜ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Αʹ ΣΑΜ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Αʹ ΣΑΜ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α΄ ΣΑΜ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("Α’ ΣΑΜ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒慕爾紀上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒母耳記上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒母耳记上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("サムエル 1 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("サムエル前書 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("サムエル記上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("列王記第一巻 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒慕爾紀上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒母耳記上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒母耳记上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SMA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SÁM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 САМ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ЦАР 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 शमू 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 ซมอ 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. SM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SMA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SÁM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. SM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("サムエル上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒慕爾紀上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒母耳記上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒母耳记上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("사무엘 상 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("사무엘기상 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 SM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 صم 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1. S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1SAM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SA 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I SM 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I. S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("사무엘상 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1 Ц 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("1사무 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("I S 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("《撒上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒上》 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("撒上 1:1").osis()).toEqual("1Sam.1.1")
		expect(p.parse("삼상 1:1").osis()).toEqual("1Sam.1.1")
		`
		true
describe "Localized book 2Chr (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Chr (full)", ->
		`
		expect(p.parse("நாளாகமத்தின் இரண்டாம் புத்தகம் 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("или Втора книга Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Cartea a doua Paralipomena 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha kniha Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá kniha Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Втора Книга на летописите 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Втора книга Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Втора книга на летописите 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy list Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý list Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Книга на летописите 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("سفر أخبار الأيام الثاني 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ବଂଶାବଳୀର ଦ୍ୱିତୀୟ ପୁସ୍ତକ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Книга на летописите 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga knjiga Ljetopisa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Книга на летописите 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Ikalawang Paralipomeno 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Liber II Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("इतिहासको दोस्रो पुस्तक 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Книга на летописите 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Ikalawang Mga Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Ikalawang Mga Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Pili Mambo ya Nyakati 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Deuxiemes Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Deuxièmes Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Dezyem liv Kwonik la 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Dezyèm liv Kwonik la 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha kniha Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha kniha Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá kniha Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá kniha Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Mambo ya Nyakati 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("itahās dī dūjī potʰī 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Втора книга летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Второ книга летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друга Паралипоменону 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге. книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Mambo ya Nyakati 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Deuxieme Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Deuxième Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga Ksiega Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga Ksiegi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga Księga Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga Księgi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Drugi Ksiega Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Drugi Ksiegi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Drugi Księga Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Drugi Księgi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy list Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy list Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý list Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý list Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Mambo ya Nyakati 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Ikalawang Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Mambo ya Nyakati II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικος Χρονικων Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικος Χρονικων Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικος Χρονικων Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικος Χρονικων Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικος Χρονικων Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικος Χρονικών Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικος Χρονικών Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικος Χρονικών Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικος Χρονικών Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικος Χρονικών Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικός Χρονικων Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικός Χρονικων Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικός Χρονικων Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικός Χρονικων Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικός Χρονικων Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικός Χρονικών Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικός Χρονικών Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικός Χρονικών Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικός Χρονικών Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικός Χρονικών Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друга книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друге книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("أخبار الأيام الثاني 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Mambo ya Nyakati 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k. Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а. книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге. книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е. Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е. книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-я. Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Andra Kronikeboken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Andra Krönikeboken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha kniha Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha kniha Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha kniha kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy kniha kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá kniha Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá kniha Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá kniha kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý kniha kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Паралипоменону 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. книга летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Ikalawang Kronikel 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Taariikhdii Labaad 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друга книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друге книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ਇਤਹਾਸ ਦੀ ਦੂਜੀ ਪੋਥੀ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а. книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е. книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-я Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Паралипоменону 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. книга летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2е. Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2я. Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy list Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy list Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý list Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý list Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Паралипоменону 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II книга летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Ksiega Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Ksiegi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Księga Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Księgi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Ikalawang Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Ikalawang Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Siðari Kronikubok 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Siðari Kronikubók 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Siðari Kroníkubok 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Siðari Kroníkubók 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Síðari Kronikubok 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Síðari Kronikubók 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Síðari Kroníkubok 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Síðari Kroníkubók 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Síðari kroníkubók 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Παραλειπομένων Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Παραλειπομένων Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Παραλειπομένων Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Παραλειπομένων Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Παραλειπομένων Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Παραλειπομενων Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Παραλειπομενων Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Παραλειπομενων Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Παραλειπομενων Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Παραλειπομενων Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ﺃﺧﺒﺎﺭ ﺍﻷﻳﺎﻡ ﺍﻟﺜﺎﻥ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Паралипоменону 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 книга летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Ksiega Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Ksiegi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Księga Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Księgi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2eme. Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ème. Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2е Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2я Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Anden Krønikebog 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Andre Krønikebok 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga Ks. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Drugi Ks. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Ksiega Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Ksiegi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Księga Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Księgi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Paralipomena 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Paralipomeno 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Sử biên niên 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. kniha kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Paralipomenon II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Seconda Cronache 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Secondo Cronache 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Segunda Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Segunda Crônicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Segundo Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Segundo Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Segundo Crônicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Toinen Aikakirja 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Tweede Kronieken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ବଂଶାବଳୀର 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ksiega Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ksiegi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Księga Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Księgi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronikeboken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Krönikeboken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Paralipomena 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Paralipomeno 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Sử biên niên 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. kniha kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2de. Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2eme Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ème Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga Ks Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga Ljetopisa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Drugi Ks Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Paralipomena 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Paralipomeno 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Sử biên niên 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II kniha kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Mga Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Mga Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Taariikhdii 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Masodik Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Masodik Krónika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Második Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Második Krónika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ବଂଶାବଳୀ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronikeboken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Krönikeboken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Paralipomena 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Paralipomeno 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Sử biên niên 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 e. Kronikave 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 i. Kronikave 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 kniha kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге. Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Mga Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Mga Cronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Mga Kronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Mga Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Taariikhdii 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2d. Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2de Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2e. Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha Letopisu 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha Letopisů 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy Letopisu 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy Letopisů 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá Letopisu 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá Letopisů 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý Letopisu 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý Letopisů 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Mga Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Mga Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Taariikhdii 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronicilor 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Ks. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Zweite Chronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Втора Летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Второ Летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друга Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друга дневника 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друге Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("इतिहास 2रा भाग 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("इतिहास २रा भाग 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Mga Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Mga Cronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Mga Kronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Mga Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Taariikhdii 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 e Kronikave 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 i Kronikave 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k. Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k. Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а. Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге. Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге. Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге. Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге. хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е. Летопись 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е. Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-я. Летопись 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronicilor 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Krønikebog 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Krønikebok 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Ks. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.o. Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.o. Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.º. Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.º. Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2d Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2e Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2e. Kronieken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Dezyem Kwonik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Dezyèm Kwonik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronicilor 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Ks. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Aikakirja 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kronieken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Ks Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Ljetopisa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друга Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друга Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друга Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друга хроника 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друге Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друге Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друге Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друге хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("דברי הימים ב' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("דברי הימים ב’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronicilor 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Krønikebog 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Krønikebok 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ks. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 e. Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 i. Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 குறிப்பேடு 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а. Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а. Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а. Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а. хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге. Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е Летопись 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е. Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е. Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е. Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е. хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-я Летопись 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Aikakirja 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronieken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronikave 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Ks Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Ljetopisa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.o Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.o Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.º Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.º Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2a. Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2a. Crônicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2e Kronieken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2o. Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2o. Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2o. Crônicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2°. Cronache 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2º. Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2º. Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2е. Летопись 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2я. Летопись 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Dezyem Istwa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Dezyèm Istwa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Drugi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Aikakirja 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kronieken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Ks Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Ljetopisa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronache 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Crônicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kronikel 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Letopisu 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Letopisů 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. дневника 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Masodik Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Masodik Krón 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Második Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Második Krón 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друга Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друге Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("דברי הימים ב 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("دوم- توارِیخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("दुसरे इतिहास 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Aikakirja 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronieken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronikave 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ks Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ljetopisa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Nalakamam 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Nalākamam 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Naḷakamam 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Naḷākamam 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Nālakamam 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Nālākamam 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Nāḷakamam 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Nāḷākamam 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 e Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 i Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k. Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а. Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е. Хроник 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е. Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-я. Хроник 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronache 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Crônicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronikel 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Letopisu 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Letopisů 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. itihasko 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. itihāsko 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Летопись 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. дневника 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. इतिहासको 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ବଂଶାବଳୀର 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. พงศาวดาร 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.- توارِیخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2a Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2a Crônicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2o Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2o Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2o Crônicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2° Cronache 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2º Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2º Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2е Летопись 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2я Летопись 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronache 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Crônicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kronikel 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Letopisu 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Letopisů 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II дневника 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronici 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronicl 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Krónika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Lịch sử 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. хроника 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Kronikak II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Kronikák II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Krónikak II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Krónikák II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Tweede Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β' Χρονικων 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β' Χρονικών 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Χρονικων 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Χρονικών 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Χρονικων 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Χρονικών 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β΄ Χρονικων 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β΄ Χρονικών 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β’ Χρονικων 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β’ Χρονικών 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Χρονικων Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Χρονικων Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Χρονικων Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Χρονικων Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Χρονικων Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Χρονικών Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Χρονικών Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Χρονικών Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Χρονικών Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Χρονικών Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("دوم تو اریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronache 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Crônicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronikel 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Letopisu 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Letopisů 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 itihasko 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 itihāsko 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Дневника 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Летопись 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 дневника 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 इतिहासको 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ବଂଶାବଳୀର 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 நாளாகமம் 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 พงศาวดาร 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2- توارِیخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е Хроник 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-я Хроник 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronici 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronicl 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Krónika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Lịch sử 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. хроника 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. تو اریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ବଂଶାବଳୀ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2е. Хроник 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2я. Хроник 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Anden Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Anden Krøn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Andre Krøn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronici 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronicl 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Krónika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Lịch sử 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II хроника 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II.  Sử Ký 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kwonik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("دوم۔تواریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("۲- توارِیخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronici 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronicl 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Krónika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Lịch sử 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 tavārīḫ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 хроника 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 تو اریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ବଂଶାବଳୀ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.  Sử Ký 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Itihas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kwonik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Хроник 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. इतिहास 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.۔تواریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2е Хроник 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2я Хроник 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Andre Krø 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II  Sử Ký 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kwonik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Babad 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Istwa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Sử ký 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Втора Лет 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("الأخبار 2 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("۲ تو اریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2  Sử Ký 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Itihas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kwonik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 itahās 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 itihas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 itihās 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Хроник 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 इतिहास 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Babad 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Istwa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Sử ký 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2e. Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2۔تواریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha Pa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy Pa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá Pa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý Pa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Babad 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Istwa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Sử ký 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Krón 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Taar 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Pili Nya 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("۲۔تواریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Aikak 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Babad 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Istwa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Sử ký 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ਇਤਹਾਸ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Krón 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Krøn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Taar 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2e Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Krón 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Taar 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Nya 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Par 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Лет 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β' Χρον 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Χρον 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Χρον 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β΄ Χρον 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β’ Χρον 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Crón 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Crôn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Krón 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Krön 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Krøn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ljet 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Taar 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 хрон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 குறி 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 நாளா 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Krø 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Nya 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Par 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Лет 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. इति 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. พศด 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Nya 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Par 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Лет 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Pa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Sử 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β' Παρ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Παρ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Παρ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β΄ Παρ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β’ Παρ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《历代志下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《歷代志下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《編年紀下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("역대기 하권 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Aik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cró 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Crô 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ist 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Krn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Krø 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Nya 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Par 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Лет 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Пар 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 इति 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 พศด 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Pa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Sử 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Pa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Sử 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β' Πα 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β' Χρ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Πα 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Χρ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Πα 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Χρ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β΄ Πα 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β΄ Χρ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β’ Πα 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β’ Χρ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《历代志下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《歷代志下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《編年紀下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("历代志下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歴代志略下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歴代誌 2 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歷代志下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("編年紀下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("역대기 하 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ch 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Pa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Sử 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Дн 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Хр 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 أخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《代下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("历代志下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歴代史下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歴代志下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歴代誌下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歷代志下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("編年紀下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("역대지하 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2역대 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《代下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("代下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("역대하 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("代下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歴下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("대하 1:1").osis()).toEqual("2Chr.1.1")
		`
		true
	it "should handle non-Latin digits in book: 2Chr (full)", ->
		p.set_options non_latin_digits_strategy: "replace"
		`
		expect(p.parse("நாளாகமத்தின் இரண்டாம் புத்தகம் 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("или Втора книга Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Cartea a doua Paralipomena 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha kniha Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá kniha Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Втора Книга на летописите 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Втора книга Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Втора книга на летописите 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy list Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý list Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Книга на летописите 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("سفر أخبار الأيام الثاني 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ବଂଶାବଳୀର ଦ୍ୱିତୀୟ ପୁସ୍ତକ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Книга на летописите 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga knjiga Ljetopisa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Книга на летописите 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Ikalawang Paralipomeno 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Liber II Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("इतिहासको दोस्रो पुस्तक 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Книга на летописите 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Ikalawang Mga Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Ikalawang Mga Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Pili Mambo ya Nyakati 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Deuxiemes Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Deuxièmes Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Dezyem liv Kwonik la 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Dezyèm liv Kwonik la 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha kniha Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha kniha Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá kniha Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá kniha Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Mambo ya Nyakati 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("itahās dī dūjī potʰī 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Втора книга летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Второ книга летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друга Паралипоменону 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге. книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Mambo ya Nyakati 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Deuxieme Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Deuxième Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga Ksiega Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga Ksiegi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga Księga Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga Księgi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Drugi Ksiega Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Drugi Ksiegi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Drugi Księga Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Drugi Księgi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy list Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy list Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý list Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý list Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Mambo ya Nyakati 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Ikalawang Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Mambo ya Nyakati II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικος Χρονικων Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικος Χρονικων Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικος Χρονικων Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικος Χρονικων Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικος Χρονικων Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικος Χρονικών Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικος Χρονικών Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικος Χρονικών Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικος Χρονικών Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικος Χρονικών Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικός Χρονικων Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικός Χρονικων Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικός Χρονικων Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικός Χρονικων Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικός Χρονικων Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικός Χρονικών Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικός Χρονικών Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικός Χρονικών Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικός Χρονικών Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("δυτικός Χρονικών Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друга книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друге книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("أخبار الأيام الثاني 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Mambo ya Nyakati 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k. Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а. книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге. книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е. Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е. книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-я. Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Andra Kronikeboken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Andra Krönikeboken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha kniha Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha kniha Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha kniha kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy kniha kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá kniha Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá kniha Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá kniha kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý kniha kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Паралипоменону 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. книга летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Ikalawang Kronikel 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Taariikhdii Labaad 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друга книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друге книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ਇਤਹਾਸ ਦੀ ਦੂਜੀ ਪੋਥੀ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а. книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е. книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-я Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Паралипоменону 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. книга летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2е. Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2я. Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy list Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy list Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý list Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý list Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Паралипоменону 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II книга летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Ksiega Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Ksiegi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Księga Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Księgi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Ikalawang Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Ikalawang Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Siðari Kronikubok 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Siðari Kronikubók 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Siðari Kroníkubok 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Siðari Kroníkubók 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Síðari Kronikubok 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Síðari Kronikubók 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Síðari Kroníkubok 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Síðari Kroníkubók 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Síðari kroníkubók 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Παραλειπομένων Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Παραλειπομένων Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Παραλειπομένων Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Παραλειπομένων Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Παραλειπομένων Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Παραλειπομενων Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Παραλειπομενων Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Παραλειπομενων Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Παραλειπομενων Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Παραλειπομενων Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ﺃﺧﺒﺎﺭ ﺍﻷﻳﺎﻡ ﺍﻟﺜﺎﻥ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Паралипоменону 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 книга летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Ksiega Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Ksiegi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Księga Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Księgi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2eme. Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ème. Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2е Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2я Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Anden Krønikebog 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Andre Krønikebok 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga Ks. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Drugi Ks. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Ksiega Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Ksiegi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Księga Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Księgi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Paralipomena 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Paralipomeno 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Sử biên niên 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. kniha kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Paralipomenon II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Seconda Cronache 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Secondo Cronache 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Segunda Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Segunda Crônicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Segundo Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Segundo Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Segundo Crônicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Toinen Aikakirja 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Tweede Kronieken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ବଂଶାବଳୀର 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ksiega Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ksiegi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Księga Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Księgi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Paralipomenon 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Паралипоменон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 книга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronikeboken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Krönikeboken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Paralipomena 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Paralipomeno 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Sử biên niên 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. kniha kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2de. Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2eme Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ème Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga Ks Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga Ljetopisa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Drugi Ks Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Paralipomena 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Paralipomeno 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Sử biên niên 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II kniha kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Mga Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Mga Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Taariikhdii 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Masodik Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Masodik Krónika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Második Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Második Krónika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ବଂଶାବଳୀ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronikeboken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Krönikeboken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Paralipomena 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Paralipomeno 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Sử biên niên 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 e. Kronikave 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 i. Kronikave 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 kniha kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 книга хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге. Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Mga Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Mga Cronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Mga Kronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Mga Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Taariikhdii 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2d. Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2de Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2e. Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha Letopisu 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha Letopisů 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy Letopisu 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy Letopisů 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá Letopisu 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá Letopisů 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý Letopisu 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý Letopisů 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Mga Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Mga Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Taariikhdii 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronicilor 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Ks. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Zweite Chronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Втора Летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Второ Летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друга Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друга дневника 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друге Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("इतिहास 2रा भाग 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("इतिहास २रा भाग 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Choronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Choronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Mga Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Mga Cronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Mga Kronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Mga Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Taariikhdii 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 e Kronikave 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 i Kronikave 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k. Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k. Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а. Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге. Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге. Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге. Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге. хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е. Летопись 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е. Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-я. Летопись 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronicilor 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Krønikebog 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Krønikebok 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Ks. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.o. Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.o. Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.º. Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.º. Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2d Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2e Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2e. Kronieken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Dezyem Kwonik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Dezyèm Kwonik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronicilor 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Ks. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Aikakirja 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kronieken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Ks Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Ljetopisa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друга Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друга Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друга Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друга хроника 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друга хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друге Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друге Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друге Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друге хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("דברי הימים ב' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("דברי הימים ב’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Choronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Choronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronicals 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chroniques 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Coronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Coronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronicilor 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Krønikebog 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Krønikebok 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ks. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 e. Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 i. Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 குறிப்பேடு 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а. Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а. Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а. Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а. хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге. Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е Летопись 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е. Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е. Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е. Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е. хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-я Летопись 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Aikakirja 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronieken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronikave 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Ks Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Ljetopisa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.o Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.o Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.º Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.º Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2a. Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2a. Crônicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2e Kronieken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2o. Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2o. Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2o. Crônicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2°. Cronache 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2º. Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2º. Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2е. Летопись 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2я. Летопись 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Dezyem Istwa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Dezyèm Istwa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druga Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Drugi Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Aikakirja 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kronieken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Ks Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Ljetopisa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronache 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Crônicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kronikel 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Letopisu 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Letopisů 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. дневника 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Masodik Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Masodik Krón 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Második Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Második Krón 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друга Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Друге Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("דברי הימים ב 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("دوم- توارِیخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("दुसरे इतिहास 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Aikakirja 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Coronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Coronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronicles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronocles 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronieken 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronikave 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ks Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ljetopisa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Nalakamam 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Nalākamam 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Naḷakamam 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Naḷākamam 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Nālakamam 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Nālākamam 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Nāḷakamam 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Nāḷākamam 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 e Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 i Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k. Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а. Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ге Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е. Хроник 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е. Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-я. Хроник 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronache 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Crônicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronikel 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Letopisu 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Letopisů 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. itihasko 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. itihāsko 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Летопись 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. дневника 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. इतिहासको 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ବଂଶାବଳୀର 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. พงศาวดาร 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.- توارِیخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2a Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2a Crônicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2o Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2o Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2o Crônicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2° Cronache 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2º Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2º Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2е Летопись 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2я Летопись 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronache 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Crônicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kronikel 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Letopisu 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Letopisů 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II дневника 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronici 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cronicl 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Krónika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Lịch sử 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. хроника 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Kronikak II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Kronikák II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Krónikak II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Krónikák II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Tweede Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β' Χρονικων 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β' Χρονικών 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Χρονικων 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Χρονικών 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Χρονικων 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Χρονικών 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β΄ Χρονικων 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β΄ Χρονικών 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β’ Χρονικων 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β’ Χρονικών 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Χρονικων Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Χρονικων Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Χρονικων Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Χρονικων Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Χρονικων Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Χρονικών Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Χρονικών Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Χρονικών Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Χρονικών Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Χρονικών Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("دوم تو اریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronache 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronicle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronocle 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Crónicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Crônicas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronicka 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronická 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronikel 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Letopisu 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Letopisů 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 itihasko 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 itihāsko 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 k Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Дневника 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Летописи 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Летопись 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Літопису 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 дневника 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 इतिहासको 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ବଂଶାବଳୀର 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 நாளாகமம் 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 พงศาวดาร 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2- توارِیخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-а Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е Хроник 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-е Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-я Хроник 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronici 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronicl 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Krónika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Lịch sử 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. хроника 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. تو اریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ବଂଶାବଳୀ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2е. Хроник 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2я. Хроник 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Anden Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Anden Krøn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Andre Krøn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronici 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cronicl 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Krónika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Lịch sử 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II хроника 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II.  Sử Ký 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kwonik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Second Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("دوم۔تواریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("۲- توارِیخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronici 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronicl 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Hroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronica 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Krónika 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Lịch sử 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 tavārīḫ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ȟroniky 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Хроніка 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 хроника 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 хроніки 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 تو اریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ବଂଶାବଳୀ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.  Sử Ký 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Itihas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kwonik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Хроник 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. इतिहास 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.۔تواریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2е Хроник 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2я Хроник 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Andre Krø 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II  Sử Ký 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kwonik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Babad 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Istwa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Sử ký 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Втора Лет 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("الأخبار 2 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("۲ تو اریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2  Sử Ký 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Itihas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kronik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kroník 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kwonik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 itahās 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 itihas 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 itihās 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Хроник 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Хронік 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 इतिहास 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Babad 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Istwa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Sử ký 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2e. Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd. Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2۔تواریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druha Pa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhy Pa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhá Pa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Druhý Pa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Babad 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Istwa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Sử ký 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Krón 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Taar 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Pili Nya 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("۲۔تواریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Aikak 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Babad 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Istwa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Sử ký 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ਇਤਹਾਸ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Krón 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Krøn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Taar 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2e Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2nd Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Krón 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Taar 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Kro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Nya 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Par 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Лет 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β' Χρον 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Χρον 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Χρον 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β΄ Χρον 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β’ Χρον 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chrn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Crón 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Crôn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kron 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Krón 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Krön 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Krøn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ljet 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Taar 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 хрон 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 குறி 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 நாளா 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Kro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Krø 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Nya 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Par 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Лет 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. इति 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. พศด 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Kro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Nya 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Par 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Лет 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Pa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. Sử 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β' Παρ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Παρ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Παρ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β΄ Παρ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β’ Παρ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《历代志下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《歷代志下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《編年紀下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("역대기 하권 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Aik 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cró 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Crô 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ist 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Krn 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Kro 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Krø 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Nya 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Par 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Лет 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Пар 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 इति 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 พศด 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Pa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. Sử 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Pa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II Sử 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β' Πα 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β' Χρ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Πα 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Χρ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Πα 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ Χρ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β΄ Πα 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β΄ Χρ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β’ Πα 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β’ Χρ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《历代志下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《歷代志下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《編年紀下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("历代志下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歴代志略下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歴代誌 2 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歷代志下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("編年紀下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("역대기 하 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Ch 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Cr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Pa 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Sử 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Дн 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 Хр 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 أخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2Chr 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《代下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("历代志下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歴代史下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歴代志下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歴代誌下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歷代志下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("編年紀下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("역대지하 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2역대 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《代下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("代下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("역대하 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("代下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歴下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("대하 1:1").osis()).toEqual("2Chr.1.1")
		p.include_apocrypha(false)
		expect(p.parse("நாளாகமத்தின் இரண்டாம் புத்தகம் 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ИЛИ ВТОРА КНИГА ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("CARTEA A DOUA PARALIPOMENA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA KNIHA PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÁ KNIHA PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ВТОРА КНИГА НА ЛЕТОПИСИТЕ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ВТОРА КНИГА ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ВТОРА КНИГА НА ЛЕТОПИСИТЕ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY LIST PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÝ LIST PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. КНИГА НА ЛЕТОПИСИТЕ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("سفر أخبار الأيام الثاني 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ବଂଶାବଳୀର ଦ୍ୱିତୀୟ ପୁସ୍ତକ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. КНИГА НА ЛЕТОПИСИТЕ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGA KNJIGA LJETOPISA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II КНИГА НА ЛЕТОПИСИТЕ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("IKALAWANG PARALIPOMENO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("LIBER II PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("इतिहासको दोस्रो पुस्तक 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 КНИГА НА ЛЕТОПИСИТЕ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("IKALAWANG MGA CRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("IKALAWANG MGA KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("PILI MAMBO YA NYAKATI 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DEUXIEMES CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DEUXIÈMES CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DEZYEM LIV KWONIK LA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DEZYÈM LIV KWONIK LA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA KNIHA KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA KNIHA KRONICKÁ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÁ KNIHA KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÁ KNIHA KRONICKÁ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. MAMBO YA NYAKATI 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ITAHĀS DĪ DŪJĪ POTʰĪ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ВТОРА КНИГА ЛЕТОПИСИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ВТОРО КНИГА ЛЕТОПИСИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ДРУГА ПАРАЛИПОМЕНОНУ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ГЕ. КНИГА ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. MAMBO YA NYAKATI 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DEUXIEME CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DEUXIÈME CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGA KSIEGA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGA KSIEGI KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGA KSIĘGA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGA KSIĘGI KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGI KSIEGA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGI KSIEGI KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGI KSIĘGA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGI KSIĘGI KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY LIST KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY LIST KRONICKÁ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÁ PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÝ PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÝ LIST KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÝ LIST KRONICKÁ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II MAMBO YA NYAKATI 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("IKALAWANG CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("MAMBO YA NYAKATI II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΧΡΟΝΙΚΩΝ Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΧΡΟΝΙΚΩΝ Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΧΡΟΝΙΚΩΝ Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΧΡΟΝΙΚΩΝ Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΧΡΟΝΙΚΩΝ Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΧΡΟΝΙΚΏΝ Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΧΡΟΝΙΚΏΝ Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΧΡΟΝΙΚΏΝ Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΧΡΟΝΙΚΏΝ Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΧΡΟΝΙΚΏΝ Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΧΡΟΝΙΚΩΝ Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΧΡΟΝΙΚΩΝ Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΧΡΟΝΙΚΩΝ Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΧΡΟΝΙΚΩΝ Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΧΡΟΝΙΚΩΝ Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΧΡΟΝΙΚΏΝ Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΧΡΟΝΙΚΏΝ Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΧΡΟΝΙΚΏΝ Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΧΡΟΝΙΚΏΝ Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΧΡΟΝΙΚΏΝ Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ДРУГА КНИГА ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ДРУГЕ КНИГА ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("أخبار الأيام الثاني 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 MAMBO YA NYAKATI 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 K. PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-А. КНИГА ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ГЕ КНИГА ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ГЕ. КНИГА ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Е. ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Е. КНИГА ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Я. ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ANDRA KRONIKEBOKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ANDRA KRÖNIKEBOKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA KNIHA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA KNIHA KRONÍK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA KNIHA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY KNIHA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÁ KNIHA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÁ KNIHA KRONÍK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÁ KNIHA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÝ KNIHA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. ПАРАЛИПОМЕНОНУ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. КНИГА ЛЕТОПИСИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("IKALAWANG KRONIKEL 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("TAARIIKHDII LABAAD 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ДРУГА КНИГА ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ДРУГЕ КНИГА ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ਇਤਹਾਸ ਦੀ ਦੂਜੀ ਪੋਥੀ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 K PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-А КНИГА ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-А. КНИГА ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ГЕ КНИГА ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Е ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Е КНИГА ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Е. КНИГА ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Я ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ПАРАЛИПОМЕНОНУ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. КНИГА ЛЕТОПИСИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2Е. ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2Я. ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY LIST KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY LIST KRONÍK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÝ LIST KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÝ LIST KRONÍK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II ПАРАЛИПОМЕНОНУ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II КНИГА ЛЕТОПИСИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KSIEGA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KSIEGI KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KSIĘGA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KSIĘGI KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. КНИГА ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("IKALAWANG CRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("IKALAWANG KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRONICALS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SIÐARI KRONIKUBOK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SIÐARI KRONIKUBÓK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SIÐARI KRONÍKUBOK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SIÐARI KRONÍKUBÓK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SÍÐARI KRONIKUBOK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SÍÐARI KRONIKUBÓK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SÍÐARI KRONÍKUBOK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SÍÐARI KRONÍKUBÓK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SÍÐARI KRONÍKUBÓK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΠΑΡΑΛΕΙΠΟΜΈΝΩΝ Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΠΑΡΑΛΕΙΠΟΜΈΝΩΝ Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΠΑΡΑΛΕΙΠΟΜΈΝΩΝ Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΠΑΡΑΛΕΙΠΟΜΈΝΩΝ Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΠΑΡΑΛΕΙΠΟΜΈΝΩΝ Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΠΑΡΑΛΕΙΠΟΜΕΝΩΝ Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΠΑΡΑΛΕΙΠΟΜΕΝΩΝ Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΠΑΡΑΛΕΙΠΟΜΕΝΩΝ Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΠΑΡΑΛΕΙΠΟΜΕΝΩΝ Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΠΑΡΑΛΕΙΠΟΜΕΝΩΝ Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ﺃﺧﺒﺎﺭ ﺍﻷﻳﺎﻡ ﺍﻟﺜﺎﻥ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ПАРАЛИПОМЕНОНУ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 КНИГА ЛЕТОПИСИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-А КНИГА ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Е КНИГА ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KSIEGA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KSIEGI KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KSIĘGA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KSIĘGI KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. КНИГА ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2EME. CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ÈME. CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2Е ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2Я ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ANDEN KRØNIKEBOG 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ANDRE KRØNIKEBOK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGA KS. KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGI KS. KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KSIEGA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KSIEGI KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KSIĘGA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KSIĘGI KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II КНИГА ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. PARALIPOMENA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. PARALIPOMENO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. SỬ BIÊN NIÊN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KNIHA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. КНИГА ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("PARALIPOMENON II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECONDA CRONACHE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECONDO CRONACHE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SEGUNDA CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SEGUNDA CRÔNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SEGUNDO CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SEGUNDO CRÓNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SEGUNDO CRÔNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("TOINEN AIKAKIRJA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("TWEEDE KRONIEKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ବଂଶାବଳୀର 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KSIEGA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KSIEGI KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KSIĘGA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KSIĘGI KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 PARALIPOMENON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 КНИГА ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRONIKEBOKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRÖNIKEBOKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. PARALIPOMENA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. PARALIPOMENO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. SỬ BIÊN NIÊN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KNIHA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. КНИГА ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2DE. CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2EME CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRONICALS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ÈME CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGA KS KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGA LJETOPISA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGI KS KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II PARALIPOMENA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II PARALIPOMENO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II SỬ BIÊN NIÊN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KNIHA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II КНИГА ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. MGA CRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. MGA KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. TAARIIKHDII 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("MASODIK KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("MASODIK KRÓNIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("MÁSODIK KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("MÁSODIK KRÓNIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ବଂଶାବଳୀ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRONIKEBOKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRÖNIKEBOKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 PARALIPOMENA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 PARALIPOMENO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 SỬ BIÊN NIÊN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 E. KRONIKAVE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 I. KRONIKAVE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KNIHA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 КНИГА ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ГЕ. ЛІТОПИСУ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. MGA CRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. MGA CRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. MGA KRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. MGA KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. TAARIIKHDII 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2D. CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2DE CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2E. CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRONICALS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA KRONICKÁ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA LETOPISU 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA LETOPISŮ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY KRONICKÁ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY LETOPISU 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY LETOPISŮ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÁ KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÁ KRONICKÁ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÁ LETOPISU 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÁ LETOPISŮ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÝ KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÝ KRONICKÁ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÝ LETOPISU 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÝ LETOPISŮ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II MGA CRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II MGA KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II TAARIIKHDII 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRONICALS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONICILOR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KS. KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ZWEITE CHRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ВТОРА ЛЕТОПИСИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ВТОРО ЛЕТОПИСИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ДРУГА ЛІТОПИСУ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ДРУГА ДНЕВНИКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ДРУГЕ ЛІТОПИСУ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("इतिहास 2रा भाग 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("इतिहास २रा भाग 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 MGA CRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 MGA CRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 MGA KRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 MGA KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 TAARIIKHDII 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 E KRONIKAVE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 I KRONIKAVE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 K. KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 K. KRONICKÁ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-А. ЛІТОПИСУ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ГЕ ЛІТОПИСУ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ГЕ. HRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ГЕ. ȞRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ГЕ. ХРОНІКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ГЕ. ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Е. ЛЕТОПИСЬ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Е. ЛІТОПИСУ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Я. ЛЕТОПИСЬ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRONICALS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONICILOR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRØNIKEBOG 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRØNIKEBOK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KS. KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.O. CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.O. CRÓNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.º. CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.º. CRÓNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2D CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2E CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2E. KRONIEKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DEZYEM KWONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DEZYÈM KWONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRONICALS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONICILOR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KS. KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. AIKAKIRJA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KRONIEKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KS KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. LJETOPISA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ДРУГА HRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ДРУГА ȞRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ДРУГА ХРОНІКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ДРУГА ХРОНИКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ДРУГА ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ДРУГЕ HRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ДРУГЕ ȞRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ДРУГЕ ХРОНІКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ДРУГЕ ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("דברי הימים ב' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("דברי הימים ב’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRONICALS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRONIQUES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CORONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CORONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONICILOR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRØNIKEBOG 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRØNIKEBOK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KS. KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 E. KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 I. KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 K KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 K KRONICKÁ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 குறிப்பேடு 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-А ЛІТОПИСУ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-А. HRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-А. ȞRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-А. ХРОНІКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-А. ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ГЕ HRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ГЕ ȞRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ГЕ ХРОНІКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ГЕ ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ГЕ. ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Е ЛЕТОПИСЬ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Е ЛІТОПИСУ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Е. HRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Е. ȞRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Е. ХРОНІКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Е. ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Я ЛЕТОПИСЬ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. AIKAKIRJA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRONIEKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRONIKAVE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KS KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. LJETOPISA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.O CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.O CRÓNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.º CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.º CRÓNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2A. CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2A. CRÔNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2E KRONIEKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2O. CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2O. CRÓNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2O. CRÔNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2°. CRONACHE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2º. CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2º. CRÓNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2Е. ЛЕТОПИСЬ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2Я. ЛЕТОПИСЬ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DEZYEM ISTWA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DEZYÈM ISTWA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUGI KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA KRONÍK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY KRONÍK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÁ KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÁ KRONÍK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÝ KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÝ KRONÍK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II AIKAKIRJA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KRONIEKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KS KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II LJETOPISA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONACHE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRÓNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRÔNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KRONICKÁ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KRONIKEL 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. LETOPISU 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. LETOPISŮ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. ЛЕТОПИСИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. ЛІТОПИСУ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. ДНЕВНИКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("MASODIK KRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("MASODIK KRÓN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("MÁSODIK KRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("MÁSODIK KRÓN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ДРУГА ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ДРУГЕ ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("דברי הימים ב 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("دوم- توارِیخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("दुसरे इतिहास 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 AIKAKIRJA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CORONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CORONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONICLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONOCLES 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRONIEKEN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRONIKAVE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KS KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 LJETOPISA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 NALAKAMAM 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 NALĀKAMAM 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 NAḶAKAMAM 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 NAḶĀKAMAM 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 NĀLAKAMAM 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 NĀLĀKAMAM 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 NĀḶAKAMAM 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 NĀḶĀKAMAM 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 E KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 I KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 K. KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 K. KRONÍK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-А HRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-А ȞRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-А ХРОНІКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-А ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-А. ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-ГЕ ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Е HRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Е ȞRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Е ХРОНІКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Е ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Е. ХРОНИК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Е. ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Я. ХРОНИК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONACHE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRÓNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRÔNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRONICKÁ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRONIKEL 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. LETOPISU 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. LETOPISŮ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ITIHASKO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ITIHĀSKO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ЛЕТОПИСИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ЛЕТОПИСЬ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ЛІТОПИСУ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ДНЕВНИКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. इतिहासको 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ବଂଶାବଳୀର 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. พงศาวดาร 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.- توارِیخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2A CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2A CRÔNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2O CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2O CRÓNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2O CRÔNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2° CRONACHE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2º CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2º CRÓNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2Е ЛЕТОПИСЬ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2Я ЛЕТОПИСЬ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONACHE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRÓNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRÔNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KRONICKÁ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KRONIKEL 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II LETOPISU 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II LETOPISŮ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II ЛЕТОПИСИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II ЛІТОПИСУ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II ДНЕВНИКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONICI 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRONICL 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. HRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KRÓNIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. LỊCH SỬ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. ȞRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. ХРОНІКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. ХРОНИКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("KRONIKAK II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("KRONIKÁK II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("KRÓNIKAK II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("KRÓNIKÁK II 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("TWEEDE KRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β' ΧΡΟΝΙΚΩΝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β' ΧΡΟΝΙΚΏΝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ ΧΡΟΝΙΚΩΝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ ΧΡΟΝΙΚΏΝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ ΧΡΟΝΙΚΩΝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ ΧΡΟΝΙΚΏΝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β΄ ΧΡΟΝΙΚΩΝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β΄ ΧΡΟΝΙΚΏΝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β’ ΧΡΟΝΙΚΩΝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β’ ΧΡΟΝΙΚΏΝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΧΡΟΝΙΚΩΝ Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΧΡΟΝΙΚΩΝ Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΧΡΟΝΙΚΩΝ Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΧΡΟΝΙΚΩΝ Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΧΡΟΝΙΚΩΝ Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΧΡΟΝΙΚΏΝ Β' 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΧΡΟΝΙΚΏΝ Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΧΡΟΝΙΚΏΝ Βʹ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΧΡΟΝΙΚΏΝ Β΄ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ΧΡΟΝΙΚΏΝ Β’ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("دوم تو اریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONACHE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONICLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONOCLE 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRÓNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRÔNICAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRONICKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRONICKÁ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRONIKEL 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 LETOPISU 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 LETOPISŮ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ITIHASKO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ITIHĀSKO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 K KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 K KRONÍK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ДНЕВНИКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ЛЕТОПИСИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ЛЕТОПИСЬ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ЛІТОПИСУ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ДНЕВНИКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 इतिहासको 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ବଂଶାବଳୀର 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 நாளாகமம் 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 พงศาวดาร 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2- توارِیخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-А ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Е ХРОНИК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Е ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2-Я ХРОНИК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONICI 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONICL 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. HRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRÓNIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. LỊCH SỬ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ȞRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ХРОНІКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ХРОНИКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. تو اریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ବଂଶାବଳୀ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2Е. ХРОНИК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2Я. ХРОНИК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ANDEN KRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ANDEN KRØN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ANDRE KRØN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONICI 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRONICL 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II HRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KRÓNIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II LỊCH SỬ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II ȞRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II ХРОНІКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II ХРОНИКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II.  SỬ KÝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KRONÍK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KWONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("SECOND CHR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("دوم۔تواریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("۲- توارِیخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONICI 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONICL 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 HRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRONICA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRONIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRÓNIKA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 LỊCH SỬ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 TAVĀRĪḪ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ȞRONIKY 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ХРОНІКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ХРОНИКА 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ХРОНІКИ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 تو اریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ବଂଶାବଳୀ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.  SỬ KÝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ITIHAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRONÍK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KWONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ХРОНИК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. इतिहास 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2.۔تواریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2Е ХРОНИК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2Я ХРОНИК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ANDRE KRØ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II  SỬ KÝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KRONÍK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KWONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. BABAD 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. ISTWA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. SỬ KÝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("ВТОРА ЛЕТ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("الأخبار 2 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("۲ تو اریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2  SỬ KÝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ITIHAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRONÍK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KWONIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ITAHĀS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ITIHAS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ITIHĀS 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ХРОНИК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ХРОНІК 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 इतिहास 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. BABAD 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ISTWA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. SỬ KÝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2E. KRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND. CHR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2۔تواریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHA PA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHY PA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÁ PA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("DRUHÝ PA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II BABAD 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II ISTWA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II SỬ KÝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KRÓN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. TAAR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("PILI NYA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("۲۔تواریخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 AIKAK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 BABAD 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ISTWA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 SỬ KÝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ਇਤਹਾਸ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRÓN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRØN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. TAAR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2E KRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2ND CHR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KRÓN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II TAAR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. CHR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. KRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. NYA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. PAR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. ЛЕТ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β' ΧΡΟΝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ ΧΡΟΝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ ΧΡΟΝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β΄ ΧΡΟΝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β’ ΧΡΟΝ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRÓN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRÔN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRON 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRÓN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRÖN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRØN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 LJET 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 TAAR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ХРОН 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 குறி 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 நாளா 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. CHR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. KRØ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. NYA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. PAR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. ЛЕТ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. इति 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. พศด 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II CHR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II KRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II NYA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II PAR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II ЛЕТ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. PA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II. SỬ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β' ΠΑΡ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ ΠΑΡ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ ΠΑΡ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β΄ ΠΑΡ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β’ ΠΑΡ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《历代志下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《歷代志下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《編年紀下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("역대기 하권 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 AIK 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CHR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRÓ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CRÔ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 IST 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRN 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRO 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 KRØ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 NYA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 PAR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ЛЕТ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ПАР 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 इति 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 พศด 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. PA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2. SỬ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II PA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("II SỬ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β' ΠΑ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β' ΧΡ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ ΠΑ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ ΧΡ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ ΠΑ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Βʹ ΧΡ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β΄ ΠΑ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β΄ ΧΡ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β’ ΠΑ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("Β’ ΧΡ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《历代志下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《歷代志下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《編年紀下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("历代志下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歴代志略下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歴代誌 2 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歷代志下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("編年紀下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("역대기 하 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CH 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 CR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 PA 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 SỬ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ДН 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 ХР 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2 أخ 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2CHR 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《代下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("历代志下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歴代史下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歴代志下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歴代誌下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歷代志下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("編年紀下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("역대지하 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("2역대 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("《代下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("代下》 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("역대하 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("代下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("歴下 1:1").osis()).toEqual("2Chr.1.1")
		expect(p.parse("대하 1:1").osis()).toEqual("2Chr.1.1")
		`
		true
describe "Localized book 1Chr (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Chr (full)", ->
		`
		expect(p.parse("или Първа книга Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("நாளாகமத்தின் முதலாம் புத்தகம் 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cartea intai Paralipomena 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cartea intâi Paralipomena 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cartea întai Paralipomena 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cartea întâi Paralipomena 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Първа Книга на летописите 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Първа книга Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Първа книга на летописите 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva kniha Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvá kniha Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Kwanza Mambo ya Nyakati 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy list Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvý list Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Книга на летописите 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Книга на летописите 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsza Ksiega Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsza Ksiegi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsza Księga Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsza Księgi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsze Ksiega Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsze Ksiegi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsze Księga Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsze Księgi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwszy Ksiega Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwszy Ksiegi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwszy Księga Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwszy Księgi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("itahās dī pahilī potʰī 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("سفر أخبار الأيام الأول 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Книга на летописите 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Ensimmainen Aikakirja 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Ensimmäinen Aikakirja 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Книга на летописите 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Liber I Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva knjiga Ljetopisa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("इतिहासको पहिलो पुस्तक 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ବଂଶାବଳୀର ପ୍ରଥମ ପୁସ୍ତକ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premieres Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premières Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premye liv Kwonik la 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше. книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Mambo ya Nyakati 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Forsta Kronikeboken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Forsta Krönikeboken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Första Kronikeboken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Första Krönikeboken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Mambo ya Nyakati 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsza Ks. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsze Ks. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwszy Ks. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premiere Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premiers Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Première Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva kniha Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva kniha Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvni Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("První Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvá kniha Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvá kniha Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικος Χρονικων Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικος Χρονικων Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικος Χρονικων Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικος Χρονικων Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικος Χρονικων Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικος Χρονικών Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικος Χρονικών Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικος Χρονικών Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικος Χρονικών Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικος Χρονικών Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικός Χρονικων Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικός Χρονικων Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικός Χρονικων Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικός Χρονικων Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικός Χρονικων Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικός Χρονικών Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικός Χρονικών Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικός Χρονικών Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικός Χρονικών Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικός Χρονικών Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перша книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перше книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Прва Паралипоменону 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Прва книга летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Прво книга летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ਇਤਹਾਸ ਦੀ ਪਹਿਲੀ ਪੋਥੀ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Mambo ya Nyakati 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k. Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а. книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е. Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е. книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше. книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-я. Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Mambo ya Nyakati 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Mambo ya Nyakati I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsza Ks Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsze Ks Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwszy Ks Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premier Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvni kniha kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("První kniha kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy list Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy list Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvá Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvý Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvý list Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvý list Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Taariikhdii Kowaad 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Unang Paralipomeno 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перша книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перше книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("أخبار الأيام الأول 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а. книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е. книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-я Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Паралипоменону 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. книга летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1е. Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1я. Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Første Krønikebog 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Første Krønikebok 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Паралипоменону 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. книга летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primeira Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primeira Crônicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primeiro Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primeiro Crônicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva kniha Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva kniha Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvá kniha Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvá kniha Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Unang Mga Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Unang Mga Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Παραλειπομένων Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Παραλειπομένων Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Παραλειπομένων Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Παραλειπομένων Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Παραλειπομένων Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Παραλειπομενων Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Παραλειπομενων Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Παραλειπομενων Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Παραλειπομενων Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Παραλειπομενων Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Паралипоменону 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 книга летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Ksiega Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Ksiegi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Księga Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Księgi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ere. Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ère. Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1е Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1я Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Eerste Kronieken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Fyrri Kronikubok 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Fyrri Kronikubók 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Fyrri Kroníkubok 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Fyrri Kroníkubók 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Fyrri kroníkubók 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Паралипоменону 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I книга летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Ksiega Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Ksiegi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Księga Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Księgi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primero Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primero Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy list Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy list Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvý list Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvý list Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Una Paralipomeno 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ksiega Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ksiegi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Księga Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Księgi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronikeboken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Krönikeboken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Paralipomena 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Paralipomeno 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Sử biên niên 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. kniha kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1er. Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ere Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1re. Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ère Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Ksiega Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Ksiegi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Księga Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Księgi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Paralipomena 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Paralipomeno 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Sử biên niên 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. kniha kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Paralipomenon I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsza Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsze Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwszy Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primer Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primer Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Una Mga Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Una Mga Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Unang Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("itihasko pustak 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("itihāsko pustak 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronikeboken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Krönikeboken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Paralipomena 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Paralipomeno 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Sử biên niên 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 e. Kronikave 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 i. Kronikave 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 kniha kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше. Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Mga Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Mga Cronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Mga Kronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Mga Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Taariikhdii 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1er Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1re Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Paralipomena 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Paralipomeno 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Sử biên niên 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I kniha kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Mga Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Mga Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Taariikhdii 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prima Cronache 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primo Cronache 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva Ljetopisa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvni Letopisu 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvni Letopisů 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("První Letopisu 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("První Letopisů 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Unang Kronikel 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перша Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перше Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Първа Летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("इतिहास 1ला भाग 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("इतिहास १ला भाग 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ପ୍ରଥମ ବଂଶାବଳୀର 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ﺃﺧﺒﺎﺭ ﺍﻷﻳﺎﻡ ﺍﻷ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Mga Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Mga Cronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Mga Kronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Mga Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Taariikhdii 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 e Kronikave 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 i Kronikave 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k. Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k. Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а. Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е. Летопись 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е. Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше. Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше. Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше. Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше. хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-я. Летопись 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronicilor 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Krønikebog 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Krønikebok 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Ks. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.o. Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.o. Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.º. Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.º. Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1e. Kronieken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Erste Chronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Mga Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Mga Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Taariikhdii 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronicilor 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Ks. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premye Kwonik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvá Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvá Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvý Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvý Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Una Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Unang Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Unang Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перша Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перша Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перша Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перша хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перше Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перше Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перше Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перше хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Прва Летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Прва дневника 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Прво Летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("דברי הימים א' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("דברי הימים א’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ପ୍ରଥମ ବଂଶାବଳୀ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronicilor 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Krønikebog 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Krønikebok 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ks. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 e. Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 i. Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 குறிப்பேடு 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а. Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а. Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а. Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а. хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е Летопись 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е. Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е. Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е. Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е. хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше. Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-я Летопись 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Aikakirja 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronieken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronikave 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Ks Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Ljetopisa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.o Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.o Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.º Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.º Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1a. Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1a. Crônicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1e Kronieken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1o. Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1o. Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1o. Crônicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1°. Cronache 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1º. Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1º. Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1е. Летопись 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1я. Летопись 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Elso Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Elso Krónika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Első Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Első Krónika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronicilor 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Ks. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Aikakirja 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kronieken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Ks Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Ljetopisa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premye Istwa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvni Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("První Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Una Kronikel 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перша Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перше Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Прва хроника 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("דברי הימים א 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("اوّل-توارِیخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("पहिले इतिहास 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Aikakirja 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronieken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronikave 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ks Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ljetopisa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Nalakamam 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Nalākamam 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Naḷakamam 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Naḷākamam 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Nālakamam 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Nālākamam 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Nāḷakamam 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Nāḷākamam 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 e Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 i Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k. Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а. Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е. Хроник 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е. Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-я. Хроник 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronache 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Crônicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronikel 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Letopisu 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Letopisů 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. itihasko 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. itihāsko 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Летопись 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. дневника 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. इतिहासको 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ବଂଶାବଳୀର 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. พงศาวดาร 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1a Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1a Crônicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1o Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1o Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1o Crônicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1° Cronache 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1º Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1º Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1е Летопись 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1я Летопись 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Eerste Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Første Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Første Krøn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Aikakirja 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kronieken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Ks Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Ljetopisa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronache 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Crônicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kronikel 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Letopisu 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Letopisů 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. дневника 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvá Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvá Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvý Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvý Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Una Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Una Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α' Χρονικων 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α' Χρονικών 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Χρονικων 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Χρονικών 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Χρονικων 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Χρονικών 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α΄ Χρονικων 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α΄ Χρονικών 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α’ Χρονικων 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α’ Χρονικών 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Χρονικων Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Χρονικων Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Χρονικων Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Χρονικων Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Χρονικων Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Χρονικών Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Χρονικών Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Χρονικών Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Χρονικών Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Χρονικών Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("اوّل تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("اوّل۔تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronache 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Crônicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronikel 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Letopisu 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Letopisů 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 itihasko 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 itihāsko 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Дневника 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Летопись 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 дневника 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 इतिहासको 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ବଂଶାବଳୀର 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 நாளாகமம் 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 พงศาวดาร 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е Хроник 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-я Хроник 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronici 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronicl 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Krónika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Lịch sử 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. хроника 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ବଂଶାବଳୀ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.-توارِیخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1е. Хроник 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1я. Хроник 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Choronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Første Krø 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronache 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Crônicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kronikel 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Letopisu 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Letopisů 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I дневника 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronici 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronicl 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Krónika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Lịch sử 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. хроника 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Kronikak I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Kronikák I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Krónikak I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Krónikák I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Kwanza Nya 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronici 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronicl 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Krónika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Lịch sử 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 tavārīḫ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 хроника 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ବଂଶାବଳୀ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-توارِیخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Itihas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kwonik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Хроник 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. इतिहास 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.۔تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1е Хроник 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1я Хроник 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Elso Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Elso Krón 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Első Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Első Krón 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronici 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronicl 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Krónika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Lịch sử 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I хроника 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kwonik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Първа Лет 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("الأخبار 1 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("۱-توارِیخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Itihas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kwonik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 itahās 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 itihas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 itihās 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Хроник 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 इतिहास 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Babad 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Istwa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Sử Ký 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Sử ký 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1e. Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1۔تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kwonik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Babad 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Istwa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Sử Ký 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Sử ký 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvni Pa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("První Pa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("۱ تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("۱۔تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Aikak 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Babad 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Istwa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Sử Ký 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Sử ký 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ਇਤਹਾਸ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Krón 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Krøn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Taar 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1e Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Babad 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Istwa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Sử Ký 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Sử ký 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Krón 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Taar 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α' Χρον 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Χρον 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Χρον 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α΄ Χρον 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α’ Χρον 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Crón 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Crôn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Krón 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Krön 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Krøn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ljet 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Taar 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 хрон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 குறி 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 நாளா 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Krø 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Nya 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Par 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Лет 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. इति 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. พศด 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Krón 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Taar 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Nya 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Par 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Лет 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α' Παρ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Παρ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Παρ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α΄ Παρ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α’ Παρ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《历代志上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《歷代志上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《編年紀上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("역대기 상권 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Aik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cró 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Crô 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ist 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Krn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Krø 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Nya 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Par 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Лет 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Пар 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 इति 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 พศด 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Pa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Sử 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Nya 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Par 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Лет 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Pa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Sử 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α' Πα 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α' Χρ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Πα 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Χρ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Πα 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Χρ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α΄ Πα 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α΄ Χρ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α’ Πα 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α’ Χρ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《历代志上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《歷代志上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《編年紀上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("历代志上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歴代志略上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歴代誌 1 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歷代志上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("編年紀上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("역대기 상 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ch 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Pa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Sử 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Дн 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Хр 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 أخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Pa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Sử 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《代上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("历代志上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歴代史上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歴代志上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歴代誌上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歷代志上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("編年紀上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("역대지상 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1역대 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《代上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("代上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("역대상 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("代上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歴上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("대상 1:1").osis()).toEqual("1Chr.1.1")
		`
		true
	it "should handle non-Latin digits in book: 1Chr (full)", ->
		p.set_options non_latin_digits_strategy: "replace"
		`
		expect(p.parse("или Първа книга Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("நாளாகமத்தின் முதலாம் புத்தகம் 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cartea intai Paralipomena 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cartea intâi Paralipomena 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cartea întai Paralipomena 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cartea întâi Paralipomena 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Първа Книга на летописите 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Първа книга Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Първа книга на летописите 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva kniha Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvá kniha Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Kwanza Mambo ya Nyakati 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy list Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvý list Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Книга на летописите 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Книга на летописите 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsza Ksiega Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsza Ksiegi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsza Księga Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsza Księgi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsze Ksiega Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsze Ksiegi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsze Księga Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsze Księgi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwszy Ksiega Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwszy Ksiegi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwszy Księga Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwszy Księgi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("itahās dī pahilī potʰī 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("سفر أخبار الأيام الأول 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Книга на летописите 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Ensimmainen Aikakirja 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Ensimmäinen Aikakirja 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Книга на летописите 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Liber I Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva knjiga Ljetopisa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("इतिहासको पहिलो पुस्तक 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ବଂଶାବଳୀର ପ୍ରଥମ ପୁସ୍ତକ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premieres Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premières Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premye liv Kwonik la 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше. книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Mambo ya Nyakati 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Forsta Kronikeboken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Forsta Krönikeboken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Första Kronikeboken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Första Krönikeboken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Mambo ya Nyakati 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsza Ks. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsze Ks. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwszy Ks. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premiere Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premiers Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Première Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva kniha Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva kniha Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvni Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("První Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvá kniha Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvá kniha Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικος Χρονικων Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικος Χρονικων Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικος Χρονικων Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικος Χρονικων Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικος Χρονικων Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικος Χρονικών Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικος Χρονικών Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικος Χρονικών Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικος Χρονικών Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικος Χρονικών Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικός Χρονικων Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικός Χρονικων Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικός Χρονικων Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικός Χρονικων Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικός Χρονικων Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικός Χρονικών Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικός Χρονικών Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικός Χρονικών Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικός Χρονικών Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("δυτικός Χρονικών Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перша книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перше книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Прва Паралипоменону 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Прва книга летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Прво книга летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ਇਤਹਾਸ ਦੀ ਪਹਿਲੀ ਪੋਥੀ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Mambo ya Nyakati 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k. Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а. книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е. Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е. книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше. книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-я. Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Mambo ya Nyakati 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Mambo ya Nyakati I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsza Ks Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsze Ks Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwszy Ks Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premier Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvni kniha kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("První kniha kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy list Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy list Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvá Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvý Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvý list Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvý list Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Taariikhdii Kowaad 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Unang Paralipomeno 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перша книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перше книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("أخبار الأيام الأول 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а. книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е. книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-я Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Паралипоменону 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. книга летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1е. Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1я. Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Første Krønikebog 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Første Krønikebok 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Паралипоменону 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. книга летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primeira Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primeira Crônicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primeiro Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primeiro Crônicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva kniha Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva kniha Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvá kniha Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvá kniha Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Unang Mga Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Unang Mga Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Παραλειπομένων Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Παραλειπομένων Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Παραλειπομένων Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Παραλειπομένων Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Παραλειπομένων Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Παραλειπομενων Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Παραλειπομενων Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Παραλειπομενων Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Παραλειπομενων Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Παραλειπομενων Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Паралипоменону 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 книга летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Ksiega Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Ksiegi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Księga Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Księgi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ere. Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ère. Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1е Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1я Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Eerste Kronieken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Fyrri Kronikubok 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Fyrri Kronikubók 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Fyrri Kroníkubok 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Fyrri Kroníkubók 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Fyrri kroníkubók 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Паралипоменону 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I книга летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Ksiega Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Ksiegi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Księga Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Księgi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primero Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primero Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy list Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy list Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvý list Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvý list Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Una Paralipomeno 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ksiega Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ksiegi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Księga Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Księgi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Паралипоменон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronikeboken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Krönikeboken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Paralipomena 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Paralipomeno 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Sử biên niên 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. kniha kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1er. Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ere Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1re. Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ère Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Ksiega Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Ksiegi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Księga Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Księgi Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I книга хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Paralipomena 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Paralipomeno 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Sử biên niên 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. kniha kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Paralipomenon I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsza Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwsze Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Pierwszy Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primer Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primer Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Una Mga Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Una Mga Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Unang Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("itihasko pustak 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("itihāsko pustak 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronikeboken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Krönikeboken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Paralipomena 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Paralipomeno 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Sử biên niên 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 e. Kronikave 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 i. Kronikave 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 kniha kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше. Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Mga Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Mga Cronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Mga Kronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Mga Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Taariikhdii 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1er Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1re Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Paralipomena 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Paralipomeno 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Sử biên niên 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I kniha kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I книга хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Mga Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Mga Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Taariikhdii 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prima Cronache 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Primo Cronache 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva Ljetopisa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvni Letopisu 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvni Letopisů 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("První Letopisu 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("První Letopisů 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Unang Kronikel 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перша Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перше Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Първа Летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("इतिहास 1ला भाग 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("इतिहास १ला भाग 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ପ୍ରଥମ ବଂଶାବଳୀର 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ﺃﺧﺒﺎﺭ ﺍﻷﻳﺎﻡ ﺍﻷ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Mga Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Mga Cronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Mga Kronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Mga Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Taariikhdii 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 e Kronikave 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 i Kronikave 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k. Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k. Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а. Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е. Летопись 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е. Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше. Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше. Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше. Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше. хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-я. Летопись 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronicilor 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Krønikebog 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Krønikebok 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Ks. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.o. Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.o. Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.º. Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.º. Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1e. Kronieken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Erste Chronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Mga Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Mga Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Taariikhdii 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronicilor 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Ks. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Paralipomenon 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premye Kwonik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvá Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvá Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvý Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvý Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Una Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Unang Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Unang Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перша Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перша Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перша Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перша хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перше Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перше Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перше Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перше хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Прва Летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Прва дневника 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Прво Летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("דברי הימים א' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("דברי הימים א’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ପ୍ରଥମ ବଂଶାବଳୀ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronicilor 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Krønikebog 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Krønikebok 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ks. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 e. Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 i. Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 குறிப்பேடு 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а. Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а. Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а. Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а. хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е Летопись 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е. Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е. Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е. Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е. хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше. Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-я Летопись 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Aikakirja 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronieken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronikave 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Ks Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Ljetopisa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.o Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.o Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.º Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.º Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1a. Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1a. Crônicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1e Kronieken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1o. Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1o. Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1o. Crônicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1°. Cronache 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1º. Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1º. Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1е. Летопись 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1я. Летопись 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Elso Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Elso Krónika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Első Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Első Krónika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chroniques 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronicilor 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Ks. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Aikakirja 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kronieken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Ks Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Ljetopisa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Premye Istwa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvni Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("První Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Una Kronikel 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перша Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Перше Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Прва хроника 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("דברי הימים א 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("اوّل-توارِیخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("पहिले इतिहास 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Aikakirja 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronieken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronikave 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ks Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ljetopisa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Nalakamam 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Nalākamam 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Naḷakamam 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Naḷākamam 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Nālakamam 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Nālākamam 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Nāḷakamam 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Nāḷākamam 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 e Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 i Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k. Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а. Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е. Хроник 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е. Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ше Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-я. Хроник 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronache 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Crônicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronikel 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Letopisu 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Letopisů 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. itihasko 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. itihāsko 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Летопись 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. дневника 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. इतिहासको 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ବଂଶାବଳୀର 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. พงศาวดาร 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1a Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1a Crônicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1o Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1o Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1o Crônicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1° Cronache 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1º Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1º Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1е Летопись 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1я Летопись 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Choronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Choronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Eerste Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Første Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Første Krøn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Aikakirja 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kronieken 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Ks Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Ljetopisa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronache 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Crônicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kronikel 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Letopisu 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Letopisů 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. дневника 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prva Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvy Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvá Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvá Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvý Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvý Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Una Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Una Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α' Χρονικων 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α' Χρονικών 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Χρονικων 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Χρονικών 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Χρονικων 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Χρονικών 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α΄ Χρονικων 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α΄ Χρονικών 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α’ Χρονικων 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α’ Χρονικών 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Χρονικων Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Χρονικων Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Χρονικων Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Χρονικων Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Χρονικων Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Χρονικών Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Χρονικών Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Χρονικών Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Χρονικών Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Χρονικών Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("اوّل تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("اوّل۔تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronache 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Crônicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronikel 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Letopisu 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Letopisů 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 itihasko 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 itihāsko 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 k Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Дневника 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Летопись 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 дневника 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 इतिहासको 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ବଂଶାବଳୀର 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 நாளாகமம் 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 พงศาวดาร 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-а Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е Хроник 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-е Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-я Хроник 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronici 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronicl 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Krónika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Lịch sử 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. хроника 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ବଂଶାବଳୀ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.-توارِیخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1е. Хроник 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1я. Хроник 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Choronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Choronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Chronicals 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Chronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Chronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Coronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Coronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Første Krø 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronache 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Crónicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Crônicas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kronicka 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kronická 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kronikel 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Letopisu 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Letopisů 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Летописи 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Літопису 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I дневника 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronici 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cronicl 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Krónika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Lịch sử 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. хроника 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Kronikak I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Kronikák I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Krónikak I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Krónikák I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Kwanza Nya 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronici 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronicl 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Krónika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Lịch sử 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 tavārīḫ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 хроника 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ବଂଶାବଳୀ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-توارِیخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Itihas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kwonik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Хроник 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. इतिहास 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.۔تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1е Хроник 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1я Хроник 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Chronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Chronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Coronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Coronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cronicles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cronocles 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Elso Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Elso Krón 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Első Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Első Krón 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("First Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronica 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronici 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cronicl 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Hroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kronika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Krónika 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Lịch sử 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Ȟroniky 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Хроніка 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I хроника 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I хроніки 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kwonik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Първа Лет 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("الأخبار 1 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("۱-توارِیخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Itihas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kwonik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 itahās 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 itihas 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 itihās 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Хроник 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 इतिहास 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Babad 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Istwa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Sử Ký 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Sử ký 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1e. Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st. Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1۔تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cronicle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Cronocle 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kronik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kroník 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kwonik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Хронік 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Babad 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Istwa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Sử Ký 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Sử ký 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Prvni Pa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("První Pa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("۱ تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("۱۔تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Aikak 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Babad 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Istwa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Sử Ký 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Sử ký 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ਇਤਹਾਸ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Krón 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Krøn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Taar 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1e Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1st Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Babad 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Istwa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Sử Ký 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Sử ký 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Krón 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Taar 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α' Χρον 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Χρον 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Χρον 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α΄ Χρον 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α’ Χρον 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Crón 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Crôn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Krón 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Krön 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Krøn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ljet 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Taar 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 хрон 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 குறி 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 நாளா 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Kro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Krø 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Nya 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Par 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Лет 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. इति 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. พศด 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chrn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Cron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kron 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Krón 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Taar 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Kro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Nya 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Par 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Лет 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α' Παρ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Παρ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Παρ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α΄ Παρ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α’ Παρ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《历代志上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《歷代志上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《編年紀上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("역대기 상권 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Aik 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cró 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Crô 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ist 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Krn 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Kro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Krø 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Nya 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Par 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Лет 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Пар 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 इति 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 พศด 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Pa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. Sử 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Kro 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Nya 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Par 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Лет 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Pa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. Sử 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α' Πα 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α' Χρ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Πα 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Χρ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Πα 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ Χρ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α΄ Πα 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α΄ Χρ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α’ Πα 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α’ Χρ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《历代志上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《歷代志上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《編年紀上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("历代志上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歴代志略上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歴代誌 1 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歷代志上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("編年紀上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("역대기 상 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Ch 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Cr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Pa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Sử 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Дн 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 Хр 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 أخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1Chr 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Pa 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I Sử 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《代上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("历代志上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歴代史上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歴代志上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歴代誌上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歷代志上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("編年紀上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("역대지상 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1역대 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《代上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("代上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("역대상 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("代上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歴上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("대상 1:1").osis()).toEqual("1Chr.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ИЛИ ПЪРВА КНИГА ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("நாளாகமத்தின் முதலாம் புத்தகம் 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CARTEA INTAI PARALIPOMENA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CARTEA INTÂI PARALIPOMENA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CARTEA ÎNTAI PARALIPOMENA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CARTEA ÎNTÂI PARALIPOMENA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПЪРВА КНИГА НА ЛЕТОПИСИТЕ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПЪРВА КНИГА ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПЪРВА КНИГА НА ЛЕТОПИСИТЕ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVA KNIHA PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVÁ KNIHA PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("KWANZA MAMBO YA NYAKATI 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVY LIST PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVÝ LIST PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. КНИГА НА ЛЕТОПИСИТЕ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. КНИГА НА ЛЕТОПИСИТЕ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZA KSIEGA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZA KSIEGI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZA KSIĘGA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZA KSIĘGI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZE KSIEGA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZE KSIEGI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZE KSIĘGA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZE KSIĘGI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZY KSIEGA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZY KSIEGI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZY KSIĘGA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZY KSIĘGI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ITAHĀS DĪ PAHILĪ POTʰĪ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("سفر أخبار الأيام الأول 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 КНИГА НА ЛЕТОПИСИТЕ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ENSIMMAINEN AIKAKIRJA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ENSIMMÄINEN AIKAKIRJA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I КНИГА НА ЛЕТОПИСИТЕ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("LIBER I PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVA KNJIGA LJETOPISA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("इतिहासको पहिलो पुस्तक 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ବଂଶାବଳୀର ପ୍ରଥମ ପୁସ୍ତକ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PREMIERES CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PREMIÈRES CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PREMYE LIV KWONIK LA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ШЕ. КНИГА ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. MAMBO YA NYAKATI 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FORSTA KRONIKEBOKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FORSTA KRÖNIKEBOKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FÖRSTA KRONIKEBOKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FÖRSTA KRÖNIKEBOKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. MAMBO YA NYAKATI 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZA KS. KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZE KS. KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZY KS. KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PREMIERE CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PREMIERS CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PREMIÈRE CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVA KNIHA KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVA KNIHA KRONICKÁ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVNI PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVNÍ PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVÁ KNIHA KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVÁ KNIHA KRONICKÁ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΧΡΟΝΙΚΩΝ Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΧΡΟΝΙΚΩΝ Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΧΡΟΝΙΚΩΝ Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΧΡΟΝΙΚΩΝ Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΧΡΟΝΙΚΩΝ Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΧΡΟΝΙΚΏΝ Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΧΡΟΝΙΚΏΝ Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΧΡΟΝΙΚΏΝ Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΧΡΟΝΙΚΏΝ Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΟΣ ΧΡΟΝΙΚΏΝ Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΧΡΟΝΙΚΩΝ Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΧΡΟΝΙΚΩΝ Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΧΡΟΝΙΚΩΝ Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΧΡΟΝΙΚΩΝ Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΧΡΟΝΙΚΩΝ Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΧΡΟΝΙΚΏΝ Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΧΡΟΝΙΚΏΝ Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΧΡΟΝΙΚΏΝ Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΧΡΟΝΙΚΏΝ Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΔΥΤΙΚΌΣ ΧΡΟΝΙΚΏΝ Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПЕРША КНИГА ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПЕРШЕ КНИГА ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПРВА ПАРАЛИПОМЕНОНУ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПРВА КНИГА ЛЕТОПИСИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПРВО КНИГА ЛЕТОПИСИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ਇਤਹਾਸ ਦੀ ਪਹਿਲੀ ਪੋਥੀ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 MAMBO YA NYAKATI 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 K. PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-А. КНИГА ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Е. ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Е. КНИГА ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ШЕ КНИГА ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ШЕ. КНИГА ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Я. ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I MAMBO YA NYAKATI 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("MAMBO YA NYAKATI I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZA KS KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZE KS KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZY KS KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PREMIER CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVA PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVNI KNIHA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVNÍ KNIHA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVY PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVY LIST KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVY LIST KRONICKÁ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVÁ PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVÝ PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVÝ LIST KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVÝ LIST KRONICKÁ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("TAARIIKHDII KOWAAD 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNANG PARALIPOMENO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПЕРША КНИГА ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПЕРШЕ КНИГА ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("أخبار الأيام الأول 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 K PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-А КНИГА ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-А. КНИГА ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Е ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Е КНИГА ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Е. КНИГА ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ШЕ КНИГА ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Я ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ПАРАЛИПОМЕНОНУ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. КНИГА ЛЕТОПИСИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1Е. ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1Я. ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FØRSTE KRØNIKEBOG 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FØRSTE KRØNIKEBOK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. ПАРАЛИПОМЕНОНУ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. КНИГА ЛЕТОПИСИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRIMEIRA CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRIMEIRA CRÔNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRIMEIRO CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRIMEIRO CRÔNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVA KNIHA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVA KNIHA KRONÍK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVÁ KNIHA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVÁ KNIHA KRONÍK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNANG MGA CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNANG MGA KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΠΑΡΑΛΕΙΠΟΜΈΝΩΝ Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΠΑΡΑΛΕΙΠΟΜΈΝΩΝ Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΠΑΡΑΛΕΙΠΟΜΈΝΩΝ Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΠΑΡΑΛΕΙΠΟΜΈΝΩΝ Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΠΑΡΑΛΕΙΠΟΜΈΝΩΝ Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΠΑΡΑΛΕΙΠΟΜΕΝΩΝ Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΠΑΡΑΛΕΙΠΟΜΕΝΩΝ Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΠΑΡΑΛΕΙΠΟΜΕΝΩΝ Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΠΑΡΑΛΕΙΠΟΜΕΝΩΝ Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΠΑΡΑΛΕΙΠΟΜΕΝΩΝ Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ПАРАЛИПОМЕНОНУ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 КНИГА ЛЕТОПИСИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-А КНИГА ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Е КНИГА ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KSIEGA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KSIEGI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KSIĘGA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KSIĘGI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. КНИГА ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ERE. CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ÈRE. CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1Е ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1Я ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("EERSTE KRONIEKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FYRRI KRONIKUBOK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FYRRI KRONIKUBÓK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FYRRI KRONÍKUBOK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FYRRI KRONÍKUBÓK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FYRRI KRONÍKUBÓK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I ПАРАЛИПОМЕНОНУ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I КНИГА ЛЕТОПИСИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KSIEGA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KSIEGI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KSIĘGA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KSIĘGI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. КНИГА ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRIMERO CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRIMERO CRÓNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVY LIST KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVY LIST KRONÍK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVÝ LIST KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVÝ LIST KRONÍK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNA PARALIPOMENO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KSIEGA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KSIEGI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KSIĘGA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KSIĘGI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ПАРАЛИПОМЕНОН 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 КНИГА ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRONIKEBOKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRÖNIKEBOKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. PARALIPOMENA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. PARALIPOMENO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. SỬ BIÊN NIÊN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KNIHA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. КНИГА ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ER. CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ERE CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1RE. CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ÈRE CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KSIEGA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KSIEGI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KSIĘGA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KSIĘGI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I КНИГА ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. PARALIPOMENA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. PARALIPOMENO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. SỬ BIÊN NIÊN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KNIHA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. КНИГА ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PARALIPOMENON I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZE KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PIERWSZY KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRIMER CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRIMER CRÓNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNA MGA CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNA MGA KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNANG CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ITIHASKO PUSTAK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ITIHĀSKO PUSTAK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRONIKEBOKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRÖNIKEBOKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 PARALIPOMENA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 PARALIPOMENO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 SỬ BIÊN NIÊN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 E. KRONIKAVE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 I. KRONIKAVE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KNIHA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 КНИГА ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ШЕ. ЛІТОПИСУ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. MGA CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. MGA CRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. MGA KRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. MGA KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. TAARIIKHDII 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ER CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1RE CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I PARALIPOMENA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I PARALIPOMENO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I SỬ BIÊN NIÊN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KNIHA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I КНИГА ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. MGA CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. MGA KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. TAARIIKHDII 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRIMA CRONACHE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRIMO CRONACHE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVA LJETOPISA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVNI LETOPISU 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVNI LETOPISŮ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVNÍ LETOPISU 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVNÍ LETOPISŮ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNANG KRONIKEL 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПЕРША ЛІТОПИСУ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПЕРШЕ ЛІТОПИСУ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПЪРВА ЛЕТОПИСИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("इतिहास 1ला भाग 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("इतिहास १ला भाग 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ପ୍ରଥମ ବଂଶାବଳୀର 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ﺃﺧﺒﺎﺭ ﺍﻷﻳﺎﻡ ﺍﻷ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 MGA CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 MGA CRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 MGA KRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 MGA KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 TAARIIKHDII 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 E KRONIKAVE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 I KRONIKAVE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 K. KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 K. KRONICKÁ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-А. ЛІТОПИСУ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Е. ЛЕТОПИСЬ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Е. ЛІТОПИСУ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ШЕ ЛІТОПИСУ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ШЕ. HRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ШЕ. ȞRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ШЕ. ХРОНІКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ШЕ. ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Я. ЛЕТОПИСЬ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONICILOR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRØNIKEBOG 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRØNIKEBOK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KS. KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.O. CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.O. CRÓNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.º. CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.º. CRÓNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1E. KRONIEKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ERSTE CHRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I MGA CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I MGA KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I TAARIIKHDII 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONICILOR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KS. KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PARALIPOMENON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PREMYE KWONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVA KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVA KRONICKÁ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVY KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVY KRONICKÁ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVÁ KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVÁ KRONICKÁ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVÝ KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVÝ KRONICKÁ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNA CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNANG CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNANG KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПЕРША HRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПЕРША ȞRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПЕРША ХРОНІКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПЕРША ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПЕРШЕ HRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПЕРШЕ ȞRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПЕРШЕ ХРОНІКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПЕРШЕ ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПРВА ЛЕТОПИСИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПРВА ДНЕВНИКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПРВО ЛЕТОПИСИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("דברי הימים א' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("דברי הימים א’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ପ୍ରଥମ ବଂଶାବଳୀ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONICILOR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRØNIKEBOG 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRØNIKEBOK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KS. KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 E. KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 I. KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 K KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 K KRONICKÁ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 குறிப்பேடு 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-А ЛІТОПИСУ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-А. HRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-А. ȞRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-А. ХРОНІКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-А. ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Е ЛЕТОПИСЬ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Е ЛІТОПИСУ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Е. HRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Е. ȞRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Е. ХРОНІКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Е. ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ШЕ HRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ШЕ ȞRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ШЕ ХРОНІКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ШЕ ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ШЕ. ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Я ЛЕТОПИСЬ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. AIKAKIRJA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRONIEKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRONIKAVE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KS KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. LJETOPISA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.O CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.O CRÓNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.º CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.º CRÓNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1A. CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1A. CRÔNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1E KRONIEKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1O. CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1O. CRÓNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1O. CRÔNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1°. CRONACHE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1º. CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1º. CRÓNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1Е. ЛЕТОПИСЬ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1Я. ЛЕТОПИСЬ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ELSO KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ELSO KRÓNIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ELSŐ KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ELSŐ KRÓNIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRONIQUES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONICILOR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KS. KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. AIKAKIRJA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KRONIEKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KS KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. LJETOPISA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PREMYE ISTWA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVNI KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVNÍ KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNA KRONIKEL 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПЕРША ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПЕРШЕ ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПРВА ХРОНИКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("דברי הימים א 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("اوّل-توارِیخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("पहिले इतिहास 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 AIKAKIRJA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRONIEKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRONIKAVE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KS KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 LJETOPISA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 NALAKAMAM 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 NALĀKAMAM 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 NAḶAKAMAM 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 NAḶĀKAMAM 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 NĀLAKAMAM 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 NĀLĀKAMAM 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 NĀḶAKAMAM 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 NĀḶĀKAMAM 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 E KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 I KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 K. KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 K. KRONÍK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-А HRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-А ȞRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-А ХРОНІКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-А ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-А. ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Е HRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Е ȞRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Е ХРОНІКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Е ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Е. ХРОНИК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Е. ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-ШЕ ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Я. ХРОНИК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONACHE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRÓNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRÔNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRONICKÁ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRONIKEL 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. LETOPISU 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. LETOPISŮ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ITIHASKO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ITIHĀSKO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ЛЕТОПИСИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ЛЕТОПИСЬ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ЛІТОПИСУ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ДНЕВНИКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. इतिहासको 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ବଂଶାବଳୀର 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. พงศาวดาร 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1A CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1A CRÔNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1O CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1O CRÓNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1O CRÔNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1° CRONACHE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1º CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1º CRÓNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1Е ЛЕТОПИСЬ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1Я ЛЕТОПИСЬ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("EERSTE KRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FØRSTE KRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FØRSTE KRØN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I AIKAKIRJA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KRONIEKEN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KS KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I LJETOPISA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONACHE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRÓNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRÔNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KRONICKÁ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KRONIKEL 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. LETOPISU 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. LETOPISŮ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. ЛЕТОПИСИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. ЛІТОПИСУ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. ДНЕВНИКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVA KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVA KRONÍK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVY KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVY KRONÍK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVÁ KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVÁ KRONÍK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVÝ KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVÝ KRONÍK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNA CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("UNA KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α' ΧΡΟΝΙΚΩΝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α' ΧΡΟΝΙΚΏΝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ ΧΡΟΝΙΚΩΝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ ΧΡΟΝΙΚΏΝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ ΧΡΟΝΙΚΩΝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ ΧΡΟΝΙΚΏΝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α΄ ΧΡΟΝΙΚΩΝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α΄ ΧΡΟΝΙΚΏΝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α’ ΧΡΟΝΙΚΩΝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α’ ΧΡΟΝΙΚΏΝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΧΡΟΝΙΚΩΝ Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΧΡΟΝΙΚΩΝ Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΧΡΟΝΙΚΩΝ Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΧΡΟΝΙΚΩΝ Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΧΡΟΝΙΚΩΝ Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΧΡΟΝΙΚΏΝ Α' 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΧΡΟΝΙΚΏΝ Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΧΡΟΝΙΚΏΝ Αʹ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΧΡΟΝΙΚΏΝ Α΄ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ΧΡΟΝΙΚΏΝ Α’ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("اوّل تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("اوّل۔تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONACHE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRÓNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRÔNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRONICKÁ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRONIKEL 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 LETOPISU 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 LETOPISŮ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ITIHASKO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ITIHĀSKO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 K KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 K KRONÍK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ДНЕВНИКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ЛЕТОПИСИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ЛЕТОПИСЬ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ЛІТОПИСУ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ДНЕВНИКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 इतिहासको 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ବଂଶାବଳୀର 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 நாளாகமம் 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 พงศาวดาร 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-А ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Е ХРОНИК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Е ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-Я ХРОНИК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONICI 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONICL 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. HRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRÓNIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. LỊCH SỬ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ȞRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ХРОНІКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ХРОНИКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ବଂଶାବଳୀ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.-توارِیخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1Е. ХРОНИК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1Я. ХРОНИК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHRONICALS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CORONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CORONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FØRSTE KRØ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONACHE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRÓNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRÔNICAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KRONICKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KRONICKÁ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KRONIKEL 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I LETOPISU 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I LETOPISŮ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I ЛЕТОПИСИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I ЛІТОПИСУ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I ДНЕВНИКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONICI 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRONICL 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. HRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KRÓNIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. LỊCH SỬ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. ȞRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. ХРОНІКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. ХРОНИКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("KRONIKAK I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("KRONIKÁK I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("KRÓNIKAK I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("KRÓNIKÁK I 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("KWANZA NYA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONICI 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONICL 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 HRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRÓNIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 LỊCH SỬ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 TAVĀRĪḪ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ȞRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ХРОНІКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ХРОНИКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ବଂଶାବଳୀ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1-توارِیخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ITIHAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRONÍK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KWONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ХРОНИК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. इतिहास 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1.۔تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1Е ХРОНИК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1Я ХРОНИК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CHRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CORONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CORONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CRONICLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CRONOCLES 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ELSO KRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ELSO KRÓN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ELSŐ KRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ELSŐ KRÓN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("FIRST CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONICA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONICI 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRONICL 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I HRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KRONIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KRÓNIKA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I LỊCH SỬ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I ȞRONIKY 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I ХРОНІКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I ХРОНИКА 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I ХРОНІКИ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KRONÍK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KWONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("ПЪРВА ЛЕТ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("الأخبار 1 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("۱-توارِیخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ITIHAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRONÍK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KWONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ITAHĀS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ITIHAS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ITIHĀS 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ХРОНИК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 इतिहास 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. BABAD 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ISTWA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. SỬ KÝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. SỬ KÝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1E. KRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST. CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1۔تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CRONICLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("CRONOCLE 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KRONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KRONÍK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KWONIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I ХРОНІК 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. BABAD 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. ISTWA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. SỬ KÝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. SỬ KÝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVNI PA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("PRVNÍ PA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("۱ تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("۱۔تواریخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 AIKAK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 BABAD 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ISTWA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 SỬ KÝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 SỬ KÝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ਇਤਹਾਸ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRÓN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRØN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. TAAR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1E KRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1ST CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I BABAD 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I ISTWA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I SỬ KÝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I SỬ KÝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KRÓN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. TAAR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α' ΧΡΟΝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ ΧΡΟΝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ ΧΡΟΝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α΄ ΧΡΟΝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α’ ΧΡΟΝ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRÓN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRÔN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRÓN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRÖN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRØN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 LJET 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 TAAR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ХРОН 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 குறி 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 நாளா 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. KRØ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. NYA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. PAR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. ЛЕТ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. इति 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. พศด 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KRON 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KRÓN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I TAAR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. KRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. NYA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. PAR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. ЛЕТ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α' ΠΑΡ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ ΠΑΡ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ ΠΑΡ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α΄ ΠΑΡ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α’ ΠΑΡ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《历代志上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《歷代志上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《編年紀上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("역대기 상권 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 AIK 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRÓ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CRÔ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 IST 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRN 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 KRØ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 NYA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 PAR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ЛЕТ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ПАР 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 इति 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 พศด 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. PA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1. SỬ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I KRO 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I NYA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I PAR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I ЛЕТ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. PA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I. SỬ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α' ΠΑ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α' ΧΡ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ ΠΑ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ ΧΡ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ ΠΑ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Αʹ ΧΡ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α΄ ΠΑ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α΄ ΧΡ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α’ ΠΑ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("Α’ ΧΡ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《历代志上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《歷代志上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《編年紀上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("历代志上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歴代志略上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歴代誌 1 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歷代志上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("編年紀上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("역대기 상 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CH 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 CR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 PA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 SỬ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ДН 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 ХР 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1 أخ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1CHR 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I PA 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("I SỬ 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《代上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("历代志上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歴代史上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歴代志上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歴代誌上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歷代志上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("編年紀上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("역대지상 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("1역대 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("《代上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("代上》 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("역대상 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("代上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("歴上 1:1").osis()).toEqual("1Chr.1.1")
		expect(p.parse("대상 1:1").osis()).toEqual("1Chr.1.1")
		`
		true
describe "Localized book Ezra (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Ezra (full)", ->
		`
		expect(p.parse("எஸ்றாவின் புத்தகம் 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ksiega Ezdrasza 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ksiegi Ezdrasza 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Księga Ezdrasza 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Księgi Ezdrasza 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Книга на Ездра 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("एज्राको पुस्तक 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Knjiga Ezrina 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Liv Esdras la 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ks. Ezdrasza 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Liber Esdrae 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Первая Ездры 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esran kirja 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ks Ezdrasza 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Книга Ездри 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Книга Ездры 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esras bok 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezras Bog 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezdrasza 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("سفر عزرا 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("E-xơ-ra 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esrabok 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esrabók 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezsdras 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezsdrás 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ê-xơ-ra 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("एज्राको 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("《厄斯德拉上》 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Cesraa 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esdrae 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esdras 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezdras 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezdraš 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezdrás 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezdráš 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("eǳrako 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("eǳrāko 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Έσδρας 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Εσδρας 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Јездра 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Езрина 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("《以斯拉記》 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("《以斯拉记》 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("《厄斯德拉上 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("厄斯德拉上》 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("1 Езд 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Aejra 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esdra 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esran 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esras 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezdra 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("edzra 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("edzrā 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ʿizrā 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Єздри 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ездра 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ездри 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ездры 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Узаир 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Узайр 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("عز را 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("एज्रा 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ਅਜ਼ਰਾ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ଏଜ୍ରା 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("எஸ்ரா 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("எஸ்றா 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("เอสรา 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("《以斯拉記 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("《以斯拉记 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("以斯拉記》 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("以斯拉记》 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("厄斯德拉上 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Cesr 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esdr 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esra 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esrā 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esṛa 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esṛā 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezdr 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezra 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezsd 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("azrā 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("eǳra 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("eǳrā 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Étra 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Êxra 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Езра 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("עזרא 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("عزرا 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("エスラ書 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("エスラ記 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("エズラ書 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("エズラ記 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("以斯拉記 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("以斯拉记 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("에스라기 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("에즈라기 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ces 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esd 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Esr 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezd 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ezr 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Єзд 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Езд 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Езр 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("عـز 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("อสร 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("《拉》 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("エスラ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("エズラ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("에스라 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("에즈라 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ed 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Εσ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ἔσ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("《拉 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("拉》 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("에즈 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("스 1:1").osis()).toEqual("Ezra.1.1")
		p.include_apocrypha(false)
		expect(p.parse("எஸ்றாவின் புத்தகம் 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("KSIEGA EZDRASZA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("KSIEGI EZDRASZA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("KSIĘGA EZDRASZA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("KSIĘGI EZDRASZA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("КНИГА НА ЕЗДРА 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("एज्राको पुस्तक 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("KNJIGA EZRINA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("LIV ESDRAS LA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("KS. EZDRASZA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("LIBER ESDRAE 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ПЕРВАЯ ЕЗДРЫ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESRAN KIRJA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("KS EZDRASZA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("КНИГА ЕЗДРИ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("КНИГА ЕЗДРЫ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESRAS BOK 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZRAS BOG 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZDRASZA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("سفر عزرا 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("E-XƠ-RA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESRABOK 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESRABÓK 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZSDRAS 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZSDRÁS 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("Ê-XƠ-RA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("एज्राको 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("《厄斯德拉上》 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("CESRAA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESDRAE 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESDRAS 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZDRAS 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZDRAŠ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZDRÁS 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZDRÁŠ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EǱRAKO 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EǱRĀKO 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ΈΣΔΡΑΣ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ΕΣΔΡΑΣ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ЈЕЗДРА 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ЕЗРИНА 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("《以斯拉記》 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("《以斯拉记》 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("《厄斯德拉上 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("厄斯德拉上》 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("1 ЕЗД 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("AEJRA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESDRA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESRAN 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESRAS 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZDRA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EDZRA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EDZRĀ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ʿIZRĀ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ЄЗДРИ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ЕЗДРА 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ЕЗДРИ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ЕЗДРЫ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("УЗАИР 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("УЗАЙР 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("عز را 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("एज्रा 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ਅਜ਼ਰਾ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ଏଜ୍ରା 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("எஸ்ரா 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("எஸ்றா 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("เอสรา 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("《以斯拉記 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("《以斯拉记 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("以斯拉記》 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("以斯拉记》 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("厄斯德拉上 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("CESR 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESDR 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESRA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESRĀ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESṚA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESṚĀ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZDR 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZRA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZSD 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("AZRĀ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EǱRA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EǱRĀ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ÉTRA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ÊXRA 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ЕЗРА 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("עזרא 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("عزرا 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("エスラ書 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("エスラ記 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("エズラ書 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("エズラ記 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("以斯拉記 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("以斯拉记 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("에스라기 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("에즈라기 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("CES 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESD 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ESR 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZD 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("EZR 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ЄЗД 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ЕЗД 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ЕЗР 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("عـز 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("อสร 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("《拉》 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("エスラ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("エズラ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("에스라 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("에즈라 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ED 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ΕΣ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("ἜΣ 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("《拉 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("拉》 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("에즈 1:1").osis()).toEqual("Ezra.1.1")
		expect(p.parse("스 1:1").osis()).toEqual("Ezra.1.1")
		`
		true
describe "Localized book Ruth (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Ruth (full)", ->
		`
		expect(p.parse("ரூத்தின் சரித்திரம் 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Kitabu cha Ruthi 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Kitabu cha Ruthu 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("ଋତର ବିବରଣ ପୁସ୍ତକ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Knjiga o Ruti 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("rutʰko pustak 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("rūtʰko pustak 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ksiega Ruthy 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ksiegi Ruthy 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Księga Ruthy 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Księgi Ruthy 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ruutin kirja 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("रूथको पुस्तक 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ksiega Rut 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ksiegi Rut 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Księga Rut 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Księgi Rut 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Liber Ruth 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Liv Rit la 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Книга Руфи 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ks. Ruthy 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ruths Bog 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Книга Рут 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("سفر راعوث 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ks Ruthy 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Rutarbok 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Rutarbók 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ruts bok 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ks. Rut 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ks Rut 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ruutin 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("rutʰko 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("rūtʰko 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("ரூத்து 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("นางรูธ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ru-tơ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ruthi 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ruthu 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("راعوث 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("रूथको 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("《盧德傳》 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("《路得記》 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("《路得记》 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Root 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ruta 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Rute 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ruth 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ruts 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ruud 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ruut 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("rutʰ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("rūtʰ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ρουθ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Рута 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Руфь 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("رُوت 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("ரூத் 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("《盧德傳 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("《路得記 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("《路得记 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("盧德傳》 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("路得記》 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("路得记》 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Rit 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Rth 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Rut 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Rút 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Rūt 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("rūt 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Рут 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Руф 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("רות 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("روت 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("रुत 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("रूत 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("रूथ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("ਰੂਥ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("นรธ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("῾Ρθ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("《得》 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("ルツ記 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("盧德傳 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("路得記 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("路得记 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Rt 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("Ru 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("را 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("《得 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("ルツ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("得》 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("룻기 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("得 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("룻 1:1").osis()).toEqual("Ruth.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ரூத்தின் சரித்திரம் 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KITABU CHA RUTHI 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KITABU CHA RUTHU 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("ଋତର ବିବରଣ ପୁସ୍ତକ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KNJIGA O RUTI 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUTʰKO PUSTAK 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RŪTʰKO PUSTAK 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KSIEGA RUTHY 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KSIEGI RUTHY 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KSIĘGA RUTHY 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KSIĘGI RUTHY 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUUTIN KIRJA 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("रूथको पुस्तक 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KSIEGA RUT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KSIEGI RUT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KSIĘGA RUT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KSIĘGI RUT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("LIBER RUTH 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("LIV RIT LA 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("КНИГА РУФИ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KS. RUTHY 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUTHS BOG 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("КНИГА РУТ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("سفر راعوث 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KS RUTHY 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUTARBOK 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUTARBÓK 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUTS BOK 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KS. RUT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("KS RUT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUUTIN 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUTʰKO 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RŪTʰKO 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("ரூத்து 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("นางรูธ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RU-TƠ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUTHI 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUTHU 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("راعوث 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("रूथको 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("《盧德傳》 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("《路得記》 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("《路得记》 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("ROOT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUTA 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUTE 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUTH 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUTS 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUUD 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUUT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUTʰ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RŪTʰ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("ΡΟΥΘ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("РУТА 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("РУФЬ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("رُوت 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("ரூத் 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("《盧德傳 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("《路得記 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("《路得记 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("盧德傳》 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("路得記》 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("路得记》 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RIT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RTH 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RUT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RÚT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RŪT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RŪT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("РУТ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("РУФ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("רות 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("روت 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("रुत 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("रूत 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("रूथ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("ਰੂਥ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("นรธ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("῾ΡΘ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("《得》 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("ルツ記 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("盧德傳 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("路得記 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("路得记 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RT 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("RU 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("را 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("《得 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("ルツ 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("得》 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("룻기 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("得 1:1").osis()).toEqual("Ruth.1.1")
		expect(p.parse("룻 1:1").osis()).toEqual("Ruth.1.1")
		`
		true
describe "Localized book Neh (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Neh (full)", ->
		`
		expect(p.parse("நெகேமியாவின் புத்தகம் 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("ନିହିମିୟାଙ୍କର ପୁସ୍ତକ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Knjiga Nehemijina 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Ksiega Nehemiasza 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Ksiegi Nehemiasza 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Księga Nehemiasza 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Księgi Nehemiasza 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("nahemyahko pustak 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("nahemyāhko pustak 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("नहेम्याहको पुस्तक 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Книга на Неемия 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Ks. Nehemiasza 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Liber Nehemiae 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemian kirja 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Ks Nehemiasza 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Liv Neyemi an 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemias’ Bog 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemjas bok 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Книга Неемии 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Книга Нееміі 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Книга Неемії 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("ନିହିମିୟାଙ୍କର 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiabok 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiabók 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiasza 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemíabok 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemíabók 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nê-hê-mi-a 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("nahemyahko 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("nahemyāhko 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("नहेम्याहको 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemaaah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemaaih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemaiah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemaiih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiaah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiaih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiiah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiiih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimaaah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimaaih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimaiah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimaiih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimiaah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimiaih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimiiah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimiiih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nexemyaah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("سفر نحميا 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("न्हेम्याह 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nahemyah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehamiah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemaah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemaih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemeia 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiae 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemian 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemias 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiaš 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemija 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiás 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemiáš 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemjas 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemjaš 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemjás 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemjáš 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemíah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemías 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimaah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimaih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimiah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimiih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nekemiya 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nekemiyā 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nekēmiya 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nekēmiyā 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nê-hê-mi 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nơkhemia 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("nahamyāh 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("niḥimyāh 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Нехемија 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("नहेमायाह 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("नहेम्याह 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("நெகேமியா 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("เนหะมีย์ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Neemias 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Neemija 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehamia 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemia 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemie 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemja 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehemya 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimah 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimia 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehimih 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nehémie 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Néhemie 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Néhémie 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("nahemya 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("nahemyā 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Νεεμίας 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Νεεμιας 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Неемија 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("नहेम्या 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("《厄斯德拉下》 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Neemia 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Neyemi 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Неемии 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Неемия 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Неемія 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Нееміі 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Неемії 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Немија 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Неєміі 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Неємії 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("نحمیاہ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("ਨਹਮਯਾਹ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("《厄斯德拉下 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("《尼希米記》 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("《尼希米记》 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("厄斯德拉下》 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Neemi 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("נחמיה 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("نحميا 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("नहेमा 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("《尼希米記 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("《尼希米记 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("ネヘミヤ記 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("厄斯德拉下 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("尼希米記》 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("尼希米记》 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("느헤미야기 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Neem 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Неем 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Неєм 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("நெகே 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("ネヘミヤ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("尼希米記 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("尼希米记 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("느헤미아 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("느헤미야 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Neh 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nex 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Néh 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Нем 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("นหม 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("《尼》 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Ne 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Né 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Nê 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("Νε 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("نح 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("《尼 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("尼》 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("느헤 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("尼 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("느 1:1").osis()).toEqual("Neh.1.1")
		p.include_apocrypha(false)
		expect(p.parse("நெகேமியாவின் புத்தகம் 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("ନିହିମିୟାଙ୍କର ପୁସ୍ତକ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("KNJIGA NEHEMIJINA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("KSIEGA NEHEMIASZA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("KSIEGI NEHEMIASZA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("KSIĘGA NEHEMIASZA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("KSIĘGI NEHEMIASZA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NAHEMYAHKO PUSTAK 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NAHEMYĀHKO PUSTAK 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("नहेम्याहको पुस्तक 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("КНИГА НА НЕЕМИЯ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("KS. NEHEMIASZA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("LIBER NEHEMIAE 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIAN KIRJA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("KS NEHEMIASZA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("LIV NEYEMI AN 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIAS’ BOG 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMJAS BOK 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("КНИГА НЕЕМИИ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("КНИГА НЕЕМІІ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("КНИГА НЕЕМІЇ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("ନିହିମିୟାଙ୍କର 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIABOK 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIABÓK 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIASZA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMÍABOK 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMÍABÓK 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NÊ-HÊ-MI-A 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NAHEMYAHKO 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NAHEMYĀHKO 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("नहेम्याहको 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMAAAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMAAIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMAIAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMAIIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIAAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIAIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIIAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIIIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMAAAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMAAIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMAIAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMAIIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIAAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIAIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIIAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIIIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEXEMYAAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("سفر نحميا 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("न्हेम्याह 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NAHEMYAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHAMIAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMAAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMAIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMEIA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIAE 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIAN 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIAS 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIAŠ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIJA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIÁS 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIÁŠ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMJAS 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMJAŠ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMJÁS 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMJÁŠ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMÍAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMÍAS 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMAAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMAIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEKEMIYA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEKEMIYĀ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEKĒMIYA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEKĒMIYĀ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NÊ-HÊ-MI 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NƠKHEMIA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NAHAMYĀH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NIḤIMYĀH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("НЕХЕМИЈА 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("नहेमायाह 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("नहेम्याह 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("நெகேமியா 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("เนหะมีย์ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEEMIAS 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEEMIJA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHAMIA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIE 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMJA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHEMYA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMAH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHIMIH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEHÉMIE 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NÉHEMIE 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NÉHÉMIE 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NAHEMYA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NAHEMYĀ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("ΝΕΕΜΊΑΣ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("ΝΕΕΜΙΑΣ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("НЕЕМИЈА 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("नहेम्या 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("《厄斯德拉下》 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEEMIA 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEYEMI 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("НЕЕМИИ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("НЕЕМИЯ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("НЕЕМІЯ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("НЕЕМІІ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("НЕЕМІЇ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("НЕМИЈА 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("НЕЄМІІ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("НЕЄМІЇ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("نحمیاہ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("ਨਹਮਯਾਹ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("《厄斯德拉下 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("《尼希米記》 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("《尼希米记》 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("厄斯德拉下》 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEEMI 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("נחמיה 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("نحميا 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("नहेमा 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("《尼希米記 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("《尼希米记 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("ネヘミヤ記 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("厄斯德拉下 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("尼希米記》 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("尼希米记》 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("느헤미야기 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEEM 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("НЕЕМ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("НЕЄМ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("நெகே 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("ネヘミヤ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("尼希米記 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("尼希米记 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("느헤미아 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("느헤미야 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NEX 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NÉH 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("НЕМ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("นหม 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("《尼》 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NE 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NÉ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("NÊ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("ΝΕ 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("نح 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("《尼 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("尼》 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("느헤 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("尼 1:1").osis()).toEqual("Neh.1.1")
		expect(p.parse("느 1:1").osis()).toEqual("Neh.1.1")
		`
		true
describe "Localized book GkEsth (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: GkEsth (full)", ->
		`
		expect(p.parse("Ester enligt den grekiska texten 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter konyvenek kiegeszitese 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter konyvenek kiegeszitése 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter konyvenek kiegeszítese 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter konyvenek kiegeszítése 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter konyvenek kiegészitese 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter konyvenek kiegészitése 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter konyvenek kiegészítese 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter konyvenek kiegészítése 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter konyvének kiegeszitese 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter konyvének kiegeszitése 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter konyvének kiegeszítese 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter konyvének kiegeszítése 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter konyvének kiegészitese 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter konyvének kiegészitése 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter konyvének kiegészítese 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter konyvének kiegészítése 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter könyvenek kiegeszitese 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter könyvenek kiegeszitése 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter könyvenek kiegeszítese 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter könyvenek kiegeszítése 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter könyvenek kiegészitese 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter könyvenek kiegészitése 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter könyvenek kiegészítese 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter könyvenek kiegészítése 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter könyvének kiegeszitese 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter könyvének kiegeszitése 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter könyvének kiegeszítese 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter könyvének kiegeszítése 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter könyvének kiegészitese 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter könyvének kiegészitése 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter könyvének kiegészítese 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Eszter könyvének kiegészítése 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Kreikkalainen Esterin kirja 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester \(versione greca\) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Grecke casti knihy Ester 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Grecke časti knihy Ester 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Grécke casti knihy Ester 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Grécke časti knihy Ester 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Den greske Ester-boken 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Den greske Ester-boka 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester (řecké dodatky) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esterarbok hin griska 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esterarbok hin gríska 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esterarbók hin griska 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esterarbók hin gríska 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Kreikkalainen Esterin 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester \(Griechisch\) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("எஸ்தர் \(கிரேக்கம்\) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester (řecké části) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester recke dodatky 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester recké dodatky 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester řecke dodatky 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester řecké dodatky 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Дополнения к Есфири 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester (Griechisch) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Εσθήρ στα ελληνικά 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Εσθήρ στα ελληνικα 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Εσθηρ στα ελληνικά 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Εσθηρ στα ελληνικα 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("תוספות למגילת אסתר 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester recke casti 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester recke cásti 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester recke časti 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester recke části 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester recké casti 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester recké cásti 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester recké časti 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester recké části 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester řecke casti 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester řecke cásti 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester řecke časti 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester řecke části 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester řecké casti 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester řecké cásti 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester řecké časti 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester řecké části 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester \(Grieks\) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester (Griyego) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester \(greco\) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester (Griego) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester (Grieks) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester (Gryego) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester (griego) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esther (Greek) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester (Grega) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester (Grego) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester (grega) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester Griyego 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esther (Grec) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esther (grec) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esther graeca 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Graeca Esther 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("எஸ்தர் \(கி\) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester Griego 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester Gryego 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester griego 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Greek Esther 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester Grega 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester Grego 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester greco 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester grega 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esther Grec 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esther grec 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("எஸ்தர் (கி) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Est \(Gr\) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester (Gr) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Greek Esth 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("எஸ் \(கி\) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester Gr. 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esther Gr 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esther gr 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Greek Est 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Est (Gr) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester Gr 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Ester gr 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("எஸ் (கி) 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("《GkEsth》 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esth Gr 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Esth gr 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Gk Esth 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("GkEsth》 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Gr Esth 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Kr. Est 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("《GkEsth 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("エステル書殘篇 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("エステル記補遺 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("에스겔 추가본 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("에스텔 추가본 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Est Gr 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Est gr 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Gk Est 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("GkEsth 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Gr Est 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Kr Est 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("GrEst 1:1").osis()).toEqual("GkEsth.1.1")
		expect(p.parse("Estg 1:1").osis()).toEqual("GkEsth.1.1")
		`
		true
describe "Localized book Esth (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Esth (full)", ->
		`
		expect(p.parse("אסתר, כולל פרקים גנוזים 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("எஸ்தரின் சரித்திரம் 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("estarko pustak 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("एस्तरको पुस्तक 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esterin kirja 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Ksiega Estery 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Ksiegi Estery 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Księga Estery 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Księgi Estery 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Liber Esther 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Книга Есфири 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Книга Естер 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Книга Естир 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Книга Есфір 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ଏଷ୍ଟର ବିବରଣ 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esterarbok 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esterarbók 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esters Bog 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esters bok 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Ks. Estery 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Liv Este a 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Liv Estè a 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Ks Estery 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("سفر أستير 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("เอสเธอร์ 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esterei 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esterin 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("estarko 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Ê-xơ-tê 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Јестира 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("एस्तरको 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("《艾斯德爾傳》 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Aester 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esteer 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Estera 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esters 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Estery 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esther 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Eszter 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Естира 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Есфирь 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("एस्तेर 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ऐस्तेर 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("எஸ்தர் 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("《以斯帖記》 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("《以斯帖记》 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("《艾斯德爾傳 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("艾斯德爾傳》 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Estar 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Ester 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esthr 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("astar 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ester 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("āstar 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Εσθήρ 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Εσθηρ 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Естер 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Естир 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Есфір 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("أستير 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ایستر 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("एस्तर 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("《以斯帖記 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("《以斯帖记 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("エステル書 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("エステル記 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("以斯帖記》 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("以斯帖记》 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("艾斯德爾傳 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("에스테르기 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esta 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Este 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Esth 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Estè 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Eszt 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Јест 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("אסתר 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("آستر 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ਅਸਤਰ 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("エステル 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("以斯帖記 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("以斯帖记 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("에스더기 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Est 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Εσθ 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Ест 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Есф 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("எஸ் 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("อสธ 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("《斯》 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("에스더 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("에스텔 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Es 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Et 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("أس 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("《斯 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("斯》 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("에스 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("斯 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("에 1:1").osis()).toEqual("Esth.1.1")
		p.include_apocrypha(false)
		expect(p.parse("אסתר, כולל פרקים גנוזים 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("எஸ்தரின் சரித்திரம் 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTARKO PUSTAK 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("एस्तरको पुस्तक 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTERIN KIRJA 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("KSIEGA ESTERY 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("KSIEGI ESTERY 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("KSIĘGA ESTERY 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("KSIĘGI ESTERY 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("LIBER ESTHER 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("КНИГА ЕСФИРИ 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("КНИГА ЕСТЕР 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("КНИГА ЕСТИР 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("КНИГА ЕСФІР 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ଏଷ୍ଟର ବିବରଣ 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTERARBOK 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTERARBÓK 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTERS BOG 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTERS BOK 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("KS. ESTERY 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("LIV ESTE A 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("LIV ESTÈ A 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("KS ESTERY 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("سفر أستير 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("เอสเธอร์ 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTEREI 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTERIN 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTARKO 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("Ê-XƠ-TÊ 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ЈЕСТИРА 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("एस्तरको 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("《艾斯德爾傳》 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("AESTER 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTEER 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTERA 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTERS 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTERY 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTHER 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESZTER 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ЕСТИРА 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ЕСФИРЬ 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("एस्तेर 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ऐस्तेर 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("எஸ்தர் 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("《以斯帖記》 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("《以斯帖记》 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("《艾斯德爾傳 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("艾斯德爾傳》 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTAR 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTER 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTHR 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ASTAR 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTER 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ĀSTAR 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ΕΣΘΉΡ 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ΕΣΘΗΡ 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ЕСТЕР 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ЕСТИР 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ЕСФІР 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("أستير 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ایستر 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("एस्तर 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("《以斯帖記 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("《以斯帖记 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("エステル書 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("エステル記 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("以斯帖記》 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("以斯帖记》 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("艾斯德爾傳 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("에스테르기 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTA 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTE 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTH 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESTÈ 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ESZT 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ЈЕСТ 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("אסתר 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("آستر 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ਅਸਤਰ 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("エステル 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("以斯帖記 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("以斯帖记 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("에스더기 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("EST 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ΕΣΘ 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ЕСТ 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ЕСФ 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("எஸ் 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("อสธ 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("《斯》 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("에스더 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("에스텔 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ES 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("ET 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("أس 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("《斯 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("斯》 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("에스 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("斯 1:1").osis()).toEqual("Esth.1.1")
		expect(p.parse("에 1:1").osis()).toEqual("Esth.1.1")
		`
		true
describe "Localized book Job (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Job (full)", ->
		`
		expect(p.parse("யோபுடைய சரித்திரம் 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Kitabu cha Ayubu 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Kitabu cha Yobu 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("अय्यूबको पुस्तक 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ayyubko pustak 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ayyūbko pustak 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Knjiga o Jobu 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Книга на Иова 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Kniha Jobova 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Kniha Jóbova 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ksiega Hioba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ksiega Ijoba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ksiegi Hioba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ksiegi Ijoba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Księga Hioba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Księga Ijoba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Księgi Hioba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Księgi Ijoba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Книга на Иов 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Книга на Йов 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jobin kirja 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ksiega Joba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ksiegi Joba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Księga Joba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Księgi Joba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ଆୟୁବ ପୁସ୍ତକ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Liv Job la 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Liv Jòb la 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Книга Іова 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Книга Иова 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Книга Йова 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("K. Jobova 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("K. Jóbova 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ks. Hioba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ks. Ijoba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Liber Iob 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jobs Bog 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jobs bok 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("K Jobova 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("K Jóbova 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ks Hioba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ks Ijoba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ks. Joba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("سفر أيوب 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("अय्यूबको 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jobsbok 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jobsbók 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ks Joba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ayyubko 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ayyūbko 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ayyoob 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Giobbe 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ایُّوب 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("अय्यूब 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ayubu 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ayuub 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Hioba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Hiobi 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jobin 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ayyūb 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ایّوب 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("अययुब 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ਅੱਯੂਬ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("《約伯傳》 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("《約伯記》 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("《约伯记》 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ayub 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Gióp 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Hiob 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ijob 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Joba 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jobi 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jobs 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Yobu 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Yopu 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Yōpu 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("iyob 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("īyob 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Іова 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Иова 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Йова 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("איוב 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("أيوب 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ایوب 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("इयोब 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ईयोब 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ਅਯੂਬ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ଆୟୁବ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("யோபு 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("《約伯傳 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("《約伯記 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("《约伯记 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("約伯傳》 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("約伯記》 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("约伯记》 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ayu 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Iob 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Iov 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Job 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jov 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jòb 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jób 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Yob 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ιωβ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ιώβ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Јов 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Аюб 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Иов 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Йов 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("โยบ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("《伯》 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ヨフ記 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ヨブ記 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("約伯傳 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("約伯記 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("约伯记 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Gb 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Hi 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jb 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Jó 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ιβ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("أي 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("Ἰβ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("《伯 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ヨフ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ヨブ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("伯》 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("욥기 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("욥 1:1").osis()).toEqual("Job.1.1")
		p.include_apocrypha(false)
		expect(p.parse("யோபுடைய சரித்திரம் 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KITABU CHA AYUBU 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KITABU CHA YOBU 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("अय्यूबको पुस्तक 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("AYYUBKO PUSTAK 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("AYYŪBKO PUSTAK 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KNJIGA O JOBU 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("КНИГА НА ИОВА 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KNIHA JOBOVA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KNIHA JÓBOVA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KSIEGA HIOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KSIEGA IJOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KSIEGI HIOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KSIEGI IJOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KSIĘGA HIOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KSIĘGA IJOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KSIĘGI HIOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KSIĘGI IJOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("КНИГА НА ИОВ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("КНИГА НА ЙОВ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JOBIN KIRJA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KSIEGA JOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KSIEGI JOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KSIĘGA JOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KSIĘGI JOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ଆୟୁବ ପୁସ୍ତକ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("LIV JOB LA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("LIV JÒB LA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("КНИГА ІОВА 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("КНИГА ИОВА 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("КНИГА ЙОВА 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("K. JOBOVA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("K. JÓBOVA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KS. HIOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KS. IJOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("LIBER IOB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JOBS BOG 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JOBS BOK 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("K JOBOVA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("K JÓBOVA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KS HIOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KS IJOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KS. JOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("سفر أيوب 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("अय्यूबको 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JOBSBOK 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JOBSBÓK 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("KS JOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("AYYUBKO 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("AYYŪBKO 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("AYYOOB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("GIOBBE 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ایُّوب 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("अय्यूब 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("AYUBU 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("AYUUB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("HIOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("HIOBI 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JOBIN 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("AYYŪB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ایّوب 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("अययुब 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ਅੱਯੂਬ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("《約伯傳》 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("《約伯記》 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("《约伯记》 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("AYUB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("GIÓP 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("HIOB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("IJOB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JOBA 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JOBI 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JOBS 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("YOBU 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("YOPU 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("YŌPU 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("IYOB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ĪYOB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ІОВА 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ИОВА 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ЙОВА 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("איוב 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("أيوب 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ایوب 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("इयोब 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ईयोब 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ਅਯੂਬ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ଆୟୁବ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("யோபு 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("《約伯傳 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("《約伯記 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("《约伯记 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("約伯傳》 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("約伯記》 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("约伯记》 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("AYU 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("IOB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("IOV 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JOB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JOV 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JÒB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JÓB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("YOB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ΙΩΒ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ΙΏΒ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ЈОВ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("АЮБ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ИОВ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ЙОВ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("โยบ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("《伯》 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ヨフ記 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ヨブ記 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("約伯傳 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("約伯記 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("约伯记 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("GB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("HI 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JB 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("JÓ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ΙΒ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("أي 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ἸΒ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("《伯 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ヨフ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("ヨブ 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("伯》 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("욥기 1:1").osis()).toEqual("Job.1.1")
		expect(p.parse("욥 1:1").osis()).toEqual("Job.1.1")
		`
		true
describe "Localized book Mal (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Mal (full)", ->
		`
		expect(p.parse("ମଲାଖି ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Proroctwo Malachyaszowe 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Книга на пророк Малахия 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Книга пророка Малахии 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Книга пророка Малахіі 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Книга пророка Малахії 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Prophetia Malachiae 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Ksiega Malachiasza 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Ksiegi Malachiasza 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Księga Malachiasza 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Księgi Malachiasza 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Ks. Malachiasza 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Ks Malachiasza 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malakian kirja 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("मलाकीको पुस्तक 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Liv Malachi a 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malakias’ Bog 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Книга Малахіі 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Книга Малахії 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malachiasza 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malakis bok 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Ma-la-chi 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malachias 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malachiaš 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malachiás 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malachiáš 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malaquias 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malaquías 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("سفر ملاخي 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Ma-la-ki 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malaakii 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malachia 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malachie 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malahija 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malakian 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malakias 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malakiás 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malaȟija 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Maleachi 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Maleakhi 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Μαλαχίας 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Μαλαχιας 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Малахија 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("எபிரேயம் 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malachi 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malakee 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malakia 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Maleahi 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malichi 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malkiya 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malkiyā 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("malakʰi 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("malakʰī 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("malākʰi 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("malākʰī 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Малахии 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Малахия 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Малахія 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Малахіі 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Малахії 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("மலாக்கி 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("மல்கியா 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malach 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malaci 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malaki 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malakí 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malaqu 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("malaki 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("malakī 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("malāki 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("malākī 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("มาลาคี 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《玛拉基书》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《瑪拉基亞》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《瑪拉基書》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malac 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malch 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("מלאכי 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("ملاخي 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("ملاکی 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("मलाकी 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("मलाखी 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("ਮਲਾਕੀ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("ମଲାଖି 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("மல்கி 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《玛拉基》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《玛拉基书 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《瑪拉基亞 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《瑪拉基書 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("玛拉基书》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("瑪拉基亞》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("瑪拉基書》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Mala 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Malc 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("मलकी 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《玛拉基 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("マラキ書 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("玛拉基》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("玛拉基书 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("瑪拉基亞 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("瑪拉基書 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("말라기서 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("말라키서 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Mal 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Μαλ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Мал 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("ملا 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("மலா 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("มลค 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《玛》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《瑪》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("マラキ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("玛拉基 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("말라기 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("ﻣﻼﺥ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Ml 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("Μα 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("مل 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《玛 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《瑪 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("マラ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("玛》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("瑪》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("말라 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("玛 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("瑪 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("말 1:1").osis()).toEqual("Mal.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ମଲାଖି ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("PROROCTWO MALACHYASZOWE 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("КНИГА НА ПРОРОК МАЛАХИЯ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("КНИГА ПРОРОКА МАЛАХИИ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("КНИГА ПРОРОКА МАЛАХІІ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("КНИГА ПРОРОКА МАЛАХІЇ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("PROPHETIA MALACHIAE 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("KSIEGA MALACHIASZA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("KSIEGI MALACHIASZA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("KSIĘGA MALACHIASZA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("KSIĘGI MALACHIASZA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("KS. MALACHIASZA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("KS MALACHIASZA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKIAN KIRJA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("मलाकीको पुस्तक 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("LIV MALACHI A 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKIAS’ BOG 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("КНИГА МАЛАХІІ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("КНИГА МАЛАХІЇ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALACHIASZA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKIS BOK 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MA-LA-CHI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALACHIAS 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALACHIAŠ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALACHIÁS 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALACHIÁŠ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAQUIAS 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAQUÍAS 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("سفر ملاخي 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MA-LA-KI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAAKII 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALACHIA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALACHIE 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAHIJA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKIAN 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKIAS 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKIÁS 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAȞIJA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALEACHI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALEAKHI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("ΜΑΛΑΧΊΑΣ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("ΜΑΛΑΧΙΑΣ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("МАЛАХИЈА 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("எபிரேயம் 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALACHI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKEE 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKIA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALEAHI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALICHI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALKIYA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALKIYĀ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKʰI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKʰĪ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALĀKʰI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALĀKʰĪ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("МАЛАХИИ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("МАЛАХИЯ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("МАЛАХІЯ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("МАЛАХІІ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("МАЛАХІЇ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("மலாக்கி 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("மல்கியா 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALACH 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALACI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKÍ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAQU 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAKĪ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALĀKI 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALĀKĪ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("มาลาคี 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《玛拉基书》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《瑪拉基亞》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《瑪拉基書》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALAC 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALCH 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("מלאכי 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("ملاخي 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("ملاکی 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("मलाकी 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("मलाखी 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("ਮਲਾਕੀ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("ମଲାଖି 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("மல்கி 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《玛拉基》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《玛拉基书 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《瑪拉基亞 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《瑪拉基書 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("玛拉基书》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("瑪拉基亞》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("瑪拉基書》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALA 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MALC 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("मलकी 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《玛拉基 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("マラキ書 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("玛拉基》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("玛拉基书 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("瑪拉基亞 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("瑪拉基書 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("말라기서 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("말라키서 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("MAL 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("ΜΑΛ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("МАЛ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("ملا 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("மலா 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("มลค 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《玛》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《瑪》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("マラキ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("玛拉基 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("말라기 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("ﻣﻼﺥ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("ML 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("ΜΑ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("مل 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《玛 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("《瑪 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("マラ 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("玛》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("瑪》 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("말라 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("玛 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("瑪 1:1").osis()).toEqual("Mal.1.1")
		expect(p.parse("말 1:1").osis()).toEqual("Mal.1.1")
		`
		true
describe "Localized book Matt (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Matt (full)", ->
		`
		expect(p.parse("The Gospel according to Saint Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mabuting Balita ayon kay San Mateo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Saint Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattayane lihilele subʰavartaman 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattayane lihilele subʰavartamān 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattayane lihilele ŝubʰavartaman 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattayane lihilele ŝubʰavartamān 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattayāne lihilele subʰavartaman 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattayāne lihilele subʰavartamān 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattayāne lihilele ŝubʰavartaman 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattayāne lihilele ŝubʰavartamān 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mabuting Balita ayon kay Mateo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St. Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evangelium secundum Matthaeum 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evankeliumi Matteuksen mukaan 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ewangelia według sw. Mateusza 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ewangelia według św. Mateusza 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to St Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ewangelia według sw Mateusza 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ewangelia według św Mateusza 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Saint Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("मत्तयाने लिहिलेले शुभवर्तमान 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St. Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel according to Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ebanghelyo ayon kay Mateo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evangelie volgens Matteus 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evangelie volgens Matteüs 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ewangelia wg sw. Mateusza 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ewangelia wg św. Mateusza 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to St Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evangeliet etter Matteus 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evangelium podle Matouse 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evangelium podle Matouše 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ewangelia wg sw Mateusza 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ewangelia wg św Mateusza 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattile lekʰeko susmacar 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattile lekʰeko susmacār 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattile lekʰeko susmācar 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattile lekʰeko susmācār 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattīle lekʰeko susmacar 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattīle lekʰeko susmacār 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattīle lekʰeko susmācar 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattīle lekʰeko susmācār 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Євангелія від св. Матвія 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Євангеліє від св. Матвія 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Евангелието според Матеј 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("От Матея свето Евангелие 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("மத்தேயு எழுதிய சுவிசேஷம் 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("மத்தேயு எழுதிய நற்செய்தி 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ebanghelyo ni San Mateo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evanjelium Podla Matusa 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evanjelium Podla Matuša 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evanjelium Podla Matúsa 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evanjelium Podla Matúša 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evanjelium Podľa Matusa 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evanjelium Podľa Matuša 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evanjelium Podľa Matúsa 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evanjelium Podľa Matúša 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Jevanhelije vid Matvija 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Євангелія від св Матвія 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Євангеліє від св Матвія 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("הבשורה הקדושה על-פי מתי 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("मत्तीले लेखेको सुसमाचार 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel according to Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matteuksen evankeliumi 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Saint Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Евангелие според Матеј 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("El Evangelio de Mateo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Vangelo di San Matteo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ମାଥିଉ ଲିଖିତ ସୁସମାଗ୍ଭର 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("พระวรสารนักบุญแม็ทธิว 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Jevanđelje po Mateju 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matousovo evangelium 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matoušovo evangelium 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St. Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Євангелія від Матвія 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Євангеліє від Матвія 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ebanghelyo ni Mateo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evanðelje po Mateju 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evanđelje po Mateju 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of St Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Євангеліє від Матея 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Јеванђеље по Матеју 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Евангелие от Матфея 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Evangelio de Mateo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ewangelia Mateusza 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Saint Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matteusarguðspjall 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthæusevangeliet 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Sulat ni San Mateo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Евангелие от Матеи 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Евангелие от Матей 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Еванђеље по Матеју 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Injili ya Mathayo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattei evangelium 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matteusevangeliet 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattæusevangeliet 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ungjilli i Mateut 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Vangelo di Matteo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("மத்தேயு நற்செய்தி 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St. Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matteyu Narceyti 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matteyu Naṛceyti 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattēyu Narceyti 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattēyu Naṛceyti 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("The Gospel of Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("הבשורה על פי מתי 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("הבשורה על-פי מתי 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("मत्तीको सुसमाचार 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of St Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattī kī injīl 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("הבשורה לפי מתי 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattī dī ĩjīl 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Κατά Ματθαίον 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Κατά Ματθαιον 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Κατα Ματθαίον 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Κατα Ματθαιον 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("متّی کی انجیل 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ਮੱਤੀ ਦੀ ਇੰਜੀਲ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ew. Mateusza 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Gospel of Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Injil Matius 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("متی کی انجیل 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ew Mateusza 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matteuksen 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Від Матвія 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathhhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathhtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Maththiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthaeus 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("San Mateo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattayane 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattayāne 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("От Матфея 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("إنجيل متى 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("マタイによる福音書 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ma-thi-ơ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathhhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathhiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathhtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Maththew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathtiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthaus 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattheus 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattheüs 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthieu 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthäus 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthæus 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthéus 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthéüs 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matttiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Saint Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ματθαίος 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ματθαιος 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("От Матея 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("मत्तयाने 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matayos 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mateusz 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathayo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathhew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathtew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matteus 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matteyu 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matteüs 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matthwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattiew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matttew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattēyu 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mátthêu 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattile 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattīle 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("मत्तीले 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("மத்தேயு 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("マタイ傳福音書 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("마태오 복음서 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ew Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matayo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mateus 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mathew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matius 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matous 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matouš 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattee 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matteo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattew 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mattwe 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matusa 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matuša 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matéus 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matúsa 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matúša 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St. Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Матвія 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Матеја 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("มัทธิว 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("《瑪竇福音》 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("《馬太福音》 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("《马太福音》 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("マタイ福音書 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("마태오 복음 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matei 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matej 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mateo 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mateu 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matth 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matus 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matuš 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matye 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matús 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matúš 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("St Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("mattī 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Матаи 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Матай 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Матеи 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Матей 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Матеј 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("मत्तय 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("मत्ति 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("मत्ती 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ମାଥିଉ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("《瑪特斐》 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("《瑪竇福音 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("《馬太福音 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("《马太福音 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("瑪竇福音》 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("馬太福音》 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("马太福音》 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("마태복음서 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mate 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Math 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Matt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Maté 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Máte 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Máté 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Ματθ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("متّی 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ਮੱਤੀ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("《瑪特斐 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("マタイ伝 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("マタイ書 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("瑪特斐》 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("瑪竇福音 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("馬太福音 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("马太福音 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("마태복음 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mat 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mth 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mtt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Мат 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("متى 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("متی 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("மத் 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("《太》 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("瑪特斐 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Mt 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Μθ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Мт 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("Мф 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("مت 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("มธ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("《太 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("太》 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("마태 1:1").osis()).toEqual("Matt.1.1")
		p.include_apocrypha(false)
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MABUTING BALITA AYON KAY SAN MATEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTAYANE LIHILELE SUBʰAVARTAMAN 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTAYANE LIHILELE SUBʰAVARTAMĀN 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTAYANE LIHILELE ŜUBʰAVARTAMAN 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTAYANE LIHILELE ŜUBʰAVARTAMĀN 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTAYĀNE LIHILELE SUBʰAVARTAMAN 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTAYĀNE LIHILELE SUBʰAVARTAMĀN 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTAYĀNE LIHILELE ŜUBʰAVARTAMAN 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTAYĀNE LIHILELE ŜUBʰAVARTAMĀN 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MABUTING BALITA AYON KAY MATEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANGELIUM SECUNDUM MATTHAEUM 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANKELIUMI MATTEUKSEN MUKAAN 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EWANGELIA WEDŁUG SW. MATEUSZA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EWANGELIA WEDŁUG ŚW. MATEUSZA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EWANGELIA WEDŁUG SW MATEUSZA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EWANGELIA WEDŁUG ŚW MATEUSZA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("मत्तयाने लिहिलेले शुभवर्तमान 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EBANGHELYO AYON KAY MATEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANGELIE VOLGENS MATTEUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANGELIE VOLGENS MATTEÜS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EWANGELIA WG SW. MATEUSZA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EWANGELIA WG ŚW. MATEUSZA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANGELIET ETTER MATTEUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANGELIUM PODLE MATOUSE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANGELIUM PODLE MATOUŠE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EWANGELIA WG SW MATEUSZA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EWANGELIA WG ŚW MATEUSZA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTILE LEKʰEKO SUSMACAR 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTILE LEKʰEKO SUSMACĀR 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTILE LEKʰEKO SUSMĀCAR 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTILE LEKʰEKO SUSMĀCĀR 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTĪLE LEKʰEKO SUSMACAR 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTĪLE LEKʰEKO SUSMACĀR 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTĪLE LEKʰEKO SUSMĀCAR 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTĪLE LEKʰEKO SUSMĀCĀR 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ЄВАНГЕЛІЯ ВІД СВ. МАТВІЯ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ЄВАНГЕЛІЄ ВІД СВ. МАТВІЯ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ЕВАНГЕЛИЕТО СПОРЕД МАТЕЈ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ОТ МАТЕЯ СВЕТО ЕВАНГЕЛИЕ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("மத்தேயு எழுதிய சுவிசேஷம் 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("மத்தேயு எழுதிய நற்செய்தி 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EBANGHELYO NI SAN MATEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANJELIUM PODLA MATUSA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANJELIUM PODLA MATUŠA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANJELIUM PODLA MATÚSA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANJELIUM PODLA MATÚŠA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANJELIUM PODĽA MATUSA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANJELIUM PODĽA MATUŠA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANJELIUM PODĽA MATÚSA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANJELIUM PODĽA MATÚŠA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("JEVANHELIJE VID MATVIJA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ЄВАНГЕЛІЯ ВІД СВ МАТВІЯ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ЄВАНГЕЛІЄ ВІД СВ МАТВІЯ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("הבשורה הקדושה על-פי מתי 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("मत्तीले लेखेको सुसमाचार 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEUKSEN EVANKELIUMI 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ЕВАНГЕЛИЕ СПОРЕД МАТЕЈ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EL EVANGELIO DE MATEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("VANGELO DI SAN MATTEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ମାଥିଉ ଲିଖିତ ସୁସମାଗ୍ଭର 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("พระวรสารนักบุญแม็ทธิว 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("JEVANĐELJE PO MATEJU 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATOUSOVO EVANGELIUM 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATOUŠOVO EVANGELIUM 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST. MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ЄВАНГЕЛІЯ ВІД МАТВІЯ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ЄВАНГЕЛІЄ ВІД МАТВІЯ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EBANGHELYO NI MATEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANÐELJE PO MATEJU 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANĐELJE PO MATEJU 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF ST MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ЄВАНГЕЛІЄ ВІД МАТЕЯ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ЈЕВАНЂЕЉЕ ПО МАТЕЈУ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ЕВАНГЕЛИЕ ОТ МАТФЕЯ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EVANGELIO DE MATEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EWANGELIA MATEUSZA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF SAINT MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEUSARGUÐSPJALL 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHÆUSEVANGELIET 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SULAT NI SAN MATEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ЕВАНГЕЛИЕ ОТ МАТЕИ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ЕВАНГЕЛИЕ ОТ МАТЕЙ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ЕВАНЂЕЉЕ ПО МАТЕЈУ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("INJILI YA MATHAYO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEI EVANGELIUM 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEUSEVANGELIET 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTÆUSEVANGELIET 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("UNGJILLI I MATEUT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("VANGELO DI MATTEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("மத்தேயு நற்செய்தி 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST. MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEYU NARCEYTI 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEYU NAṚCEYTI 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTĒYU NARCEYTI 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTĒYU NAṚCEYTI 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("THE GOSPEL OF MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("הבשורה על פי מתי 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("הבשורה על-פי מתי 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("मत्तीको सुसमाचार 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF ST MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTĪ KĪ INJĪL 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("הבשורה לפי מתי 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTĪ DĪ ĨJĪL 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ΚΑΤΆ ΜΑΤΘΑΊΟΝ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ΚΑΤΆ ΜΑΤΘΑΙΟΝ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ΚΑΤΑ ΜΑΤΘΑΊΟΝ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ΚΑΤΑ ΜΑΤΘΑΙΟΝ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("متّی کی انجیل 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ਮੱਤੀ ਦੀ ਇੰਜੀਲ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EW. MATEUSZA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("GOSPEL OF MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("INJIL MATIUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("متی کی انجیل 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EW MATEUSZA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEUKSEN 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ВІД МАТВІЯ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHAEUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAN MATEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTAYANE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTAYĀNE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ОТ МАТФЕЯ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("إنجيل متى 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("マタイによる福音書 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MA-THI-Ơ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHAUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHEUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHEÜS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHIEU 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHÄUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHÆUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHÉUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHÉÜS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("SAINT MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ΜΑΤΘΑΊΟΣ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ΜΑΤΘΑΙΟΣ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ОТ МАТЕЯ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("मत्तयाने 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATAYOS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATEUSZ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHAYO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEYU 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEÜS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTHWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTIEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTĒYU 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MÁTTHÊU 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTILE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTĪLE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("मत्तीले 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("மத்தேயு 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("マタイ傳福音書 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("마태오 복음서 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("EW MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATAYO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATEUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATHEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATIUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATOUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATOUŠ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTEW 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTWE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATUSA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATUŠA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATÉUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATÚSA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATÚŠA 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST. MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("МАТВІЯ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("МАТЕЈА 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("มัทธิว 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("《瑪竇福音》 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("《馬太福音》 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("《马太福音》 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("マタイ福音書 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("마태오 복음 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATEI 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATEJ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATEO 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATEU 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTH 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATUS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATUŠ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATYE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATÚS 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATÚŠ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ST MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATTĪ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("МАТАИ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("МАТАЙ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("МАТЕИ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("МАТЕЙ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("МАТЕЈ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("मत्तय 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("मत्ति 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("मत्ती 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ମାଥିଉ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("《瑪特斐》 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("《瑪竇福音 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("《馬太福音 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("《马太福音 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("瑪竇福音》 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("馬太福音》 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("马太福音》 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("마태복음서 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATH 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MATÉ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MÁTE 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MÁTÉ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ΜΑΤΘ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("متّی 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ਮੱਤੀ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("《瑪特斐 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("マタイ伝 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("マタイ書 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("瑪特斐》 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("瑪竇福音 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("馬太福音 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("马太福音 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("마태복음 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MAT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MTH 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MTT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("МАТ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("متى 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("متی 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("மத் 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("《太》 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("瑪特斐 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("MT 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("ΜΘ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("МТ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("МФ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("مت 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("มธ 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("《太 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("太》 1:1").osis()).toEqual("Matt.1.1")
		expect(p.parse("마태 1:1").osis()).toEqual("Matt.1.1")
		`
		true
describe "Localized book Ps (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Ps (full)", ->
		`
		expect(p.parse("Cartea Psalmilor 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Libri i Psalmeve 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ψαλμοί του Δαυίδ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ψαλμοί του Δαυιδ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ψαλμοι του Δαυίδ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ψαλμοι του Δαυιδ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Liber Psalmorum 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Псалми Давидови 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("स्त्रोत्रसंहिता 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("சங்கீத புத்தகம் 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ksiega Psalmow 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ksiega Psalmów 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ksiegi Psalmow 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ksiegi Psalmów 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Księga Psalmow 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Księga Psalmów 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Księgi Psalmow 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Księgi Psalmów 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmien kirja 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("திருப்பாடல்கள் 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salmernes Bog 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("bʰaǳansamgrah 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("bʰaǳansaṃgrah 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("stotrasamhita 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("stotrasamhitā 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("stotrasaṃhita 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("stotrasaṃhitā 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Книга Псалмів 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("स्तोत्रसंहिता 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Kniha zalmov 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Kniha žalmov 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salmenes bok 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("سفر المزامير 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Kniha zalmu 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Kniha zalmů 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Kniha žalmu 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Kniha žalmů 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ks. Psalmow 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ks. Psalmów 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Sabuurradii 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("भजन-सहिन्ता 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("சங்கீதங்கள் 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("திருப்பாடல் 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ks Psalmow 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ks Psalmów 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Liv Som yo 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Liv Sòm yo 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Thánh vịnh 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("भजन संहिता 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ଗୀତିସଂହିତା 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("K. zalmov 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("K. žalmov 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Mga Salmo 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psaltaren 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salmarnir 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Sálmarnir 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Thi Thiên 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Thánh Thi 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Zsoltarok 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Zsoltárok 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("المَزمُور 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("भजनसंग्रह 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ଗାତସଂହିତା 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ଗୀତସଂହିତା 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("เพลงสดุดี 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Cankitam 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Cankītam 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Caṅkitam 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Caṅkītam 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("K zalmov 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("K žalmov 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Mga Awit 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmien 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salmenes 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salmerne 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Псалти́р 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Псалтирь 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("المزامير 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("भजनसग्रह 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("சங்கீதம் 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plasmas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plsssss 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psaalms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalams 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psallms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmau 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmen 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmet 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmii 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmit 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmls 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmul 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmus 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psamlms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psaumes 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslalms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psmalms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salmene 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Псалмів 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Псалтир 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("מזמורים 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("المزمور 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("स्तोत्र 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("சஙகீதம் 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Masmur 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Palsms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Paslms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pasmls 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plamas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plasma 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plasms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plsams 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plssss 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psaalm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psaams 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalam 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psallm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalma 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalme 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmi 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalml 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalmy 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psamas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psamla 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psamlm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psamls 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psamms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psaume 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslalm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslams 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslmas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psmalm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psmals 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Sabuur 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salmau 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salmos 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Zaburi 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Zaltar 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Zaltár 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Žaltar 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Žaltár 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ψαλμοί 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ψαλμοι 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ψαλμος 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ψαλμός 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Псалам 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Псалми 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Псалмы 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Псалом 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("תהילים 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Bhjan 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Jabur 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Palls 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Palms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Palsm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pamls 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pamss 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Paslm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pasms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Passs 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plaas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plams 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plasm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plass 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plsam 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plsms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plsss 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psaaa 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psala 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psalm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psals 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psaml 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psamm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psams 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslam 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslmm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psmal 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psmls 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salme 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salmi 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salmo 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Zabur 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Zalmy 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Zsolt 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("zabūr 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Žalmy 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Забур 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("زبُور 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("مزمور 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ਜ਼ਬੂਰ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("சங்கீ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("สดุดี 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("《聖詠集》 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("詩篇/聖詠 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Awit 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plaa 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plam 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plas 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plms 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plsa 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plsm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Plss 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psal 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psam 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psau 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psla 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pslm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psma 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psml 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psmm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pssm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Salm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Zalm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Žalm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Псал 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("زبور 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("زبُو 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ਜਬੂਰ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("திபா 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("《聖詠集 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("《詩篇》 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("《诗篇》 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("聖詠集》 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psa 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Psm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Pss 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Sal 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Slm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Som 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Sòm 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Thi 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Zab 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Заб 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("भजन 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("சங் 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("สดด 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("《詩》 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("《詩篇 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("《诗》 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("《诗篇 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("聖詠集 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("詩篇》 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("诗篇》 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ps 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Sl 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ψα 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Пс 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("مز 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("《詩 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("《诗 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("詩》 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("詩篇 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("詩編 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("诗》 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("诗篇 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("시편 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Z 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ž 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("詩 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("诗 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("시 1:1").osis()).toEqual("Ps.1.1")
		p.include_apocrypha(false)
		expect(p.parse("CARTEA PSALMILOR 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("LIBRI I PSALMEVE 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ΨΑΛΜΟΊ ΤΟΥ ΔΑΥΊΔ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ΨΑΛΜΟΊ ΤΟΥ ΔΑΥΙΔ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ΨΑΛΜΟΙ ΤΟΥ ΔΑΥΊΔ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ΨΑΛΜΟΙ ΤΟΥ ΔΑΥΙΔ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("LIBER PSALMORUM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ПСАЛМИ ДАВИДОВИ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("स्त्रोत्रसंहिता 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("சங்கீத புத்தகம் 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KSIEGA PSALMOW 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KSIEGA PSALMÓW 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KSIEGI PSALMOW 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KSIEGI PSALMÓW 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KSIĘGA PSALMOW 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KSIĘGA PSALMÓW 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KSIĘGI PSALMOW 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KSIĘGI PSALMÓW 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMIEN KIRJA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("திருப்பாடல்கள் 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMERNES BOG 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("BʰAǱANSAMGRAH 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("BʰAǱANSAṂGRAH 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("STOTRASAMHITA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("STOTRASAMHITĀ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("STOTRASAṂHITA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("STOTRASAṂHITĀ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("КНИГА ПСАЛМІВ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("स्तोत्रसंहिता 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KNIHA ZALMOV 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KNIHA ŽALMOV 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMENES BOK 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("سفر المزامير 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KNIHA ZALMU 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KNIHA ZALMŮ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KNIHA ŽALMU 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KNIHA ŽALMŮ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KS. PSALMOW 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KS. PSALMÓW 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SABUURRADII 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("भजन-सहिन्ता 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("சங்கீதங்கள் 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("திருப்பாடல் 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KS PSALMOW 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("KS PSALMÓW 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("LIV SOM YO 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("LIV SÒM YO 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("THÁNH VỊNH 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("भजन संहिता 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ଗୀତିସଂହିତା 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("K. ZALMOV 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("K. ŽALMOV 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("MGA SALMO 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALTAREN 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMARNIR 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SÁLMARNIR 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("THI THIÊN 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("THÁNH THI 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ZSOLTAROK 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ZSOLTÁROK 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("المَزمُور 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("भजनसंग्रह 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ଗାତସଂହିତା 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ଗୀତସଂହିତା 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("เพลงสดุดี 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("CANKITAM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("CANKĪTAM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("CAṄKITAM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("CAṄKĪTAM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("K ZALMOV 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("K ŽALMOV 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("MGA AWIT 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMIEN 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMENES 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMERNE 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ПСАЛТИ́Р 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ПСАЛТИРЬ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("المزامير 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("भजनसग्रह 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("சங்கீதம் 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLASMAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSSSSS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAALMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALAMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALLMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMAU 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMEN 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMET 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMII 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMIT 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMLS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMUL 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMUS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMLMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAUMES 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLALMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSMALMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMENE 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ПСАЛМІВ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ПСАЛТИР 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("מזמורים 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("المزمور 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("स्तोत्र 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("சஙகீதம் 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("MASMUR 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PALSMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PASLMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PASMLS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLAMAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLASMA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLASMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSAMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSSSS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAALM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAAMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALAM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALLM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALME 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMI 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALML 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALMY 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMLA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMLM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMLS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAUME 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLALM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLAMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLMAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSMALM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSMALS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SABUUR 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMAU 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMOS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ZABURI 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ZALTAR 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ZALTÁR 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ŽALTAR 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ŽALTÁR 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ΨΑΛΜΟΊ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ΨΑΛΜΟΙ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ΨΑΛΜΟΣ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ΨΑΛΜΌΣ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ПСАЛАМ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ПСАЛМИ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ПСАЛМЫ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ПСАЛОМ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("תהילים 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("BHJAN 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("JABUR 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PALLS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PALMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PALSM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PAMLS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PAMSS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PASLM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PASMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PASSS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLAAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLAMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLASM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLASS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSAM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSSS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAAA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSALS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAML 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLAM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLMM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSMAL 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSMLS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALME 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMI 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMO 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ZABUR 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ZALMY 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ZSOLT 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ZABŪR 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ŽALMY 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ЗАБУР 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("زبُور 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("مزمور 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ਜ਼ਬੂਰ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("சங்கீ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("สดุดี 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("《聖詠集》 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("詩篇/聖詠 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("AWIT 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLAA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLAM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLAS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLMS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PLSS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAL 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSAU 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSLM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSMA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSML 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSMM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSSM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SALM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ZALM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ŽALM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ПСАЛ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("زبور 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("زبُو 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ਜਬੂਰ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("திபா 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("《聖詠集 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("《詩篇》 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("《诗篇》 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("聖詠集》 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSA 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PSS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SAL 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SLM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SOM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SÒM 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("THI 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ZAB 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ЗАБ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("भजन 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("சங் 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("สดด 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("《詩》 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("《詩篇 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("《诗》 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("《诗篇 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("聖詠集 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("詩篇》 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("诗篇》 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("PS 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("SL 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ΨΑ 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("ПС 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("مز 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("《詩 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("《诗 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("詩》 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("詩篇 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("詩編 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("诗》 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("诗篇 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("시편 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Z 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("Ž 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("詩 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("诗 1:1").osis()).toEqual("Ps.1.1")
		expect(p.parse("시 1:1").osis()).toEqual("Ps.1.1")
		`
		true
describe "Localized book Eccl (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Eccl (full)", ->
		`
		expect(p.parse("Книга на Еклисиаста или Проповедника 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ksiega Kaznodziei Salomona 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ksiegi Kaznodziei Salomona 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Księga Kaznodziei Salomona 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Księgi Kaznodziei Salomona 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eklezyas - Liv Filozof la 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eklezyas - Liv Filozòf la 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Kaznodziei Salomonowego 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ks. Kaznodziei Salomona 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ks Kaznodziei Salomona 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("சங்கத் திருவுரை ஆகமம் 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ksiega Eklezjastesa 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ksiegi Eklezjastesa 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Księga Eklezjastesa 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Księgi Eklezjastesa 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Книга Екклезіястова 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Liber Ecclesiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Книга Еклезіястова 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Kohelet — Kazatel 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Kohelet — Kazateľ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("upadesakko pustak 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("upadešakko pustak 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Книга Екклесиаста 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Forkynnerens bok 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Kniha kazatelova 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Kniha kazateľova 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ks. Eklezjastesa 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Predikantens bok 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Saarnaajan kirja 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ang Mangangaral 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ks Eklezjastesa 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ksiega Koheleta 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ksiegi Koheleta 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Księga Koheleta 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Księgi Koheleta 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Predikarens bok 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Prædikerens Bog 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("उपदेशकको पुस्तक 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiaiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiastices 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiasticés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Liv Filozof la 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Liv Filozòf la 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiaastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiaistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiasties 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiastiés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaastés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaistés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiastés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiistés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiaiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiastices 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiasticés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("K. kazatelova 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("K. kazateľova 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Predikarboken 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Sabhopadeshak 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Екклезіястова 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaastés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaistés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiaates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiastul 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiastés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiistés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaaste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaasté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaatés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaiste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaisté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaites 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaités 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiaste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiasté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiatés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiiste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiisté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiites 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiités 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiasties 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiastiés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaastés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaistés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiastés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiistés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ekklesiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("K kazatelova 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("K kazateľova 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ks. Koheleta 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Liber Qoelet 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Propovjednik 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Εκκλησιαστής 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Εκκλησιαστης 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Еклезіястова 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Проповедника 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Проповідника 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("சபை உரையாளர் 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaaste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaasté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaatés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaiste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaisté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaites 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaités 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiaste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiasté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiatés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiiste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiisté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiites 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiités 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaate 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaaté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaite 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessaité 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiate 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiaté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiite 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclessiité 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclésiaste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaastés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaistés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiastul 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiastés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiistés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaaste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaasté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaatés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaiste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaisté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaites 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaités 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiaste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiasté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiatés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiiste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiisté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiites 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiités 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesyastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesyastés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecleziastul 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclisiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclisyastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ekklezijast 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eklesiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eklesiastés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eklesyastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eklesyastés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ekleziastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eklisiastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eklisyastes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Forkynneren 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Juru Kotbah 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ks Koheleta 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Mangangaral 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Predikarinn 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Predikerens 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Prédikarinn 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Екклезіяста 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Проповедник 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Размышления 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("سفر الجامعة 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaate 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaaté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaite 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesaité 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiast 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiate 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiaté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiite 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesiité 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclesites 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaaste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaasté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaatés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaiste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaisté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaites 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaités 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiaste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiasté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiates 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiatés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiiste 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiisté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiites 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiités 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesistes 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaate 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaaté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaite 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessaité 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiate 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiaté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiite 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclessiité 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Predikaren 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Predikator 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Predikeren 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Predikuesi 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Predikátor 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Prædikeren 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Prédikator 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Prédikátor 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Saarnaajan 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Truyền đạo 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Wacdiyahii 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("upadesakko 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("upadešakko 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Екклезіяст 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Екклесиаст 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Еклисиаста 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ปัญญาจารย์ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaate 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaaté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaite 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesaité 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiate 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiaté 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiite 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eclesiité 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecleziast 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Giáo huấn 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Magwawali 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Piracanki 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Piracaṅki 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Pregethwr 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Saarnaaja 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Wacdiyaha 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Еклесиаст 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Еклисиаст 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eklezyas 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Giảng Sư 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Koheleth 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Prediger 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Prediker 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Qoheleth 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("upadesak 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("upadeŝak 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("upadešak 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Коге́лет 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("उपदेशकको 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("सभोपदेशक 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("பிரசங்கி 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("コヘレトのことは 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("コヘレトのことば 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Filozof 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Filozòf 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Kazatel 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Kazateľ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Kohelet 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Mhubiri 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Qohelet 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Qohèlet 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("الجامعة 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ਉਪਦੇਸ਼ਕ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("コヘレトの言葉 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Coelet 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Coélet 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eccles 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecclés 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Kaalam 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Qoelet 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Qoèlet 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("המקהיל 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("उपदेशक 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ଉପଦେଶକ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecles 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Manga 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Saarn 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("המרצה 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("واعِظ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("《传道书》 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("《傳道書》 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("《訓道篇》 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Eccl 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Fork 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Giáo 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Kazn 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Prad 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Pred 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Preg 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Prop 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Præd 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Préd 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Saar 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("vāʿẓ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Еккл 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Проп 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Разм 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("קהלת 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("واعظ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("பிரச 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("《传道书 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("《傳道書 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("《訓道篇 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("コヘレト 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("伝道の書 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("传道书》 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("傳道之書 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("傳道書》 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("訓道篇》 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecc 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ecl 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ekl 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Kaz 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Koh 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Mhu 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Qoh 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Wac 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Екк 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Екл 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("सभो 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ปญจ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("《传》 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("《傳》 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("传道书 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("傳道書 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("訓道篇 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("전도서 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("코헬렛 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ec 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Qo 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Εκ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("جا 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("சஉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("Ἐκ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("《传 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("《傳 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("传》 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("傳》 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("코헬 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("传 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("傳 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("전 1:1").osis()).toEqual("Eccl.1.1")
		p.include_apocrypha(false)
		expect(p.parse("КНИГА НА ЕКЛИСИАСТА ИЛИ ПРОПОВЕДНИКА 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KSIEGA KAZNODZIEI SALOMONA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KSIEGI KAZNODZIEI SALOMONA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KSIĘGA KAZNODZIEI SALOMONA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KSIĘGI KAZNODZIEI SALOMONA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKLEZYAS - LIV FILOZOF LA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKLEZYAS - LIV FILOZÒF LA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KAZNODZIEI SALOMONOWEGO 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KS. KAZNODZIEI SALOMONA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KS KAZNODZIEI SALOMONA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("சங்கத் திருவுரை ஆகமம் 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KSIEGA EKLEZJASTESA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KSIEGI EKLEZJASTESA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KSIĘGA EKLEZJASTESA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KSIĘGI EKLEZJASTESA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("КНИГА ЕККЛЕЗІЯСТОВА 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("LIBER ECCLESIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("КНИГА ЕКЛЕЗІЯСТОВА 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KOHELET — KAZATEL 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KOHELET — KAZATEĽ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("UPADESAKKO PUSTAK 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("UPADEŠAKKO PUSTAK 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("КНИГА ЕККЛЕСИАСТА 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("FORKYNNERENS BOK 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KNIHA KAZATELOVA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KNIHA KAZATEĽOVA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KS. EKLEZJASTESA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIKANTENS BOK 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("SAARNAAJAN KIRJA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ANG MANGANGARAL 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KS EKLEZJASTESA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KSIEGA KOHELETA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KSIEGI KOHELETA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KSIĘGA KOHELETA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KSIĘGI KOHELETA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIKARENS BOK 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PRÆDIKERENS BOG 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("उपदेशकको पुस्तक 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIAIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIASTICES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIASTICÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("LIV FILOZOF LA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("LIV FILOZÒF LA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIAASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIAISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIASTIES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIASTIÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAASTÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAISTÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIASTÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIISTÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIAIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIASTICES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIASTICÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("K. KAZATELOVA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("K. KAZATEĽOVA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIKARBOKEN 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("SABHOPADESHAK 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ЕККЛЕЗІЯСТОВА 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAASTÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAISTÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIAATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIASTUL 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIASTÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIISTÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAASTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAASTÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAATÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAISTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAISTÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAITES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAITÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIASTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIASTÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIATÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIISTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIISTÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIITES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIITÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIASTIES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIASTIÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAASTÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAISTÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIASTÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIISTÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKKLESIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("K KAZATELOVA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("K KAZATEĽOVA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KS. KOHELETA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("LIBER QOELET 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PROPOVJEDNIK 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ΕΚΚΛΗΣΙΑΣΤΉΣ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ΕΚΚΛΗΣΙΑΣΤΗΣ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ЕКЛЕЗІЯСТОВА 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ПРОПОВЕДНИКА 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ПРОПОВІДНИКА 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("சபை உரையாளர் 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAASTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAASTÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAATÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAISTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAISTÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAITES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAITÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIASTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIASTÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIATÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIISTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIISTÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIITES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIITÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAATE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAATÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAITE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSAITÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIATE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIATÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIITE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESSIITÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLÉSIASTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAASTÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAISTÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIASTUL 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIASTÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIISTÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAASTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAASTÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAATÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAISTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAISTÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAITES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAITÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIASTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIASTÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIATÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIISTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIISTÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIITES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIITÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESYASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESYASTÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLEZIASTUL 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLISIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLISYASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKKLEZIJAST 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKLESIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKLESIASTÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKLESYASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKLESYASTÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKLEZIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKLISIASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKLISYASTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("FORKYNNEREN 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("JURU KOTBAH 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KS KOHELETA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("MANGANGARAL 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIKARINN 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIKERENS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PRÉDIKARINN 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ЕККЛЕЗІЯСТА 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ПРОПОВЕДНИК 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("РАЗМЫШЛЕНИЯ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("سفر الجامعة 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAATE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAATÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAITE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESAITÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIAST 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIATE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIATÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIITE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESIITÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLESITES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAASTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAASTÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAATÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAISTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAISTÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAITES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAITÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIASTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIASTÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIATES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIATÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIISTE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIISTÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIITES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIITÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESISTES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAATE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAATÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAITE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSAITÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIATE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIATÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIITE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESSIITÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIKAREN 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIKATOR 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIKEREN 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIKUESI 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIKÁTOR 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PRÆDIKEREN 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PRÉDIKATOR 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PRÉDIKÁTOR 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("SAARNAAJAN 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("TRUYỀN ĐẠO 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("WACDIYAHII 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("UPADESAKKO 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("UPADEŠAKKO 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ЕККЛЕЗІЯСТ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ЕККЛЕСИАСТ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ЕКЛИСИАСТА 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ปัญญาจารย์ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAATE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAATÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAITE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESAITÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIATE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIATÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIITE 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLESIITÉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLEZIAST 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("GIÁO HUẤN 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("MAGWAWALI 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PIRACANKI 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PIRACAṄKI 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREGETHWR 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("SAARNAAJA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("WACDIYAHA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ЕКЛЕСИАСТ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ЕКЛИСИАСТ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKLEZYAS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("GIẢNG SƯ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KOHELETH 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIGER 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREDIKER 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("QOHELETH 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("UPADESAK 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("UPADEŜAK 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("UPADEŠAK 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("КОГЕ́ЛЕТ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("उपदेशकको 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("सभोपदेशक 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("பிரசங்கி 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("コヘレトのことは 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("コヘレトのことば 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("FILOZOF 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("FILOZÒF 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KAZATEL 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KAZATEĽ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KOHELET 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("MHUBIRI 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("QOHELET 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("QOHÈLET 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("الجامعة 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ਉਪਦੇਸ਼ਕ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("コヘレトの言葉 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("COELET 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("COÉLET 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCLÉS 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KAALAM 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("QOELET 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("QOÈLET 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("המקהיל 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("उपदेशक 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ଉପଦେଶକ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECLES 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("MANGA 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("SAARN 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("המרצה 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("واعِظ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("《传道书》 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("《傳道書》 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("《訓道篇》 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECCL 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("FORK 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("GIÁO 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KAZN 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PRAD 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PRED 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PREG 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PROP 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PRÆD 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("PRÉD 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("SAAR 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("VĀʿẒ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ЕККЛ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ПРОП 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("РАЗМ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("קהלת 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("واعظ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("பிரச 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("《传道书 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("《傳道書 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("《訓道篇 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("コヘレト 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("伝道の書 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("传道书》 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("傳道之書 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("傳道書》 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("訓道篇》 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECC 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ECL 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EKL 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KAZ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("KOH 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("MHU 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("QOH 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("WAC 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ЕКК 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ЕКЛ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("सभो 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ปญจ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("《传》 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("《傳》 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("传道书 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("傳道書 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("訓道篇 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("전도서 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("코헬렛 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("EC 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("QO 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ΕΚ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("جا 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("சஉ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("ἘΚ 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("《传 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("《傳 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("传》 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("傳》 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("코헬 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("传 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("傳 1:1").osis()).toEqual("Eccl.1.1")
		expect(p.parse("전 1:1").osis()).toEqual("Eccl.1.1")
		`
		true
describe "Localized book Ezek (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Ezek (full)", ->
		`
		expect(p.parse("எசேக்கியேல் தீர்க்கதரிசியின் புத்தகம் 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ଯିହିଜିକଲ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Книга на пророк Иезекииля 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Книга на пророк Езекиил 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Книга пророка Иезекииля 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Книга пророка Єзекііля 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Книга пророка Єзекіїля 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Prophetia Ezechielis 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Hesekielin kirja 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ksiega Ezechiela 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ksiegi Ezechiela 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Księga Ezechiela 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Księgi Ezechiela 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("iǳakielko pustak 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("इजकिएलको पुस्तक 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Liv Ezekyel la 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Liv Ezekyèl la 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezekiels’ Bog 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Hesekiels bok 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ks. Ezechiela 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Esekiels bok 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezekiels Bog 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ks Ezechiela 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ê-xê-chi-ên 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("எசேக்கியேல் 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Hesekielin 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ê-xê-chiên 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ê-xê-ki-ên 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("سفر حزقيال 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ecekkiyel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ecekkiyēl 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ecēkkiyel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ecēkkiyēl 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezechiela 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezechiele 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeequiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeiquiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziequiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziiquiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Hezechiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Iezechiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Jezekiil' 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Jezekiil’ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Jezekiïl' 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Jezekiïl’ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Yahejakel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Yeheskiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Yehezkiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Yehezkièl 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Yehèzkiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Yehèzkièl 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Yexesqeel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Yéhezkiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Yéhezkièl 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Yéhèzkiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Yéhèzkièl 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("iǳakielko 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("yahedzkel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Иезекииль 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Иезекииля 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("حِزقی ایل 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("เอเสเคียล 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ḥiziqīʾīl 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exeekiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exeikiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exiekiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exiikiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezechiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezechiël 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeekiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeequel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeikiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeiquel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezekieli 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezequial 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezequiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziekiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziequel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziikiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziiquel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziquiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezéchiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Hesekiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("yaheǳkel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ézechiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ézéchiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ιεζεκιήλ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ιεζεκιηλ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Єзекііла 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Єзекііль 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Єзекііля 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Єзекіїла 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Єзекіїль 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Єзекіїля 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Иезекиил 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Йезекиил 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("حزقی ایل 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("حزقی‌ایل 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("इजकिएलको 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("यहेज्केल 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ਹਿਜ਼ਕੀਏਲ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ଯିହିଜିକଲ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eseciel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Esekiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Esekyel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Esekíel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exeekel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exeikel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exekiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exiekel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exiikel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exikiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeciel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeekel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeikel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezekial 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezekiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezekyel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezekyèl 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezequel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziekel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziikel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezikiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eziquel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezékiel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("hizkīel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Језекиљ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Езекиел 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Езекиил 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("यहेजकेल 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exekel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Exikel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezekel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezikel 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Езекил 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("יחזקאל 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("حزقيال 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("इजकिएल 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《以西結书》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《以西結書》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《以西结书》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《厄則克耳》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("エセキエル書 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("エゼキエル書 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezech 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezequ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezéch 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ézech 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ézéch 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ιεζεκ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《以西結书 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《以西結書 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《以西结书 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《厄則克耳 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("エセキエル 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("エゼキエル 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("以西結书》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("以西結書》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("以西结书》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("厄則克耳》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("에제키엘서 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Esec 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Esek 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezec 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezek 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezeq 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ê-xê 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ιεζκ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Езек 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("यहेज 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("以西結书 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("以西結書 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("以西结书 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("厄則克耳 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("에스겔서 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("에제키엘 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Esk 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Eze 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezk 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezq 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ezé 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Hes 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Yex 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ιεζ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Јез 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Иез 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Йез 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("எசே 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("อสค 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("᾿Ιζ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《結》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《结》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("에스겔 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Єз 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("حز 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《結 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《结 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("結》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("结》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("에제 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("結 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("结 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("겔 1:1").osis()).toEqual("Ezek.1.1")
		p.include_apocrypha(false)
		expect(p.parse("எசேக்கியேல் தீர்க்கதரிசியின் புத்தகம் 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ଯିହିଜିକଲ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("КНИГА НА ПРОРОК ИЕЗЕКИИЛЯ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("КНИГА НА ПРОРОК ЕЗЕКИИЛ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("КНИГА ПРОРОКА ИЕЗЕКИИЛЯ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("КНИГА ПРОРОКА ЄЗЕКІІЛЯ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("КНИГА ПРОРОКА ЄЗЕКІЇЛЯ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("PROPHETIA EZECHIELIS 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("HESEKIELIN KIRJA 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("KSIEGA EZECHIELA 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("KSIEGI EZECHIELA 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("KSIĘGA EZECHIELA 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("KSIĘGI EZECHIELA 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("IǱAKIELKO PUSTAK 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("इजकिएलको पुस्तक 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("LIV EZEKYEL LA 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("LIV EZEKYÈL LA 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEKIELS’ BOG 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("HESEKIELS BOK 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("KS. EZECHIELA 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ESEKIELS BOK 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEKIELS BOG 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("KS EZECHIELA 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ê-XÊ-CHI-ÊN 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("எசேக்கியேல் 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("HESEKIELIN 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ê-XÊ-CHIÊN 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ê-XÊ-KI-ÊN 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("سفر حزقيال 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ECEKKIYEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ECEKKIYĒL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ECĒKKIYEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ECĒKKIYĒL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZECHIELA 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZECHIELE 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEEQUIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEIQUIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIEQUIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIIQUIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("HEZECHIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("IEZECHIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("JEZEKIIL' 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("JEZEKIIL’ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("JEZEKIÏL' 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("JEZEKIÏL’ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("YAHEJAKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("YEHESKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("YEHEZKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("YEHEZKIÈL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("YEHÈZKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("YEHÈZKIÈL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("YEXESQEEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("YÉHEZKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("YÉHEZKIÈL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("YÉHÈZKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("YÉHÈZKIÈL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("IǱAKIELKO 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("YAHEDZKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ИЕЗЕКИИЛЬ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ИЕЗЕКИИЛЯ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("حِزقی ایل 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("เอเสเคียล 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ḤIZIQĪʾĪL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXEEKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXEIKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXIEKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXIIKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZECHIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZECHIËL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEEKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEEQUEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEIKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEIQUEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEKIELI 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEQUIAL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEQUIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIEKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIEQUEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIIKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIIQUEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIQUIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZÉCHIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("HESEKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("YAHEǱKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ÉZECHIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ÉZÉCHIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ΙΕΖΕΚΙΉΛ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ΙΕΖΕΚΙΗΛ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ЄЗЕКІІЛА 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ЄЗЕКІІЛЬ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ЄЗЕКІІЛЯ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ЄЗЕКІЇЛА 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ЄЗЕКІЇЛЬ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ЄЗЕКІЇЛЯ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ИЕЗЕКИИЛ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ЙЕЗЕКИИЛ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("حزقی ایل 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("حزقی‌ایل 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("इजकिएलको 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("यहेज्केल 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ਹਿਜ਼ਕੀਏਲ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ଯିହିଜିକଲ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ESECIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ESEKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ESEKYEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ESEKÍEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXEEKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXEIKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXEKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXIEKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXIIKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXIKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZECIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEEKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEIKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEKIAL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEKYEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEKYÈL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEQUEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIEKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIIKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIQUEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZÉKIEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("HIZKĪEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ЈЕЗЕКИЉ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ЕЗЕКИЕЛ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ЕЗЕКИИЛ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("यहेजकेल 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXEKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EXIKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZIKEL 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ЕЗЕКИЛ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("יחזקאל 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("حزقيال 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("इजकिएल 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《以西結书》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《以西結書》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《以西结书》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《厄則克耳》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("エセキエル書 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("エゼキエル書 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZECH 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEQU 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZÉCH 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ÉZECH 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ÉZÉCH 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ΙΕΖΕΚ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《以西結书 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《以西結書 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《以西结书 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《厄則克耳 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("エセキエル 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("エゼキエル 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("以西結书》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("以西結書》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("以西结书》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("厄則克耳》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("에제키엘서 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ESEC 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ESEK 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEC 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEK 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZEQ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ê-XÊ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ΙΕΖΚ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ЕЗЕК 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("यहेज 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("以西結书 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("以西結書 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("以西结书 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("厄則克耳 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("에스겔서 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("에제키엘 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ESK 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZE 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZK 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZQ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("EZÉ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("HES 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("YEX 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ΙΕΖ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ЈЕЗ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ИЕЗ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ЙЕЗ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("எசே 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("อสค 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("᾿ΙΖ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《結》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《结》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("에스겔 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ЄЗ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("حز 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《結 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("《结 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("結》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("结》 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("에제 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("結 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("结 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("겔 1:1").osis()).toEqual("Ezek.1.1")
		`
		true
describe "Localized book Hos (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Hos (full)", ->
		`
		expect(p.parse("ହୋଶେୟ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Книга на пророк Осия 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Книга пророка Осии 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Книга пророка Осіі 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Книга пророка Осії 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ksiega Ozeasza 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ksiegi Ozeasza 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Księga Ozeasza 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Księgi Ozeasza 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Prophetia Osee 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hoosean kirja 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("होशेको पुस्तक 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hoseas’ Bog 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ks. Ozeasza 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hoseas bok 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ks Ozeasza 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hoosheeca 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Liv Oze a 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("سفر هوشع 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ہو سیعاہ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("โฮเชยาห์ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hoosean 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hoseias 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hô-sê-a 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ozeasza 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ہوسیعَِ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hoseas 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hoseia 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hoseás 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hozeas 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hozeaš 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hozeás 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hozeáš 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hóseas 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hóseás 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Oseiah 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Oseias 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Oséias 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ਹੋਸ਼ੇਆ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("โฮเชยา 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("《何西阿书》 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("《何西阿書》 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hoosh 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hosea 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hosho 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hošea 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hósea 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ociya 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ociyā 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Oseah 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Oseas 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Oseia 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Osija 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ozeas 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ozeaš 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ozeás 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ozeáš 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("hosey 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("hoŝey 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("hošeā 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("hūsīʿ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ōciya 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ōciyā 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Осија 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Хошеа 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ہوسیع 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("होशेय 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ହୋଶହେ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ହୋଶେୟ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ஒசேயா 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ஓசியா 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ஓசேயா 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("《何西阿书 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("《何西阿書 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("《歐瑟亞》 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ホセアしょ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("何西阿书》 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("何西阿書》 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hoos 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Osea 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Osee 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Osée 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("hose 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("hoše 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ô-sê 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ωσηέ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ωσηε 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Осии 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Осия 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Осія 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Осіі 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Осії 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("הושע 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("هوشع 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("होशे 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("《歐瑟亞 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ホセア書 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("何西阿书 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("何西阿書 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("歐瑟亞》 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("호세아서 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hos 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hoš 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hós 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Oze 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ஓசி 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ஓசே 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ฮชย 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("《何》 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ホセア 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("歐瑟亞 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("호세아 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ho 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Hs 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Os 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Oz 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ωσ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ос 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("هو 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ὠσ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("《何 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("何》 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("호세 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("何 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("호 1:1").osis()).toEqual("Hos.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ହୋଶେୟ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("КНИГА НА ПРОРОК ОСИЯ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("КНИГА ПРОРОКА ОСИИ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("КНИГА ПРОРОКА ОСІІ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("КНИГА ПРОРОКА ОСІЇ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("KSIEGA OZEASZA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("KSIEGI OZEASZA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("KSIĘGA OZEASZA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("KSIĘGI OZEASZA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("PROPHETIA OSEE 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOOSEAN KIRJA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("होशेको पुस्तक 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOSEAS’ BOG 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("KS. OZEASZA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOSEAS BOK 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("KS OZEASZA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOOSHEECA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("LIV OZE A 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("سفر هوشع 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ہو سیعاہ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("โฮเชยาห์ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOOSEAN 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOSEIAS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HÔ-SÊ-A 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OZEASZA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ہوسیعَِ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOSEAS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOSEIA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOSEÁS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOZEAS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOZEAŠ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOZEÁS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOZEÁŠ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HÓSEAS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HÓSEÁS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OSEIAH 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OSEIAS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OSÉIAS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ਹੋਸ਼ੇਆ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("โฮเชยา 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("《何西阿书》 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("《何西阿書》 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOOSH 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOSEA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOSHO 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOŠEA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HÓSEA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OCIYA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OCIYĀ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OSEAH 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OSEAS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OSEIA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OSIJA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OZEAS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OZEAŠ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OZEÁS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OZEÁŠ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOSEY 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOŜEY 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOŠEĀ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HŪSĪʿ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ŌCIYA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ŌCIYĀ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ОСИЈА 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ХОШЕА 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ہوسیع 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("होशेय 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ହୋଶହେ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ହୋଶେୟ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ஒசேயா 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ஓசியா 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ஓசேயா 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("《何西阿书 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("《何西阿書 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("《歐瑟亞》 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ホセアしょ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("何西阿书》 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("何西阿書》 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOOS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OSEA 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OSEE 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OSÉE 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOSE 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOŠE 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("Ô-SÊ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ΩΣΗΈ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ΩΣΗΕ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ОСИИ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ОСИЯ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ОСІЯ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ОСІІ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ОСІЇ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("הושע 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("هوشع 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("होशे 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("《歐瑟亞 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ホセア書 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("何西阿书 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("何西阿書 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("歐瑟亞》 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("호세아서 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HOŠ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HÓS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OZE 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ஓசி 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ஓசே 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ฮชย 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("《何》 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ホセア 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("歐瑟亞 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("호세아 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HO 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("HS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OS 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("OZ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ΩΣ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ОС 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("هو 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("ὨΣ 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("《何 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("何》 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("호세 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("何 1:1").osis()).toEqual("Hos.1.1")
		expect(p.parse("호 1:1").osis()).toEqual("Hos.1.1")
		`
		true
describe "Localized book Obad (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Obad (full)", ->
		`
		expect(p.parse("ଓବଦିଅ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Книга на пророк Авдии 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Книга на пророк Авдий 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Proroctwo Abdyaszowe 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Книга пророка Авдия 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Книга пророка Авдія 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Книга пророка Овдія 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Prophetia Abdiae 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Ksiega Abdiasza 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Ksiegi Abdiasza 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Księga Abdiasza 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Księgi Abdiasza 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ओबदियाको पुस्तक 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Liv Abdyas la 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadjan kirja 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Ks. Abdiasza 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadias' Bog 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadias’ Bog 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Ks Abdiasza 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadjas bok 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("سفر عوبديا 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Cobadyaah 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Ô-ba-đi-a 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ʿabadiyāh 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Abdiasza 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("โอบาดีย์ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("โอบาดีห์ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Abdijas 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Abdijaš 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Abdijás 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Abdijáš 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadeia 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadhah 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadiah 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadias 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadiaš 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadija 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadiás 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadiáš 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadjan 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadjas 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadjaš 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadjás 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadjáš 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obedias 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obediaš 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obediás 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obediáš 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Opatiya 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Opatiyā 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("obadiya 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("obadiyā 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("obadyāh 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Овадија 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ओबद्दाह 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ओबद्याह 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("《俄巴底亚书》 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("《俄巴底亞書》 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Abdias 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Abdiaš 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Abdiás 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Abdiáš 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Abdyas 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Abdías 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadia 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadja 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadjá 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadía 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obidah 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Ovadia 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("obadʰa 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("obadʰā 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Áp-đia 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Óbadia 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Óbadía 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Αβδιου 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Αβδιού 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Οβδίας 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Οβδιας 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Авдија 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Авдије 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("עובדיה 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("عبدیاہ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("عوبديا 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ओबदिया 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ओबद्या 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ओबेधाह 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ਓਬਦਯਾਹ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ஒபதியா 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("《亞北底亞》 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("《俄巴底亚书 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("《俄巴底亞書 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オハテヤしょ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オハデヤしょ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オバテヤしょ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オバデヤしょ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("俄巴底亚书》 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("俄巴底亞書》 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Abdia 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Avdie 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Cobad 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obadj 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obaja 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Ovdij 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Авдии 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Авдий 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Авдия 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Авдиј 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Авдія 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Овдіи 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Овдій 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Овдія 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("עבדיה 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ओबधाह 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ଓବଦିଅ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("《亞北底亞 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オハテア書 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オハテヤ書 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オハデア書 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オハデヤ書 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オバテア書 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オバテヤ書 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オバデア書 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オバデヤ書 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("亞北底亞》 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("俄巴底亚书 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("俄巴底亞書 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("오바드야서 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obad 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ओबधा 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ஒபதி 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オハテヤ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オハデヤ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オバテヤ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オバデヤ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("亞北底亞 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("오바댜서 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("오바디야 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Abd 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Cob 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Oba 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Obd 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Αβδ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Авд 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Овд 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("อบด 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Ἀβδ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("《俄》 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("오바댜 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Ab 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Ob 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Áp 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Ób 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Ов 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("عو 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ओब 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ஒப 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("《俄 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オハ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オバ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("俄》 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("오바 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("俄 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("옵 1:1").osis()).toEqual("Obad.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ଓବଦିଅ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("КНИГА НА ПРОРОК АВДИИ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("КНИГА НА ПРОРОК АВДИЙ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("PROROCTWO ABDYASZOWE 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("КНИГА ПРОРОКА АВДИЯ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("КНИГА ПРОРОКА АВДІЯ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("КНИГА ПРОРОКА ОВДІЯ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("PROPHETIA ABDIAE 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("KSIEGA ABDIASZA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("KSIEGI ABDIASZA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("KSIĘGA ABDIASZA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("KSIĘGI ABDIASZA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ओबदियाको पुस्तक 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("LIV ABDYAS LA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADJAN KIRJA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("KS. ABDIASZA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADIAS' BOG 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADIAS’ BOG 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("KS ABDIASZA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADJAS BOK 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("سفر عوبديا 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("COBADYAAH 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("Ô-BA-ĐI-A 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ʿABADIYĀH 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ABDIASZA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("โอบาดีย์ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("โอบาดีห์ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ABDIJAS 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ABDIJAŠ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ABDIJÁS 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ABDIJÁŠ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADEIA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADHAH 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADIAH 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADIAS 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADIAŠ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADIJA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADIÁS 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADIÁŠ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADJAN 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADJAS 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADJAŠ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADJÁS 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADJÁŠ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBEDIAS 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBEDIAŠ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBEDIÁS 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBEDIÁŠ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OPATIYA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OPATIYĀ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADIYA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADIYĀ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADYĀH 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ОВАДИЈА 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ओबद्दाह 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ओबद्याह 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("《俄巴底亚书》 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("《俄巴底亞書》 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ABDIAS 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ABDIAŠ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ABDIÁS 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ABDIÁŠ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ABDYAS 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ABDÍAS 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADIA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADJA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADJÁ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADÍA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBIDAH 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OVADIA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADʰA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADʰĀ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ÁP-ĐIA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ÓBADIA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ÓBADÍA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ΑΒΔΙΟΥ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ΑΒΔΙΟΎ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ΟΒΔΊΑΣ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ΟΒΔΙΑΣ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("АВДИЈА 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("АВДИЈЕ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("עובדיה 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("عبدیاہ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("عوبديا 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ओबदिया 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ओबद्या 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ओबेधाह 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ਓਬਦਯਾਹ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ஒபதியா 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("《亞北底亞》 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("《俄巴底亚书 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("《俄巴底亞書 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オハテヤしょ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オハデヤしょ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オバテヤしょ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オバデヤしょ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("俄巴底亚书》 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("俄巴底亞書》 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ABDIA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("AVDIE 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("COBAD 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBADJ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBAJA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OVDIJ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("АВДИИ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("АВДИЙ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("АВДИЯ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("АВДИЈ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("АВДІЯ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ОВДІИ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ОВДІЙ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ОВДІЯ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("עבדיה 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ओबधाह 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ଓବଦିଅ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("《亞北底亞 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オハテア書 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オハテヤ書 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オハデア書 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オハデヤ書 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オバテア書 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オバテヤ書 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オバデア書 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オバデヤ書 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("亞北底亞》 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("俄巴底亚书 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("俄巴底亞書 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("오바드야서 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBAD 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ओबधा 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ஒபதி 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オハテヤ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オハデヤ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オバテヤ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オバデヤ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("亞北底亞 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("오바댜서 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("오바디야 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ABD 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("COB 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBA 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OBD 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ΑΒΔ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("АВД 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ОВД 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("อบด 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ἈΒΔ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("《俄》 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("오바댜 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("AB 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("OB 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ÁP 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ÓB 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ОВ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("عو 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ओब 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("ஒப 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("《俄 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オハ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("オバ 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("俄》 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("오바 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("俄 1:1").osis()).toEqual("Obad.1.1")
		expect(p.parse("옵 1:1").osis()).toEqual("Obad.1.1")
		`
		true
describe "Localized book Hag (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Hag (full)", ->
		`
		expect(p.parse("ହାଗୟ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Proroctwo Aggieuszowe 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Книга на пророк Агеи 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Книга на пророк Агей 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Книга пророка Аггея 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Книга пророка Огія 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Prophetia Aggaei 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ksiega Aggeusza 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ksiegi Aggeusza 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Księga Aggeusza 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Księgi Aggeusza 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("हाग्गैको पुस्तक 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggain kirja 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ks. Aggeusza 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggais bok 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggajs Bog 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ks Aggeusza 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Книга Огія 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Liv Aje a 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Aggeusza 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Aggaeus 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggaai 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggain 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggeus 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggiah 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggiai 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Αγγαίος 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Αγγαιος 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("سفر حجي 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Aggaus 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Aggeus 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Aggäus 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ha-gai 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggai 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggaj 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggaí 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggaï 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Haggeo 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Xaggay 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("haggay 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("haggəi 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("hajjaī 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("hāggay 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("hāggəi 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("हाग्गय 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("हाग्गे 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("हाग्गै 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ฮักกัย 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ḥajjai 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("A-gai 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("A-ghê 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ageus 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Aggee 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Aggeo 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Aggée 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Agheu 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Hagai 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Hagaj 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Hagej 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Hageo 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Аггеи 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Аггей 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Аггея 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Хагај 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("حجَّي 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("حجَّی 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ஆகாய் 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《哈該书》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《哈該書》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《哈该书》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ハカイしょ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ハガイしょ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Agai 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Agej 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ageo 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ageu 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Akay 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Akāy 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Hagg 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ohij 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Xagg 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ākay 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ākāy 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Агеи 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Агей 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Агеј 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Огіи 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Огій 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Огія 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("حجاي 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("حجيّ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ਹੱਜਈ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ହାଗୟ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《哈蓋》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《哈該书 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《哈該書 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《哈该书 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ハカイ書 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ハガイ書 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("哈該书》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("哈該書》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("哈该书》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("하까이서 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Agg 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Aje 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Hag 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Hgg 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Xag 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Агг 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("חגי 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("حجي 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("حجی 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ஆகா 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ฮกก 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《哈蓋 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《該》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《该》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ハカイ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ハガイ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("哈蓋》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("哈該书 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("哈該書 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("哈该书 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("학개서 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ag 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Hg 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Αγ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Аг 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ог 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("حج 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("Ἀγ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《該 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《该 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("哈蓋 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("該》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("该》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("하까 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("하깨 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("학개 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("該 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("该 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("학 1:1").osis()).toEqual("Hag.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ହାଗୟ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("PROROCTWO AGGIEUSZOWE 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("КНИГА НА ПРОРОК АГЕИ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("КНИГА НА ПРОРОК АГЕЙ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("КНИГА ПРОРОКА АГГЕЯ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("КНИГА ПРОРОКА ОГІЯ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("PROPHETIA AGGAEI 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("KSIEGA AGGEUSZA 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("KSIEGI AGGEUSZA 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("KSIĘGA AGGEUSZA 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("KSIĘGI AGGEUSZA 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("हाग्गैको पुस्तक 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGAIN KIRJA 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("KS. AGGEUSZA 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGAIS BOK 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGAJS BOG 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("KS AGGEUSZA 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("КНИГА ОГІЯ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("LIV AJE A 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGGEUSZA 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGGAEUS 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGAAI 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGAIN 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGEUS 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGIAH 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGIAI 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ΑΓΓΑΊΟΣ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ΑΓΓΑΙΟΣ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("سفر حجي 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGGAUS 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGGEUS 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGGÄUS 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HA-GAI 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGAI 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGAJ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGAÍ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGAÏ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGEO 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("XAGGAY 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGAY 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGGƏI 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAJJAĪ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HĀGGAY 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HĀGGƏI 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("हाग्गय 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("हाग्गे 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("हाग्गै 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ฮักกัย 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ḤAJJAI 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("A-GAI 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("A-GHÊ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGEUS 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGGEE 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGGEO 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGGÉE 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGHEU 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGAI 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGAJ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGEJ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGEO 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("АГГЕИ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("АГГЕЙ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("АГГЕЯ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ХАГАЈ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("حجَّي 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("حجَّی 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ஆகாய் 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《哈該书》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《哈該書》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《哈该书》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ハカイしょ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ハガイしょ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGAI 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGEJ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGEO 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGEU 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AKAY 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AKĀY 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAGG 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("OHIJ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("XAGG 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ĀKAY 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ĀKĀY 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("АГЕИ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("АГЕЙ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("АГЕЈ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ОГІИ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ОГІЙ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ОГІЯ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("حجاي 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("حجيّ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ਹੱਜਈ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ହାଗୟ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《哈蓋》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《哈該书 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《哈該書 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《哈该书 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ハカイ書 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ハガイ書 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("哈該书》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("哈該書》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("哈该书》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("하까이서 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AGG 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AJE 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HAG 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HGG 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("XAG 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("АГГ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("חגי 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("حجي 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("حجی 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ஆகா 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ฮกก 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《哈蓋 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《該》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《该》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ハカイ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ハガイ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("哈蓋》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("哈該书 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("哈該書 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("哈该书 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("학개서 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("AG 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("HG 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ΑΓ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("АГ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ОГ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("حج 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("ἈΓ 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《該 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("《该 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("哈蓋 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("該》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("该》 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("하까 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("하깨 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("학개 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("該 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("该 1:1").osis()).toEqual("Hag.1.1")
		expect(p.parse("학 1:1").osis()).toEqual("Hag.1.1")
		`
		true
describe "Localized book Hab (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Hab (full)", ->
		`
		expect(p.parse("ହବ‌କ୍‌କୂକ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Книга на пророк Авакума 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Книга на пророк Авакум 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Книга пророка Аввакума 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Книга пророка Авакума 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Proroctwo Abakukowe 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Prophetia Habacuc 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakukin kirja 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Ksiega Habakuka 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Ksiegi Habakuka 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Księga Habakuka 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Księgi Habakuka 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("हबकूकको पुस्तक 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakkuks Bog 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakkuks bok 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Liv Abakik la 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Ks. Habakuka 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Ks Habakuka 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakkakk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakkukk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("அபக்கூக்கு 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Ha-ba-cúc 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habacuque 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakkakk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakkook 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakkukk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakukin 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakakk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakkak 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakkuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakukk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("سفر حبقوق 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ହବ‌କ୍‌କୂକ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habaccuc 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habackuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakakk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakkak 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakkuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakuka 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakuki 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakukk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakuku 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbacac 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbacuc 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakak 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habbakuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Xabaquuq 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("habakkuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("habakkūk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Αββακουμ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Αββακούμ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Αμβακουμ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Αμβακούμ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Аввакума 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ḥabaqqūq 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Abakouk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Abakuka 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habacac 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habacuc 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakak 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habakuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("habakuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("habakūk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Авакума 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Аввакум 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Хабакук 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Хавакук 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("حبقُّوق 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("हबक्कूक 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ฮาบากุก 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Abacuc 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Abakik 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Abakuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Apakuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Apakūk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Avacum 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Avakum 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Āpakuk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Āpakūk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Авакум 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("حبقّوق 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("हबक्कू 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ਹਬਕੱੂਕ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ਹਬੱਕੂਕ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ହବକୁକ୍ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ହବକୂକ୍ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ஆபகூக் 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("《哈巴谷书》 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("《哈巴谷書》 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ハハククしょ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ハバククしょ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habac 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habak 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("חבקוק 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("حبقوق 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("हबकूक 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ਹਬਕੂਕ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("《哈巴谷》 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("《哈巴谷书 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("《哈巴谷書 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ハハクク書 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ハバクク書 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("哈巴谷书》 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("哈巴谷書》 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Abak 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habc 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Habk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Авак 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("《哈巴谷 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ハハクク 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ハバクク 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("哈巴谷》 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("哈巴谷书 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("哈巴谷書 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("하바쿡서 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("하박국서 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Abk 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Hab 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Xab 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Авв 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("हबक 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ฮบก 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("《哈》 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("哈巴谷 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("하바꾹 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("하박국 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Αβ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Ав 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("حب 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("அப 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ஆப 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("Ἀβ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("《哈 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("哈》 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("하바 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("哈 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("합 1:1").osis()).toEqual("Hab.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ହବ‌କ୍‌କୂକ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("КНИГА НА ПРОРОК АВАКУМА 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("КНИГА НА ПРОРОК АВАКУМ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("КНИГА ПРОРОКА АВВАКУМА 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("КНИГА ПРОРОКА АВАКУМА 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("PROROCTWO ABAKUKOWE 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("PROPHETIA HABACUC 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKUKIN KIRJA 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("KSIEGA HABAKUKA 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("KSIEGI HABAKUKA 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("KSIĘGA HABAKUKA 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("KSIĘGI HABAKUKA 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("हबकूकको पुस्तक 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKKUKS BOG 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKKUKS BOK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("LIV ABAKIK LA 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("KS. HABAKUKA 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("KS HABAKUKA 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKKAKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKKUKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("அபக்கூக்கு 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HA-BA-CÚC 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABACUQUE 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKKAKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKKOOK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKKUKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKUKIN 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKAKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKKAK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKUKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("سفر حبقوق 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ହବ‌କ୍‌କୂକ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABACCUC 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABACKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKAKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKKAK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKUKA 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKUKI 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKUKK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKUKU 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBACAC 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBACUC 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKAK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABBAKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("XABAQUUQ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKKŪK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ΑΒΒΑΚΟΥΜ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ΑΒΒΑΚΟΎΜ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ΑΜΒΑΚΟΥΜ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ΑΜΒΑΚΟΎΜ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("АВВАКУМА 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ḤABAQQŪQ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ABAKOUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ABAKUKA 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABACAC 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABACUC 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKAK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAKŪK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("АВАКУМА 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("АВВАКУМ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ХАБАКУК 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ХАВАКУК 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("حبقُّوق 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("हबक्कूक 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ฮาบากุก 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ABACUC 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ABAKIK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ABAKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("APAKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("APAKŪK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("AVACUM 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("AVAKUM 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ĀPAKUK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ĀPAKŪK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("АВАКУМ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("حبقّوق 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("हबक्कू 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ਹਬਕੱੂਕ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ਹਬੱਕੂਕ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ହବକୁକ୍ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ହବକୂକ୍ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ஆபகூக் 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("《哈巴谷书》 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("《哈巴谷書》 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ハハククしょ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ハバククしょ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAC 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABAK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("חבקוק 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("حبقوق 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("हबकूक 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ਹਬਕੂਕ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("《哈巴谷》 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("《哈巴谷书 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("《哈巴谷書 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ハハクク書 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ハバクク書 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("哈巴谷书》 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("哈巴谷書》 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ABAK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABC 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HABK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("АВАК 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("《哈巴谷 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ハハクク 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ハバクク 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("哈巴谷》 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("哈巴谷书 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("哈巴谷書 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("하바쿡서 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("하박국서 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ABK 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("HAB 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("XAB 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("АВВ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("हबक 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ฮบก 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("《哈》 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("哈巴谷 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("하바꾹 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("하박국 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ΑΒ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("АВ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("حب 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("அப 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ஆப 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("ἈΒ 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("《哈 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("哈》 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("하바 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("哈 1:1").osis()).toEqual("Hab.1.1")
		expect(p.parse("합 1:1").osis()).toEqual("Hab.1.1")
		`
		true
describe "Localized book Mic (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Mic (full)", ->
		`
		expect(p.parse("ମୀଖା ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Книга на пророк Михеи 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Книга на пророк Михей 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Книга пророка Михея 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Книга пророка Міхея 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Prophetia Michaeae 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Ksiega Micheasza 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Ksiegi Micheasza 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Księga Micheasza 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Księgi Micheasza 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Ks. Micheasza 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("मीकाको पुस्तक 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Ks Micheasza 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Miikan kirja 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Liv Miche a 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Micheasza 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mikas Bog 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mikas bok 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Michaeas 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Miqueias 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Miquéias 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ΜΙΧΑΪ́ΑΣ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("سفر ميخا 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Michaas 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Michaaš 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Michaás 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Michaáš 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Micheas 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Micheaš 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Micheás 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Micheáš 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Michäas 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Miikaah 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mikeyas 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mikieas 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Miqueas 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ΜΙΧΑΊΑΣ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ΜΙΧΑΙΑΣ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Μιχαΐας 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Μιχαίας 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Μιχαιας 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mi-chê 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Michah 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Michea 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Michee 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Michée 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Miheia 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Miikan 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mikeas 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mikeás 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("مِیکاہ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("மீக்கா 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("มีคาห์ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Meeka 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mi-ca 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Micah 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Micha 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Miche 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mihej 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Miika 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mikah 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mikas 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mikea 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mikha 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Myhej 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Myȟej 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("mikʰa 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("mikʰā 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("mīkāh 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("mīkʰa 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("mīkʰā 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Михеи 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Михей 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Михея 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Михеј 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Міхея 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("میکاہ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ਮੀਕਾਹ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("《弥迦书》 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("《彌迦書》 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("《米該亞》 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mica 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mich 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Miik 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mika 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mikā 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Míka 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mīka 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mīkā 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("mika 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("mikā 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("mīka 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("mīkā 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Миха 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("מיכה 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ميخا 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("मिका 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("मीका 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("मीखा 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ମିଖା 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ମୀଖା 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("மீகா 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("மீக் 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("《弥迦书 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("《彌迦書 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("《米該亞 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ミカしょ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("弥迦书》 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("彌迦書》 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("米該亞》 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mic 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mih 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mik 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Miq 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mík 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Мих 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Міх 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("มคา 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("《弥》 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("《彌》 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ミカ書 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("弥迦书 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("彌迦書 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("米該亞 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("미가서 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("미카서 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Mq 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("Μχ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("مي 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("《弥 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("《彌 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ミカ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("弥》 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("彌》 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("미가 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("미카 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("弥 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("彌 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("미 1:1").osis()).toEqual("Mic.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ମୀଖା ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("КНИГА НА ПРОРОК МИХЕИ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("КНИГА НА ПРОРОК МИХЕЙ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("КНИГА ПРОРОКА МИХЕЯ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("КНИГА ПРОРОКА МІХЕЯ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("PROPHETIA MICHAEAE 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("KSIEGA MICHEASZA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("KSIEGI MICHEASZA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("KSIĘGA MICHEASZA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("KSIĘGI MICHEASZA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("KS. MICHEASZA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("मीकाको पुस्तक 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("KS MICHEASZA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIIKAN KIRJA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("LIV MICHE A 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHEASZA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKAS BOG 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKAS BOK 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHAEAS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIQUEIAS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIQUÉIAS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ΜΙΧΑΪ́ΑΣ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("سفر ميخا 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHAAS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHAAŠ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHAÁS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHAÁŠ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHEAS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHEAŠ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHEÁS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHEÁŠ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHÄAS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIIKAAH 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKEYAS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKIEAS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIQUEAS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ΜΙΧΑΊΑΣ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ΜΙΧΑΙΑΣ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ΜΙΧΑΪ́ΑΣ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ΜΙΧΑΊΑΣ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ΜΙΧΑΙΑΣ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MI-CHÊ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHAH 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHEA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHEE 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHÉE 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIHEIA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIIKAN 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKEAS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKEÁS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("مِیکاہ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("மீக்கா 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("มีคาห์ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MEEKA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MI-CA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICAH 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICHE 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIHEJ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIIKA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKAH 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKAS 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKEA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKHA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MYHEJ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MYȞEJ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKʰA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKʰĀ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MĪKĀH 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MĪKʰA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MĪKʰĀ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("МИХЕИ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("МИХЕЙ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("МИХЕЯ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("МИХЕЈ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("МІХЕЯ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("میکاہ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ਮੀਕਾਹ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("《弥迦书》 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("《彌迦書》 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("《米該亞》 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MICH 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIIK 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKĀ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MÍKA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MĪKA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MĪKĀ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIKĀ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MĪKA 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MĪKĀ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("МИХА 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("מיכה 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ميخا 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("मिका 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("मीका 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("मीखा 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ମିଖା 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ମୀଖା 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("மீகா 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("மீக் 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("《弥迦书 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("《彌迦書 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("《米該亞 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ミカしょ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("弥迦书》 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("彌迦書》 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("米該亞》 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIC 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIH 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIK 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MIQ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MÍK 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("МИХ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("МІХ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("มคา 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("《弥》 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("《彌》 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ミカ書 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("弥迦书 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("彌迦書 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("米該亞 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("미가서 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("미카서 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("MQ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ΜΧ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("مي 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("《弥 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("《彌 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("ミカ 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("弥》 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("彌》 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("미가 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("미카 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("弥 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("彌 1:1").osis()).toEqual("Mic.1.1")
		expect(p.parse("미 1:1").osis()).toEqual("Mic.1.1")
		`
		true
describe "Localized book Zech (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Zech (full)", ->
		`
		expect(p.parse("ଯିଖରିୟ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Книга на пророк Захария 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Книга пророка Захарии 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Книга пророка Захарія 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Prophetia Zachariae 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Ksiega Zachariasza 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Ksiegi Zachariasza 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Księga Zachariasza 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Księgi Zachariasza 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Ks. Zachariasza 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("जकरियाको पुस्तक 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Ks Zachariasza 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sakarjan kirja 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zakarias' Bog 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zakarias’ Bog 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Книга Захаріі 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Книга Захарії 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Liv Zakari a 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sakarjaboken 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sakarjas bok 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Xa-cha-ri-a 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zachariasza 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Xê-ca-ri-a 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("เศคาริยาห์ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sechareia 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sekaryaah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Xa-cha-ri 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zaccharie 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharaah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharaih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zachariah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharias 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zachariaš 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zachariih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zachariás 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zachariáš 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharjas 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharjaš 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharjás 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharjáš 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacheraah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacheraih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacheriah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacheriih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecharaah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecharaih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zechariah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zechariih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecheraah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecheraih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecheriah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecheriih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("zakariyāh 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("زَكَرِيّا 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("سفر زكريا 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("செக்கரியா 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Cakariya 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Cakariyā 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Jakaryah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sacarias 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sacarías 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sacharja 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sakarias 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sakarjan 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacarias 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacarías 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zaccaria 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharia 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharie 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacharih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacherah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacheria 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacherih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zaharija 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zakariah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zakarias 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zakariás 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zakharia 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecharah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecharia 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecharih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecherah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecheria 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zecherih 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zekariah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("jakariya 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("jakariyā 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("jakʰarya 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("jakʰaryā 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("zakaryāh 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Ζαχαρίας 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Ζαχαριας 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Захарија 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sakaria 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sakarja 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sakaría 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zaharia 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zaharij 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zakaria 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zaȟarij 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zekaria 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Закария 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Захарии 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Захария 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Захаріи 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Захарій 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Захарія 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Захаріі 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Захарії 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("जकयार्ह 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("जकर्याह 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ਜ਼ਕਰਜਾਹ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ਜ਼ਕਰਯਾਹ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《撒加利亞書》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《撒迦利亚书》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《撒迦利亞書》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zakari 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("زکریاہ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("जकरिया 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("जखर्या 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("जखऱ्या 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ਜਕਰਯਾਹ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ଯିଖରିୟ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("சகரியா 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《匝加利亞》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《撒加利亞書 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《撒迦利亚书 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《撒迦利亞》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《撒迦利亞書 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("セカリヤしょ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ゼカリヤしょ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("撒加利亞書》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("撒迦利亚书》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("撒迦利亞書》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacar 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacch 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("זכריה 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("زكريا 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("زکریا 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《匝加利亞 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《撒迦利亞 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("セカリヤ書 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ゼカリヤ書 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("匝加利亞》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("撒加利亞書 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("撒迦利亚书 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("撒迦利亞》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("撒迦利亞書 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("즈카르야서 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sach 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sech 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zacc 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zach 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zech 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("சகரி 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("செக் 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("セカリヤ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ゼカリヤ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("匝加利亞 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("撒迦利亞 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("스가랴서 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("즈가리야 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sak 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Sek 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zac 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zah 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zak 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zch 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zec 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zek 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Ζαχ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Зак 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Зах 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ศคย 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《亚》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《亞》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("스가랴 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Xa 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Za 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Zc 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Ζα 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("Ζχ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("زك 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《亚 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《亞 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("亚》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("亞》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("즈카 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("亚 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("亞 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("슥 1:1").osis()).toEqual("Zech.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ଯିଖରିୟ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("КНИГА НА ПРОРОК ЗАХАРИЯ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("КНИГА ПРОРОКА ЗАХАРИИ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("КНИГА ПРОРОКА ЗАХАРІЯ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("PROPHETIA ZACHARIAE 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("KSIEGA ZACHARIASZA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("KSIEGI ZACHARIASZA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("KSIĘGA ZACHARIASZA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("KSIĘGI ZACHARIASZA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("KS. ZACHARIASZA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("जकरियाको पुस्तक 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("KS ZACHARIASZA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SAKARJAN KIRJA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAKARIAS' BOG 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAKARIAS’ BOG 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("КНИГА ЗАХАРІІ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("КНИГА ЗАХАРІЇ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("LIV ZAKARI A 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SAKARJABOKEN 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SAKARJAS BOK 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("XA-CHA-RI-A 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARIASZA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("XÊ-CA-RI-A 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("เศคาริยาห์ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SECHAREIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SEKARYAAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("XA-CHA-RI 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACCHARIE 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARAAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARAIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARIAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARIAS 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARIAŠ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARIIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARIÁS 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARIÁŠ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARJAS 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARJAŠ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARJÁS 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARJÁŠ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHERAAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHERAIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHERIAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHERIIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHARAAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHARAIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHARIAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHARIIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHERAAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHERAIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHERIAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHERIIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAKARIYĀH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("زَكَرِيّا 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("سفر زكريا 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("செக்கரியா 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("CAKARIYA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("CAKARIYĀ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("JAKARYAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SACARIAS 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SACARÍAS 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SACHARJA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SAKARIAS 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SAKARJAN 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACARIAS 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACARÍAS 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACCARIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARIE 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHARIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHERAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHERIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACHERIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAHARIJA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAKARIAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAKARIAS 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAKARIÁS 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAKHARIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHARAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHARIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHARIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHERAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHERIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECHERIH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZEKARIAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("JAKARIYA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("JAKARIYĀ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("JAKʰARYA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("JAKʰARYĀ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAKARYĀH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ΖΑΧΑΡΊΑΣ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ΖΑΧΑΡΙΑΣ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ЗАХАРИЈА 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SAKARIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SAKARJA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SAKARÍA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAHARIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAHARIJ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAKARIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAȞARIJ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZEKARIA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ЗАКАРИЯ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ЗАХАРИИ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ЗАХАРИЯ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ЗАХАРІИ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ЗАХАРІЙ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ЗАХАРІЯ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ЗАХАРІІ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ЗАХАРІЇ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("जकयार्ह 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("जकर्याह 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ਜ਼ਕਰਜਾਹ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ਜ਼ਕਰਯਾਹ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《撒加利亞書》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《撒迦利亚书》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《撒迦利亞書》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAKARI 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("زکریاہ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("जकरिया 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("जखर्या 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("जखऱ्या 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ਜਕਰਯਾਹ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ଯିଖରିୟ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("சகரியா 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《匝加利亞》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《撒加利亞書 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《撒迦利亚书 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《撒迦利亞》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《撒迦利亞書 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("セカリヤしょ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ゼカリヤしょ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("撒加利亞書》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("撒迦利亚书》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("撒迦利亞書》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACAR 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACCH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("זכריה 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("زكريا 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("زکریا 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《匝加利亞 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《撒迦利亞 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("セカリヤ書 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ゼカリヤ書 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("匝加利亞》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("撒加利亞書 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("撒迦利亚书 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("撒迦利亞》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("撒迦利亞書 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("즈카르야서 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SACH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SECH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACC 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZACH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZECH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("சகரி 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("செக் 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("セカリヤ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ゼカリヤ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("匝加利亞 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("撒迦利亞 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("스가랴서 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("즈가리야 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SAK 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("SEK 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAC 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZAK 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZCH 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZEC 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZEK 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ΖΑΧ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ЗАК 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ЗАХ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ศคย 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《亚》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《亞》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("스가랴 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("XA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZA 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ZC 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ΖΑ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("ΖΧ 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("زك 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《亚 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("《亞 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("亚》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("亞》 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("즈카 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("亚 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("亞 1:1").osis()).toEqual("Zech.1.1")
		expect(p.parse("슥 1:1").osis()).toEqual("Zech.1.1")
		`
		true
describe "Localized book Zeph (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Zeph (full)", ->
		`
		expect(p.parse("ସିଫନିୟ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Книга на пророк Софония 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Proroctwo Sofoniaszowe 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Книга пророка Софонии 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Книга пророка Софоніі 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Книга пророка Софонії 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Prophetia Sophoniae 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Ksiega Sofoniasza 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Ksiegi Sofoniasza 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Księga Sofoniasza 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Księgi Sofoniasza 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("सपन्याहको पुस्तक 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Ks. Sofoniasza 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sefanjan kirja 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Ks Sofoniasza 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Liv Sofoni an 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sefanias' Bog 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sefanias’ Bog 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sefanjas bok 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sô-phô-ni-a 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Xê-pha-ni-a 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofoniasza 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zephanaiah 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Ceppaniya 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Ceppaniyā 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Ceppaṉiya 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Ceppaṉiyā 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sefanyaah 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Seffaneia 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sophonias 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Szefanias 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Szefaniás 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Szofonias 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Szofoniás 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sô-phô-ni 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Xô-phô-ni 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zaphaniah 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zephanaia 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zephaniah 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zephanias 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("سفر صفنيا 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("செப்பனியா 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("เศฟันยาห์ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ṣafaniyāh 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sapanyah 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sefanias 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sefanija 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sefanjan 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sepanias 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofonias 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofoniaš 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofonija 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofonije 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofoniás 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofoniáš 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofonjas 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofonjaš 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofonjás 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofonjáš 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofonías 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sophonie 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zafaniah 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zaphania 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zefaniah 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zefanias 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zepanias 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zephania 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zephanja 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zofonias 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zofoniás 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zofónias 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zofóniás 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("safanyāh 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("sapanyah 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("sapanyāh 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("sapʰanya 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("sapʰanyā 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Σοφονίας 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Σοφονιας 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Сефанија 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Софонија 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Софоније 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sefania 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sefanja 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sefanía 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sepania 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofonia 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofonie 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Tefania 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zafania 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zefania 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zefanja 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zefanya 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Ţefania 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Țefania 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Софонии 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Софоний 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Софония 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Софонія 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Софоніі 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Софонії 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("सपन्याह 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ਸਫ਼ਨਯਾਹ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("セファニヤしょ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ゼファニヤしょ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sofoni 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zephan 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("صفنیاہ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("सफन्या 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ସିଫନିୟ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("《索福尼亞》 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("《西番雅书》 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("《西番雅書》 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("セファニア書 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("セファニヤ書 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ゼファニア書 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ゼファニヤ書 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("צפניה 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("صفنيا 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("《索福尼亞 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("《西番雅书 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("《西番雅書 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("セハニヤ書 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("セパニヤ書 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("セファニア 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ゼハニヤ書 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ゼパニヤ書 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ゼファニア 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("索福尼亞》 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("西番雅书》 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("西番雅書》 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("스바니야서 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Seff 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Seph 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Soph 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Szof 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zeph 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("செப் 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("索福尼亞 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("西番雅书 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("西番雅書 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("스바냐서 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("스바니야 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sef 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sof 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Tef 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zef 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zep 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zph 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Ţef 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Țef 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Σφν 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Соф 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("सपन 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ศฟย 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("《番》 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("セファ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ゼファ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("스바냐 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Sf 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Xô 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("Zp 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("صف 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("《番 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("番》 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("스바 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("番 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("습 1:1").osis()).toEqual("Zeph.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ସିଫନିୟ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("КНИГА НА ПРОРОК СОФОНИЯ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("PROROCTWO SOFONIASZOWE 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("КНИГА ПРОРОКА СОФОНИИ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("КНИГА ПРОРОКА СОФОНІІ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("КНИГА ПРОРОКА СОФОНІЇ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("PROPHETIA SOPHONIAE 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("KSIEGA SOFONIASZA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("KSIEGI SOFONIASZA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("KSIĘGA SOFONIASZA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("KSIĘGI SOFONIASZA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("सपन्याहको पुस्तक 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("KS. SOFONIASZA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFANJAN KIRJA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("KS SOFONIASZA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("LIV SOFONI AN 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFANIAS' BOG 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFANIAS’ BOG 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFANJAS BOK 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SÔ-PHÔ-NI-A 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("XÊ-PHA-NI-A 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONIASZA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEPHANAIAH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("CEPPANIYA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("CEPPANIYĀ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("CEPPAṈIYA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("CEPPAṈIYĀ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFANYAAH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFFANEIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOPHONIAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SZEFANIAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SZEFANIÁS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SZOFONIAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SZOFONIÁS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SÔ-PHÔ-NI 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("XÔ-PHÔ-NI 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZAPHANIAH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEPHANAIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEPHANIAH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEPHANIAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("سفر صفنيا 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("செப்பனியா 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("เศฟันยาห์ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ṢAFANIYĀH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SAPANYAH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFANIAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFANIJA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFANJAN 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEPANIAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONIAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONIAŠ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONIJA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONIJE 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONIÁS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONIÁŠ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONJAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONJAŠ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONJÁS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONJÁŠ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONÍAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOPHONIE 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZAFANIAH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZAPHANIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEFANIAH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEFANIAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEPANIAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEPHANIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEPHANJA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZOFONIAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZOFONIÁS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZOFÓNIAS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZOFÓNIÁS 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SAFANYĀH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SAPANYAH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SAPANYĀH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SAPʰANYA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SAPʰANYĀ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ΣΟΦΟΝΊΑΣ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ΣΟΦΟΝΙΑΣ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("СЕФАНИЈА 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("СОФОНИЈА 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("СОФОНИЈЕ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFANIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFANJA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFANÍA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEPANIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONIE 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("TEFANIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZAFANIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEFANIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEFANJA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEFANYA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ŢEFANIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ȚEFANIA 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("СОФОНИИ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("СОФОНИЙ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("СОФОНИЯ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("СОФОНІЯ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("СОФОНІІ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("СОФОНІЇ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("सपन्याह 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ਸਫ਼ਨਯਾਹ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("セファニヤしょ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ゼファニヤしょ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOFONI 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEPHAN 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("صفنیاہ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("सफन्या 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ସିଫନିୟ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("《索福尼亞》 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("《西番雅书》 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("《西番雅書》 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("セファニア書 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("セファニヤ書 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ゼファニア書 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ゼファニヤ書 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("צפניה 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("صفنيا 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("《索福尼亞 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("《西番雅书 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("《西番雅書 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("セハニヤ書 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("セパニヤ書 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("セファニア 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ゼハニヤ書 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ゼパニヤ書 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ゼファニア 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("索福尼亞》 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("西番雅书》 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("西番雅書》 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("스바니야서 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEFF 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEPH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOPH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SZOF 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEPH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("செப் 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("索福尼亞 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("西番雅书 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("西番雅書 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("스바냐서 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("스바니야 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SEF 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SOF 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("TEF 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEF 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZEP 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZPH 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ŢEF 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ȚEF 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ΣΦΝ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("СОФ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("सपन 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ศฟย 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("《番》 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("セファ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ゼファ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("스바냐 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("SF 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("XÔ 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("ZP 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("صف 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("《番 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("番》 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("스바 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("番 1:1").osis()).toEqual("Zeph.1.1")
		expect(p.parse("습 1:1").osis()).toEqual("Zeph.1.1")
		`
		true
describe "Localized book Luke (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Luke (full)", ->
		`
		expect(p.parse("Mabuting Balita ayon kay San Lucas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Mabuting Balita ayon kay San Lukas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Saint Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Saint Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Saint Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Saint Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St. Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St. Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Saint Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Mabuting Balita ayon kay Lucas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Mabuting Balita ayon kay Lukas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St. Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St. Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ebanghelyo ayon kay San Lucas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ebanghelyo ayon kay San Lukas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Saint Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to St Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lukane lihilele subʰavartaman 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lukane lihilele subʰavartamān 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lukane lihilele ŝubʰavartaman 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lukane lihilele ŝubʰavartamān 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lukāne lihilele subʰavartaman 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lukāne lihilele subʰavartamān 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lukāne lihilele ŝubʰavartaman 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lukāne lihilele ŝubʰavartamān 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūkane lihilele subʰavartaman 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūkane lihilele subʰavartamān 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūkane lihilele ŝubʰavartaman 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūkane lihilele ŝubʰavartamān 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūkāne lihilele subʰavartaman 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūkāne lihilele subʰavartamān 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūkāne lihilele ŝubʰavartaman 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūkāne lihilele ŝubʰavartamān 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ewangelia według sw. Łukasza 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ewangelia według św. Łukasza 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Saint Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Saint Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St. Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evankeliumi Luukkaan mukaan 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ewangelia według sw Łukasza 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ewangelia według św Łukasza 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St. Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St. Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St. Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel according to Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("लूकाने लिहिलेले शुभवर्तमान 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ebanghelyo ayon kay Lucas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ebanghelyo ayon kay Lukas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evangelium secundum Lucam 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to St Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ewangelia wg sw. Łukasza 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ewangelia wg św. Łukasza 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Saint Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ebanghelyo ni San Lucas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ebanghelyo ni San Lukas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evangelie volgens Lucas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evangelie volgens Lukas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evangelium podle Lukase 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evangelium podle Lukaše 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evangelium podle Lukáse 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evangelium podle Lukáše 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evanjelium Podla Lukasa 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evanjelium Podla Lukaša 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evanjelium Podla Lukása 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evanjelium Podla Lukáša 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evanjelium Podľa Lukasa 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evanjelium Podľa Lukaša 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evanjelium Podľa Lukása 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evanjelium Podľa Lukáša 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ewangelia wg sw Łukasza 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ewangelia wg św Łukasza 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Saint Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lukale lekʰeko susmacar 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lukale lekʰeko susmacār 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lukale lekʰeko susmācar 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lukale lekʰeko susmācār 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lukāle lekʰeko susmacar 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lukāle lekʰeko susmacār 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lukāle lekʰeko susmācar 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lukāle lekʰeko susmācār 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūkale lekʰeko susmacar 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūkale lekʰeko susmacār 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūkale lekʰeko susmācar 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūkale lekʰeko susmācār 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūkāle lekʰeko susmacar 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūkāle lekʰeko susmacār 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūkāle lekʰeko susmācar 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūkāle lekʰeko susmācār 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Евангелието според Лука 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("От Лука свето Евангелие 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("லூக்கா எழுதிய சுவிசேஷம் 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("லூக்கா எழுதிய நற்செய்தி 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evangeliet etter Lukas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel according to Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Saint Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Saint Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St. Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Євангелія від св. Луки 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Євангеліє від св. Луки 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("लूकाले लेखेको सुसमाचार 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("El Evangelio de Lucas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St. Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Євангелія від св Луки 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Євангеліє від св Луки 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Евангелие според Лука 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Saint Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Jevanhelije vid Luky 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Luukkaan evankeliumi 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St. Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St. Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Saint Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukasovo evangelium 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukašovo evangelium 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukásovo evangelium 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukášovo evangelium 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of St Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Vangelo di San Luca 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Євангеліє від Лу ки 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ଲୂକ ଲିଖିତ ସୁସମାଗ୍ଭର 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evangelio de Lucas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Saint Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Saint Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St. Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Jevanđelje po Luki 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Sulat ni San Lucas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Євангелія від Луки 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Євангеліє від Луки 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("הבשורה על-פי לוקאס 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evanðelje po Luki 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Evanđelje po Luki 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ewangelia Łukasza 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St. Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Јеванђеље по Луки 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Евангелие от Лука 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Евангелие от Луки 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("הבשורה על פי לוקס 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("הבשורה על-פי לוקס 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("พระวรสารนักบุญลูค 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St. Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St. Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukas evangelium 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukasarguðspjall 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lúkasarguðspjall 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("The Gospel of Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ungjilli i Lukes 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ungjilli i Lukës 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Еванђеље по Луки 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("லூக்கா நற்செய்தி 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of St Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukasevangeliet 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Vangelo di Luca 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("लूकाको सुसमाचार 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Injili ya Luka 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukka Narceyti 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukka Naṛceyti 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukkā Narceyti 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukkā Naṛceyti 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lūkka Narceyti 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lūkka Naṛceyti 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lūkkā Narceyti 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lūkkā Naṛceyti 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("لُوقا کی انجیل 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūqā kī injīl 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("لوقا کی انجیل 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ਲੂਕਾ ਦੀ ਇੰਜੀਲ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Gospel of Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūkā dī ĩjīl 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ew. Łukasza 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Injil Lukas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Κατά Λουκάν 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Κατά Λουκαν 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Κατα Λουκάν 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Κατα Λουκαν 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ew Łukasza 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Saint Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("إنجيل لوقا 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Saint Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("San Lucas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Luukkaan 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Saint Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Saint Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St. Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Від Луки 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ルカによる福音書 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St. Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("От Лука 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("От Луки 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Ew Łuk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukacs 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukasa 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukaša 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukács 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukása 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukáša 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Luukos 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St. Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St. Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lukale 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lukane 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lukāle 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lukāne 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūkale 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūkane 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūkāle 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūkāne 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Łukasz 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Λουκάς 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Λουκας 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("लूकाने 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("लूकाले 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("லூக்கா 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("《路加福音》 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ルカ傳福音書 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("루카 복음서 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lluka 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Looka 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lu-ca 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lucas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukas 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukaš 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukka 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukkā 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukás 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lukáš 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lūkka 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lūkkā 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("St Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("لُوقا 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("《路加福音 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ルカ福音書 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("路加福音》 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("누가복음서 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("루카 복음 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Luca 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Luka 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Luke 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Luuk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("lūkā 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Λουκ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Лукa 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Лука 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Луки 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("لوقا 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("लुका 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("लूका 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ਲੂਕਾ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("லூக் 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ลูกา 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("《魯喀》 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("路加福音 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("누가복음 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lik 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Llu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Luc 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Luk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lúk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Łuk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("लूक 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ଲୂକ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("《路》 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("《魯喀 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ルカ伝 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ルカ書 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("魯喀》 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lc 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Lu 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Łk 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Λκ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("Лк 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("لو 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("லூ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ลก 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("《路 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ルカ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("路》 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("魯喀 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("누가 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("루카 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("L 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("路 1:1").osis()).toEqual("Luke.1.1")
		p.include_apocrypha(false)
		expect(p.parse("MABUTING BALITA AYON KAY SAN LUCAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("MABUTING BALITA AYON KAY SAN LUKAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("MABUTING BALITA AYON KAY LUCAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("MABUTING BALITA AYON KAY LUKAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EBANGHELYO AYON KAY SAN LUCAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EBANGHELYO AYON KAY SAN LUKAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKANE LIHILELE SUBʰAVARTAMAN 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKANE LIHILELE SUBʰAVARTAMĀN 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKANE LIHILELE ŜUBʰAVARTAMAN 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKANE LIHILELE ŜUBʰAVARTAMĀN 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKĀNE LIHILELE SUBʰAVARTAMAN 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKĀNE LIHILELE SUBʰAVARTAMĀN 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKĀNE LIHILELE ŜUBʰAVARTAMAN 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKĀNE LIHILELE ŜUBʰAVARTAMĀN 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKANE LIHILELE SUBʰAVARTAMAN 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKANE LIHILELE SUBʰAVARTAMĀN 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKANE LIHILELE ŜUBʰAVARTAMAN 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKANE LIHILELE ŜUBʰAVARTAMĀN 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKĀNE LIHILELE SUBʰAVARTAMAN 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKĀNE LIHILELE SUBʰAVARTAMĀN 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKĀNE LIHILELE ŜUBʰAVARTAMAN 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKĀNE LIHILELE ŜUBʰAVARTAMĀN 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EWANGELIA WEDŁUG SW. ŁUKASZA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EWANGELIA WEDŁUG ŚW. ŁUKASZA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANKELIUMI LUUKKAAN MUKAAN 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EWANGELIA WEDŁUG SW ŁUKASZA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EWANGELIA WEDŁUG ŚW ŁUKASZA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("लूकाने लिहिलेले शुभवर्तमान 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EBANGHELYO AYON KAY LUCAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EBANGHELYO AYON KAY LUKAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANGELIUM SECUNDUM LUCAM 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EWANGELIA WG SW. ŁUKASZA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EWANGELIA WG ŚW. ŁUKASZA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF SAINT LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EBANGHELYO NI SAN LUCAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EBANGHELYO NI SAN LUKAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANGELIE VOLGENS LUCAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANGELIE VOLGENS LUKAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANGELIUM PODLE LUKASE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANGELIUM PODLE LUKAŠE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANGELIUM PODLE LUKÁSE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANGELIUM PODLE LUKÁŠE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANJELIUM PODLA LUKASA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANJELIUM PODLA LUKAŠA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANJELIUM PODLA LUKÁSA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANJELIUM PODLA LUKÁŠA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANJELIUM PODĽA LUKASA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANJELIUM PODĽA LUKAŠA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANJELIUM PODĽA LUKÁSA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANJELIUM PODĽA LUKÁŠA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EWANGELIA WG SW ŁUKASZA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EWANGELIA WG ŚW ŁUKASZA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF SAINT LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKALE LEKʰEKO SUSMACAR 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKALE LEKʰEKO SUSMACĀR 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKALE LEKʰEKO SUSMĀCAR 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKALE LEKʰEKO SUSMĀCĀR 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKĀLE LEKʰEKO SUSMACAR 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKĀLE LEKʰEKO SUSMACĀR 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKĀLE LEKʰEKO SUSMĀCAR 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKĀLE LEKʰEKO SUSMĀCĀR 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKALE LEKʰEKO SUSMACAR 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKALE LEKʰEKO SUSMACĀR 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKALE LEKʰEKO SUSMĀCAR 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKALE LEKʰEKO SUSMĀCĀR 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKĀLE LEKʰEKO SUSMACAR 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKĀLE LEKʰEKO SUSMACĀR 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKĀLE LEKʰEKO SUSMĀCAR 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKĀLE LEKʰEKO SUSMĀCĀR 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ЕВАНГЕЛИЕТО СПОРЕД ЛУКА 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ОТ ЛУКА СВЕТО ЕВАНГЕЛИЕ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("லூக்கா எழுதிய சுவிசேஷம் 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("லூக்கா எழுதிய நற்செய்தி 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANGELIET ETTER LUKAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL ACCORDING TO LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF SAINT LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF SAINT LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST. LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ЄВАНГЕЛІЯ ВІД СВ. ЛУКИ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ЄВАНГЕЛІЄ ВІД СВ. ЛУКИ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("लूकाले लेखेको सुसमाचार 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EL EVANGELIO DE LUCAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST. LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ЄВАНГЕЛІЯ ВІД СВ ЛУКИ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ЄВАНГЕЛІЄ ВІД СВ ЛУКИ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ЕВАНГЕЛИЕ СПОРЕД ЛУКА 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF SAINT LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("JEVANHELIJE VID LUKY 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUUKKAAN EVANKELIUMI 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST. LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST. LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF SAINT LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKASOVO EVANGELIUM 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKAŠOVO EVANGELIUM 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKÁSOVO EVANGELIUM 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKÁŠOVO EVANGELIUM 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF ST LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("VANGELO DI SAN LUCA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ЄВАНГЕЛІЄ ВІД ЛУ КИ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ଲୂକ ଲିଖିତ ସୁସମାଗ୍ଭର 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANGELIO DE LUCAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF SAINT LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF SAINT LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST. LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("JEVANĐELJE PO LUKI 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("SULAT NI SAN LUCAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ЄВАНГЕЛІЯ ВІД ЛУКИ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ЄВАНГЕЛІЄ ВІД ЛУКИ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("הבשורה על-פי לוקאס 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANÐELJE PO LUKI 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EVANĐELJE PO LUKI 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EWANGELIA ŁUKASZA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST. LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ЈЕВАНЂЕЉЕ ПО ЛУКИ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ЕВАНГЕЛИЕ ОТ ЛУКА 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ЕВАНГЕЛИЕ ОТ ЛУКИ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("הבשורה על פי לוקס 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("הבשורה על-פי לוקס 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("พระวรสารนักบุญลูค 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST. LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST. LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKAS EVANGELIUM 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKASARGUÐSPJALL 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LÚKASARGUÐSPJALL 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("THE GOSPEL OF LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("UNGJILLI I LUKES 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("UNGJILLI I LUKËS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ЕВАНЂЕЉЕ ПО ЛУКИ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("லூக்கா நற்செய்தி 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF ST LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKASEVANGELIET 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("VANGELO DI LUCA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("लूकाको सुसमाचार 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("INJILI YA LUKA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKKA NARCEYTI 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKKA NAṚCEYTI 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKKĀ NARCEYTI 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKKĀ NAṚCEYTI 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKKA NARCEYTI 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKKA NAṚCEYTI 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKKĀ NARCEYTI 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKKĀ NAṚCEYTI 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("لُوقا کی انجیل 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪQĀ KĪ INJĪL 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("لوقا کی انجیل 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ਲੂਕਾ ਦੀ ਇੰਜੀਲ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("GOSPEL OF LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKĀ DĪ ĨJĪL 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EW. ŁUKASZA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("INJIL LUKAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ΚΑΤΆ ΛΟΥΚΆΝ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ΚΑΤΆ ΛΟΥΚΑΝ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ΚΑΤΑ ΛΟΥΚΆΝ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ΚΑΤΑ ΛΟΥΚΑΝ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EW ŁUKASZA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("SAINT LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("إنجيل لوقا 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("SAINT LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("SAN LUCAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUUKKAAN 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("SAINT LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("SAINT LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST. LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ВІД ЛУКИ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ルカによる福音書 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST. LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ОТ ЛУКА 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ОТ ЛУКИ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("EW ŁUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKACS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKASA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKAŠA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKÁCS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKÁSA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKÁŠA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUUKOS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST. LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST. LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKALE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKANE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKĀLE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKĀNE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKALE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKANE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKĀLE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKĀNE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ŁUKASZ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ΛΟΥΚΆΣ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ΛΟΥΚΑΣ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("लूकाने 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("लूकाले 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("லூக்கா 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("《路加福音》 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ルカ傳福音書 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("루카 복음서 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LLUKA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LOOKA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LU-CA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUCAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKAS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKAŠ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKKA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKKĀ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKÁS 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKÁŠ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKKA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKKĀ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ST LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("لُوقا 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("《路加福音 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ルカ福音書 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("路加福音》 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("누가복음서 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("루카 복음 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUCA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUKE 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LŪKĀ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ΛΟΥΚ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ЛУКA 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ЛУКА 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ЛУКИ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("لوقا 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("लुका 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("लूका 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ਲੂਕਾ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("லூக் 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ลูกา 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("《魯喀》 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("路加福音 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("누가복음 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LIK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LLU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUC 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LÚK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ŁUK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("लूक 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ଲୂକ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("《路》 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("《魯喀 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ルカ伝 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ルカ書 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("魯喀》 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LC 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("LU 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ŁK 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ΛΚ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ЛК 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("لو 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("லூ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ลก 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("《路 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("ルカ 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("路》 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("魯喀 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("누가 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("루카 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("L 1:1").osis()).toEqual("Luke.1.1")
		expect(p.parse("路 1:1").osis()).toEqual("Luke.1.1")
		`
		true
describe "Localized book Jer (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Jer (full)", ->
		`
		expect(p.parse("ଯିରିମିୟ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("எரேமியா தீர்க்கதரிசியின் புத்தகம் 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Книга на пророк Иеремия 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Книга на пророк Йеремия 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Книга на пророк Еремия 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Книга пророка Иеремии 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Книга пророка Єреміі 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Книга пророка Єремії 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Aklat ni Jeremiah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Aklat ni Jeremias 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Ksiega Jeremiasza 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Ksiegi Jeremiasza 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Księga Jeremiasza 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Księgi Jeremiasza 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Sulat ni Jeremias 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("yarmiyako pustak 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("yarmiyāko pustak 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("यर्मियाको पुस्तक 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremian kirja 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Ks. Jeremiasza 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Liber Ieremiae 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremias' Bog 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremias’ Bog 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Ks Jeremiasza 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Liv Jeremi an 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremias bok 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Giê-rê-mi-a 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremiasza 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("เยเรมียาห์ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Giê-rê-mi 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremaiah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Yeremyaah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("yarmiyako 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("yarmiyāko 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("سفر إرميا 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("यर्मियाको 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Heremias 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Heremyas 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Herimias 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Herimyas 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Hiremias 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Hiremyas 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Hirimias 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Hirimyas 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Ieremias 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeramaih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeramiah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeramiha 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeramiih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremaih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremeia 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremiah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremian 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremias 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremiaš 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremiha 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremiih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremija 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremiás 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremiáš 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremjas 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremjaš 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremjás 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremjáš 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremías 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jerimiah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jerimiih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Yirmayah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("yirmayāh 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("yirmiyāh 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Ιερεμίας 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Ιερεμιας 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Јеремија 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("यिर्मयाह 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ਯਿਰਮਿਯਾਹ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("เยเรมีย์ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Eremiya 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Eremiyā 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Erēmiya 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Erēmiyā 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Geremia 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Ieremia 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeraiah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeramah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeramia 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeramih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremia 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremie 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremía 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jerimah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jerimih 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jermiah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jermmah 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jerémie 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jéremie 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jérémie 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Yeremia 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Yerémia 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Yéremia 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Yérémia 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("yirmaya 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("yirmayā 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Еремија 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Иеремии 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Иеремия 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Йеремия 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("یرمِیاہ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("यर्मिया 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("यिर्मया 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ଯିରିମିୟ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("எரேமியா 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ஏரேமியா 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jeremi 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Єремія 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Єреміі 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Єремії 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Еремия 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ירמיהו 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("یرمیاہ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("《耶利米书》 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("《耶利米書》 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("《耶肋米亞》 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ﺃﺭﻣﻴﺎء 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jerem 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jerém 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jérem 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jérém 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ירמיה 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("أرميا 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("إرميا 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("यिर्म 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("《耶利米书 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("《耶利米書 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("《耶肋米亞 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("エレミヤ書 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ヱレミヤ記 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("耶利米书》 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("耶利米書》 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("耶肋米亞》 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("예레미야서 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jere 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("エレミヤ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("耶利米书 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("耶利米書 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("耶肋米亞 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("예레미아 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("예레미야 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Ger 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Giê 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Ier 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jer 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jér 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Yer 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Јер 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Иер 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Йер 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("எரே 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ஏரே 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ยรม 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("《耶》 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Gr 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Je 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jr 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Jé 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Ιε 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Єр 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Ер 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ار 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("Ἰε 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("《耶 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("耶》 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("예레 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("耶 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("렘 1:1").osis()).toEqual("Jer.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ଯିରିମିୟ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("எரேமியா தீர்க்கதரிசியின் புத்தகம் 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("КНИГА НА ПРОРОК ИЕРЕМИЯ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("КНИГА НА ПРОРОК ЙЕРЕМИЯ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("КНИГА НА ПРОРОК ЕРЕМИЯ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("КНИГА ПРОРОКА ИЕРЕМИИ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("КНИГА ПРОРОКА ЄРЕМІІ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("КНИГА ПРОРОКА ЄРЕМІЇ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("AKLAT NI JEREMIAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("AKLAT NI JEREMIAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("KSIEGA JEREMIASZA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("KSIEGI JEREMIASZA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("KSIĘGA JEREMIASZA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("KSIĘGI JEREMIASZA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("SULAT NI JEREMIAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("YARMIYAKO PUSTAK 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("YARMIYĀKO PUSTAK 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("यर्मियाको पुस्तक 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIAN KIRJA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("KS. JEREMIASZA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("LIBER IEREMIAE 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIAS' BOG 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIAS’ BOG 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("KS JEREMIASZA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("LIV JEREMI AN 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIAS BOK 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("GIÊ-RÊ-MI-A 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIASZA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("เยเรมียาห์ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("GIÊ-RÊ-MI 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMAIAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("YEREMYAAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("YARMIYAKO 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("YARMIYĀKO 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("سفر إرميا 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("यर्मियाको 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("HEREMIAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("HEREMYAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("HERIMIAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("HERIMYAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("HIREMIAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("HIREMYAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("HIRIMIAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("HIRIMYAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("IEREMIAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAMAIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAMIAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAMIHA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAMIIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMAIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMEIA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIAN 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIAŠ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIHA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIJA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIÁS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIÁŠ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMJAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMJAŠ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMJÁS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMJÁŠ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMÍAS 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERIMIAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERIMIIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("YIRMAYAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("YIRMAYĀH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("YIRMIYĀH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ΙΕΡΕΜΊΑΣ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ΙΕΡΕΜΙΑΣ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ЈЕРЕМИЈА 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("यिर्मयाह 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ਯਿਰਮਿਯਾਹ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("เยเรมีย์ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("EREMIYA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("EREMIYĀ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ERĒMIYA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ERĒMIYĀ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("GEREMIA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("IEREMIA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAIAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAMAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAMIA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERAMIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIE 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMÍA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERIMAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERIMIH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERMIAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERMMAH 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERÉMIE 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JÉREMIE 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JÉRÉMIE 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("YEREMIA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("YERÉMIA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("YÉREMIA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("YÉRÉMIA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("YIRMAYA 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("YIRMAYĀ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ЕРЕМИЈА 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ИЕРЕМИИ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ИЕРЕМИЯ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ЙЕРЕМИЯ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("یرمِیاہ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("यर्मिया 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("यिर्मया 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ଯିରିମିୟ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("எரேமியா 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ஏரேமியா 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREMI 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ЄРЕМІЯ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ЄРЕМІІ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ЄРЕМІЇ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ЕРЕМИЯ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ירמיהו 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("یرمیاہ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("《耶利米书》 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("《耶利米書》 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("《耶肋米亞》 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ﺃﺭﻣﻴﺎء 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JEREM 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERÉM 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JÉREM 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JÉRÉM 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ירמיה 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("أرميا 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("إرميا 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("यिर्म 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("《耶利米书 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("《耶利米書 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("《耶肋米亞 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("エレミヤ書 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ヱレミヤ記 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("耶利米书》 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("耶利米書》 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("耶肋米亞》 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("예레미야서 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JERE 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("エレミヤ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("耶利米书 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("耶利米書 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("耶肋米亞 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("예레미아 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("예레미야 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("GER 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("GIÊ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("IER 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JER 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JÉR 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("YER 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ЈЕР 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ИЕР 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ЙЕР 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("எரே 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ஏரே 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ยรม 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("《耶》 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("GR 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JE 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JR 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("JÉ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ΙΕ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ЄР 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ЕР 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ار 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("ἸΕ 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("《耶 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("耶》 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("예레 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("耶 1:1").osis()).toEqual("Jer.1.1")
		expect(p.parse("렘 1:1").osis()).toEqual("Jer.1.1")
		`
		true
describe "Localized book 2Cor (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Cor (full)", ->
		`
		expect(p.parse("Втора писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Второ писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Второ послание на св. ап. Павла до Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhe poslannja apostola Pavla do korynfjan 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Второ послание на св ап. Павла до Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Второ послание на св. ап Павла до Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Второ послание на св ап Павла до Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய இரண்டாவது திருமுகம் 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге. послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друга послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друге послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("رسالة بولس الرسول الثانية إلى أهل كورنثوس 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а. послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е. послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய இரண்டாவது நிருபம் 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("کرنتھِیُوں کے نام پولس رسول کا دوسرا خط 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய இரண்டாம் கடிதம் 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Pavlova druga poslanica Korincanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Pavlova druga poslanica Korinćanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Paulus' Andet Brev til Korintherne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Paulus’ Andet Brev til Korintherne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga List sw. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga List św. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Drugi List sw. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Drugi List św. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Paulus’ andre brev til korinterne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara bref Pals til Korintumanna 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara bref Páls til Korintumanna 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara bréf Pals til Korintumanna 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara bréf Páls til Korintumanna 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara bref Pals til Korintumanna 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara bref Páls til Korintumanna 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara bréf Pals til Korintumanna 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara bréf Páls til Korintumanna 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("कोरिन्थीहरूलाई पावलको दोस्रो पत्र 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga List sw Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga List św Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Drugi List sw Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Drugi List św Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. List sw. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. List św. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("kurintʰiyōṅ ke nām kā dūsrā ḫaṭ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("الرسالة الثانية إلى أهل كورنثوس 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. List sw. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. List św. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II List sw. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II List św. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. List sw Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. List św Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Второ послание към коринтяните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("کُرِنتھِیوں کے نام کا دوسرا خط 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("କରିନ୍ଥୀୟଙ୍କ ପ୍ରତି ଦ୍ୱିତୀୟ ପତ୍ର 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 List sw. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 List św. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. List sw Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. List św Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II List sw Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II List św Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Toinen Kirje korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Waraka wa Pili kwa Wakorintho 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 List sw Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 List św Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Barua ya Pili kwa Wakorintho 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ika- 2 Sulat sa mga Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND Sulat sa mga Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Waraka wa Pili kwa Wakorinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰiharulai dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰiharulaī dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰiharulāi dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰiharulāī dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰiharūlai dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰiharūlaī dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰiharūlāi dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰiharūlāī dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰīharulai dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰīharulaī dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰīharulāi dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰīharulāī dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰīharūlai dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰīharūlaī dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰīharūlāi dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰīharūlāī dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("कोरिन्थीहरूलाई दोस्त्रो पत्र 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("पौलाचे करिंथकरांस दूसरे पत्र 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga Korincanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga Korinćanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga poslanica Korincanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga poslanica Korinæanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga poslanica Korinćanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ika 2 Sulat sa mga Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ika- 2 Sulat sa mga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ikalawang Mga Taga- Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND Sulat sa mga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друга посланица Коринћанима 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("אגרת פולוס השנייה אל-הקורינ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("کرنتھیوں کے نام کا دوسرا خط 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге. Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Kirje korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ika 2 Sulat sa mga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ikalawang Mga Taga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Seconda lettera ai Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друга Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друге Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("האיגרת השנייה אל הקורינתים 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а. Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е. Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Kirje korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Epistula II ad Corinthios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Epistula ad Corinthios II 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Kirje korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korincanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinćanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. посланица Коринћанима 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara bref Pals til Kori 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara bref Páls til Kori 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara bréf Pals til Kori 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara bréf Páls til Kori 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara bref Pals til Kori 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara bref Páls til Kori 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara bréf Pals til Kori 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara bréf Páls til Kori 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("karimtʰkarams dusre patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("karimtʰkaraṃs dusre patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("karimtʰkarāms dusre patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("karimtʰkarāṃs dusre patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("kariṃtʰkarams dusre patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("kariṃtʰkaraṃs dusre patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("kariṃtʰkarāms dusre patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("kariṃtʰkarāṃs dusre patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("kurĩtʰīāṃ nū̃ dūjī pattrī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ਕੁਰਿੰਥੀਆਂ ਨੂੰ ਦੂਜੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Kirje korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korincanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinćanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. посланица Коринћанима 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korincanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinćanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II посланица Коринћанима 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Toinen Korinttolaiskirje 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korincanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinćanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 посланица Коринћанима 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga list do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Drugi list do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Masodik Korinthusiakhoz 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Második Korinthusiakhoz 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Toinen Korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andra Korinthierbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha kniha Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha kniha Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha kniha Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha kniha Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá kniha Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá kniha Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá kniha Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá kniha Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andra Korintherbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andra Korintierbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Deuxiemes Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Deuxièmes Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha list Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha list Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy list Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy list Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy list Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy list Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá list Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá list Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhý list Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhý list Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhý list Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhý list Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinttolaiskirje 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Mga Taga- Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. list do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("करिंथकरांस दुसरे पत्र 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinttolaiskirje 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Mga Taga- Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. list do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andra Korinterbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Deuxieme Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Deuxième Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha list Korinskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha list Korinským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy list Korinskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy list Korinským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá list Korinskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá list Korinským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhý list Korinskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhý list Korinským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinttolaiskirje 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Mga Taga- Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II list do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Mga Taga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinttolaiskirje 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Mga Taga- Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 list do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinthierbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Mga Taga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Mga Taga-Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Anden Korintherbrev 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andet Korintherbrev 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Mga Taga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinthusiakhoz 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. list Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. list Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("השנייה אל הקורינתים 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ କରିନ୍ଥୀୟଙ୍କ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinthierbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Mga Taga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Mga Taga-Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintherbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinthusiakhoz 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintierbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰiharulai 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰiharulaī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰiharulāi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰiharulāī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰiharūlai 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰiharūlaī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰiharūlāi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰiharūlāī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰīharulai 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰīharulaī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰīharulāi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰīharulāī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰīharūlai 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰīharūlaī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰīharūlāi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰīharūlāī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. list Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. list Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andre korinterbrev 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinthusiakhoz 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II list Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II list Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. list Korinskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. list Korinským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ikalawang Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ikalawang Korintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara Korintubref 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara Korintubréf 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara Kórintubref 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara Kórintubréf 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara Korintubref 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara Korintubréf 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara Kórintubref 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara Kórintubréf 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Προς Κορινθίους Β' 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Προς Κορινθίους Βʹ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Προς Κορινθίους Βʹ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Προς Κορινθίους Β΄ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Προς Κορινθίους Β’ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Προς Κορινθιους Β' 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Προς Κορινθιους Βʹ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Προς Κορινθιους Βʹ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Προς Κορινθιους Β΄ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Προς Κορινθιους Β’ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("코린토 신자들에게 보낸 둘째 서간 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintherbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinthusiakhoz 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintierbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰiharulai 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰiharulaī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰiharulāi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰiharulāī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰiharūlai 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰiharūlaī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰiharūlāi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰiharūlāī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰīharulai 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰīharulaī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰīharulāi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰīharulāī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰīharūlai 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰīharūlaī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰīharūlāi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰīharūlāī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 list Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 list Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге. до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е. к Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-я. к Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinterbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. list Korinskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. list Korinským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कोरिन्थीहरूलाई 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2eme. Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ème. Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andre Korintierne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga Korincanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga Korinćanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II list Korinskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II list Korinským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ikalawang Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ikalawang Korinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Masodik Korinthus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Masodik Korintusi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Második Korinthus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Második Korintusi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Segunda Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Segunda Coríntios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Segundo Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Segundo Coríntios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Втора Коринканите 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Втора Коринтяните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Втора Коринќаните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Второ Коринканите 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Второ Коринќаните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друга Коринћанима 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друга до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друге до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinterbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintiyarukku 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 list Korinskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 list Korinským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कोरिन्थीहरूलाई 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а. до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е к Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е. до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-я к Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintherbrev 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2de. Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2eme Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ème Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2е. к Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2я. к Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Anden Korinterne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Dezyem Korentyen 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Dezyèm Korentyen 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhý Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhý Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhý Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhý Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Zweite Korinther 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ad Corinthios II 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Втора Коринтјани 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Второ Коринтјани 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ କରିନ୍ଥୀୟ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintherbrev 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 e. Korintasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 i. Korintasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 k. Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 k. Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 k. Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 k. Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 karimtʰkarams 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 karimtʰkaraṃs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 karimtʰkarāms 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 karimtʰkarāṃs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 kariṃtʰkarams 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 kariṃtʰkaraṃs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 kariṃtʰkarāms 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 kariṃtʰkarāṃs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 ਕੁਰਿੰਥੀਆਂ ਨੂੰ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге. Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е. Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-я. Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Kurinthiayon 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Taga-Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korinterbrev 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. к Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कुरिन्यि़यों 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2d. Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2de Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2е к Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2я к Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Drugi Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiaid 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korincanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinćanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Коринканите 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Коринтяните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Коринћанима 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Коринќаните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintos Labaad 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Pili Wakorintho 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Seconda Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Secondo Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Втора Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друга Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друге Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("دوم-کُرِنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("كورنثوس الثانية 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Kurinthiayon 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Taga-Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 e Korintasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 e. Koritasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 i Korintasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 i. Koritasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 k Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 k Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 k Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 k Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korinterbrev 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 к Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कुरिन्यि़यों 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а. Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге. Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге. коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е. Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-я Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiaid 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korincanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintierne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinćanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Коринканите 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Коринтяните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Коринћанима 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Коринќаните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कुरिन्थियों 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. କରିନ୍ଥୀୟଙ୍କ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2.-کُرِنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2.o. Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2.º. Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2d Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2е. Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2я. Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andre Korinter 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga Koryntow 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga Koryntów 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Drugi Koryntow 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Drugi Koryntów 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiaid 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korincanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinćanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Коринканите 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Коринтяните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Коринћанима 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Коринќаните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintieni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cô-rinh-tô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Wakorintho 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Коринтјани 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Pili Wakorinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друга Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друга коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друге Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друге коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("دوم کرنتھِیُوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("دوم کُرنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiaid 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korincanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintierne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinćanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 e Koritasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 i Koritasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Коринканите 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Коринтяните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Коринћанима 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Коринќаните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कुरिन्थियों 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 କରିନ୍ଥୀୟଙ୍କ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 கொரிந்தியர் 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а. Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а. коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е. Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е. коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-کُرِنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintieni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cô-rinh-tô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinterne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Wakorintho 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Коринтјани 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. کرنتھِیُوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. کُرنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कुरन्थियों 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कुरिन्थियो 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2.o Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2.º Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2a. Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2a. Coríntios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2o. Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2o. Coríntios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2º. Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2е Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2я Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Corinthios II 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Dezyem Korint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Dezyèm Korint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintieni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cô-rinh-tô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Wakorintho 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Коринтјани 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinteni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Coríntios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korentyen 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinthus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintusi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Wakorinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Wakorintho II 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β' Κορινθίους 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β' Κορινθιους 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ Κορινθίους 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ Κορινθιους 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ Κορινθίους 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ Κορινθιους 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β΄ Κορινθίους 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β΄ Κορινθιους 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β’ Κορινθίους 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β’ Κορινθιους 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("۲-کُرِنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintieni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cô-rinh-tô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinterne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Wakorintho 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Коринтјани 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 کرنتھِیُوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 کُرنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 करिंथकरांस 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कुरन्थियों 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कुरिन्थियो 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinteni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Coríntios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korentyen 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinther 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinthus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintusi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Koritasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Wakorinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कोरिन्‍थी 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2a Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2a Coríntios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2o Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2o Coríntios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2º Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinteni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Coríntios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korentyen 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinthus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintusi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Wakorinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Koryntow 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Koryntów 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("دوم کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("دوم۔کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("۲ کرنتھِیُوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("۲ کُرنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("コリントの信徒への手紙二 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("コリント人への第二の手紙 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinteni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Coríntios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korentyen 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinther 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinthus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintusi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Koritasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Wakorinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 kurĩtʰīāṃ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कोरिन्‍थी 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 ਕੁਰਿੰਥੀਆਂ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinter 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Koryntow 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Koryntów 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कोरिन्थी 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. କରିନ୍ଥୀୟ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2.۔کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2°. Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Koryntow 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Koryntów 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cô-rinh 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Côrintô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinta 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Masodik Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Második Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinter 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Koryntow 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Koryntów 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कोरिन्थी 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 କରିନ୍ଥୀୟ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cô-rinh 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Côrintô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinta 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कुरिन्थ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. โครินธ์ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2° Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2۔کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cô-rinh 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Côrintô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinta 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("۲ کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("۲۔کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("コリント人への後の書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("コリント人への手紙二 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinti 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cô-rinh 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Côrintô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinta 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कुरिन्थ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 โครินธ์ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Anden Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andre Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Втора Кор 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corini 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Pili Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha K 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy K 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá K 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhý K 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Кор 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《哥林多后书》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《哥林多後書》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《格林多後書》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《歌林多後書》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《适凌爾福後》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 கொரி 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Кор 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DruhaK 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DruhyK 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DruháK 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DruhýK 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Кор 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β' Κορ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ Κορ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ Κορ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β΄ Κορ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β’ Κορ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《哥林多后书 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《哥林多後書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《格林多後書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《歌林多後書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《适凌爾福後 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("コリント 2 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("コリント後書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("哥林多后书》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("哥林多後書》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("格林多後書》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("歌林多後書》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("适凌爾福後》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Кор 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 قور 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β' Κο 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ Κο 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ Κο 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β΄ Κο 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β’ Κο 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("哥林多后书 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("哥林多後書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("格林多後書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("歌林多後書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("适凌爾福後 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("고린도2서 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("고린도후서 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("코린토2서 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 கொ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 คธ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 คร 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《林后》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《林後》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2كو 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2코린 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《林后 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《林後 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("林后》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("林後》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("林后 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("林後 1:1").osis()).toEqual("2Cor.1.1")
		`
		true
	it "should handle non-Latin digits in book: 2Cor (full)", ->
		p.set_options non_latin_digits_strategy: "replace"
		`
		expect(p.parse("Втора писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Второ писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Второ послание на св. ап. Павла до Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhe poslannja apostola Pavla do korynfjan 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Второ послание на св ап. Павла до Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Второ послание на св. ап Павла до Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Второ послание на св ап Павла до Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய இரண்டாவது திருமுகம் 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге. послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintiyarukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друга послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друге послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("رسالة بولس الرسول الثانية إلى أهل كورنثوس 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а. послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е. послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய இரண்டாவது நிருபம் 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("کرنتھِیُوں کے نام پولس رسول کا دوسرا خط 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய இரண்டாம் கடிதம் 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 послання апостола Павла до коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Pavlova druga poslanica Korincanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Pavlova druga poslanica Korinćanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Paulus' Andet Brev til Korintherne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Paulus’ Andet Brev til Korintherne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga List sw. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga List św. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Drugi List sw. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Drugi List św. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Paulus’ andre brev til korinterne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara bref Pals til Korintumanna 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara bref Páls til Korintumanna 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara bréf Pals til Korintumanna 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara bréf Páls til Korintumanna 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara bref Pals til Korintumanna 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara bref Páls til Korintumanna 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara bréf Pals til Korintumanna 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara bréf Páls til Korintumanna 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("कोरिन्थीहरूलाई पावलको दोस्रो पत्र 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga List sw Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga List św Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Drugi List sw Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Drugi List św Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. List sw. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. List św. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("kurintʰiyōṅ ke nām kā dūsrā ḫaṭ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("الرسالة الثانية إلى أهل كورنثوس 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. List sw. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. List św. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II List sw. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II List św. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. List sw Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. List św Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Второ послание към коринтяните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("کُرِنتھِیوں کے نام کا دوسرا خط 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("କରିନ୍ଥୀୟଙ୍କ ପ୍ରତି ଦ୍ୱିତୀୟ ପତ୍ର 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 List sw. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 List św. Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. List sw Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. List św Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II List sw Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II List św Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Toinen Kirje korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Waraka wa Pili kwa Wakorintho 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 List sw Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 List św Pawła do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Barua ya Pili kwa Wakorintho 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ika- 2 Sulat sa mga Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND Sulat sa mga Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Waraka wa Pili kwa Wakorinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰiharulai dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰiharulaī dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰiharulāi dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰiharulāī dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰiharūlai dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰiharūlaī dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰiharūlāi dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰiharūlāī dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰīharulai dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰīharulaī dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰīharulāi dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰīharulāī dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰīharūlai dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰīharūlaī dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰīharūlāi dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("korintʰīharūlāī dostro patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("कोरिन्थीहरूलाई दोस्त्रो पत्र 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("पौलाचे करिंथकरांस दूसरे पत्र 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga Korincanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga Korinćanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga poslanica Korincanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga poslanica Korinæanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga poslanica Korinćanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ika 2 Sulat sa mga Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ika- 2 Sulat sa mga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ikalawang Mga Taga- Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND Sulat sa mga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друга посланица Коринћанима 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("אגרת פולוס השנייה אל-הקורינ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("کرنتھیوں کے نام کا دوسرا خط 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге. Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Kirje korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ika 2 Sulat sa mga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ikalawang Mga Taga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Seconda lettera ai Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друга Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друге Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("האיגרת השנייה אל הקורינתים 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а. Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е. Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Kirje korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Epistula II ad Corinthios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Epistula ad Corinthios II 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Kirje korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korincanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinćanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. посланица Коринћанима 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara bref Pals til Kori 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara bref Páls til Kori 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara bréf Pals til Kori 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara bréf Páls til Kori 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara bref Pals til Kori 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara bref Páls til Kori 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara bréf Pals til Kori 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara bréf Páls til Kori 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("karimtʰkarams dusre patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("karimtʰkaraṃs dusre patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("karimtʰkarāms dusre patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("karimtʰkarāṃs dusre patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("kariṃtʰkarams dusre patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("kariṃtʰkaraṃs dusre patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("kariṃtʰkarāms dusre patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("kariṃtʰkarāṃs dusre patra 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("kurĩtʰīāṃ nū̃ dūjī pattrī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ਕੁਰਿੰਥੀਆਂ ਨੂੰ ਦੂਜੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Kirje korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korincanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinćanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. посланица Коринћанима 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korincanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinćanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II посланица Коринћанима 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Toinen Korinttolaiskirje 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korincanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinćanima Poslanica 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 посланица Коринћанима 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga list do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Drugi list do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Masodik Korinthusiakhoz 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Második Korinthusiakhoz 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Toinen Korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Послання до Коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andra Korinthierbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha kniha Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha kniha Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha kniha Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha kniha Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá kniha Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá kniha Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá kniha Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá kniha Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andra Korintherbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andra Korintierbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Deuxiemes Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Deuxièmes Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha list Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha list Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy list Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy list Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy list Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy list Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá list Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá list Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhý list Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhý list Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhý list Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhý list Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinttolaiskirje 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Mga Taga- Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. list do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("करिंथकरांस दुसरे पत्र 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinttolaiskirje 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Mga Taga- Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. list do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andra Korinterbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Deuxieme Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Deuxième Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha list Korinskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha list Korinským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy list Korinskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy list Korinským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá list Korinskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá list Korinským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhý list Korinskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhý list Korinským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinttolaiskirje 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Mga Taga- Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II list do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Mga Taga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinttolaiskirje 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Mga Taga- Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 list do Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinthierbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Mga Taga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Mga Taga-Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Anden Korintherbrev 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andet Korintherbrev 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Mga Taga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinthusiakhoz 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. list Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. list Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("השנייה אל הקורינתים 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ କରିନ୍ଥୀୟଙ୍କ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinthierbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinttilaisille 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Mga Taga Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Mga Taga-Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintherbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinthusiakhoz 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintierbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰiharulai 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰiharulaī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰiharulāi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰiharulāī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰiharūlai 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰiharūlaī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰiharūlāi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰiharūlāī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰīharulai 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰīharulaī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰīharulāi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰīharulāī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰīharūlai 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰīharūlaī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰīharūlāi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korintʰīharūlāī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. list Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. list Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andre korinterbrev 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinthusiakhoz 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II list Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II list Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. list Korinskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. list Korinským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ikalawang Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ikalawang Korintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara Korintubref 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara Korintubréf 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara Kórintubref 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Siðara Kórintubréf 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara Korintubref 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara Korintubréf 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara Kórintubref 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Síðara Kórintubréf 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Προς Κορινθίους Β' 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Προς Κορινθίους Βʹ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Προς Κορινθίους Βʹ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Προς Κορινθίους Β΄ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Προς Κορινθίους Β’ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Προς Κορινθιους Β' 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Προς Κορινθιους Βʹ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Προς Κορινθιους Βʹ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Προς Κορινθιους Β΄ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Προς Κορινθιους Β’ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("코린토 신자들에게 보낸 둘째 서간 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintherbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinthusiakhoz 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintierbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰiharulai 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰiharulaī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰiharulāi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰiharulāī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰiharūlai 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰiharūlaī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰiharūlāi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰiharūlāī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰīharulai 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰīharulaī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰīharulāi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰīharulāī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰīharūlai 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰīharūlaī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰīharūlāi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korintʰīharūlāī 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 list Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 list Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге. до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е. к Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-я. к Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinterbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. list Korinskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. list Korinským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कोरिन्थीहरूलाई 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2eme. Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ème. Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andre Korintierne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga Korincanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga Korinćanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II list Korinskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II list Korinským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ikalawang Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Ikalawang Korinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Masodik Korinthus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Masodik Korintusi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Második Korinthus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Második Korintusi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Segunda Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Segunda Coríntios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Segundo Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Segundo Coríntios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Втора Коринканите 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Втора Коринтяните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Втора Коринќаните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Второ Коринканите 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Второ Коринќаните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друга Коринћанима 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друга до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друге до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinterbrevet 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintiyarukku 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 list Korinskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 list Korinským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कोरिन्थीहरूलाई 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а. до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е к Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е. до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-я к Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintherbrev 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2de. Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2eme Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ème Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2е. к Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2я. к Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Anden Korinterne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Dezyem Korentyen 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Dezyèm Korentyen 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhý Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhý Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhý Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhý Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Zweite Korinther 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ad Corinthios II 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Втора Коринтјани 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Второ Коринтјани 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ କରିନ୍ଥୀୟ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Coriinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintherbrev 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 e. Korintasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 i. Korintasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 k. Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 k. Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 k. Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 k. Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 karimtʰkarams 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 karimtʰkaraṃs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 karimtʰkarāms 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 karimtʰkarāṃs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 kariṃtʰkarams 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 kariṃtʰkaraṃs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 kariṃtʰkarāms 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 kariṃtʰkarāṃs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 ਕੁਰਿੰਥੀਆਂ ਨੂੰ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге. Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е. Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-я. Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Kurinthiayon 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Taga-Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. korinterbrev 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. к Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कुरिन्यि़यों 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2d. Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2de Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2е к Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2я к Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Drugi Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiaid 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korincanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinćanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Коринканите 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Коринтяните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Коринћанима 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Коринќаните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Korintos Labaad 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Pili Wakorintho 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Seconda Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Secondo Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Corinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Korinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Втора Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друга Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друге Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("دوم-کُرِنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("كورنثوس الثانية 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Choranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Chorinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Chorinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Coriinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinathians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinithinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinnthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiaans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthianas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthianos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthoians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corninthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corninthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornithaians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corrinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corrinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Kurinthiayon 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Taga-Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 e Korintasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 e. Koritasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 i Korintasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 i. Koritasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 k Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 k Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 k Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 k Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 korinterbrev 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 к Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कुरिन्यि़यों 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а. Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге. Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге. коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е. Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-я Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiaid 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korincanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintierne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinćanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Коринканите 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Коринтяните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Коринћанима 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Коринќаните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कुरिन्थियों 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. କରିନ୍ଥୀୟଙ୍କ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2.-کُرِنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2.o. Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2.º. Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2d Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2е. Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2я. Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andre Korinter 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga Koryntow 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druga Koryntów 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Drugi Koryntow 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Drugi Koryntów 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiaid 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korincanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinćanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Коринканите 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Коринтяните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Коринћанима 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Коринќаните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintieni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cô-rinh-tô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Wakorintho 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Коринтјани 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Pili Wakorinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друга Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друга коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друге Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Друге коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("دوم کرنتھِیُوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("دوم کُرنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Chorinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Chorithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Chornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Coranthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiaid 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiens 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthinas 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corninthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornthiians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corrithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corrithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korincanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinthiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinthiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintierne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinćanima 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 e Koritasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 i Koritasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Коринканите 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Коринтяните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Коринћанима 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Коринќаните 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 до коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कुरिन्थियों 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 କରିନ୍ଥୀୟଙ୍କ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 கொரிந்தியர் 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а. Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а. коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ге коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е. Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е. коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-کُرِنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintieni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cô-rinh-tô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinterne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Wakorintho 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Коринтјани 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. کرنتھِیُوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. کُرنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कुरन्थियों 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कुरिन्थियो 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2.o Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2.º Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2a. Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2a. Coríntios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2o. Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2o. Coríntios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2º. Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2е Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2я Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Corinthios II 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Dezyem Korint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Dezyèm Korint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintieni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cô-rinh-tô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Wakorintho 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Коринтјани 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinteni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Coríntios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korentyen 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinthus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintusi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Wakorinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Wakorintho II 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β' Κορινθίους 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β' Κορινθιους 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ Κορινθίους 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ Κορινθιους 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ Κορινθίους 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ Κορινθιους 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β΄ Κορινθίους 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β΄ Κορινθιους 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β’ Κορινθίους 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β’ Κορινθιους 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("۲-کُرِنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintieni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintions 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithoans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornthains 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cô-rinh-tô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinterne 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinthier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinthiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintiers 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintiërs 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintskym 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintským 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinťanom 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Wakorintho 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Коринтјани 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Коринфянам 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 کرنتھِیُوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 کُرنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 करिंथकरांस 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कुरन्थियों 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कुरिन्थियो 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-а коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-е коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinteni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Coríntios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korentyen 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinther 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinthus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintusi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Koritasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Wakorinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कोरिन्‍थी 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2a Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2a Coríntios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Corinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Korinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2o Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2o Coríntios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2º Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinteni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Coríntios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korentyen 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinthus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintusi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Wakorinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korintus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Koryntow 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Koryntów 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("دوم کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("دوم۔کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("۲ کرنتھِیُوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("۲ کُرنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("コリントの信徒への手紙二 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("コリント人への第二の手紙 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinteni 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithans 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corithins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cornthins 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corthians 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Coríntios 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korentyen 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinther 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinthus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintier 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintiër 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintusi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Koritasve 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Koryntian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Wakorinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 kurĩtʰīāṃ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Коринтяни 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कोरिन्‍थी 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 ਕੁਰਿੰਥੀਆਂ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinter 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korintus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Koryntow 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Koryntów 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कोरिन्थी 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. କରିନ୍ଥୀୟ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2.۔کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Corinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Korinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2°. Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korintus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Koryntow 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Koryntów 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cô-rinh 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Côrintô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinta 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Masodik Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Második Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corthian 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinter 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinthe 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintio 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintos 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korintus 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Koryntow 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Koryntów 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Коринфян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 коринтян 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कोरिन्थी 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 କରିନ୍ଥୀୟ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cô-rinh 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Côrintô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinta 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कुरिन्थ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. โครินธ์ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2° Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2۔کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cô-rinh 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Côrintô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinta 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Korint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Tweede Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("۲ کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("۲۔کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("コリント人への後の書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("コリント人への手紙二 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinti 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corinzi 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cô-rinh 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Côrintô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinta 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korinto 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कुरिन्थ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 โครินธ์ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Korint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Anden Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Andre Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Korint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Second Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Втора Кор 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corini 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Korint 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Pili Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corin 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Corth 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e. Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd. Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druha K 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhy K 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhá K 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Druhý K 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Кор 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《哥林多后书》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《哥林多後書》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《格林多後書》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《歌林多後書》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《适凌爾福後》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 கொரி 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Кор 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2e Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2nd Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DruhaK 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DruhyK 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DruháK 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DruhýK 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Кор 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. Cô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β' Κορ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ Κορ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ Κορ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β΄ Κορ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β’ Κορ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《哥林多后书 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《哥林多後書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《格林多後書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《歌林多後書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《适凌爾福後 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("コリント 2 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("コリント後書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("哥林多后书》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("哥林多後書》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("格林多後書》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("歌林多後書》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("适凌爾福後》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Кор 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 قور 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. Cô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II Cô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β' Κο 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ Κο 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ Κο 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β΄ Κο 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β’ Κο 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("哥林多后书 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("哥林多後書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("格林多後書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("歌林多後書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("适凌爾福後 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("고린도2서 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("고린도후서 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("코린토2서 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Co 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 Cô 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 கொ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 คธ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 คร 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2Cor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2Kor 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《林后》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《林後》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2كو 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2코린 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《林后 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《林後 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("林后》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("林後》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("林后 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("林後 1:1").osis()).toEqual("2Cor.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ВТОРА ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО КОРИНТ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ВТОРО ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО КОРИНТ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО КОРИНТ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО КОРИНТ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО КОРИНТ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО КОРИНТ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ВТОРО ПОСЛАНИЕ НА СВ. АП. ПАВЛА ДО КОРИНТЯНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHE POSLANNJA APOSTOLA PAVLA DO KORYNFJAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ВТОРО ПОСЛАНИЕ НА СВ АП. ПАВЛА ДО КОРИНТЯНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ВТОРО ПОСЛАНИЕ НА СВ. АП ПАВЛА ДО КОРИНТЯНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ВТОРО ПОСЛАНИЕ НА СВ АП ПАВЛА ДО КОРИНТЯНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய இரண்டாவது திருமுகம் 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ГЕ. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTIYARUKKU ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTIYARUKKU ELUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTIYARUKKU ELUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTIYARUKKU ELUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTIYARUKKU ELUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTIYARUKKU ELUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTIYARUKKU ELUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTIYARUKKU ELUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTIYARUKKU EḺUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTIYARUKKU EḺUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTIYARUKKU EḺUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTIYARUKKU EḺUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTIYARUKKU EḺUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTIYARUKKU EḺUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTIYARUKKU EḺUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTIYARUKKU EḺUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ДРУГА ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ДРУГЕ ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("رسالة بولس الرسول الثانية إلى أهل كورنثوس 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-А. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ГЕ ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-Е. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய இரண்டாவது நிருபம் 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-А ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-Е ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("کرنتھِیُوں کے نام پولس رسول کا دوسرا خط 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய இரண்டாம் கடிதம் 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("PAVLOVA DRUGA POSLANICA KORINCANIMA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("PAVLOVA DRUGA POSLANICA KORINĆANIMA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("PAULUS' ANDET BREV TIL KORINTHERNE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("PAULUS’ ANDET BREV TIL KORINTHERNE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGA LIST SW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGA LIST ŚW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGI LIST SW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGI LIST ŚW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("PAULUS’ ANDRE BREV TIL KORINTERNE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SIÐARA BREF PALS TIL KORINTUMANNA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SIÐARA BREF PÁLS TIL KORINTUMANNA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SIÐARA BRÉF PALS TIL KORINTUMANNA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SIÐARA BRÉF PÁLS TIL KORINTUMANNA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SÍÐARA BREF PALS TIL KORINTUMANNA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SÍÐARA BREF PÁLS TIL KORINTUMANNA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SÍÐARA BRÉF PALS TIL KORINTUMANNA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SÍÐARA BRÉF PÁLS TIL KORINTUMANNA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("कोरिन्थीहरूलाई पावलको दोस्रो पत्र 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGA LIST SW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGA LIST ŚW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGI LIST SW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGI LIST ŚW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. LIST SW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. LIST ŚW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KURINTʰIYŌṄ KE NĀM KĀ DŪSRĀ ḪAṬ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("الرسالة الثانية إلى أهل كورنثوس 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. LIST SW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. LIST ŚW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II LIST SW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II LIST ŚW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. LIST SW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. LIST ŚW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ВТОРО ПОСЛАНИЕ КЪМ КОРИНТЯНИТЕ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("کُرِنتھِیوں کے نام کا دوسرا خط 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("କରିନ୍ଥୀୟଙ୍କ ପ୍ରତି ଦ୍ୱିତୀୟ ପତ୍ର 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 LIST SW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 LIST ŚW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. LIST SW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. LIST ŚW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II LIST SW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II LIST ŚW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TOINEN KIRJE KORINTTILAISILLE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("WARAKA WA PILI KWA WAKORINTHO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 LIST SW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 LIST ŚW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("BARUA YA PILI KWA WAKORINTHO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("IKA- 2 SULAT SA MGA CORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND SULAT SA MGA CORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("WARAKA WA PILI KWA WAKORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTʰIHARULAI DOSTRO PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTʰIHARULAĪ DOSTRO PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTʰIHARULĀI DOSTRO PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTʰIHARULĀĪ DOSTRO PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTʰIHARŪLAI DOSTRO PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTʰIHARŪLAĪ DOSTRO PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTʰIHARŪLĀI DOSTRO PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTʰIHARŪLĀĪ DOSTRO PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTʰĪHARULAI DOSTRO PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTʰĪHARULAĪ DOSTRO PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTʰĪHARULĀI DOSTRO PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTʰĪHARULĀĪ DOSTRO PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTʰĪHARŪLAI DOSTRO PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTʰĪHARŪLAĪ DOSTRO PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTʰĪHARŪLĀI DOSTRO PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTʰĪHARŪLĀĪ DOSTRO PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("कोरिन्थीहरूलाई दोस्त्रो पत्र 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("पौलाचे करिंथकरांस दूसरे पत्र 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGA KORINCANIMA POSLANICA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGA KORINĆANIMA POSLANICA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGA POSLANICA KORINCANIMA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGA POSLANICA KORINÆANIMA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGA POSLANICA KORINĆANIMA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("IKA 2 SULAT SA MGA CORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("IKA- 2 SULAT SA MGA CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("IKALAWANG MGA TAGA- CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND SULAT SA MGA CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ДРУГА ПОСЛАНИЦА КОРИНЋАНИМА 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("אגרת פולוס השנייה אל-הקורינ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("کرنتھیوں کے نام کا دوسرا خط 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ГЕ. ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KIRJE KORINTTILAISILLE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("IKA 2 SULAT SA MGA CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("IKALAWANG MGA TAGA CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECONDA LETTERA AI CORINZI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ДРУГА ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ДРУГЕ ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("האיגרת השנייה אל הקורינתים 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-А. ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ГЕ ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-Е. ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KIRJE KORINTTILAISILLE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("EPISTULA II AD CORINTHIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("EPISTULA AD CORINTHIOS II 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KIRJE KORINTTILAISILLE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINCANIMA POSLANICA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINĆANIMA POSLANICA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. ПОСЛАНИЦА КОРИНЋАНИМА 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SIÐARA BREF PALS TIL KORI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SIÐARA BREF PÁLS TIL KORI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SIÐARA BRÉF PALS TIL KORI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SIÐARA BRÉF PÁLS TIL KORI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SÍÐARA BREF PALS TIL KORI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SÍÐARA BREF PÁLS TIL KORI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SÍÐARA BRÉF PALS TIL KORI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SÍÐARA BRÉF PÁLS TIL KORI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KARIMTʰKARAMS DUSRE PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KARIMTʰKARAṂS DUSRE PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KARIMTʰKARĀMS DUSRE PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KARIMTʰKARĀṂS DUSRE PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KARIṂTʰKARAMS DUSRE PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KARIṂTʰKARAṂS DUSRE PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KARIṂTʰKARĀMS DUSRE PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KARIṂTʰKARĀṂS DUSRE PATRA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KURĨTʰĪĀṂ NŪ̃ DŪJĪ PATTRĪ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ਕੁਰਿੰਥੀਆਂ ਨੂੰ ਦੂਜੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KIRJE KORINTTILAISILLE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-А ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-Е ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINCANIMA POSLANICA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINĆANIMA POSLANICA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. ПОСЛАНИЦА КОРИНЋАНИМА 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINCANIMA POSLANICA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINĆANIMA POSLANICA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II ПОСЛАНИЦА КОРИНЋАНИМА 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TOINEN KORINTTOLAISKIRJE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINCANIMA POSLANICA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINĆANIMA POSLANICA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 ПОСЛАНИЦА КОРИНЋАНИМА 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGA LIST DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGI LIST DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("MASODIK KORINTHUSIAKHOZ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("MÁSODIK KORINTHUSIAKHOZ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TOINEN KORINTTILAISILLE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDRA KORINTHIERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHA KNIHA KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHA KNIHA KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHA KNIHA KORINTSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHA KNIHA KORINŤANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÁ KNIHA KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÁ KNIHA KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÁ KNIHA KORINTSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÁ KNIHA KORINŤANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDRA KORINTHERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDRA KORINTIERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DEUXIEMES CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DEUXIÈMES CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHA LIST KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHA LIST KORINTSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHY LIST KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHY LIST KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHY LIST KORINTSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHY LIST KORINŤANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÁ LIST KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÁ LIST KORINTSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÝ LIST KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÝ LIST KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÝ LIST KORINTSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÝ LIST KORINŤANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTTOLAISKIRJE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. MGA TAGA- CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. LIST DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("करिंथकरांस दुसरे पत्र 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTTOLAISKIRJE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. MGA TAGA- CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. LIST DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDRA KORINTERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DEUXIEME CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DEUXIÈME CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHA LIST KORINSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHA LIST KORINSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHY LIST KORINSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHY LIST KORINSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÁ LIST KORINSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÁ LIST KORINSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÝ LIST KORINSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÝ LIST KORINSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTTOLAISKIRJE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II MGA TAGA- CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II LIST DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTTILAISILLE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. MGA TAGA CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORIINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTTOLAISKIRJE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 MGA TAGA- CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 LIST DO KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTHIERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTTILAISILLE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. MGA TAGA CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. MGA TAGA-CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDEN KORINTHERBREV 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDET KORINTHERBREV 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTTILAISILLE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II MGA TAGA CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTHUSIAKHOZ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. LIST KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. LIST KORINTSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CHORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CHORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CHORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORIINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINATHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINITHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIAANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIANAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIANOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHOIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNITHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORRINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORRINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("השנייה אל הקורינתים 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ କରିନ୍ଥୀୟଙ୍କ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTHIERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTTILAISILLE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 MGA TAGA CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 MGA TAGA-CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTHERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTHUSIAKHOZ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTIERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTʰIHARULAI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTʰIHARULAĪ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTʰIHARULĀI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTʰIHARULĀĪ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTʰIHARŪLAI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTʰIHARŪLAĪ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTʰIHARŪLĀI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTʰIHARŪLĀĪ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTʰĪHARULAI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTʰĪHARULAĪ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTʰĪHARULĀI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTʰĪHARULĀĪ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTʰĪHARŪLAI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTʰĪHARŪLAĪ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTʰĪHARŪLĀI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTʰĪHARŪLĀĪ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. LIST KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. LIST KORINTSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORIINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDRE KORINTERBREV 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTHUSIAKHOZ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II LIST KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II LIST KORINTSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. LIST KORINSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. LIST KORINSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("IKALAWANG CORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("IKALAWANG KORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CHORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CHORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CHORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORITHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORRITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORRITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SIÐARA KORINTUBREF 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SIÐARA KORINTUBRÉF 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SIÐARA KÓRINTUBREF 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SIÐARA KÓRINTUBRÉF 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SÍÐARA KORINTUBREF 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SÍÐARA KORINTUBRÉF 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SÍÐARA KÓRINTUBREF 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SÍÐARA KÓRINTUBRÉF 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE CORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE CORINTHIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE KORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE KORINTHIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ΠΡΟΣ ΚΟΡΙΝΘΊΟΥΣ Β' 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ΠΡΟΣ ΚΟΡΙΝΘΊΟΥΣ Βʹ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ΠΡΟΣ ΚΟΡΙΝΘΊΟΥΣ Βʹ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ΠΡΟΣ ΚΟΡΙΝΘΊΟΥΣ Β΄ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ΠΡΟΣ ΚΟΡΙΝΘΊΟΥΣ Β’ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ΠΡΟΣ ΚΟΡΙΝΘΙΟΥΣ Β' 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ΠΡΟΣ ΚΟΡΙΝΘΙΟΥΣ Βʹ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ΠΡΟΣ ΚΟΡΙΝΘΙΟΥΣ Βʹ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ΠΡΟΣ ΚΟΡΙΝΘΙΟΥΣ Β΄ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ΠΡΟΣ ΚΟΡΙΝΘΙΟΥΣ Β’ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("코린토 신자들에게 보낸 둘째 서간 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTHERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTHUSIAKHOZ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTIERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTʰIHARULAI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTʰIHARULAĪ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTʰIHARULĀI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTʰIHARULĀĪ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTʰIHARŪLAI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTʰIHARŪLAĪ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTʰIHARŪLĀI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTʰIHARŪLĀĪ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTʰĪHARULAI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTʰĪHARULAĪ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTʰĪHARULĀI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTʰĪHARULĀĪ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTʰĪHARŪLAI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTʰĪHARŪLAĪ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTʰĪHARŪLĀI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTʰĪHARŪLĀĪ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 LIST KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 LIST KORINTSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ГЕ. ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-Е. К КОРИНФЯНАМ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-Я. К КОРИНФЯНАМ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. LIST KORINSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. LIST KORINSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कोरिन्थीहरूलाई 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2EME. CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORIINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CHORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CHORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CHORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORIINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINATHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINITHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIAANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIANAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIANOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHOIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNITHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORRINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORRINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ÈME. CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDRE KORINTIERNE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGA KORINCANIMA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGA KORINĆANIMA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II LIST KORINSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II LIST KORINSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORIINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("IKALAWANG CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("IKALAWANG KORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("MASODIK KORINTHUS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("MASODIK KORINTUSI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("MÁSODIK KORINTHUS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("MÁSODIK KORINTUSI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORITHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SEGUNDA CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SEGUNDA CORÍNTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SEGUNDO CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SEGUNDO CORÍNTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE CORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE CORINTHIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE CORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE CORINTIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE KORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE KORINTHIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE KORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE KORINTIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ВТОРА КОРИНКАНИТЕ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ВТОРА КОРИНТЯНИТЕ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ВТОРА КОРИНЌАНИТЕ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ВТОРО КОРИНКАНИТЕ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ВТОРО КОРИНЌАНИТЕ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ДРУГА КОРИНЋАНИМА 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ДРУГА ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ДРУГЕ ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTERBREVET 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTIYARUKKU 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 LIST KORINSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 LIST KORINSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कोरिन्थीहरूलाई 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-А. ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ГЕ ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-Е К КОРИНФЯНАМ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-Е. ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-Я К КОРИНФЯНАМ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORIINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTHERBREV 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2DE. CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2EME CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CHORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CHORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CHORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORIINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINATHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINITHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIAANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIANAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIANOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHOIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNITHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORRINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORRINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CHORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CHORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CHORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORITHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORRITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORRITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ÈME CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2Е. К КОРИНФЯНАМ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2Я. К КОРИНФЯНАМ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDEN KORINTERNE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DEZYEM KORENTYEN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DEZYÈM KORENTYEN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHA KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHA KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHA KORINTSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHA KORINŤANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHY KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHY KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHY KORINTSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHY KORINŤANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÁ KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÁ KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÁ KORINTSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÁ KORINŤANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÝ KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÝ KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÝ KORINTSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÝ KORINŤANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORIINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CHORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CHORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CHORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORIINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINATHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINITHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIAANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIANAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIANOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHOIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNITHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORRINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORRINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORITHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORNTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE CORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE CORINTIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE KORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE KORINTIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ZWEITE KORINTHER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("AD CORINTHIOS II 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ВТОРА КОРИНТЈАНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ВТОРО КОРИНТЈАНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ କରିନ୍ଥୀୟ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORIINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTHERBREV 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 E. KORINTASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 I. KORINTASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 K. KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 K. KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 K. KORINTSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 K. KORINŤANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KARIMTʰKARAMS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KARIMTʰKARAṂS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KARIMTʰKARĀMS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KARIMTʰKARĀṂS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KARIṂTʰKARAMS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KARIṂTʰKARAṂS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KARIṂTʰKARĀMS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KARIṂTʰKARĀṂS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 ਕੁਰਿੰਥੀਆਂ ਨੂੰ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-А ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ГЕ. КОРИНТЯНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-Е ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-Е. КОРИНФЯНАМ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-Я. КОРИНФЯНАМ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CHORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CHORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CHORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORIINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINATHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINITHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIAANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIANAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIANOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHOIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNITHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORRINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORRINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KURINTHIAYON 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. TAGA-CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTERBREV 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. К КОРИНФЯНАМ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कुरिन्यि़यों 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2D. CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2DE CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. CORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. CORINTHIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. KORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. KORINTHIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CHORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CHORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CHORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORITHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORRITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORRITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORITHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2Е К КОРИНФЯНАМ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2Я К КОРИНФЯНАМ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGA KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGI KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CHORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CHORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CHORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORIINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINATHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINITHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIAANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIANAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIANOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHOIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNITHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORRINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORRINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CHORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CHORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CHORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIAID 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORITHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORRITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORRITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINCANIMA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTHIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINĆANIMA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. КОРИНКАНИТЕ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. КОРИНТЯНИТЕ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. КОРИНЋАНИМА 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. КОРИНЌАНИТЕ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("KORINTOS LABAAD 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("PILI WAKORINTHO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECONDA CORINZI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECONDO CORINZI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE CORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE KORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ВТОРА КОРИНТЯНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ДРУГА КОРИНТЯНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ДРУГЕ КОРИНТЯНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("دوم-کُرِنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("كورنثوس الثانية 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CHORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CHORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CHORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORIINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINATHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINITHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIAANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIANAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIANOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHOIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNITHAIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORRINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORRINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KURINTHIAYON 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 TAGA-CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 E KORINTASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 E. KORITASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 I KORINTASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 I. KORITASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 K KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 K KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 K KORINTSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 K KORINŤANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTERBREV 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 К КОРИНФЯНАМ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कुरिन्यि़यों 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-А. КОРИНТЯНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ГЕ КОРИНТЯНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ГЕ. КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ГЕ. КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-Е КОРИНФЯНАМ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-Е. КОРИНТЯНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-Я КОРИНФЯНАМ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CHORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CHORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CHORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIAID 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORITHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORRITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORRITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINCANIMA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTHIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTIERNE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINĆANIMA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. КОРИНКАНИТЕ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. КОРИНТЯНИТЕ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. КОРИНЋАНИМА 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. КОРИНЌАНИТЕ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कुरिन्थियों 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. କରିନ୍ଥୀୟଙ୍କ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2.-کُرِنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2.O. CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2.º. CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2D CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E CORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E CORINTHIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E KORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E KORINTHIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. CORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. CORINTHIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. CORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. CORINTIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. KORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. KORINTHIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. KORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. KORINTIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORITHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORITHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORNTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2Е. КОРИНФЯНАМ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2Я. КОРИНФЯНАМ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDRE KORINTER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGA KORYNTOW 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGA KORYNTÓW 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGI KORYNTOW 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUGI KORYNTÓW 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CHORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CHORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CHORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIAID 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORITHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORRITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORRITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINCANIMA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTHIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINĆANIMA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II КОРИНКАНИТЕ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II КОРИНТЯНИТЕ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II КОРИНЋАНИМА 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II КОРИНЌАНИТЕ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTIENI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORITHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CÔ-RINH-TÔ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTHIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINŤANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. WAKORINTHO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. КОРИНТЈАНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("PILI WAKORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ДРУГА КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ДРУГА КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ДРУГЕ КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ДРУГЕ КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("دوم کرنتھِیُوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("دوم کُرنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CHORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CHORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CHORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORANTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIAID 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIENS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHINAS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORITHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNTHIIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORRITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORRITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINCANIMA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTHIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTHIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTIERNE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINĆANIMA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 E KORITASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 I KORITASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 КОРИНКАНИТЕ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 КОРИНТЯНИТЕ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 КОРИНЋАНИМА 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 КОРИНЌАНИТЕ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 ДО КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कुरिन्थियों 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 କରିନ୍ଥୀୟଙ୍କ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 கொரிந்தியர் 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-А КОРИНТЯНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-А. КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-А. КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ГЕ КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-ГЕ КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-Е КОРИНТЯНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-Е. КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-Е. КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-کُرِنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTIENI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORITHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CÔ-RINH-TÔ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTERNE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTHIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINŤANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. WAKORINTHO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. КОРИНТЈАНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. КОРИНФЯНАМ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. کرنتھِیُوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. کُرنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कुरन्थियों 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कुरिन्थियो 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2.O CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2.º CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2A. CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2A. CORÍNTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E CORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E CORINTHIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E CORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E CORINTIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E KORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E KORINTHIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E KORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E KORINTIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. CORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. CORINTIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. KORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. KORINTIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORITHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORNTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2O. CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2O. CORÍNTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2º. CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2Е КОРИНФЯНАМ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2Я КОРИНФЯНАМ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("CORINTHIOS II 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DEZYEM KORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DEZYÈM KORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTIENI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORITHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CÔ-RINH-TÔ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTHIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINŤANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II WAKORINTHO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II КОРИНТЈАНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTENI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORITHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORNTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORÍNTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORENTYEN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTHUS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTUSI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. WAKORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. КОРИНТЯНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("WAKORINTHO II 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β' ΚΟΡΙΝΘΊΟΥΣ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β' ΚΟΡΙΝΘΙΟΥΣ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ ΚΟΡΙΝΘΊΟΥΣ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ ΚΟΡΙΝΘΙΟΥΣ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ ΚΟΡΙΝΘΊΟΥΣ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ ΚΟΡΙΝΘΙΟΥΣ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β΄ ΚΟΡΙΝΘΊΟΥΣ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β΄ ΚΟΡΙΝΘΙΟΥΣ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β’ ΚΟΡΙΝΘΊΟΥΣ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β’ ΚΟΡΙΝΘΙΟΥΣ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("۲-کُرِنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTIENI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTIONS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORITHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORITHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORITHOANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNTHAINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CÔ-RINH-TÔ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTERNE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTHIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTHIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTIERS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTIËRS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTSKYM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTSKÝM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINŤANOM 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 WAKORINTHO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 КОРИНТЈАНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 КОРИНФЯНАМ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 کرنتھِیُوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 کُرنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 करिंथकरांस 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कुरन्थियों 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कुरिन्थियो 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-А КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-А КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-Е КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2-Е КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTENI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORITHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORNTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORÍNTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORENTYEN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTHER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTHUS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTUSI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORITASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. WAKORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. КОРИНТЯНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कोरिन्‍थी 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2A CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2A CORÍNTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E CORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E CORINTIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E KORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E KORINTIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. CORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. KORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2O CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2O CORÍNTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2º CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTENI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORITHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORNTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORÍNTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORENTYEN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTHUS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTUSI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II WAKORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II КОРИНТЯНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTUS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORYNTOW 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORYNTÓW 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORIN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CORTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("دوم کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("دوم۔کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("۲ کرنتھِیُوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("۲ کُرنتھِیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("コリントの信徒への手紙二 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("コリント人への第二の手紙 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTENI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORITHANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORITHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORNTHINS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORTHIANS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORÍNTIOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORENTYEN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTHER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTHUS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTIER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTIËR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTUSI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORITASVE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORYNTIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 WAKORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KURĨTʰĪĀṂ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 КОРИНТЯНИ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कोरिन्‍थी 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 ਕੁਰਿੰਥੀਆਂ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTUS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORYNTOW 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORYNTÓW 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कोरिन्थी 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. କରିନ୍ଥୀୟ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2.۔کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E CORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E KORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2°. CORINZI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTUS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORYNTOW 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORYNTÓW 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINZI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CÔ-RINH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CÔRINTÔ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("MASODIK KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("MÁSODIK KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORTHIAN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTER 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTHE 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTIO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTOS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTUS 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORYNTOW 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORYNTÓW 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 КОРИНФЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 КОРИНТЯН 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कोरिन्थी 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 କରିନ୍ଥୀୟ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINZI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CÔ-RINH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CÔRINTÔ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. कुरिन्थ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. โครินธ์ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORIN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CORTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2° CORINZI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2۔کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINZI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CÔ-RINH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CÔRINTÔ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("TWEEDE KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("۲ کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("۲۔کرنتھیوں 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("コリント人への後の書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("コリント人への手紙二 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINZI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CÔ-RINH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CÔRINTÔ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTA 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINTO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 कुरिन्थ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 โครินธ์ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORIN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CORTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDEN KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ANDRE KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORIN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CORTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("SECOND CO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("ВТОРА КОР 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINI 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KORINT 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORIN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CORTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORIN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CORTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("PILI KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORIN 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CORTH 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E. KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND. CO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHA K 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHY K 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÁ K 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÝ K 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. КОР 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《哥林多后书》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《哥林多後書》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《格林多後書》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《歌林多後書》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《适凌爾福後》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 கொரி 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. КОР 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2E KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2ND CO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHAK 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHYK 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÁK 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("DRUHÝK 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II КОР 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II. CÔ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β' ΚΟΡ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ ΚΟΡ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ ΚΟΡ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β΄ ΚΟΡ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β’ ΚΟΡ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《哥林多后书 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《哥林多後書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《格林多後書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《歌林多後書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《适凌爾福後 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("コリント 2 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("コリント後書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("哥林多后书》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("哥林多後書》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("格林多後書》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("歌林多後書》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("适凌爾福後》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 КОР 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 قور 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2. CÔ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("II CÔ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β' ΚΟ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ ΚΟ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Βʹ ΚΟ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β΄ ΚΟ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("Β’ ΚΟ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("哥林多后书 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("哥林多後書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("格林多後書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("歌林多後書 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("适凌爾福後 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("고린도2서 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("고린도후서 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("코린토2서 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CO 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 CÔ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 கொ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 คธ 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2 คร 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2COR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2KOR 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《林后》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《林後》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2كو 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("2코린 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《林后 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("《林後 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("林后》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("林後》 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("林后 1:1").osis()).toEqual("2Cor.1.1")
		expect(p.parse("林後 1:1").osis()).toEqual("2Cor.1.1")
		`
		true
describe "Localized book 1Cor (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Cor (full)", ->
		`
		expect(p.parse("Прва писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Прво писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Първо послание на св. ап. Павла до Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Perse poslannja apostola Pavla do korynfjan 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Perše poslannja apostola Pavla do korynfjan 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Първо послание на св ап. Павла до Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Първо послание на св. ап Павла до Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Първо послание на св ап Павла до Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше. послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Korintiyarukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Korintiyarukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Korintiyarukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Korintiyarukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перша послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перше послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய முதலாவது திருமுகம் 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а. послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е. послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("رسالة بولس الرسول الأولى إلى أهل كورنثوس 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய முதலாவது நிருபம் 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("کرنتھِیُوں کے نام پولس رسول کا پہلا خط 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய முதல் திருமுகம் 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsza List sw. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsza List św. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsze List sw. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsze List św. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwszy List sw. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwszy List św. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Paulus' Første Brev til Korintherne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Paulus’ Første Brev til Korintherne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsza List sw Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsza List św Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsze List sw Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsze List św Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwszy List sw Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwszy List św Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ensimmainen Kirje korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ensimmäinen Kirje korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Paulus’ første brev til korinterne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pavlova prva poslanica Korincanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pavlova prva poslanica Korinćanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra bref Pals til Korintumanna 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra bref Páls til Korintumanna 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra bréf Pals til Korintumanna 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra bréf Páls til Korintumanna 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("कोरिन्थीहरूलाई पावलको पहिलो पत्र 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Paulus' 1. Brev til Korintherne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Paulus’ 1. Brev til Korintherne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Waraka wa Kwanza kwa Wakorintho 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("kurintʰiyōṅ ke nām kā pahlā ḫaṭ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. List sw. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. List św. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Barua ya Kwanza kwa Wakorintho 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. List sw. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. List św. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Paulus' 1 Brev til Korintherne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Paulus’ 1 Brev til Korintherne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Waraka wa Kwanza kwa Wakorinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Първо послание към коринтяните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("الرسالة الأولى إلى أهل كورنثوس 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய முதலாம் 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 List sw. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 List św. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. List sw Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. List św Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ensimmainen Korinttolaiskirje 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ensimmäinen Korinttolaiskirje 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I List sw. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I List św. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. List sw Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. List św Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("کُرِنتھِیوں کے نام کا پہلا خط 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 List sw Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 List św Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ensimmainen Korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ensimmäinen Korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I List sw Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I List św Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ika- 1 Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰiharulai pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰiharulaī pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰiharulāi pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰiharulāī pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰiharūlai pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰiharūlaī pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰiharūlāi pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰiharūlāī pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰīharulai pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰīharulaī pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰīharulāi pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰīharulāī pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰīharūlai pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰīharūlaī pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰīharūlāi pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰīharūlāī pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("पौलाचे करिंथकरांस पहिले पत्र 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("କରିନ୍ଥୀୟଙ୍କ ପ୍ରତି ପ୍ରଥମ ପତ୍ର 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ika 1 Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ika- 1 Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("kurĩtʰīāṃ nū̃ pahilī pattrī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("אגרת פולוס הראשונה אל-הקורי 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("האיגרת הראשונה אל הקורינתים 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше. Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ika 1 Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsza list do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsze list do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwszy list do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva Korincanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva Korinćanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva poslanica Korincanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva poslanica Korinæanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva poslanica Korinćanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("karimtʰkarams pahile patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("karimtʰkaraṃs pahile patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("karimtʰkarāms pahile patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("karimtʰkarāṃs pahile patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("kariṃtʰkarams pahile patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("kariṃtʰkaraṃs pahile patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("kariṃtʰkarāms pahile patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("kariṃtʰkarāṃs pahile patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перша Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перше Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Прва посланица Коринћанима 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("کرنتھیوں کے نام کا پہلا خط 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ਕੁਰਿੰਥੀਆਂ ਨੂੰ ਪਹਿਲੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а. Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е. Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Kirje korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra bref Pals til Korin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra bref Páls til Korin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra bréf Pals til Korin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra bréf Páls til Korin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Kirje korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("कोरिन्थीहरूलाई पहिलो पत्र 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Kirje korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korincanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinćanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. посланица Коринћанима 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Epistula I ad Corinthios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Epistula ad Corinthios I 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Kirje korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korincanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinćanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. посланица Коринћанима 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prima lettera ai Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korincanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinćanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 посланица Коринћанима 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Forsta Korinthierbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Första Korinthierbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korincanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinćanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I посланица Коринћанима 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Mga Taga- Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Forsta Korintherbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Forsta Korintierbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Första Korintherbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Första Korintierbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Mga Taga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Forsta Korinterbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Första Korinterbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Premieres Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Premières Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva kniha Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva kniha Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva kniha Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva kniha Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvni list Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvni list Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("První list Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("První list Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvá kniha Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvá kniha Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvá kniha Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvá kniha Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Mga Taga- Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("करिंथकरांस पहिले पत्र 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinttolaiskirje 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Mga Taga- Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. list do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Elso Korinthusiakhoz 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Első Korinthusiakhoz 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Første Korintherbrev 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinttolaiskirje 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Mga Taga- Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. list do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Premiere Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Premiers Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Première Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvni list Korinskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvni list Korinským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("První list Korinskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("První list Korinským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvy list Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvy list Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvy list Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvy list Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvý list Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvý list Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvý list Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvý list Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Mga Taga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("הראשונה אל הקורינתים 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinttolaiskirje 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Mga Taga- Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 list do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinthierbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Mga Taga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Mga Taga-Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Første korinterbrev 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinttolaiskirje 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Mga Taga- Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I list do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Mga Taga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Premier Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinthierbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Mga Taga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Mga Taga-Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintherbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinthusiakhoz 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintierbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰiharulai 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰiharulaī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰiharulāi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰiharulāī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰiharūlai 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰiharūlaī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰiharūlāi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰiharūlāī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰīharulai 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰīharulaī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰīharulāi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰīharulāī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰīharūlai 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰīharūlaī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰīharūlāi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰīharūlāī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. list Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. list Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Første Korintierne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Mga Taga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinthusiakhoz 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. list Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. list Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsza Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsze Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwszy Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Primeira Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Primeira Coríntios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Primeiro Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Primeiro Coríntios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Προς Κορινθίους Α' 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Προς Κορινθίους Αʹ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Προς Κορινθίους Αʹ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Προς Κορινθίους Α΄ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Προς Κορινθίους Α’ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Προς Κορινθιους Α' 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Προς Κορινθιους Αʹ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Προς Κορινθιους Αʹ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Προς Κορινθιους Α΄ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Προς Κορινθιους Α’ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("코린토 신자들에게 보낸 첫째 서간 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintherbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinthusiakhoz 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintierbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰiharulai 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰiharulaī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰiharulāi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰiharulāī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰiharūlai 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰiharūlaī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰiharūlāi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰiharūlāī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰīharulai 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰīharulaī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰīharulāi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰīharulāī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰīharūlai 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰīharūlaī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰīharūlāi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰīharūlāī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 list Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 list Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е. к Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше. до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-я. к Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinterbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. list Korinskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. list Korinským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कोरिन्थीहरूलाई 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ere. Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ère. Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra Korintubref 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra Korintubréf 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Første Korinterne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinthusiakhoz 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I list Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I list Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. list Korinskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. list Korinským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Kwanza Wakorintho 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsza Koryntow 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsza Koryntów 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsze Koryntow 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsze Koryntów 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwszy Koryntow 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwszy Koryntów 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Primero Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перша до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перше до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Първа Коринтяните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ପ୍ରଥମ କରିନ୍ଥୀୟଙ୍କ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinterbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintiyarukku 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 list Korinskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 list Korinským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कोरिन्थीहरूलाई 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а. до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е к Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е. до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-я к Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintherbrev 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1er. Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ere Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1re. Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ère Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1е. к Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1я. к Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I list Korinskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I list Korinským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Kwanza Wakorinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Premye Korentyen 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Primer Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva Korincanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva Korinćanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvni Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvni Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("První Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("První Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Прва Коринканите 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Прва Коринћанима 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Прва Коринќаните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Прво Коринканите 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Прво Коринќаните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("اوّل-کُرِنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintherbrev 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 e. Korintasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 i. Korintasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 k. Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 k. Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 k. Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 k. Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 karimtʰkarams 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 karimtʰkaraṃs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 karimtʰkarāms 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 karimtʰkarāṃs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 kariṃtʰkarams 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 kariṃtʰkaraṃs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 kariṃtʰkarāms 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 kariṃtʰkarāṃs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 ਕੁਰਿੰਥੀਆਂ ਨੂੰ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е. Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше. Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-я. Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Kurinthiayon 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Taga-Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korinterbrev 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. к Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कुरिन्यि़यों 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1er Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1re Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1е к Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1я к Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Erste Korinther 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Første Korinter 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Korintos Kowaad 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvy Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvy Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvy Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvy Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvá Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvá Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvá Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvá Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvý Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvý Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvý Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvý Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ad Corinthios I 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перша Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перше Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Прва Коринтјани 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Прво Коринтјани 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Първа Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("اوّل کرنتھِیُوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("اوّل کُرنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Kurinthiayon 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Taga-Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 e Korintasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 e. Koritasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 i Korintasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 i. Koritasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 k Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 k Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 k Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 k Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korinterbrev 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 к Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कुरिन्यि़यों 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а. Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е. Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше. Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше. коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-я Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiaid 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korincanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintierne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinćanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Коринканите 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Коринтяните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Коринћанима 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Коринќаните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कुरिन्थियों 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. କରିନ୍ଥୀୟଙ୍କ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1.-کُرِنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1.o. Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1.º. Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1е. Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1я. Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Elso Korinthus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Elso Korintusi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Első Korinthus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Első Korintusi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiaid 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korincanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinćanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Коринканите 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Коринтяните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Коринћанима 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Коринќаните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Korintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перша Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перша коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перше Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перше коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("كورنثوس الأولى 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ପ୍ରଥମ କରିନ୍ଥୀୟ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiaid 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korincanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintierne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinćanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 e Koritasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 i Koritasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Коринканите 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Коринтяните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Коринћанима 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Коринќаните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कुरिन्थियों 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 କରିନ୍ଥୀୟଙ୍କ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 கொரிந்தியர் 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а. Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а. коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е. Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е. коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-کُرِنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintieni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cô-rinh-tô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinterne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Wakorintho 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Коринтјани 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. کرنتھِیُوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. کُرنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कुरन्थियों 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कुरिन्थियो 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1.o Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1.º Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1a. Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1a. Coríntios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1o. Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1o. Coríntios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1º. Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1е Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1я Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiaid 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korincanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinćanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Коринканите 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Коринтяните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Коринћанима 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Коринќаните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintieni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cô-rinh-tô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Wakorintho 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Коринтјани 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Premye Korint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prima Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Primo Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Korinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α' Κορινθίους 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α' Κορινθιους 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ Κορινθίους 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ Κορινθιους 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ Κορινθίους 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ Κορινθιους 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α΄ Κορινθίους 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α΄ Κορινθιους 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α’ Κορινθίους 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α’ Κορινθιους 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("اوّل۔کرنتھیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("۱-کُرِنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ਕੁਰਿੰਥੀਆਂ ਨੂੰ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintieni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cô-rinh-tô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinterne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Wakorintho 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Коринтјани 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 کرنتھِیُوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 کُرنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 करिंथकरांस 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कुरन्थियों 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कुरिन्थियो 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinteni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Coríntios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korentyen 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinther 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinthus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintusi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Koritasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Wakorinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कोरिन्‍थी 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1a Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1a Coríntios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1o Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1o Coríntios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1º Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthios I 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintieni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cô-rinh-tô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Wakorintho 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Коринтјани 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinteni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Coríntios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korentyen 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinthus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintusi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Wakorinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Korintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Wakorintho I 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("۱ کرنتھِیُوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("۱ کُرنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("コリントの信徒への手紙一 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("コリント人への第一の手紙 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ﻛﻮﺭﻧﺜﻮﺱ ﺍﻻﻭﻝ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinteni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Coríntios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korentyen 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinther 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinthus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintusi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Koritasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Wakorinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 kurĩtʰīāṃ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कोरिन्‍थी 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 ਕੁਰਿੰਥੀਆਂ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinter 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Koryntow 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Koryntów 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कोरिन्थी 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. କରିନ୍ଥୀୟ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1.۔کرنتھیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1°. Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinteni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Coríntios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korentyen 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinthus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintusi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Wakorinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Koryntow 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Koryntów 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Korinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinter 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Koryntow 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Koryntów 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कोरिन्थी 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 କରିନ୍ଥୀୟ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cô-rinh 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Côrintô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinta 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कुरिन्थ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. โครินธ์ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1° Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1۔کرنتھیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Første Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Koryntow 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Koryntów 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cô-rinh 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Côrintô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinta 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Kwanza Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("۱۔کرنتھیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("コリント人への前の書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("コリント人への手紙一 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinti 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cô-rinh 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Côrintô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinta 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कुरिन्थ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 โครินธ์ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cô-rinh 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Côrintô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinta 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvni Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("První Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Първа Кор 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corini 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Elso Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Első Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvni K 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("První K 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《哥林多前书》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《哥林多前書》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《格林多前書》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《歌林多前書》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《适凌爾福前》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 கொரி 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Кор 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Кор 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PrvniK 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PrvníK 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α' Κορ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ Κορ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ Κορ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α΄ Κορ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α’ Κορ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《哥林多前书 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《哥林多前書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《格林多前書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《歌林多前書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《适凌爾福前 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("コリント 1 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("コリント前書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("哥林多前书》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("哥林多前書》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("格林多前書》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("歌林多前書》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("适凌爾福前》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Кор 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 قور 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Кор 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α' Κο 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ Κο 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ Κο 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α΄ Κο 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α’ Κο 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("哥林多前书 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("哥林多前書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("格林多前書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("歌林多前書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("适凌爾福前 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("고린도1서 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("고린도전서 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("코린토1서 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 கொ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 คธ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 คร 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《林前》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1كو 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1코린 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《林前 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("林前》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("林前 1:1").osis()).toEqual("1Cor.1.1")
		`
		true
	it "should handle non-Latin digits in book: 1Cor (full)", ->
		p.set_options non_latin_digits_strategy: "replace"
		`
		expect(p.parse("Прва писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Прво писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I писмо од апостол Павле до христијаните во Коринт 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Първо послание на св. ап. Павла до Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Perse poslannja apostola Pavla do korynfjan 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Perše poslannja apostola Pavla do korynfjan 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Първо послание на св ап. Павла до Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Първо послание на св. ап Павла до Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Първо послание на св ап Павла до Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше. послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Korintiyarukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Korintiyarukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Korintiyarukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Korintiyarukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перша послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перше послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய முதலாவது திருமுகம் 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а. послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е. послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("رسالة بولس الرسول الأولى إلى أهل كورنثوس 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய முதலாவது நிருபம் 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("کرنتھِیُوں کے نام پولس رسول کا پہلا خط 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய முதல் திருமுகம் 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I послання апостола Павла до коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsza List sw. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsza List św. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsze List sw. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsze List św. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwszy List sw. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwszy List św. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Paulus' Første Brev til Korintherne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Paulus’ Første Brev til Korintherne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsza List sw Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsza List św Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsze List sw Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsze List św Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwszy List sw Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwszy List św Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ensimmainen Kirje korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ensimmäinen Kirje korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Paulus’ første brev til korinterne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pavlova prva poslanica Korincanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pavlova prva poslanica Korinćanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra bref Pals til Korintumanna 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra bref Páls til Korintumanna 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra bréf Pals til Korintumanna 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra bréf Páls til Korintumanna 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("कोरिन्थीहरूलाई पावलको पहिलो पत्र 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Paulus' 1. Brev til Korintherne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Paulus’ 1. Brev til Korintherne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Waraka wa Kwanza kwa Wakorintho 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("kurintʰiyōṅ ke nām kā pahlā ḫaṭ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. List sw. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. List św. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Barua ya Kwanza kwa Wakorintho 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. List sw. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. List św. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Paulus' 1 Brev til Korintherne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Paulus’ 1 Brev til Korintherne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Waraka wa Kwanza kwa Wakorinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Първо послание към коринтяните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("الرسالة الأولى إلى أهل كورنثوس 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய முதலாம் 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 List sw. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 List św. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. List sw Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. List św Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ensimmainen Korinttolaiskirje 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ensimmäinen Korinttolaiskirje 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I List sw. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I List św. Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. List sw Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. List św Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("کُرِنتھِیوں کے نام کا پہلا خط 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 List sw Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 List św Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ensimmainen Korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ensimmäinen Korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I List sw Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I List św Pawła do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ika- 1 Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰiharulai pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰiharulaī pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰiharulāi pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰiharulāī pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰiharūlai pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰiharūlaī pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰiharūlāi pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰiharūlāī pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰīharulai pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰīharulaī pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰīharulāi pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰīharulāī pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰīharūlai pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰīharūlaī pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰīharūlāi pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("korintʰīharūlāī pahilo patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("पौलाचे करिंथकरांस पहिले पत्र 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("କରିନ୍ଥୀୟଙ୍କ ପ୍ରତି ପ୍ରଥମ ପତ୍ର 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ika 1 Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ika- 1 Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("kurĩtʰīāṃ nū̃ pahilī pattrī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("אגרת פולוס הראשונה אל-הקורי 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("האיגרת הראשונה אל הקורינתים 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше. Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Ika 1 Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsza list do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsze list do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwszy list do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva Korincanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva Korinćanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva poslanica Korincanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva poslanica Korinæanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva poslanica Korinćanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("karimtʰkarams pahile patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("karimtʰkaraṃs pahile patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("karimtʰkarāms pahile patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("karimtʰkarāṃs pahile patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("kariṃtʰkarams pahile patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("kariṃtʰkaraṃs pahile patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("kariṃtʰkarāms pahile patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("kariṃtʰkarāṃs pahile patra 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перша Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перше Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Прва посланица Коринћанима 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("کرنتھیوں کے نام کا پہلا خط 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ਕੁਰਿੰਥੀਆਂ ਨੂੰ ਪਹਿਲੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а. Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е. Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Kirje korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra bref Pals til Korin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra bref Páls til Korin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra bréf Pals til Korin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra bréf Páls til Korin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Kirje korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("कोरिन्थीहरूलाई पहिलो पत्र 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Kirje korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korincanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinćanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. посланица Коринћанима 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Epistula I ad Corinthios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Epistula ad Corinthios I 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Kirje korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korincanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinćanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. посланица Коринћанима 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prima lettera ai Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korincanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinćanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 посланица Коринћанима 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Forsta Korinthierbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Första Korinthierbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korincanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinćanima Poslanica 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Sulat sa mga Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I посланица Коринћанима 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Mga Taga- Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Forsta Korintherbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Forsta Korintierbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Första Korintherbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Första Korintierbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Sulat sa mga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Послання до Коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Mga Taga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Forsta Korinterbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Första Korinterbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Premieres Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Premières Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva kniha Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva kniha Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva kniha Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva kniha Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvni list Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvni list Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("První list Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("První list Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvá kniha Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvá kniha Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvá kniha Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvá kniha Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Mga Taga- Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("करिंथकरांस पहिले पत्र 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinttolaiskirje 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Mga Taga- Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. list do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Elso Korinthusiakhoz 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Első Korinthusiakhoz 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Første Korintherbrev 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinttolaiskirje 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Mga Taga- Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. list do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Premiere Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Premiers Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Première Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvni list Korinskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvni list Korinským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("První list Korinskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("První list Korinským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvy list Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvy list Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvy list Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvy list Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvý list Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvý list Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvý list Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvý list Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Mga Taga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("הראשונה אל הקורינתים 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinttolaiskirje 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Mga Taga- Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 list do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinthierbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Mga Taga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Mga Taga-Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Første korinterbrev 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinttolaiskirje 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Mga Taga- Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I list do Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Mga Taga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Premier Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinthierbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Mga Taga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Mga Taga-Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintherbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinthusiakhoz 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintierbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰiharulai 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰiharulaī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰiharulāi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰiharulāī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰiharūlai 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰiharūlaī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰiharūlāi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰiharūlāī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰīharulai 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰīharulaī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰīharulāi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰīharulāī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰīharūlai 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰīharūlaī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰīharūlāi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korintʰīharūlāī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. list Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. list Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Første Korintierne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinttilaisille 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Mga Taga Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinthusiakhoz 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. list Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. list Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsza Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsze Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwszy Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Primeira Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Primeira Coríntios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Primeiro Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Primeiro Coríntios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Προς Κορινθίους Α' 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Προς Κορινθίους Αʹ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Προς Κορινθίους Αʹ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Προς Κορινθίους Α΄ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Προς Κορινθίους Α’ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Προς Κορινθιους Α' 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Προς Κορινθιους Αʹ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Προς Κορινθιους Αʹ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Προς Κορινθιους Α΄ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Προς Κορινθιους Α’ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("코린토 신자들에게 보낸 첫째 서간 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintherbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinthusiakhoz 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintierbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰiharulai 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰiharulaī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰiharulāi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰiharulāī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰiharūlai 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰiharūlaī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰiharūlāi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰiharūlāī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰīharulai 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰīharulaī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰīharulāi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰīharulāī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰīharūlai 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰīharūlaī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰīharūlāi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korintʰīharūlāī 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 list Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 list Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е. к Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше. до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-я. к Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinterbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. list Korinskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. list Korinským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कोरिन्थीहरूलाई 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ere. Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ère. Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra Korintubref 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Fyrra Korintubréf 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Første Korinterne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinthusiakhoz 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I list Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I list Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. list Korinskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. list Korinským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Kwanza Wakorintho 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsza Koryntow 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsza Koryntów 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsze Koryntow 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwsze Koryntów 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwszy Koryntow 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Pierwszy Koryntów 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Primero Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перша до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перше до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Първа Коринтяните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ପ୍ରଥମ କରିନ୍ଥୀୟଙ୍କ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinterbrevet 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintiyarukku 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 list Korinskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 list Korinským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कोरिन्थीहरूलाई 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а. до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е к Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е. до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-я к Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintherbrev 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1er. Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ere Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1re. Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ère Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1е. к Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1я. к Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I list Korinskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I list Korinským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Kwanza Wakorinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Premye Korentyen 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Primer Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva Korincanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva Korinćanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvni Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvni Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("První Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("První Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Прва Коринканите 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Прва Коринћанима 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Прва Коринќаните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Прво Коринканите 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Прво Коринќаните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("اوّل-کُرِنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintherbrev 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 e. Korintasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 i. Korintasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 k. Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 k. Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 k. Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 k. Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 karimtʰkarams 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 karimtʰkaraṃs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 karimtʰkarāms 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 karimtʰkarāṃs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 kariṃtʰkarams 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 kariṃtʰkaraṃs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 kariṃtʰkarāms 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 kariṃtʰkarāṃs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 ਕੁਰਿੰਥੀਆਂ ਨੂੰ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е. Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше. Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-я. Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Kurinthiayon 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Taga-Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. korinterbrev 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. к Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कुरिन्यि़यों 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1er Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1re Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1е к Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1я к Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Corinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Korinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Erste Korinther 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Første Korinter 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Korintos Kowaad 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prva Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvy Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvy Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvy Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvy Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvá Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvá Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvá Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvá Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvý Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvý Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvý Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvý Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ad Corinthios I 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перша Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перше Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Прва Коринтјани 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Прво Коринтјани 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Първа Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("اوّل کرنتھِیُوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("اوّل کُرنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Kurinthiayon 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Taga-Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 e Korintasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 e. Koritasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 i Korintasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 i. Koritasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 k Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 k Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 k Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 k Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 korinterbrev 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 к Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कुरिन्यि़यों 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а. Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е. Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше. Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше. коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-я Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiaid 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korincanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintierne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinćanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Коринканите 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Коринтяните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Коринћанима 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Коринќаните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कुरिन्थियों 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. କରିନ୍ଥୀୟଙ୍କ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1.-کُرِنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1.o. Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1.º. Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1е. Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1я. Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Elso Korinthus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Elso Korintusi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Első Korinthus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Első Korintusi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiaid 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korincanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinćanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Коринканите 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Коринтяните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Коринћанима 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Коринќаните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Korintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перша Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перша коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перше Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Перше коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("كورنثوس الأولى 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ପ୍ରଥମ କରିନ୍ଥୀୟ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiaid 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korincanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintierne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinćanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 e Koritasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 i Koritasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Коринканите 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Коринтяните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Коринћанима 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Коринќаните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कुरिन्थियों 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 କରିନ୍ଥୀୟଙ୍କ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 கொரிந்தியர் 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а. Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а. коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е. Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е. коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ше коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-کُرِنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintieni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cô-rinh-tô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinterne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Wakorintho 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Коринтјани 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. کرنتھِیُوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. کُرنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कुरन्थियों 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कुरिन्थियो 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1.o Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1.º Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1a. Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1a. Coríntios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1o. Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1o. Coríntios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1º. Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1е Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1я Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Coriinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Coranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiaid 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiens 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korincanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinthiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinthiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinćanima 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Коринканите 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Коринтяните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Коринћанима 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Коринќаните 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I до коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintieni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cô-rinh-tô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Wakorintho 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Коринтјани 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Premye Korint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prima Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Primo Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Unang Korinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α' Κορινθίους 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α' Κορινθιους 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ Κορινθίους 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ Κορινθιους 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ Κορινθίους 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ Κορινθιους 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α΄ Κορινθίους 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α΄ Κορινθιους 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α’ Κορινθίους 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α’ Κορινθιους 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("اوّل۔کرنتھیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("۱-کُرِنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ਕੁਰਿੰਥੀਆਂ ਨੂੰ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintieni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cô-rinh-tô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinterne 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Wakorintho 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Коринтјани 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Коринфянам 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 کرنتھِیُوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 کُرنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 करिंथकरांस 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कुरन्थियों 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कुरिन्थियो 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-а коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-е коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinteni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Coríntios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korentyen 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinther 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinthus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintusi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Koritasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Wakorinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कोरिन्‍थी 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1a Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1a Coríntios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Corinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Korinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1o Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1o Coríntios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1º Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Choranthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Chorinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Chorinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Coriinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinathians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinithinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinnthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthiaans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthiains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthianas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthianos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthios I 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthoians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corninthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corninthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornithaians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corrinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corrinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintieni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cô-rinh-tô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinthier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinthiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintiers 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintiërs 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintskym 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintským 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinťanom 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Wakorintho 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Коринтјани 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinteni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Coríntios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korentyen 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinthus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintusi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Wakorinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Korintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Wakorintho I 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("۱ کرنتھِیُوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("۱ کُرنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("コリントの信徒への手紙一 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("コリント人への第一の手紙 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ﻛﻮﺭﻧﺜﻮﺱ ﺍﻻﻭﻝ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinteni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Coríntios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korentyen 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinther 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinthus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintusi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Koritasve 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Wakorinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 kurĩtʰīāṃ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कोरिन्‍थी 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 ਕੁਰਿੰਥੀਆਂ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinter 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korintus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Koryntow 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Koryntów 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कोरिन्थी 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. କରିନ୍ଥୀୟ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1.۔کرنتھیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Corinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Korinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1°. Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Chorinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Chorithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Chornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthinas 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corninthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornthiians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corrithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corrithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinteni 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Coríntios 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korentyen 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinthus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintier 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintiër 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintusi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Koryntian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Wakorinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Коринтяни 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korintus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Koryntow 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Koryntów 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Una Korinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinter 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korintus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Koryntow 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Koryntów 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कोरिन्थी 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 କରିନ୍ଥୀୟ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cô-rinh 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Côrintô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinta 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कुरिन्थ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. โครินธ์ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1° Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1۔کرنتھیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corinthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corintians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corintions 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithoans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornthains 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornthians 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Eerste Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Første Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corthian 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinthe 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintio 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintos 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korintus 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Koryntow 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Koryntów 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Коринфян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I коринтян 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cô-rinh 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Côrintô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinta 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Kwanza Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("۱۔کرنتھیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("コリント人への前の書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("コリント人への手紙一 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinti 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cô-rinh 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Côrintô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinta 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कुरिन्थ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 โครินธ์ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Korint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithans 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Corithins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Cornthins 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corinzi 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cô-rinh 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Côrintô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinta 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korinto 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Korint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvni Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("První Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Първа Кор 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corini 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Korint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Elso Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Első Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("First Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Korint 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e. Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st. Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corin 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Corth 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Prvni K 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("První K 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《哥林多前书》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《哥林多前書》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《格林多前書》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《歌林多前書》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《适凌爾福前》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 கொரி 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Кор 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1e Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1st Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Кор 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PrvniK 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PrvníK 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α' Κορ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ Κορ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ Κορ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α΄ Κορ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α’ Κορ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《哥林多前书 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《哥林多前書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《格林多前書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《歌林多前書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《适凌爾福前 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("コリント 1 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("コリント前書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("哥林多前书》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("哥林多前書》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("格林多前書》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("歌林多前書》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("适凌爾福前》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Кор 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 قور 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. Cô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Kor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Кор 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. Cô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α' Κο 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ Κο 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ Κο 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α΄ Κο 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α’ Κο 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("哥林多前书 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("哥林多前書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("格林多前書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("歌林多前書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("适凌爾福前 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("고린도1서 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("고린도전서 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("코린토1서 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 Cô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 கொ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 คธ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 คร 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1Cor 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Co 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I Cô 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《林前》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1كو 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1코린 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《林前 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("林前》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("林前 1:1").osis()).toEqual("1Cor.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ПРВА ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО КОРИНТ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПРВО ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО КОРИНТ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО КОРИНТ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО КОРИНТ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО КОРИНТ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО КОРИНТ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПЪРВО ПОСЛАНИЕ НА СВ. АП. ПАВЛА ДО КОРИНТЯНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PERSE POSLANNJA APOSTOLA PAVLA DO KORYNFJAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PERŠE POSLANNJA APOSTOLA PAVLA DO KORYNFJAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПЪРВО ПОСЛАНИЕ НА СВ АП. ПАВЛА ДО КОРИНТЯНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПЪРВО ПОСЛАНИЕ НА СВ. АП ПАВЛА ДО КОРИНТЯНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПЪРВО ПОСЛАНИЕ НА СВ АП ПАВЛА ДО КОРИНТЯНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ШЕ. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTIYARUKKU ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTIYARUKKU ELUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTIYARUKKU EḺUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTIYARUKKU EḺUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПЕРША ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПЕРШЕ ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய முதலாவது திருமுகம் 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-А. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-Е. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ШЕ ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("رسالة بولس الرسول الأولى إلى أهل كورنثوس 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-А ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-Е ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய முதலாவது நிருபம் 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("کرنتھِیُوں کے نام پولس رسول کا پہلا خط 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய முதல் திருமுகம் 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZA LIST SW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZA LIST ŚW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZE LIST SW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZE LIST ŚW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZY LIST SW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZY LIST ŚW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PAULUS' FØRSTE BREV TIL KORINTHERNE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PAULUS’ FØRSTE BREV TIL KORINTHERNE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZA LIST SW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZA LIST ŚW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZE LIST SW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZE LIST ŚW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZY LIST SW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZY LIST ŚW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ENSIMMAINEN KIRJE KORINTTILAISILLE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ENSIMMÄINEN KIRJE KORINTTILAISILLE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PAULUS’ FØRSTE BREV TIL KORINTERNE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PAVLOVA PRVA POSLANICA KORINCANIMA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PAVLOVA PRVA POSLANICA KORINĆANIMA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FYRRA BREF PALS TIL KORINTUMANNA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FYRRA BREF PÁLS TIL KORINTUMANNA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FYRRA BRÉF PALS TIL KORINTUMANNA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FYRRA BRÉF PÁLS TIL KORINTUMANNA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("कोरिन्थीहरूलाई पावलको पहिलो पत्र 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PAULUS' 1. BREV TIL KORINTHERNE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PAULUS’ 1. BREV TIL KORINTHERNE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("WARAKA WA KWANZA KWA WAKORINTHO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KURINTʰIYŌṄ KE NĀM KĀ PAHLĀ ḪAṬ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. LIST SW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. LIST ŚW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("BARUA YA KWANZA KWA WAKORINTHO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. LIST SW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. LIST ŚW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PAULUS' 1 BREV TIL KORINTHERNE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PAULUS’ 1 BREV TIL KORINTHERNE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("WARAKA WA KWANZA KWA WAKORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПЪРВО ПОСЛАНИЕ КЪМ КОРИНТЯНИТЕ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("الرسالة الأولى إلى أهل كورنثوس 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("கொரிந்தியருக்கு எழுதிய முதலாம் 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 LIST SW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 LIST ŚW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. LIST SW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. LIST ŚW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ENSIMMAINEN KORINTTOLAISKIRJE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ENSIMMÄINEN KORINTTOLAISKIRJE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I LIST SW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I LIST ŚW. PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. LIST SW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. LIST ŚW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("کُرِنتھِیوں کے نام کا پہلا خط 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 LIST SW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 LIST ŚW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ENSIMMAINEN KORINTTILAISILLE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ENSIMMÄINEN KORINTTILAISILLE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I LIST SW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I LIST ŚW PAWŁA DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("IKA- 1 SULAT SA MGA CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTʰIHARULAI PAHILO PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTʰIHARULAĪ PAHILO PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTʰIHARULĀI PAHILO PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTʰIHARULĀĪ PAHILO PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTʰIHARŪLAI PAHILO PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTʰIHARŪLAĪ PAHILO PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTʰIHARŪLĀI PAHILO PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTʰIHARŪLĀĪ PAHILO PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTʰĪHARULAI PAHILO PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTʰĪHARULAĪ PAHILO PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTʰĪHARULĀI PAHILO PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTʰĪHARULĀĪ PAHILO PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTʰĪHARŪLAI PAHILO PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTʰĪHARŪLAĪ PAHILO PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTʰĪHARŪLĀI PAHILO PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTʰĪHARŪLĀĪ PAHILO PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("पौलाचे करिंथकरांस पहिले पत्र 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("କରିନ୍ଥୀୟଙ୍କ ପ୍ରତି ପ୍ରଥମ ପତ୍ର 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("IKA 1 SULAT SA MGA CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("IKA- 1 SULAT SA MGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNANG SULAT SA MGA CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KURĨTʰĪĀṂ NŪ̃ PAHILĪ PATTRĪ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("אגרת פולוס הראשונה אל-הקורי 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("האיגרת הראשונה אל הקורינתים 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ШЕ. ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("IKA 1 SULAT SA MGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZA LIST DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZE LIST DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZY LIST DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVA KORINCANIMA POSLANICA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVA KORINĆANIMA POSLANICA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVA POSLANICA KORINCANIMA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVA POSLANICA KORINÆANIMA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVA POSLANICA KORINĆANIMA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNANG SULAT SA MGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KARIMTʰKARAMS PAHILE PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KARIMTʰKARAṂS PAHILE PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KARIMTʰKARĀMS PAHILE PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KARIMTʰKARĀṂS PAHILE PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KARIṂTʰKARAMS PAHILE PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KARIṂTʰKARAṂS PAHILE PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KARIṂTʰKARĀMS PAHILE PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KARIṂTʰKARĀṂS PAHILE PATRA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПЕРША ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПЕРШЕ ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПРВА ПОСЛАНИЦА КОРИНЋАНИМА 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("کرنتھیوں کے نام کا پہلا خط 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ਕੁਰਿੰਥੀਆਂ ਨੂੰ ਪਹਿਲੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-А. ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-Е. ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ШЕ ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KIRJE KORINTTILAISILLE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FYRRA BREF PALS TIL KORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FYRRA BREF PÁLS TIL KORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FYRRA BRÉF PALS TIL KORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FYRRA BRÉF PÁLS TIL KORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KIRJE KORINTTILAISILLE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNA SULAT SA MGA CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("कोरिन्थीहरूलाई पहिलो पत्र 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KIRJE KORINTTILAISILLE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-А ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-Е ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINCANIMA POSLANICA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINĆANIMA POSLANICA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. SULAT SA MGA CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. ПОСЛАНИЦА КОРИНЋАНИМА 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EPISTULA I AD CORINTHIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EPISTULA AD CORINTHIOS I 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KIRJE KORINTTILAISILLE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINCANIMA POSLANICA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINĆANIMA POSLANICA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. SULAT SA MGA CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. ПОСЛАНИЦА КОРИНЋАНИМА 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRIMA LETTERA AI CORINZI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNA SULAT SA MGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINCANIMA POSLANICA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINĆANIMA POSLANICA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 SULAT SA MGA CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 ПОСЛАНИЦА КОРИНЋАНИМА 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. SULAT SA MGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FORSTA KORINTHIERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FÖRSTA KORINTHIERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINCANIMA POSLANICA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINĆANIMA POSLANICA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I SULAT SA MGA CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I ПОСЛАНИЦА КОРИНЋАНИМА 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. SULAT SA MGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNANG MGA TAGA- CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 SULAT SA MGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FORSTA KORINTHERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FORSTA KORINTIERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FÖRSTA KORINTHERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FÖRSTA KORINTIERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I SULAT SA MGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I ПОСЛАННЯ ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNANG MGA TAGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FORSTA KORINTERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FÖRSTA KORINTERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PREMIERES CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PREMIÈRES CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVA KNIHA KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVA KNIHA KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVA KNIHA KORINTSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVA KNIHA KORINŤANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNI LIST KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNI LIST KORINTSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNÍ LIST KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNÍ LIST KORINTSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVÁ KNIHA KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVÁ KNIHA KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVÁ KNIHA KORINTSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVÁ KNIHA KORINŤANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNA MGA TAGA- CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("करिंथकरांस पहिले पत्र 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTTOLAISKIRJE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. MGA TAGA- CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. LIST DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ELSO KORINTHUSIAKHOZ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ELSŐ KORINTHUSIAKHOZ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FØRSTE KORINTHERBREV 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTTOLAISKIRJE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. MGA TAGA- CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. LIST DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PREMIERE CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PREMIERS CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PREMIÈRE CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNI LIST KORINSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNI LIST KORINSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNÍ LIST KORINSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNÍ LIST KORINSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVY LIST KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVY LIST KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVY LIST KORINTSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVY LIST KORINŤANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVÝ LIST KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVÝ LIST KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVÝ LIST KORINTSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVÝ LIST KORINŤANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNA MGA TAGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("הראשונה אל הקורינתים 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTTOLAISKIRJE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 MGA TAGA- CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 LIST DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTHIERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTTILAISILLE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. MGA TAGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. MGA TAGA-CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FØRSTE KORINTERBREV 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTTOLAISKIRJE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I MGA TAGA- CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I LIST DO KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTTILAISILLE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. MGA TAGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PREMIER CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTHIERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTTILAISILLE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 MGA TAGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 MGA TAGA-CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTHERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTHUSIAKHOZ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTIERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTʰIHARULAI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTʰIHARULAĪ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTʰIHARULĀI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTʰIHARULĀĪ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTʰIHARŪLAI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTʰIHARŪLAĪ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTʰIHARŪLĀI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTʰIHARŪLĀĪ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTʰĪHARULAI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTʰĪHARULAĪ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTʰĪHARULĀI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTʰĪHARULĀĪ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTʰĪHARŪLAI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTʰĪHARŪLAĪ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTʰĪHARŪLĀI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTʰĪHARŪLĀĪ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. LIST KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. LIST KORINTSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE CORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE CORINTHIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE KORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE KORINTHIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FØRSTE KORINTIERNE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTTILAISILLE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I MGA TAGA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTHUSIAKHOZ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. LIST KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. LIST KORINTSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZA KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZE KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZY KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRIMEIRA CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRIMEIRA CORÍNTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRIMEIRO CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRIMEIRO CORÍNTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ΠΡΟΣ ΚΟΡΙΝΘΊΟΥΣ Α' 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ΠΡΟΣ ΚΟΡΙΝΘΊΟΥΣ Αʹ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ΠΡΟΣ ΚΟΡΙΝΘΊΟΥΣ Αʹ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ΠΡΟΣ ΚΟΡΙΝΘΊΟΥΣ Α΄ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ΠΡΟΣ ΚΟΡΙΝΘΊΟΥΣ Α’ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ΠΡΟΣ ΚΟΡΙΝΘΙΟΥΣ Α' 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ΠΡΟΣ ΚΟΡΙΝΘΙΟΥΣ Αʹ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ΠΡΟΣ ΚΟΡΙΝΘΙΟΥΣ Αʹ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ΠΡΟΣ ΚΟΡΙΝΘΙΟΥΣ Α΄ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ΠΡΟΣ ΚΟΡΙΝΘΙΟΥΣ Α’ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("코린토 신자들에게 보낸 첫째 서간 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTHERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTHUSIAKHOZ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTIERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTʰIHARULAI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTʰIHARULAĪ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTʰIHARULĀI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTʰIHARULĀĪ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTʰIHARŪLAI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTʰIHARŪLAĪ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTʰIHARŪLĀI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTʰIHARŪLĀĪ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTʰĪHARULAI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTʰĪHARULAĪ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTʰĪHARULĀI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTʰĪHARULĀĪ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTʰĪHARŪLAI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTʰĪHARŪLAĪ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTʰĪHARŪLĀI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTʰĪHARŪLĀĪ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 LIST KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 LIST KORINTSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-Е. К КОРИНФЯНАМ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ШЕ. ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-Я. К КОРИНФЯНАМ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. LIST KORINSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. LIST KORINSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कोरिन्थीहरूलाई 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ERE. CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ÈRE. CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE CORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE CORINTHIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE CORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE CORINTIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE KORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE KORINTHIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE KORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE KORINTIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FYRRA KORINTUBREF 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FYRRA KORINTUBRÉF 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FØRSTE KORINTERNE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTHUSIAKHOZ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I LIST KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I LIST KORINTSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. LIST KORINSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. LIST KORINSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KWANZA WAKORINTHO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZA KORYNTOW 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZA KORYNTÓW 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZE KORYNTOW 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZE KORYNTÓW 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZY KORYNTOW 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PIERWSZY KORYNTÓW 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRIMERO CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПЕРША ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПЕРШЕ ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПЪРВА КОРИНТЯНИТЕ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ପ୍ରଥମ କରିନ୍ଥୀୟଙ୍କ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTERBREVET 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTIYARUKKU 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 LIST KORINSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 LIST KORINSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कोरिन्थीहरूलाई 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-А. ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-Е К КОРИНФЯНАМ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-Е. ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ШЕ ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-Я К КОРИНФЯНАМ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTHERBREV 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ER. CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ERE CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1RE. CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ÈRE CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1Е. К КОРИНФЯНАМ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1Я. К КОРИНФЯНАМ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE CORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE CORINTIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE KORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE KORINTIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I LIST KORINSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I LIST KORINSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KWANZA WAKORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PREMYE KORENTYEN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRIMER CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVA KORINCANIMA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVA KORINĆANIMA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNI KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNI KORINTSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNÍ KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNÍ KORINTSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПРВА КОРИНКАНИТЕ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПРВА КОРИНЋАНИМА 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПРВА КОРИНЌАНИТЕ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПРВО КОРИНКАНИТЕ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПРВО КОРИНЌАНИТЕ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("اوّل-کُرِنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTHERBREV 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 E. KORINTASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 I. KORINTASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 K. KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 K. KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 K. KORINTSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 K. KORINŤANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KARIMTʰKARAMS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KARIMTʰKARAṂS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KARIMTʰKARĀMS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KARIMTʰKARĀṂS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KARIṂTʰKARAMS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KARIṂTʰKARAṂS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KARIṂTʰKARĀMS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KARIṂTʰKARĀṂS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 ਕੁਰਿੰਥੀਆਂ ਨੂੰ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-А ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-Е ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-Е. КОРИНФЯНАМ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ШЕ. КОРИНТЯНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-Я. КОРИНФЯНАМ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KURINTHIAYON 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. TAGA-CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTERBREV 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. К КОРИНФЯНАМ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कुरिन्यि़यों 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. CORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. CORINTHIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. KORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. KORINTHIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ER CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1RE CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1Е К КОРИНФЯНАМ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1Я К КОРИНФЯНАМ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE CORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE KORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ERSTE KORINTHER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FØRSTE KORINTER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KORINTOS KOWAAD 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVA KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVA KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVA KORINTSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVA KORINŤANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVY KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVY KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVY KORINTSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVY KORINŤANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVÁ KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVÁ KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVÁ KORINTSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVÁ KORINŤANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVÝ KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVÝ KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVÝ KORINTSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVÝ KORINŤANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("AD CORINTHIOS I 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПЕРША КОРИНТЯНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПЕРШЕ КОРИНТЯНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПРВА КОРИНТЈАНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПРВО КОРИНТЈАНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПЪРВА КОРИНТЯНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("اوّل کرنتھِیُوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("اوّل کُرنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KURINTHIAYON 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 TAGA-CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 E KORINTASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 E. KORITASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 I KORINTASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 I. KORITASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 K KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 K KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 K KORINTSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 K KORINŤANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTERBREV 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 К КОРИНФЯНАМ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कुरिन्यि़यों 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-А. КОРИНТЯНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-Е КОРИНФЯНАМ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-Е. КОРИНТЯНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ШЕ КОРИНТЯНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ШЕ. КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ШЕ. КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-Я КОРИНФЯНАМ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIAID 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINCANIMA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTHIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTIERNE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINĆANIMA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. КОРИНКАНИТЕ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. КОРИНТЯНИТЕ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. КОРИНЋАНИМА 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. КОРИНЌАНИТЕ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कुरिन्थियों 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. କରିନ୍ଥୀୟଙ୍କ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1.-کُرِنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1.O. CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1.º. CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E CORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E CORINTHIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E KORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E KORINTHIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. CORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. CORINTHIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. CORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. CORINTIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. KORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. KORINTHIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. KORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. KORINTIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1Е. КОРИНФЯНАМ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1Я. КОРИНФЯНАМ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ELSO KORINTHUS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ELSO KORINTUSI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ELSŐ KORINTHUS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ELSŐ KORINTUSI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIAID 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINCANIMA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTHIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINĆANIMA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. КОРИНКАНИТЕ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. КОРИНТЯНИТЕ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. КОРИНЋАНИМА 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. КОРИНЌАНИТЕ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNANG CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNANG KORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПЕРША КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПЕРША КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПЕРШЕ КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПЕРШЕ КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("كورنثوس الأولى 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ପ୍ରଥମ କରିନ୍ଥୀୟ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIAID 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINCANIMA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTHIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTIERNE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINĆANIMA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 E KORITASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 I KORITASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 КОРИНКАНИТЕ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 КОРИНТЯНИТЕ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 КОРИНЋАНИМА 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 КОРИНЌАНИТЕ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कुरिन्थियों 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 କରିନ୍ଥୀୟଙ୍କ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 கொரிந்தியர் 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-А КОРИНТЯНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-А. КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-А. КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-Е КОРИНТЯНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-Е. КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-Е. КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ШЕ КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-ШЕ КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-کُرِنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTIENI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CÔ-RINH-TÔ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTERNE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTHIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINŤANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. WAKORINTHO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. КОРИНТЈАНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. КОРИНФЯНАМ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. کرنتھِیُوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. کُرنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कुरन्थियों 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कुरिन्थियो 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1.O CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1.º CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1A. CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1A. CORÍNTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E CORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E CORINTHIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E CORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E CORINTIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E KORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E KORINTHIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E KORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E KORINTIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. CORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. CORINTIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. KORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. KORINTIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1O. CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1O. CORÍNTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1º. CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1Е КОРИНФЯНАМ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1Я КОРИНФЯНАМ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORIINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIAID 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIENS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINCANIMA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTHIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTHIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINĆANIMA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I КОРИНКАНИТЕ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I КОРИНТЯНИТЕ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I КОРИНЋАНИМА 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I КОРИНЌАНИТЕ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I ДО КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTIENI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CÔ-RINH-TÔ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTHIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINŤANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. WAKORINTHO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. КОРИНТЈАНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PREMYE KORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRIMA CORINZI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRIMO CORINZI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNANG CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNANG KORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α' ΚΟΡΙΝΘΊΟΥΣ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α' ΚΟΡΙΝΘΙΟΥΣ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ ΚΟΡΙΝΘΊΟΥΣ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ ΚΟΡΙΝΘΙΟΥΣ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ ΚΟΡΙΝΘΊΟΥΣ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ ΚΟΡΙΝΘΙΟΥΣ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α΄ ΚΟΡΙΝΘΊΟΥΣ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α΄ ΚΟΡΙΝΘΙΟΥΣ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α’ ΚΟΡΙΝΘΊΟΥΣ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α’ ΚΟΡΙΝΘΙΟΥΣ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("اوّل۔کرنتھیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("۱-کُرِنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ਕੁਰਿੰਥੀਆਂ ਨੂੰ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTIENI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CÔ-RINH-TÔ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTERNE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTHIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINŤANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 WAKORINTHO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 КОРИНТЈАНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 КОРИНФЯНАМ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 کرنتھِیُوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 کُرنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 करिंथकरांस 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कुरन्थियों 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कुरिन्थियो 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-А КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-А КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-Е КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1-Е КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTENI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORÍNTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORENTYEN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTHER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTHUS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTUSI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORITASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. WAKORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. КОРИНТЯНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कोरिन्‍थी 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1A CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1A CORÍNTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E CORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E CORINTIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E KORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E KORINTIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. CORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. KORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1O CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1O CORÍNTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1º CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CHORANTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CHORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CHORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORIINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINATHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINITHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIAANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIANAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIANOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIOS I 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHOIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNITHAIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORRINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORRINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTIENI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CÔ-RINH-TÔ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTHIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTHIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTIERS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTIËRS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTSKYM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTSKÝM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINŤANOM 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I WAKORINTHO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I КОРИНТЈАНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTENI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORÍNTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORENTYEN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTHUS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTUSI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. WAKORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. КОРИНТЯНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNA CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNA KORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("WAKORINTHO I 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("۱ کرنتھِیُوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("۱ کُرنتھِیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("コリントの信徒への手紙一 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("コリント人への第一の手紙 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ﻛﻮﺭﻧﺜﻮﺱ ﺍﻻﻭﻝ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTENI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORÍNTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORENTYEN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTHER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTHUS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTUSI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORITASVE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 WAKORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KURĨTʰĪĀṂ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 КОРИНТЯНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कोरिन्‍थी 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 ਕੁਰਿੰਥੀਆਂ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTUS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORYNTOW 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORYNTÓW 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कोरिन्थी 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. କରିନ୍ଥୀୟ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1.۔کرنتھیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E CORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E KORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1°. CORINZI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CHORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CHORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CHORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHINAS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORITHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNTHIIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORRITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORRITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CORTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTENI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORÍNTIOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORENTYEN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTHUS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTIER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTIËR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTUSI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORYNTIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I WAKORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I КОРИНТЯНИ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTUS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORYNTOW 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORYNTÓW 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNA CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("UNA KORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTER 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTUS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORYNTOW 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORYNTÓW 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कोरिन्थी 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 କରିନ୍ଥୀୟ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINZI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CÔ-RINH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CÔRINTÔ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. कुरिन्थ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. โครินธ์ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CORTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1° CORINZI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1۔کرنتھیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORINTIONS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORITHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORITHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORITHOANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNTHAINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNTHIANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("EERSTE KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FØRSTE KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORTHIAN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTHE 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTIO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTOS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTUS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORYNTOW 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORYNTÓW 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I КОРИНФЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I КОРИНТЯН 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINZI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CÔ-RINH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CÔRINTÔ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("KWANZA KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("۱۔کرنتھیوں 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("コリント人への前の書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("コリント人への手紙一 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINZI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CÔ-RINH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CÔRINTÔ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 कुरिन्थ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 โครินธ์ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CORTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORITHANS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORITHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("CORNTHINS 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINZI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CÔ-RINH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CÔRINTÔ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTA 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINTO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNI KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNÍ KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ПЪРВА КОР 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINI 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CORTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ELSO KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("ELSŐ KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("FIRST CO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KORINT 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CORTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CORTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E. KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST. CO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORIN 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CORTH 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNI K 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNÍ K 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《哥林多前书》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《哥林多前書》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《格林多前書》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《歌林多前書》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《适凌爾福前》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 கொரி 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. КОР 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1E KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1ST CO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. КОР 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNIK 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("PRVNÍK 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α' ΚΟΡ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ ΚΟΡ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ ΚΟΡ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α΄ ΚΟΡ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α’ ΚΟΡ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《哥林多前书 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《哥林多前書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《格林多前書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《歌林多前書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《适凌爾福前 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("コリント 1 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("コリント前書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("哥林多前书》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("哥林多前書》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("格林多前書》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("歌林多前書》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("适凌爾福前》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 КОР 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 قور 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1. CÔ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I KOR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I КОР 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I. CÔ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α' ΚΟ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ ΚΟ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Αʹ ΚΟ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α΄ ΚΟ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("Α’ ΚΟ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("哥林多前书 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("哥林多前書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("格林多前書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("歌林多前書 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("适凌爾福前 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("고린도1서 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("고린도전서 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("코린토1서 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 CÔ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 கொ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 คธ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1 คร 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1COR 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CO 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("I CÔ 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《林前》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1كو 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("1코린 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("《林前 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("林前》 1:1").osis()).toEqual("1Cor.1.1")
		expect(p.parse("林前 1:1").osis()).toEqual("1Cor.1.1")
		`
		true
describe "Localized book Gal (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Gal (full)", ->
		`
		expect(p.parse("Писмо од апостол Павле до христијаните во Галатија 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Послання св. апостола Павла до галатів 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Послание на св. ап. Павла до Галатяни 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Послання св апостола Павла до галатів 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Послание на св ап. Павла до Галатяни 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Послание на св. ап Павла до Галатяни 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Poslannja apostola Pavla do halativ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Послание на св ап Павла до Галатяни 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Послання апостола Павла до галатів 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("رسالة بولس الرسول إلى أهل غلاطية 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("கலாத்தியருக்கு எழுதிய திருமுகம் 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Kalattiyarukku Elutiya Nirupam 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Kalattiyarukku Eḻutiya Nirupam 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Kalāttiyarukku Elutiya Nirupam 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Kalāttiyarukku Eḻutiya Nirupam 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("گلتیوں کے نام پولُس رسول کا خط 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("கலாத்தியருக்கு எழுதிய நிருபம் 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Pavlova poslanica Galacanima 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Pavlova poslanica Galaćanima 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("கலாத்தியருக்கு எழுதிய கடிதம் 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("List sw. Pawła do Galacjan 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("List św. Pawła do Galacjan 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Paulus' Brev til Galaterne 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Paulus’ Brev til Galaterne 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Paulus’ brev til galaterne 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("אגרת פולוס השליח אל-הגלטים 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Bref Pals til Galatamanna 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Bref Páls til Galatamanna 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Bréf Pals til Galatamanna 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Bréf Páls til Galatamanna 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("List sw Pawła do Galacjan 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("List św Pawła do Galacjan 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Sulat sa mga taga Galacia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatiyōṅ ke nām kā ḫaṭ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Послание към галатяните 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("गलातीहरूलाई पावलको पत्र 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("الرسالة إلى أهل غلاطية 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Layang Paulus Galatia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("पौलाचे गलतीकरांस पत्र 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ଗାଲାତୀୟଙ୍କ ପ୍ରତି ପତ୍ର 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Brevet til Galaterne 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Kirje galatalaisille 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Poslanica Galacanima 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Poslanica Galaæanima 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Poslanica Galaćanima 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Sulat sa mga Galacia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("По слання до Галатів 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Посланица Галаћанима 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("گلتِیوں کے نام کا خط 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Barua kwa Wagalatia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Epistula ad Galatas 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatiharulai patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatiharulaī patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatiharulāi patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatiharulāī patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatiharūlai patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatiharūlaī patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatiharūlāi patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatiharūlāī patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīharulai patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīharulaī patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīharulāi patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīharulāī patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīharūlai patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīharūlaī patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīharūlāi patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīharūlāī patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātiharulai patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātiharulaī patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātiharulāi patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātiharulāī patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātiharūlai patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātiharūlaī patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātiharūlāi patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātiharūlāī patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātīharulai patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātīharulaī patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātīharulāi patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātīharulāī patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātīharūlai patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātīharūlaī patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātīharūlāi patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātīharūlāī patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātīāṃ nū̃ pattrī 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Послання до галатів 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("گلتیوں کے نام کا خط 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatikarams patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatikaraṃs patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatikarāms patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatikarāṃs patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīkarams patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīkaraṃs patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīkarāms patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīkarāṃs patra 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Послание к Галатам 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Посланица Галатима 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ਗਲਾਤੀਆਂ ਨੂੰ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Lettera ai Galati 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Mga Taga- Galacia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Mga Taga- Galasya 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("List do Galacjan 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Mga Taga Galacia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Mga Taga Galasya 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Mga Taga-Galacia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("האיגרת אל הגלטים 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("गलातीहरूलाई पत्र 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("갈라티아 신자들에게 보낸 서간 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("List do Galatow 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("List do Galatów 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatalaisille 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatalaiskirj 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galaterbrefvet 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Kalattiyarukku 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Kalāttiyarukku 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("List Galatanom 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("List Galatskym 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("List Galatským 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("List Galaťanom 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("गलतीकरांस पत्र 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galaterbrevet 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Taga- Galacia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatiharulai 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatiharulaī 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatiharulāi 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatiharulāī 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatiharūlai 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatiharūlaī 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatiharūlāi 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatiharūlāī 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīharulai 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīharulaī 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīharulāi 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīharulāī 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīharūlai 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīharūlaī 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīharūlāi 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīharūlāī 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātiharulai 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātiharulaī 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātiharulāi 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātiharulāī 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātiharūlai 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātiharūlaī 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātiharūlāi 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātiharūlāī 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātīharulai 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātīharulaī 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātīharulāi 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātīharulāī 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātīharūlai 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātīharūlaī 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātīharūlāi 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātīharūlāī 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatabrefið 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatabréfið 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatenbrief 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Taga Galacia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Taga-Galacia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatikarams 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatikaraṃs 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatikarāms 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatikarāṃs 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīkarams 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīkaraṃs 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīkarāms 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galatīkarāṃs 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Προς Γαλάτας 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Προς Γαλατας 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("رسالة غلاطية 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("गलातीहरूलाई 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ਗਲਾਤੀਆਂ ਨੂੰ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("カラテヤの信徒への手紙 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ガラテヤの信徒への手紙 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galacanima 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galataians 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galataions 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatakhoz 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatiaans 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatiains 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatianas 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatianis 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatiians 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatiions 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatinans 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatioans 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galationas 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galationns 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatákhoz 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galaćanima 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gallatians 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gallations 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ad Galatas 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Галатяните 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Галаћанима 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("До галатів 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ଗାଲାତୀୟଙ୍କ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("கலாத்தியர் 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galasyano 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galataans 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatains 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatanom 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galataons 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatasve 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galaterne 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatiaid 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatians 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatiins 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatinas 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galations 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatiyon 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatoans 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatskym 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatským 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galaťanom 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gallatins 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Wagalatia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Галатјани 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("К Галатам 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("אל הגלטים 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("गलतीकरांस 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("カラテヤ人への手紙 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ガラテヤ人への手紙 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Ga-la-ti 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galacjan 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galasyen 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatans 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galateni 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatian 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatias 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatins 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatios 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatiya 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatons 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("galātīāṃ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Галатима 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Галатите 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Галатяни 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("गलातियों 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("กาลาเทีย 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("カラテヤ人への書 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ガラテヤ人への書 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galacia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galasia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatas 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galaten 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galater 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galates 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatia 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatns 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatow 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galatów 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gálatas 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Γαλάτες 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Γαλατες 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Галатам 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Галатів 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("گلتِیوں 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("गलतियों 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galasi 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galata 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galati 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gàlati 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("گلتیوں 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("《加拉太书》 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("《加拉太書》 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("《戛拉提亞》 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("《迦拉達書》 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galat 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Galát 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gálat 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("गलाति 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("गलाती 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("கலாத் 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("《加拉太书 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("《加拉太書 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("《戛拉提亞 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("《迦拉達書 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("カラテヤ書 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ガラテヤ書 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("加拉太书》 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("加拉太書》 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("戛拉提亞》 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("迦拉達書》 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("갈라디아서 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gala 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("カラテヤ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ガラテヤ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("加拉太书 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("加拉太書 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("戛拉提亞 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("迦拉達書 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ﻏﻼﻃﻲ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gal 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gál 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Γαλ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Гал 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("கலா 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("《加》 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Ga 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gl 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Gá 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("Γα 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("غل 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("กท 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("《加 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("加》 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("갈라 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("加 1:1").osis()).toEqual("Gal.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО ГАЛАТИЈА 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ГАЛАТІВ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ. АП. ПАВЛА ДО ГАЛАТЯНИ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ГАЛАТІВ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ АП. ПАВЛА ДО ГАЛАТЯНИ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ. АП ПАВЛА ДО ГАЛАТЯНИ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("POSLANNJA APOSTOLA PAVLA DO HALATIV 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ АП ПАВЛА ДО ГАЛАТЯНИ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ГАЛАТІВ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("رسالة بولس الرسول إلى أهل غلاطية 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("கலாத்தியருக்கு எழுதிய திருமுகம் 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("KALATTIYARUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("KALATTIYARUKKU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("KALĀTTIYARUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("KALĀTTIYARUKKU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("گلتیوں کے نام پولُس رسول کا خط 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("கலாத்தியருக்கு எழுதிய நிருபம் 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("PAVLOVA POSLANICA GALACANIMA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("PAVLOVA POSLANICA GALAĆANIMA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("கலாத்தியருக்கு எழுதிய கடிதம் 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("LIST SW. PAWŁA DO GALACJAN 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("LIST ŚW. PAWŁA DO GALACJAN 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("PAULUS' BREV TIL GALATERNE 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("PAULUS’ BREV TIL GALATERNE 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("PAULUS’ BREV TIL GALATERNE 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("אגרת פולוס השליח אל-הגלטים 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("BREF PALS TIL GALATAMANNA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("BREF PÁLS TIL GALATAMANNA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("BRÉF PALS TIL GALATAMANNA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("BRÉF PÁLS TIL GALATAMANNA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("LIST SW PAWŁA DO GALACJAN 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("LIST ŚW PAWŁA DO GALACJAN 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("SULAT SA MGA TAGA GALACIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIYŌṄ KE NĀM KĀ ḪAṬ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ПОСЛАНИЕ КЪМ ГАЛАТЯНИТЕ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("गलातीहरूलाई पावलको पत्र 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("الرسالة إلى أهل غلاطية 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("LAYANG PAULUS GALATIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("पौलाचे गलतीकरांस पत्र 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ଗାଲାତୀୟଙ୍କ ପ୍ରତି ପତ୍ର 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("BREVET TIL GALATERNE 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("KIRJE GALATALAISILLE 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("POSLANICA GALACANIMA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("POSLANICA GALAÆANIMA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("POSLANICA GALAĆANIMA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("SULAT SA MGA GALACIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ПО СЛАННЯ ДО ГАЛАТІВ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ПОСЛАНИЦА ГАЛАЋАНИМА 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("گلتِیوں کے نام کا خط 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("BARUA KWA WAGALATIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("EPISTULA AD GALATAS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIHARULAI PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIHARULAĪ PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIHARULĀI PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIHARULĀĪ PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIHARŪLAI PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIHARŪLAĪ PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIHARŪLĀI PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIHARŪLĀĪ PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪHARULAI PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪHARULAĪ PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪHARULĀI PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪHARULĀĪ PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪHARŪLAI PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪHARŪLAĪ PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪHARŪLĀI PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪHARŪLĀĪ PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTIHARULAI PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTIHARULAĪ PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTIHARULĀI PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTIHARULĀĪ PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTIHARŪLAI PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTIHARŪLAĪ PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTIHARŪLĀI PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTIHARŪLĀĪ PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTĪHARULAI PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTĪHARULAĪ PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTĪHARULĀI PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTĪHARULĀĪ PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTĪHARŪLAI PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTĪHARŪLAĪ PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTĪHARŪLĀI PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTĪHARŪLĀĪ PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTĪĀṂ NŪ̃ PATTRĪ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ПОСЛАННЯ ДО ГАЛАТІВ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("گلتیوں کے نام کا خط 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIKARAMS PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIKARAṂS PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIKARĀMS PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIKARĀṂS PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪKARAMS PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪKARAṂS PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪKARĀMS PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪKARĀṂS PATRA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ПОСЛАНИЕ К ГАЛАТАМ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ПОСЛАНИЦА ГАЛАТИМА 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ਗਲਾਤੀਆਂ ਨੂੰ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("LETTERA AI GALATI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("MGA TAGA- GALACIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("MGA TAGA- GALASYA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("LIST DO GALACJAN 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("MGA TAGA GALACIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("MGA TAGA GALASYA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("MGA TAGA-GALACIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("האיגרת אל הגלטים 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("गलातीहरूलाई पत्र 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("갈라티아 신자들에게 보낸 서간 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("LIST DO GALATOW 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("LIST DO GALATÓW 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATALAISILLE 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATALAISKIRJ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATERBREFVET 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("KALATTIYARUKKU 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("KALĀTTIYARUKKU 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("LIST GALATANOM 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("LIST GALATSKYM 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("LIST GALATSKÝM 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("LIST GALAŤANOM 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("गलतीकरांस पत्र 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATERBREVET 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("TAGA- GALACIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIHARULAI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIHARULAĪ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIHARULĀI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIHARULĀĪ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIHARŪLAI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIHARŪLAĪ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIHARŪLĀI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIHARŪLĀĪ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪHARULAI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪHARULAĪ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪHARULĀI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪHARULĀĪ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪHARŪLAI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪHARŪLAĪ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪHARŪLĀI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪHARŪLĀĪ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTIHARULAI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTIHARULAĪ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTIHARULĀI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTIHARULĀĪ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTIHARŪLAI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTIHARŪLAĪ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTIHARŪLĀI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTIHARŪLĀĪ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTĪHARULAI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTĪHARULAĪ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTĪHARULĀI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTĪHARULĀĪ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTĪHARŪLAI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTĪHARŪLAĪ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTĪHARŪLĀI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTĪHARŪLĀĪ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATABREFIÐ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATABRÉFIÐ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATENBRIEF 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("TAGA GALACIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("TAGA-GALACIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIKARAMS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIKARAṂS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIKARĀMS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIKARĀṂS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪKARAMS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪKARAṂS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪKARĀMS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATĪKARĀṂS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ΠΡΟΣ ΓΑΛΆΤΑΣ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ΠΡΟΣ ΓΑΛΑΤΑΣ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("رسالة غلاطية 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("गलातीहरूलाई 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ਗਲਾਤੀਆਂ ਨੂੰ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("カラテヤの信徒への手紙 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ガラテヤの信徒への手紙 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALACANIMA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATAIANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATAIONS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATAKHOZ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIAANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIAINS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIANAS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIANIS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIIANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIIONS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATINANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIOANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIONAS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIONNS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATÁKHOZ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALAĆANIMA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALLATIANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALLATIONS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("AD GALATAS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ГАЛАТЯНИТЕ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ГАЛАЋАНИМА 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ДО ГАЛАТІВ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ଗାଲାତୀୟଙ୍କ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("கலாத்தியர் 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALASYANO 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATAANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATAINS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATANOM 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATAONS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATASVE 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATERNE 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIAID 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIINS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATINAS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIONS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIYON 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATOANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATSKYM 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATSKÝM 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALAŤANOM 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALLATINS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("WAGALATIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ГАЛАТЈАНИ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("К ГАЛАТАМ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("אל הגלטים 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("गलतीकरांस 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("カラテヤ人への手紙 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ガラテヤ人への手紙 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GA-LA-TI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALACJAN 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALASYEN 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATANS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATENI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIAN 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIAS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATINS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIOS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIYA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATONS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALĀTĪĀṂ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ГАЛАТИМА 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ГАЛАТИТЕ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ГАЛАТЯНИ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("गलातियों 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("กาลาเทีย 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("カラテヤ人への書 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ガラテヤ人への書 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALACIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALASIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATAS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATEN 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATER 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATES 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATIA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATNS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATOW 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATÓW 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GÁLATAS 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ΓΑΛΆΤΕΣ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ΓΑΛΑΤΕΣ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ГАЛАТАМ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ГАЛАТІВ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("گلتِیوں 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("गलतियों 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALASI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALATI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GÀLATI 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("گلتیوں 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("《加拉太书》 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("《加拉太書》 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("《戛拉提亞》 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("《迦拉達書》 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALAT 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALÁT 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GÁLAT 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("गलाति 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("गलाती 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("கலாத் 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("《加拉太书 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("《加拉太書 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("《戛拉提亞 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("《迦拉達書 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("カラテヤ書 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ガラテヤ書 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("加拉太书》 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("加拉太書》 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("戛拉提亞》 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("迦拉達書》 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("갈라디아서 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GALA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("カラテヤ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ガラテヤ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("加拉太书 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("加拉太書 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("戛拉提亞 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("迦拉達書 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ﻏﻼﻃﻲ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GAL 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GÁL 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ΓΑΛ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ГАЛ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("கலா 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("《加》 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GA 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GL 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("GÁ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("ΓΑ 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("غل 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("กท 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("《加 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("加》 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("갈라 1:1").osis()).toEqual("Gal.1.1")
		expect(p.parse("加 1:1").osis()).toEqual("Gal.1.1")
		`
		true
describe "Localized book Eph (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Eph (full)", ->
		`
		expect(p.parse("Писмо од апостол Павле до христијаните во Ефес 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List Swietego Pawła Apostoła do Efezow 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List Swietego Pawła Apostoła do Efezów 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List Swiętego Pawła Apostoła do Efezow 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List Swiętego Pawła Apostoła do Efezów 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List Świetego Pawła Apostoła do Efezow 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List Świetego Pawła Apostoła do Efezów 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List Świętego Pawła Apostoła do Efezow 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List Świętego Pawła Apostoła do Efezów 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Послання св. апостола Павла до ефесян 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Послание на св. ап. Павла до Ефесяни 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Послання св апостола Павла до ефесян 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Poslannja apostola Pavla do efesjan 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Послание на св ап. Павла до Ефесяни 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Послание на св. ап Павла до Ефесяни 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Послание на св ап Павла до Ефесяни 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Послання апостола Павла до ефесян 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("افسیوں کے نام پو لس رسول کا خط 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("رسالة بولس الرسول إلى أهل أفسس 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("எபேசியருக்கு எழுதிய திருமுகம் 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Epeciyarukku Elutiya Nirupam 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Epeciyarukku Eḻutiya Nirupam 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Epēciyarukku Elutiya Nirupam 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Epēciyarukku Eḻutiya Nirupam 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Pavlova poslanica Efezanima 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Pavlova poslanica Efežanima 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("எபேசியருக்கு எழுதிய நிருபம் 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("אגרת פולוס השליח אל-האפסים 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("எபேசியருக்கு எழுதிய கடிதம் 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Bref Pals til Efesusmanna 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Bref Páls til Efesusmanna 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Bréf Pals til Efesusmanna 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Bréf Páls til Efesusmanna 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List sw. Pawła do Efezjan 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List św. Pawła do Efezjan 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Paulus' Brev til Efeserne 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Paulus’ Brev til Efeserne 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Paulus’ brev til efeserne 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List sw Pawła do Efezjan 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List św Pawła do Efezjan 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("एफिसीहरूलाई पावलको पत्र 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ifisiyōṅ ke nām kā ḫaṭ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Послание към ефесяните 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("اِفِسِیوں کے نام کا خط 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("पौलाचे इफिसकरांस पत्र 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Epistula ad Ephesios 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Layang Paulus Efesus 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Lettera agli Efesini 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("По слан ня до Єфесян 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("الرسالة إلى أهل أفسس 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ଏଫିସୀୟଙ୍କ ପ୍ରତି ପତ୍ର 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Kirje efesolaisille 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Poslanica Efezanima 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Poslanica Efežanima 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Sulat sa mga Efesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Sulat sa mga Epesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisiharulai patra 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisiharulaī patra 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisiharulāi patra 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisiharulāī patra 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisiharūlai patra 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisiharūlaī patra 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisiharūlāi patra 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisiharūlāī patra 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisīharulai patra 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisīharulaī patra 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisīharulāi patra 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisīharulāī patra 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisīharūlai patra 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisīharūlaī patra 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisīharūlāi patra 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisīharūlāī patra 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Послание к Ефесянам 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("افسیوں کے نام کا خط 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Sulat sa mga Efeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Sulat sa mga Epeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Waraka kwa Waefeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("afasīāṃ nū̃ pattrī 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Посланица Ефесцима 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Послання до ефесян 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ਅਫ਼ਸੀਆਂ ਨੂੰ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Barua kwa Waefeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ipʰiskarams patra 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ipʰiskaraṃs patra 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ipʰiskarāms patra 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ipʰiskarāṃs patra 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Taga- Efesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Taga- Epesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("האיגרת אל האפסים 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("एफिसीहरूलाई पत्र 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Epheszosziakhoz 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List do Efezjan 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Taga Efesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Taga Epesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Taga- Efeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Taga- Epeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("에페소 신자들에게 보낸 서간 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efesolaiskirje 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Taga Efeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Taga Epeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Taga-Efeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Taga-Éfeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("इफिसकरांस पत्र 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efesierbrevet 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efesolaisille 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List Efezanom 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List Efezanum 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List Efezanům 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List Efezskym 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List Efezským 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List Efézskym 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("List Efézským 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisiharulai 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisiharulaī 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisiharulāi 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisiharulāī 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisiharūlai 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisiharūlaī 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisiharūlāi 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisiharūlāī 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisīharulai 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisīharulaī 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisīharulāi 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisīharulāī 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisīharūlai 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisīharūlaī 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisīharūlāi 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("epʰisīharūlāī 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Προς Εφεσίους 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Προς Εφεσιους 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efeserbrevet 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efesusbrefið 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efesusbréfið 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efezusiakhoz 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efézusiakhoz 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Epeciyarukku 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Epēciyarukku 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Taga- Efesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Taga- Epesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Taga Efesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Taga Epesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Taga- Efeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Taga- Epeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ad Ephesios 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ipʰiskarams 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ipʰiskaraṃs 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ipʰiskarāms 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ipʰiskarāṃs 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("एफिसीहरूलाई 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ਅਫ਼ਸੀਆਂ ਨੂੰ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("エフェソの信徒への手紙 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efesianeve 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efesianëve 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Epehesians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Esphesians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Efesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Epesio 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Taga Efeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Taga Epeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Taga-Efeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Taga-Éfeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("К Ефесянам 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("رسالة أفسس 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efezanima 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efežanima 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Effesiaid 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ehpesians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ehpisians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesains 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesiaid 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesiand 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesiens 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesions 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephisians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephésiens 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Iafisiyon 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Efeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Mga Epeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Éphesiens 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Éphésiens 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("До ефесян 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ефесяните 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ефешаните 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("אל האפסים 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("इफिसकरांस 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ଏଫିସୀୟଙ୍କ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("エフェソ人への手紙 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efeserne 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efezanom 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efeziers 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efeziërs 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efezskym 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efezským 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Epesians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesain 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesian 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephesios 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephisian 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephsians 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ê-phê-sô 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Εφεσίους 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Εφεσιους 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ефесцима 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ефесянам 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ефесјани 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Эфесянам 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("اِفسِیوں 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("इफिसियों 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("எபேசியர் 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("エヘソ人への手紙 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("エペソ人への手紙 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efeseni 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efesini 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efesios 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efeskym 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efeským 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efezjan 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efezyen 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efésios 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Epheser 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephsian 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Waefeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("afasīāṃ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ефесяни 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("اِفسیوں 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("เอเฟซัส 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("エヘソ人への書 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("エペソ人への書 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efesos 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efesus 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efezow 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efezus 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efezów 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Êphêsô 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ефесян 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("افسیوں 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("《以弗所书》 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("《以弗所書》 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("《厄弗所書》 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efese 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efése 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephes 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephés 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Éfeso 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Éphes 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Éphés 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("इफिसि 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("इफिसी 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("एफिसी 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("எபேசி 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("《以弗所书 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("《以弗所書 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("《厄弗所書 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("《耶斐斯》 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("エフェソ書 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("以弗所书》 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("以弗所書》 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("厄弗所書》 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efes 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efez 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efèz 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephe 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephs 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ephé 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Éphe 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Éphé 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("《耶斐斯 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("エフェソ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("エヘソ書 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("エペソ書 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("以弗所书 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("以弗所書 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("厄弗所書 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("耶斐斯》 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("에베소서 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("에페소서 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ﺃﻓﺴﺲ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Efe 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Eff 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ehp 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Eph 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Éph 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Êph 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("எபே 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("᾿Εφ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("《弗》 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("耶斐斯 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ef 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ep 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ép 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Εφ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Єф 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Еф 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Эф 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("أف 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("อฟ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("《弗 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("弗》 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("에페 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("弗 1:1").osis()).toEqual("Eph.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО ЕФЕС 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST SWIETEGO PAWŁA APOSTOŁA DO EFEZOW 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST SWIETEGO PAWŁA APOSTOŁA DO EFEZÓW 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST SWIĘTEGO PAWŁA APOSTOŁA DO EFEZOW 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST SWIĘTEGO PAWŁA APOSTOŁA DO EFEZÓW 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST ŚWIETEGO PAWŁA APOSTOŁA DO EFEZOW 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST ŚWIETEGO PAWŁA APOSTOŁA DO EFEZÓW 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST ŚWIĘTEGO PAWŁA APOSTOŁA DO EFEZOW 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST ŚWIĘTEGO PAWŁA APOSTOŁA DO EFEZÓW 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ЕФЕСЯН 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ. АП. ПАВЛА ДО ЕФЕСЯНИ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ЕФЕСЯН 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("POSLANNJA APOSTOLA PAVLA DO EFESJAN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ АП. ПАВЛА ДО ЕФЕСЯНИ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ. АП ПАВЛА ДО ЕФЕСЯНИ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ АП ПАВЛА ДО ЕФЕСЯНИ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ЕФЕСЯН 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("افسیوں کے نام پو لس رسول کا خط 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("رسالة بولس الرسول إلى أهل أفسس 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("எபேசியருக்கு எழுதிய திருமுகம் 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPECIYARUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPECIYARUKKU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPĒCIYARUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPĒCIYARUKKU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("PAVLOVA POSLANICA EFEZANIMA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("PAVLOVA POSLANICA EFEŽANIMA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("எபேசியருக்கு எழுதிய நிருபம் 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("אגרת פולוס השליח אל-האפסים 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("எபேசியருக்கு எழுதிய கடிதம் 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("BREF PALS TIL EFESUSMANNA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("BREF PÁLS TIL EFESUSMANNA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("BRÉF PALS TIL EFESUSMANNA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("BRÉF PÁLS TIL EFESUSMANNA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST SW. PAWŁA DO EFEZJAN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST ŚW. PAWŁA DO EFEZJAN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("PAULUS' BREV TIL EFESERNE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("PAULUS’ BREV TIL EFESERNE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("PAULUS’ BREV TIL EFESERNE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST SW PAWŁA DO EFEZJAN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST ŚW PAWŁA DO EFEZJAN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("एफिसीहरूलाई पावलको पत्र 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("IFISIYŌṄ KE NĀM KĀ ḪAṬ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ПОСЛАНИЕ КЪМ ЕФЕСЯНИТЕ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("اِفِسِیوں کے نام کا خط 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("पौलाचे इफिसकरांस पत्र 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPISTULA AD EPHESIOS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LAYANG PAULUS EFESUS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LETTERA AGLI EFESINI 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ПО СЛАН НЯ ДО ЄФЕСЯН 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("الرسالة إلى أهل أفسس 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ଏଫିସୀୟଙ୍କ ପ୍ରତି ପତ୍ର 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("KIRJE EFESOLAISILLE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("POSLANICA EFEZANIMA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("POSLANICA EFEŽANIMA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("SULAT SA MGA EFESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("SULAT SA MGA EPESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISIHARULAI PATRA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISIHARULAĪ PATRA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISIHARULĀI PATRA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISIHARULĀĪ PATRA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISIHARŪLAI PATRA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISIHARŪLAĪ PATRA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISIHARŪLĀI PATRA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISIHARŪLĀĪ PATRA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISĪHARULAI PATRA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISĪHARULAĪ PATRA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISĪHARULĀI PATRA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISĪHARULĀĪ PATRA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISĪHARŪLAI PATRA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISĪHARŪLAĪ PATRA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISĪHARŪLĀI PATRA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISĪHARŪLĀĪ PATRA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ПОСЛАНИЕ К ЕФЕСЯНАМ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("افسیوں کے نام کا خط 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("SULAT SA MGA EFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("SULAT SA MGA EPESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("WARAKA KWA WAEFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("AFASĪĀṂ NŪ̃ PATTRĪ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ПОСЛАНИЦА ЕФЕСЦИМА 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ПОСЛАННЯ ДО ЕФЕСЯН 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ਅਫ਼ਸੀਆਂ ਨੂੰ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("BARUA KWA WAEFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("IPʰISKARAMS PATRA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("IPʰISKARAṂS PATRA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("IPʰISKARĀMS PATRA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("IPʰISKARĀṂS PATRA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA TAGA- EFESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA TAGA- EPESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("האיגרת אל האפסים 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("एफिसीहरूलाई पत्र 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESZOSZIAKHOZ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST DO EFEZJAN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA TAGA EFESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA TAGA EPESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA TAGA- EFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA TAGA- EPESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("에페소 신자들에게 보낸 서간 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESOLAISKIRJE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA TAGA EFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA TAGA EPESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA TAGA-EFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA TAGA-ÉFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("इफिसकरांस पत्र 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESIERBREVET 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESOLAISILLE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST EFEZANOM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST EFEZANUM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST EFEZANŮM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST EFEZSKYM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST EFEZSKÝM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST EFÉZSKYM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("LIST EFÉZSKÝM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISIHARULAI 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISIHARULAĪ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISIHARULĀI 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISIHARULĀĪ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISIHARŪLAI 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISIHARŪLAĪ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISIHARŪLĀI 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISIHARŪLĀĪ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISĪHARULAI 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISĪHARULAĪ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISĪHARULĀI 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISĪHARULĀĪ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISĪHARŪLAI 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISĪHARŪLAĪ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISĪHARŪLĀI 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPʰISĪHARŪLĀĪ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ΠΡΟΣ ΕΦΕΣΊΟΥΣ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ΠΡΟΣ ΕΦΕΣΙΟΥΣ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESERBREVET 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESUSBREFIÐ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESUSBRÉFIÐ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZUSIAKHOZ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFÉZUSIAKHOZ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPECIYARUKKU 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPĒCIYARUKKU 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("TAGA- EFESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("TAGA- EPESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("TAGA EFESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("TAGA EPESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("TAGA- EFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("TAGA- EPESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("AD EPHESIOS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("IPʰISKARAMS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("IPʰISKARAṂS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("IPʰISKARĀMS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("IPʰISKARĀṂS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("एफिसीहरूलाई 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ਅਫ਼ਸੀਆਂ ਨੂੰ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("エフェソの信徒への手紙 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESIANEVE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESIANËVE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPEHESIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ESPHESIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA EFESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA EPESIO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("TAGA EFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("TAGA EPESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("TAGA-EFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("TAGA-ÉFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("К ЕФЕСЯНАМ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("رسالة أفسس 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZANIMA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEŽANIMA 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFFESIAID 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EHPESIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EHPISIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESAINS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESIAID 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESIAND 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESIENS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESIONS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHISIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHÉSIENS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("IAFISIYON 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA EFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("MGA EPESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ÉPHESIENS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ÉPHÉSIENS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ДО ЕФЕСЯН 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ЕФЕСЯНИТЕ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ЕФЕШАНИТЕ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("אל האפסים 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("इफिसकरांस 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ଏଫିସୀୟଙ୍କ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("エフェソ人への手紙 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESERNE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZANOM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZIERS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZIËRS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZSKYM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZSKÝM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPESIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESAIN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESIAN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESIOS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHISIAN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHSIANS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("Ê-PHÊ-SÔ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ΕΦΕΣΊΟΥΣ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ΕΦΕΣΙΟΥΣ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ЕФЕСЦИМА 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ЕФЕСЯНАМ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ЕФЕСЈАНИ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ЭФЕСЯНАМ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("اِفسِیوں 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("इफिसियों 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("எபேசியர் 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("エヘソ人への手紙 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("エペソ人への手紙 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESENI 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESINI 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESIOS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESKYM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESKÝM 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZJAN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZYEN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFÉSIOS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHESER 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHSIAN 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("WAEFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("AFASĪĀṂ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ЕФЕСЯНИ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("اِفسیوں 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("เอเฟซัส 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("エヘソ人への書 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("エペソ人への書 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESOS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESUS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZOW 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZUS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZÓW 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ÊPHÊSÔ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ЕФЕСЯН 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("افسیوں 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("《以弗所书》 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("《以弗所書》 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("《厄弗所書》 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFÉSE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHES 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHÉS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ÉFESO 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ÉPHES 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ÉPHÉS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("इफिसि 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("इफिसी 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("एफिसी 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("எபேசி 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("《以弗所书 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("《以弗所書 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("《厄弗所書 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("《耶斐斯》 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("エフェソ書 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("以弗所书》 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("以弗所書》 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("厄弗所書》 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFES 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFEZ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFÈZ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHS 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPHÉ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ÉPHE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ÉPHÉ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("《耶斐斯 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("エフェソ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("エヘソ書 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("エペソ書 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("以弗所书 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("以弗所書 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("厄弗所書 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("耶斐斯》 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("에베소서 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("에페소서 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ﺃﻓﺴﺲ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFE 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EFF 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EHP 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EPH 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ÉPH 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ÊPH 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("எபே 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("᾿ΕΦ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("《弗》 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("耶斐斯 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EF 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("EP 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ÉP 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ΕΦ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ЄФ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ЕФ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("ЭФ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("أف 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("อฟ 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("《弗 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("弗》 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("에페 1:1").osis()).toEqual("Eph.1.1")
		expect(p.parse("弗 1:1").osis()).toEqual("Eph.1.1")
		`
		true
describe "Localized book Col (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Col (full)", ->
		`
		expect(p.parse("Писмо од апостол Павле до христијаните во Колос 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Послання св. апостола Павла до колосян 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Послание на св. ап. Павла до Колосяни 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Послання св апостола Павла до колосян 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Poslannja apostola Pavla do kolosjan 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Послание на св ап. Павла до Колосяни 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Послание на св. ап Павла до Колосяни 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Послание на св ап Павла до Колосяни 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Послання апостола Павла до колосян 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("کُلِسّیوں کے نام پولُس رسُول کا خط 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("رسالة بولس الرسول إلى أهل كولوسي 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Paulus' Brev til Kolossenserne 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Paulus’ Brev til Kolossenserne 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("கொலோசையருக்கு எழுதிய திருமுகம் 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Koloceyarukku Elutiya Nirupam 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Koloceyarukku Eḻutiya Nirupam 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolōceyarukku Elutiya Nirupam 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolōceyarukku Eḻutiya Nirupam 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Pavlova poslanica Kolosanima 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Pavlova poslanica Kološanima 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("கொலோசெயருக்கு எழுதிய நிருபம் 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Paulus’ brev til kolosserne 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("אגרת פולוס השליח אל-הקולוסי 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("கொலோசெயருக்கு எழுதிய கடிதம் 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Bref Pals til Kolossumanna 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Bref Pals til Kólossumanna 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Bref Páls til Kolossumanna 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Bref Páls til Kólossumanna 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Bréf Pals til Kolossumanna 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Bréf Pals til Kólossumanna 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Bréf Páls til Kolossumanna 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Bréf Páls til Kólossumanna 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Bref Pals til Kolossumann 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Bref Pals til Kólossumann 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Bref Páls til Kolossumann 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Bref Páls til Kólossumann 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Bréf Pals til Kolossumann 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Bréf Pals til Kólossumann 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Bréf Páls til Kolossumann 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Bréf Páls til Kólossumann 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("List sw. Pawła do Kolosan 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("List św. Pawła do Kolosan 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("List sw Pawła do Kolosan 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("List św Pawła do Kolosan 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kulussiyōṅ ke nām kā ḫaṭ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("कलस्सीहरूलाई पावलको पत्र 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Epistula ad Colossenses 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Sulat sa mga Colonsense 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Sulat sa mga Kolonsense 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Послание към колосяните 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("کُلُسِّیوں کے نام کا خط 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("पौलाचे कलस्सैकरांस पत्र 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Sulat sa mga Colosense 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Sulat sa mga Kolosense 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("الرسالة إلى أهل كولوسي 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kirje kolossalaisille 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Послание к Колоссянам 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Layang Paulus Kolose 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Layang Paulus Kolosé 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Lettera ai Colossesi 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Poslanica Kolosanima 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Poslanica Kološanima 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Waraka kwa Wakolosai 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassaikarams patra 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassaikaraṃs patra 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassaikarāms patra 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassaikarāṃs patra 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassiharulai patra 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassiharulaī patra 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassiharulāi patra 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassiharulāī patra 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassiharūlai patra 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassiharūlaī patra 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassiharūlāi patra 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassiharūlāī patra 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassīharulai patra 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassīharulaī patra 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassīharulāi patra 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassīharulāī patra 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassīharūlai patra 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassīharūlaī patra 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassīharūlāi patra 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassīharūlāī patra 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kulussīāṃ nū̃ pattrī 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Посланица Колошанима 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ਕੁਲੁੱਸੀਆਂ ਨੂੰ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Barua kwa Wakolosai 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Послання до Колосян 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("کلسیوں کے نام کا خط 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("କଲସୀୟଙ୍କ ପ୍ରତି ପତ୍ର 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("האיגרת אל הקולוסים 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolossenserbrevet 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosszebeliekhez 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosszébeliekhez 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Mga Taga- Colosas 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Mga Taga- Kolosas 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("कलस्सीहरूलाई पत्र 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolossalaiskirje 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Mga Taga Colosas 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Mga Taga Kolosas 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Mga Taga-Colosas 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("कलस्सैकरांस पत्र 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolossalaisille 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("List do Kolosan 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Προς Κολοσσαείς 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Προς Κολοσσαεις 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("콜로새 신자들에게 보낸 서간 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosserbrevet 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosszeieknek 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("List Kolosanom 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("List Kolosanum 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("List Kolosanům 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Mga Colonsense 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Mga Kolonsense 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ad Colossenses 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassaikarams 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassaikaraṃs 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassaikarāms 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassaikarāṃs 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassiharulai 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassiharulaī 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassiharulāi 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassiharulāī 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassiharūlai 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassiharūlaī 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassiharūlāi 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassiharūlāī 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassīharulai 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassīharulaī 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassīharulāi 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassīharulāī 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassīharūlai 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassīharūlaī 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassīharūlāi 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kalassīharūlāī 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Koloceyarukku 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosseiakhoz 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolossenserne 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolossubrefið 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolossubréfið 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosséiakhoz 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolussubrefið 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolussubréfið 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolōceyarukku 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kólossubrefið 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kólossubréfið 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kólussubrefið 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kólussubréfið 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("List Koloskym 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("List Koloským 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Mga Colosense 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Mga Kolosense 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Taga- Colosas 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ਕੁਲੁੱਸੀਆਂ ਨੂੰ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolossensern 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolossenskym 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolossenským 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Taga Colosas 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Taga-Colosas 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("К Колоссянам 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("رسالة كولوسي 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("कलस्सीहरूलाई 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Callossians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colossenses 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colossenzen 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosenskym 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosenským 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosianeve 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosianëve 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolossenzen 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kulussaiyon 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("До колоссян 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("אל הקולוסים 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("कलस्सैकरांस 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("कुलुस्सियों 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("コロサイの信徒への手紙 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calassians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calassions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Callasians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Callasions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Callosians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Callosions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calossians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calossions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colassians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colassions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Collasians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Collasions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Collosians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Collosions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colosenses 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colossiaid 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colossians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colossiens 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colossions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosanima 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosensow 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosensów 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosserne 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kološanima 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Κολοσσαείς 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Κολοσσαεις 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Колоссянам 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Колосяните 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Колошанима 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Колошаните 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calasians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calasions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calosians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Calosions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colasians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colasions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colosiaid 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colosians 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colosions 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colossans 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colossesi 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colossian 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosanom 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosanum 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosanům 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Wakolosai 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("kulussīāṃ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Колосјани 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("کُلِسّیوں 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("कलसैकरांस 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("कुलुस्‍सी 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("கொலோசெயர் 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("கொலோசையர் 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("コロサイ人への手紙 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Coloseni 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Cô-lô-se 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Koloskym 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Koloským 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosser 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosyen 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Колоссян 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Колосяни 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("کُلسِیوں 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("کُلسّیوں 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("कुलुस्सि 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("କଲସୀୟଙ୍କ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("コロサイ人への書 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colosas 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosan 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosay 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosse 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolossé 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Колосян 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Coloss 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Côlôxê 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolose 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolosé 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("کلسیوں 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("कलस्सी 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("โคโลสี 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("《哥羅森書》 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("《歌罗西书》 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("《歌羅西書》 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ﻛﻮﻟﻮﺳﻲ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Colos 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolos 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kolòs 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("《哥羅森書 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("《歌罗西书 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("《歌羅西書 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("《适羅斯》 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("コロサイ書 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("哥羅森書》 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("歌罗西书》 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("歌羅西書》 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("கொலோ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("《适羅斯 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("コロサイ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("哥羅森書 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("歌罗西书 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("歌羅西書 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("适羅斯》 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("골로새서 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("콜로새서 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Col 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Côl 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kol 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Kól 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Κολ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Кол 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("قول 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("《西》 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("适羅斯 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Cl 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Co 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Ko 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("Κλ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("كو 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("คส 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("《西 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("西》 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("콜로 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("西 1:1").osis()).toEqual("Col.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО КОЛОС 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО КОЛОСЯН 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ. АП. ПАВЛА ДО КОЛОСЯНИ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО КОЛОСЯН 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("POSLANNJA APOSTOLA PAVLA DO KOLOSJAN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ АП. ПАВЛА ДО КОЛОСЯНИ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ. АП ПАВЛА ДО КОЛОСЯНИ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ АП ПАВЛА ДО КОЛОСЯНИ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО КОЛОСЯН 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("کُلِسّیوں کے نام پولُس رسُول کا خط 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("رسالة بولس الرسول إلى أهل كولوسي 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("PAULUS' BREV TIL KOLOSSENSERNE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("PAULUS’ BREV TIL KOLOSSENSERNE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("கொலோசையருக்கு எழுதிய திருமுகம் 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOCEYARUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOCEYARUKKU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLŌCEYARUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLŌCEYARUKKU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("PAVLOVA POSLANICA KOLOSANIMA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("PAVLOVA POSLANICA KOLOŠANIMA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("கொலோசெயருக்கு எழுதிய நிருபம் 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("PAULUS’ BREV TIL KOLOSSERNE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("אגרת פולוס השליח אל-הקולוסי 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("கொலோசெயருக்கு எழுதிய கடிதம் 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("BREF PALS TIL KOLOSSUMANNA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("BREF PALS TIL KÓLOSSUMANNA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("BREF PÁLS TIL KOLOSSUMANNA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("BREF PÁLS TIL KÓLOSSUMANNA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("BRÉF PALS TIL KOLOSSUMANNA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("BRÉF PALS TIL KÓLOSSUMANNA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("BRÉF PÁLS TIL KOLOSSUMANNA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("BRÉF PÁLS TIL KÓLOSSUMANNA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("BREF PALS TIL KOLOSSUMANN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("BREF PALS TIL KÓLOSSUMANN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("BREF PÁLS TIL KOLOSSUMANN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("BREF PÁLS TIL KÓLOSSUMANN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("BRÉF PALS TIL KOLOSSUMANN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("BRÉF PALS TIL KÓLOSSUMANN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("BRÉF PÁLS TIL KOLOSSUMANN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("BRÉF PÁLS TIL KÓLOSSUMANN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("LIST SW. PAWŁA DO KOLOSAN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("LIST ŚW. PAWŁA DO KOLOSAN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("LIST SW PAWŁA DO KOLOSAN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("LIST ŚW PAWŁA DO KOLOSAN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KULUSSIYŌṄ KE NĀM KĀ ḪAṬ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("कलस्सीहरूलाई पावलको पत्र 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("EPISTULA AD COLOSSENSES 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("SULAT SA MGA COLONSENSE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("SULAT SA MGA KOLONSENSE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ПОСЛАНИЕ КЪМ КОЛОСЯНИТЕ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("کُلُسِّیوں کے نام کا خط 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("पौलाचे कलस्सैकरांस पत्र 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("SULAT SA MGA COLOSENSE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("SULAT SA MGA KOLOSENSE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("الرسالة إلى أهل كولوسي 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KIRJE KOLOSSALAISILLE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ПОСЛАНИЕ К КОЛОССЯНАМ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("LAYANG PAULUS KOLOSE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("LAYANG PAULUS KOLOSÉ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("LETTERA AI COLOSSESI 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("POSLANICA KOLOSANIMA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("POSLANICA KOLOŠANIMA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("WARAKA KWA WAKOLOSAI 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSAIKARAMS PATRA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSAIKARAṂS PATRA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSAIKARĀMS PATRA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSAIKARĀṂS PATRA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSIHARULAI PATRA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSIHARULAĪ PATRA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSIHARULĀI PATRA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSIHARULĀĪ PATRA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSIHARŪLAI PATRA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSIHARŪLAĪ PATRA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSIHARŪLĀI PATRA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSIHARŪLĀĪ PATRA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSĪHARULAI PATRA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSĪHARULAĪ PATRA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSĪHARULĀI PATRA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSĪHARULĀĪ PATRA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSĪHARŪLAI PATRA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSĪHARŪLAĪ PATRA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSĪHARŪLĀI PATRA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSĪHARŪLĀĪ PATRA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KULUSSĪĀṂ NŪ̃ PATTRĪ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ПОСЛАНИЦА КОЛОШАНИМА 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ਕੁਲੁੱਸੀਆਂ ਨੂੰ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("BARUA KWA WAKOLOSAI 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ПОСЛАННЯ ДО КОЛОСЯН 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("کلسیوں کے نام کا خط 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("କଲସୀୟଙ୍କ ପ୍ରତି ପତ୍ର 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("האיגרת אל הקולוסים 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSENSERBREVET 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSZEBELIEKHEZ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSZÉBELIEKHEZ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("MGA TAGA- COLOSAS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("MGA TAGA- KOLOSAS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("कलस्सीहरूलाई पत्र 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSALAISKIRJE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("MGA TAGA COLOSAS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("MGA TAGA KOLOSAS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("MGA TAGA-COLOSAS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("कलस्सैकरांस पत्र 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSALAISILLE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("LIST DO KOLOSAN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ΠΡΟΣ ΚΟΛΟΣΣΑΕΊΣ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ΠΡΟΣ ΚΟΛΟΣΣΑΕΙΣ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("콜로새 신자들에게 보낸 서간 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSERBREVET 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSZEIEKNEK 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("LIST KOLOSANOM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("LIST KOLOSANUM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("LIST KOLOSANŮM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("MGA COLONSENSE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("MGA KOLONSENSE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("AD COLOSSENSES 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSAIKARAMS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSAIKARAṂS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSAIKARĀMS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSAIKARĀṂS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSIHARULAI 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSIHARULAĪ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSIHARULĀI 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSIHARULĀĪ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSIHARŪLAI 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSIHARŪLAĪ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSIHARŪLĀI 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSIHARŪLĀĪ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSĪHARULAI 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSĪHARULAĪ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSĪHARULĀI 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSĪHARULĀĪ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSĪHARŪLAI 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSĪHARŪLAĪ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSĪHARŪLĀI 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KALASSĪHARŪLĀĪ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOCEYARUKKU 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSEIAKHOZ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSENSERNE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSUBREFIÐ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSUBRÉFIÐ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSÉIAKHOZ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLUSSUBREFIÐ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLUSSUBRÉFIÐ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLŌCEYARUKKU 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KÓLOSSUBREFIÐ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KÓLOSSUBRÉFIÐ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KÓLUSSUBREFIÐ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KÓLUSSUBRÉFIÐ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("LIST KOLOSKYM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("LIST KOLOSKÝM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("MGA COLOSENSE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("MGA KOLOSENSE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("TAGA- COLOSAS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ਕੁਲੁੱਸੀਆਂ ਨੂੰ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSENSERN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSENSKYM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSENSKÝM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("TAGA COLOSAS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("TAGA-COLOSAS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("К КОЛОССЯНАМ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("رسالة كولوسي 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("कलस्सीहरूलाई 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALLOSSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSSENSES 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSSENZEN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSENSKYM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSENSKÝM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSIANEVE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSIANËVE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSENZEN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KULUSSAIYON 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ДО КОЛОССЯН 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("אל הקולוסים 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("कलस्सैकरांस 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("कुलुस्सियों 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("コロサイの信徒への手紙 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALASSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALASSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALLASIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALLASIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALLOSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALLOSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALOSSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALOSSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLASSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLASSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLLASIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLLASIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLLOSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLLOSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSENSES 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSSIAID 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSSIENS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSANIMA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSENSOW 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSENSÓW 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSERNE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOŠANIMA 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ΚΟΛΟΣΣΑΕΊΣ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ΚΟΛΟΣΣΑΕΙΣ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("КОЛОССЯНАМ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("КОЛОСЯНИТЕ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("КОЛОШАНИМА 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("КОЛОШАНИТЕ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALASIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALASIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALOSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CALOSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLASIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLASIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSIAID 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSIANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSIONS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSSANS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSSESI 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSSIAN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSANOM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSANUM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSANŮM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("WAKOLOSAI 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KULUSSĪĀṂ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("КОЛОСЈАНИ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("کُلِسّیوں 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("कलसैकरांस 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("कुलुस्‍सी 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("கொலோசெயர் 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("கொலோசையர் 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("コロサイ人への手紙 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSENI 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CÔ-LÔ-SE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSKYM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSKÝM 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSER 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSYEN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("КОЛОССЯН 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("КОЛОСЯНИ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("کُلسِیوں 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("کُلسّیوں 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("कुलुस्सि 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("କଲସୀୟଙ୍କ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("コロサイ人への書 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSAS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSAN 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSAY 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSSÉ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("КОЛОСЯН 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOSS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CÔLÔXÊ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSE 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOSÉ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("کلسیوں 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("कलस्सी 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("โคโลสี 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("《哥羅森書》 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("《歌罗西书》 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("《歌羅西書》 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ﻛﻮﻟﻮﺳﻲ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COLOS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLOS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOLÒS 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("《哥羅森書 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("《歌罗西书 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("《歌羅西書 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("《适羅斯》 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("コロサイ書 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("哥羅森書》 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("歌罗西书》 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("歌羅西書》 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("கொலோ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("《适羅斯 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("コロサイ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("哥羅森書 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("歌罗西书 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("歌羅西書 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("适羅斯》 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("골로새서 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("콜로새서 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("COL 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CÔL 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KOL 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KÓL 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ΚΟΛ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("КОЛ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("قول 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("《西》 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("适羅斯 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CL 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("CO 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("KO 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("ΚΛ 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("كو 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("คส 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("《西 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("西》 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("콜로 1:1").osis()).toEqual("Col.1.1")
		expect(p.parse("西 1:1").osis()).toEqual("Col.1.1")
		`
		true
describe "Localized book 2Tim (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Tim (full)", ->
		`
		expect(p.parse("2-ге. послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друге послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а. послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге. послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друге послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а. послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhe poslannja apostola Pavla do Tymofija 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Второ послание на св. ап. Павла до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("திமொத்தேயுவுக்கு எழுதிய இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("திமோத்தேயுவுக்கு எழுதிய இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Второ послание на св ап. Павла до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Второ послание на св. ап Павла до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("தீமோத்தேயுவுக்கு எழுதிய இரண்டாவது நிருபம் 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге. послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Второ послание на св ап Павла до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друге послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("تیِمُتھِیُس کے نام پولس رسول کا دوسرا خط 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а. послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Втора писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Второ писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("தீமோத்தேயுவுக்கு எழுதிய இரண்டாம் கடிதம் 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("رسالة بولس الرسول الثانية إلى تيموثاوس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga List św. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Drugi List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Drugi List św. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga List sw Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga List św Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Drugi List sw Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Drugi List św Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. List św. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Paulus' Andet Brev til Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Paulus’ Andet Brev til Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Pavlova druga poslanica Timoteju 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. List św. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II List św. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. List sw Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. List św Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Paulus’ andre brev til Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Pals til Timoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Pals til Timóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Pals til Tímoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Pals til Tímóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Páls til Timoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Páls til Timóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Páls til Tímoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Páls til Tímóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Pals til Timoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Pals til Timóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Pals til Tímoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Pals til Tímóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Páls til Timoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Páls til Timóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Páls til Tímoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Páls til Tímóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Pals til Timoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Pals til Timóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Pals til Tímoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Pals til Tímóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Páls til Timoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Páls til Timóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Páls til Tímoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Páls til Tímóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Pals til Timoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Pals til Timóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Pals til Tímoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Pals til Tímóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Páls til Timoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Páls til Timóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Páls til Tímoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Páls til Tímóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 List św. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. List sw Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. List św Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II List sw Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II List św Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("tīmutʰiyus ke nām kā dūsrā ḫaṭ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("تِیمُتھِیُس کے نام کا دوسرا خط 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 List sw Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 List św Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("الرسالة الثانية إلى تيموثاوس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("तिमोथीलाई पावलको दोस्रो पत्र 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Waraka wa Pili kwa Timotheo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("אגרת פולוס השנייה אל-טימותי 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("पौलाचे तीमथ्थाला दुसरे पत्र 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ତୀମଥିଙ୍କ ପ୍ରତି ଦ୍ୱିତୀୟ ପତ୍ର 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Barua ya Pili kwa Timotheo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Toinen Kirje Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Второ послание към Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Второ послание към Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("تیمتھیس کے نام کا دوسرا خط 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге. послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге. послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Seconda lettera a Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Pals til Timo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Pals til Timó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Pals til Tímo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Pals til Tímó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Páls til Timo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Páls til Timó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Páls til Tímo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Páls til Tímó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Pals til Timo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Pals til Timó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Pals til Tímo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Pals til Tímó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Páls til Timo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Páls til Timó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Páls til Tímo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Páls til Tímó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Pals til Timo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Pals til Timó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Pals til Tímo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Pals til Tímó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Páls til Timo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Páls til Timó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Páls til Tímo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Páls til Tímó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Pals til Timo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Pals til Timó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Pals til Tímo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Pals til Tímó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Páls til Timo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Páls til Timó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Páls til Tímo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Páls til Tímó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timotʰius nū̃ dūjī pattrī 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друге послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друге послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("האיגרת השנייה אל טימותיוס 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а. послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а. послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga List do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga Timoteju Poslanica 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga poslanica Timoteju 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Drugi List do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Epistula II ad Timotheum 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Epistula ad Timotheum II 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга посланица Тимотеју 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ਤਿਮੋਥਿਉਸ ਨੂੰ ਦੂਜੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Kirje Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timatʰtʰala dusre patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timatʰtʰalā dusre patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timatʰtʰāla dusre patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timatʰtʰālā dusre patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timotʰilai dostro patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timotʰilaī dostro patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timotʰilāi dostro patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timotʰilāī dostro patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timotʰīlai dostro patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timotʰīlaī dostro patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timotʰīlāi dostro patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timotʰīlāī dostro patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("tīmatʰtʰala dusre patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("tīmatʰtʰalā dusre patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("tīmatʰtʰāla dusre patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("tīmatʰtʰālā dusre patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("तिमोथीलाई दोस्त्रो पत्र 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге. послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Kirje Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha kniha Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhá kniha Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Kirje Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. List do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteju Poslanica 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. посланица Тимотеју 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друге послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Kirje Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а. послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. List do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteju Poslanica 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. посланица Тимотеју 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Andra Timotheosbrevet 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha kniha Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy list Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhá kniha Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhý list Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II List do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteju Poslanica 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II посланица Тимотеју 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Ikalawang Kay Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara Timoteusarbref 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara Timoteusarbréf 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara Timóteusarbref 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara Timóteusarbréf 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara Tímoteusarbref 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara Tímoteusarbréf 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara Tímóteusarbref 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara Tímóteusarbréf 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara Timoteusarbref 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara Timoteusarbréf 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara Timóteusarbref 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara Timóteusarbréf 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara Tímoteusarbref 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara Tímoteusarbréf 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara Tímóteusarbref 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara Tímóteusarbréf 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 List do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteju Poslanica 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 посланица Тимотеју 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Andra Timoteusbrevet 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha list Timeteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha list Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy list Timeteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy list Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhá list Timeteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhá list Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhý list Timeteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhý list Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Toinen Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Toinen Timoteuskirje 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("तीमथ्थाला दुसरे पत्र 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Anden Timotheusbrev 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Andet Timotheusbrev 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Timoteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Timoteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Timóteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Timóteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Második Timoteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Második Timoteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Második Timóteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Második Timóteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("השנייה אל טימותיאוס 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotheosbrevet 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Andre Timoteusbrev 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Deuxiemes Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Deuxiemes Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Deuxièmes Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Deuxièmes Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. list Timeteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. list Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Timotheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Timótheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Második Timotheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Második Timótheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("השנייה אל טימותיוס 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotheosbrevet 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteusbrevet 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. list Timeteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. list Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Deuxieme Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Deuxieme Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Deuxième Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Deuxième Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II list Timeteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II list Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteuskirje 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Ikalawang Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteusbrevet 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotteyuvukku 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timottēyuvukku 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timōtteyuvukku 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timōttēyuvukku 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tīmotteyuvukku 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tīmottēyuvukku 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tīmōtteyuvukku 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tīmōttēyuvukku 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 list Timeteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 list Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Teemuathaiyus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteuskirje 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotheusbrev 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Drugi Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhá Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhý Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteuskirje 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Timóteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Második Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Második Timóteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timoteyos Labaad 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tweede Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tweede Timotheüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Zweite Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Προς Τιμοθεον Β' 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Προς Τιμοθεον Βʹ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Προς Τιμοθεον Βʹ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Προς Τιμοθεον Β΄ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Προς Τιμοθεον Β’ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Προς Τιμόθεον Β' 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Προς Τιμόθεον Βʹ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Προς Τιμόθεον Βʹ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Προς Τιμόθεον Β΄ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Προς Τιμόθεον Β’ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("تيموثاوس الثانية 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ତୀମଥିଙ୍କ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ﺍﻟﺜﺎﻧﻴﺔ ﺗﻴﻤﻮﺛﺎﻭﺱ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Teemuathaiyus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteuskirje 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotheusbrev 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 k. Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Kang Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteusbrev 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhá Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhý Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Kay Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timóteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timóteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Seconda Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Secondo Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Segunda Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Segunda Timóteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Segundo Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Segundo Timóteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tweede Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tweede Timoteüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ad Timotheum II 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("دوم تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("دوم تیِمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("دوم-تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("티모테오에게 보낸 둘째 서간 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Kang Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteusbrev 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 k Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 k. Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ਤਿਮੋਥਿਉਸ ਨੂੰ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге. Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. к Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-я. к Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Kay Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timóteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timóteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. تیِمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2.-تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2eme. Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2eme. Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ème. Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ème. Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Anden Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Andre Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga Timoteju 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhá Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhý Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Kay Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timóteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timóteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timótheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга Тимотеју 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друге Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Kay Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timóteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timóteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 e. Timoteut 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 i. Timoteut 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 k Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timatʰtʰala 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timatʰtʰalā 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timatʰtʰāla 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timatʰtʰālā 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 tīmatʰtʰala 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 tīmatʰtʰalā 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 tīmatʰtʰāla 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 tīmatʰtʰālā 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 تیِمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а. Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге. Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге. Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге. Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е к Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-я к Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timótheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. timotʰilai 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. timotʰilaī 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. timotʰilāi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. timotʰilāī 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. timotʰīlai 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. timotʰīlaī 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. timotʰīlāi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. timotʰīlāī 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. तीमुाथैयुस 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2de. Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2de. Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e. Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e. Timotheüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2eme Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2eme Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ème Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ème Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2е. к Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2я. к Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Dezyem Timote 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Dezyèm Timote 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timótheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Ti-mô-thê 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteyos 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotheum 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotheüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Pili Timotheo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Втора Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Втора Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Втора Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Второ Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друге Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друге Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друге Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("دوم تیمِتھُیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("۲ تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("۲ تیِمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("۲-تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timótheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 e Timoteut 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 i Timoteut 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timotʰilai 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timotʰilaī 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timotʰilāi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timotʰilāī 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timotʰīlai 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timotʰīlaī 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timotʰīlāi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timotʰīlāī 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 तीमुाथैयुस 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 திமொத்தேயு 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 தீமோத்தேயு 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а. Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а. Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а. Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. Тиметею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-я. Тиметею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-я. Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Ti-mô-thê 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteyos 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotheum 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotheüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. к Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. تیمِتھُیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. तिमुथियुस 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. तिमोथीलाई 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. तीमुथियुस 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2.o. Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2.º. Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2d. Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2d. Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2de Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2de Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e Timotheüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e. Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e. Timoteüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e. Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e. Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2е к Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2я к Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Ti-mô-thê 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteyos 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotheum 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotheüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteju 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotheo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotius 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timóteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Тимотеју 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotheum II 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Ti-mô-thê 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteyos 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotheum 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotheüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timotʰius 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 к Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 تیمِتھُیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 तिमुथियुस 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 तिमोथीलाई 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 तीमथ्थाला 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 तीमुथियुस 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е Тиметею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-я Тиметею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-я Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteju 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteut 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotheo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotius 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timóteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Тимотеју 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ତୀମଥିଙ୍କ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2.o Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2.º Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2a. Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2a. Timóteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2d Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2d Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e Timoteüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2o. Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2o. Timóteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2°. Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2º. Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2е. Тиметею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2е. Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2я. Тиметею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2я. Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteju 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotheo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotius 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timóteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Тимотеју 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotei 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timóteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timôthê 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Második Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotheo II 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("دوم۔تیمتھیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("۲ تیمِتھُیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteju 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteut 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotheo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotius 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timóteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Тимотеју 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ତୀମଥିଙ୍କ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotei 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timóteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timôthê 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Тиметею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2.۔تیمتھیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2a Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2a Timóteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2o Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2o Timóteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2° Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2º Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2е Тиметею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2е Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2я Тиметею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2я Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotei 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timóteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timôthê 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timote 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tweede Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β' Τιμοθεο 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β' Τιμόθεο 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ Τιμοθεο 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ Τιμόθεο 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ Τιμοθεο 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ Τιμόθεο 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β΄ Τιμοθεο 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β΄ Τιμόθεο 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β’ Τιμοθεο 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β’ Τιμόθεο 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("テモテヘの第二の手紙 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotei 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timóteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timôthê 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Тиметею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timote 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. तिमोथी 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ทิโมธี 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2۔تیمتھیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Anden Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Andre Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhá Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhý Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timote 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Втора Тим 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("۲۔تیمتھیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timote 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 तिमोथी 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 தீமோத் 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ทิโมธี 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhá Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhý Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Pili Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("テモテへの後の書 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("テモテへの手紙二 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e. Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Tím 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Тим 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《弟茂德後書》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提摩太后书》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提摩太後書》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 திமொ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Tím 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Тим 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. तीम 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Tím 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Тим 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β' Τιμ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ Τιμ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ Τιμ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β΄ Τιμ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β’ Τιμ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《弟茂德後書 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提摩太后书 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提摩太後書 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提摩斐後》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("弟茂德後書》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提摩太后书》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提摩太後書》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("티모테오2서 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tym 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tím 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Тим 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 طيم 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 तीम 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β' Τι 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ Τι 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ Τι 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β΄ Τι 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β’ Τι 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提摩斐後 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("テモテ 2 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("テモテ後書 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("弟茂德後書 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提摩太后书 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提摩太後書 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提摩斐後》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("디모데2서 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("디모데후서 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ทธ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提后》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提後》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("二テモテ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提摩斐後 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2티모 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提后 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提後 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提后》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提後》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提后 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提後 1:1").osis()).toEqual("2Tim.1.1")
		`
		true
	it "should handle non-Latin digits in book: 2Tim (full)", ->
		p.set_options non_latin_digits_strategy: "replace"
		`
		expect(p.parse("2-ге. послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друге послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а. послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге. послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друге послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а. послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhe poslannja apostola Pavla do Tymofija 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Второ послание на св. ап. Павла до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("திமொத்தேயுவுக்கு எழுதிய இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("திமோத்தேயுவுக்கு எழுதிய இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotteyuvukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timottēyuvukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōtteyuvukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timōttēyuvukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Elutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Elutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Elutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Elutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Elutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Elutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Elutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Elutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Eḻutiya Irantavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Eḻutiya Irantāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Eḻutiya Iranṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Eḻutiya Iranṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Eḻutiya Iraṇtavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Eḻutiya Iraṇtāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Eḻutiya Iraṇṭavatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Eḻutiya Iraṇṭāvatu Nirupam 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Второ послание на св ап. Павла до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Второ послание на св. ап Павла до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("தீமோத்தேயுவுக்கு எழுதிய இரண்டாவது நிருபம் 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге. послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Второ послание на св ап Павла до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друге послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("تیِمُتھِیُس کے نام پولس رسول کا دوسرا خط 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а. послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Втора писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Второ писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("தீமோத்தேயுவுக்கு எழுதிய இரண்டாம் கடிதம் 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("رسالة بولس الرسول الثانية إلى تيموثاوس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 послання апостола Павла до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga List św. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Drugi List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Drugi List św. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga List sw Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga List św Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Drugi List sw Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Drugi List św Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. List św. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Paulus' Andet Brev til Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Paulus’ Andet Brev til Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Pavlova druga poslanica Timoteju 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. List św. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II List św. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. List sw Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. List św Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Paulus’ andre brev til Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Pals til Timoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Pals til Timóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Pals til Tímoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Pals til Tímóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Páls til Timoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Páls til Timóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Páls til Tímoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Páls til Tímóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Pals til Timoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Pals til Timóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Pals til Tímoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Pals til Tímóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Páls til Timoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Páls til Timóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Páls til Tímoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Páls til Tímóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Pals til Timoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Pals til Timóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Pals til Tímoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Pals til Tímóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Páls til Timoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Páls til Timóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Páls til Tímoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Páls til Tímóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Pals til Timoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Pals til Timóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Pals til Tímoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Pals til Tímóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Páls til Timoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Páls til Timóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Páls til Tímoteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Páls til Tímóteusar 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 List św. Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. List sw Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. List św Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II List sw Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II List św Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("tīmutʰiyus ke nām kā dūsrā ḫaṭ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("تِیمُتھِیُس کے نام کا دوسرا خط 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 List sw Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 List św Pawła do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("الرسالة الثانية إلى تيموثاوس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("तिमोथीलाई पावलको दोस्रो पत्र 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Waraka wa Pili kwa Timotheo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("אגרת פולוס השנייה אל-טימותי 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("पौलाचे तीमथ्थाला दुसरे पत्र 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ତୀମଥିଙ୍କ ପ୍ରତି ଦ୍ୱିତୀୟ ପତ୍ର 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Barua ya Pili kwa Timotheo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Toinen Kirje Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Второ послание към Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Второ послание към Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("تیمتھیس کے نام کا دوسرا خط 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге. послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге. послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Seconda lettera a Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Pals til Timo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Pals til Timó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Pals til Tímo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Pals til Tímó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Páls til Timo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Páls til Timó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Páls til Tímo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bref Páls til Tímó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Pals til Timo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Pals til Timó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Pals til Tímo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Pals til Tímó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Páls til Timo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Páls til Timó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Páls til Tímo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara bréf Páls til Tímó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Pals til Timo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Pals til Timó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Pals til Tímo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Pals til Tímó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Páls til Timo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Páls til Timó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Páls til Tímo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bref Páls til Tímó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Pals til Timo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Pals til Timó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Pals til Tímo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Pals til Tímó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Páls til Timo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Páls til Timó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Páls til Tímo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara bréf Páls til Tímó 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timotʰius nū̃ dūjī pattrī 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друге послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друге послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("האיגרת השנייה אל טימותיוס 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а. послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а. послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga List do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga Timoteju Poslanica 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga poslanica Timoteju 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Drugi List do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Epistula II ad Timotheum 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Epistula ad Timotheum II 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга посланица Тимотеју 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ਤਿਮੋਥਿਉਸ ਨੂੰ ਦੂਜੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Kirje Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timatʰtʰala dusre patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timatʰtʰalā dusre patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timatʰtʰāla dusre patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timatʰtʰālā dusre patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timotʰilai dostro patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timotʰilaī dostro patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timotʰilāi dostro patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timotʰilāī dostro patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timotʰīlai dostro patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timotʰīlaī dostro patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timotʰīlāi dostro patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("timotʰīlāī dostro patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("tīmatʰtʰala dusre patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("tīmatʰtʰalā dusre patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("tīmatʰtʰāla dusre patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("tīmatʰtʰālā dusre patra 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("तिमोथीलाई दोस्त्रो पत्र 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге. послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Kirje Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha kniha Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhá kniha Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Kirje Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. List do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteju Poslanica 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. посланица Тимотеју 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друге послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Kirje Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 послання до Тимотея 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 послання до Тимофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а. послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. List do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteju Poslanica 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. посланица Тимотеју 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Andra Timotheosbrevet 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha kniha Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy list Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhá kniha Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhý list Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II List do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteju Poslanica 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II посланица Тимотеју 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Ikalawang Kay Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara Timoteusarbref 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara Timoteusarbréf 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara Timóteusarbref 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara Timóteusarbréf 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara Tímoteusarbref 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara Tímoteusarbréf 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara Tímóteusarbref 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Siðara Tímóteusarbréf 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara Timoteusarbref 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara Timoteusarbréf 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara Timóteusarbref 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara Timóteusarbréf 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara Tímoteusarbref 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara Tímoteusarbréf 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara Tímóteusarbref 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Síðara Tímóteusarbréf 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 List do Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteju Poslanica 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 посланица Тимотеју 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Andra Timoteusbrevet 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha list Timeteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha list Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy list Timeteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy list Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhá list Timeteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhá list Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhý list Timeteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhý list Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Toinen Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Toinen Timoteuskirje 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("तीमथ्थाला दुसरे पत्र 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Anden Timotheusbrev 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Andet Timotheusbrev 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Timoteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Timoteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Timóteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Timóteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Második Timoteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Második Timoteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Második Timóteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Második Timóteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("השנייה אל טימותיאוס 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 послання Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotheosbrevet 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Andre Timoteusbrev 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Deuxiemes Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Deuxiemes Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Deuxièmes Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Deuxièmes Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. list Timeteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. list Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Timotheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Timótheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Második Timotheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Második Timótheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("השנייה אל טימותיוס 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotheosbrevet 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteusbrevet 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. list Timeteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. list Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Deuxieme Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Deuxieme Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Deuxième Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Deuxième Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II list Timeteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II list Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteuskirje 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Ikalawang Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteusbrevet 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotteyuvukku 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timottēyuvukku 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timōtteyuvukku 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timōttēyuvukku 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tīmotteyuvukku 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tīmottēyuvukku 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tīmōtteyuvukku 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tīmōttēyuvukku 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 list Timeteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 list Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Teemuathaiyus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteuskirje 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotheusbrev 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Drugi Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhá Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhý Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteuskirje 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Timóteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Második Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Második Timóteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timoteyos Labaad 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tweede Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tweede Timotheüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Zweite Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Προς Τιμοθεον Β' 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Προς Τιμοθεον Βʹ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Προς Τιμοθεον Βʹ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Προς Τιμοθεον Β΄ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Προς Τιμοθεον Β’ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Προς Τιμόθεον Β' 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Προς Τιμόθεον Βʹ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Προς Τιμόθεον Βʹ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Προς Τιμόθεον Β΄ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Προς Τιμόθεον Β’ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("تيموثاوس الثانية 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ତୀମଥିଙ୍କ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ﺍﻟﺜﺎﻧﻴﺔ ﺗﻴﻤﻮﺛﺎﻭﺱ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Teemuathaiyus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteukselle 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteuskirje 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotheusbrev 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 k. Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Kang Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteusbrev 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhá Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhý Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Kay Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timóteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timóteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Seconda Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Secondo Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Segunda Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Segunda Timóteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Segundo Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Segundo Timóteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tweede Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tweede Timoteüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ad Timotheum II 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("دوم تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("دوم تیِمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("دوم-تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("티모테오에게 보낸 둘째 서간 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Kang Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteusbrev 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 k Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 k. Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ਤਿਮੋਥਿਉਸ ਨੂੰ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге. Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. к Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-я. к Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Kay Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timóteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timóteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. تیِمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2.-تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2eme. Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2eme. Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ème. Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ème. Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Anden Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Andre Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druga Timoteju 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhá Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhý Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Kay Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timóteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timóteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timótheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга Тимотеју 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друге Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Kay Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timóteushoz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timóteusnak 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 e. Timoteut 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 i. Timoteut 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 k Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timatʰtʰala 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timatʰtʰalā 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timatʰtʰāla 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timatʰtʰālā 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 tīmatʰtʰala 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 tīmatʰtʰalā 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 tīmatʰtʰāla 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 tīmatʰtʰālā 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 تیِمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а. Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге. Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге. Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге. Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е к Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-я к Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timótheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. timotʰilai 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. timotʰilaī 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. timotʰilāi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. timotʰilāī 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. timotʰīlai 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. timotʰīlaī 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. timotʰīlāi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. timotʰīlāī 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. तीमुाथैयुस 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2de. Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2de. Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e. Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e. Timotheüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2eme Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2eme Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ème Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ème Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2е. к Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2я. к Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Dezyem Timote 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Dezyèm Timote 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timótheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Ti-mô-thê 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteyos 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotheum 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotheüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Pili Timotheo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Втора Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Втора Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Втора Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Второ Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друга Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друге Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друге Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Друге Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("دوم تیمِتھُیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("۲ تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("۲ تیِمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("۲-تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotejovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timótheosz 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tymoteusza 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 e Timoteut 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 i Timoteut 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timotʰilai 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timotʰilaī 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timotʰilāi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timotʰilāī 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timotʰīlai 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timotʰīlaī 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timotʰīlāi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timotʰīlāī 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 तीमुाथैयुस 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 திமொத்தேயு 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 தீமோத்தேயு 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а. Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а. Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а. Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ге Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. Тиметею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е. Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-я. Тиметею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-я. Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Ti-mô-thê 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteyos 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotheum 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotheüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. к Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. تیمِتھُیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. तिमुथियुस 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. तिमोथीलाई 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. तीमुथियुस 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2.o. Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2.º. Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2d. Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2d. Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2de Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2de Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e Timotheüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e. Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e. Timoteüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e. Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e. Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2е к Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2я к Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Ti-mô-thê 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteyos 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotheum 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotheüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteju 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotheo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotius 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timóteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Тимотеју 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotheum II 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Ti-mô-thê 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteovi 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteyos 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotheum 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotheus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotheüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 timotʰius 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 к Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 تیمِتھُیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 तिमुथियुस 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 तिमोथीलाई 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 तीमथ्थाला 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 तीमुथियुस 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-а Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е Тиметею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-е Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-я Тиметею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-я Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteju 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteut 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotheo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotius 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timóteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Тимотеју 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ତୀମଥିଙ୍କ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2.o Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2.º Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2a. Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2a. Timóteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2d Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2d Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e Timoteüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2o. Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2o. Timóteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2°. Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2º. Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2е. Тиметею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2е. Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2я. Тиметею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2я. Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteju 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotheo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotius 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timóteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Тимотеју 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timotei 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timóteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timôthê 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Masodik Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Második Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Timotheo II 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("دوم۔تیمتھیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("۲ تیمِتھُیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Thimothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteju 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteut 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteüs 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timothee 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotheo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timothée 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotius 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timóteus 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Ти­мофія 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Тимотеју 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ତୀମଥିଙ୍କ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timotei 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timóteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timôthê 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Тиметею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2.۔تیمتھیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2a Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2a Timóteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2o Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2o Timóteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2° Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2º Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2е Тиметею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2е Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2я Тиметею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2я Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timotei 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timóteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timôthê 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timote 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Tweede Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β' Τιμοθεο 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β' Τιμόθεο 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ Τιμοθεο 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ Τιμόθεο 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ Τιμοθεο 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ Τιμόθεο 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β΄ Τιμοθεο 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β΄ Τιμόθεο 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β’ Τιμοθεο 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β’ Τιμόθεο 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("テモテヘの第二の手紙 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Thimoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timotei 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timóteo 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timôthê 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tomothy 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Тиметею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Тимотеи 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Тимотей 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Тимотеј 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Тимофею 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Тимофію 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timote 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. तिमोथी 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ทิโมธี 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2۔تیمتھیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Anden Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Andre Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhá Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhý Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timote 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Second Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Втора Тим 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("۲۔تیمتھیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timote 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoth 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Timoty 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 तिमोथी 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 தீமோத் 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ทิโมธี 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druha Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhy Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhá Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Druhý Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Pili Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("テモテへの後の書 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("テモテへの手紙二 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e. Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd. Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Tím 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Тим 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《弟茂德後書》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提摩太后书》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提摩太後書》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 திமொ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Tím 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Тим 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. तीम 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2e Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2nd Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Tím 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Тим 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β' Τιμ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ Τιμ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ Τιμ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β΄ Τιμ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β’ Τιμ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《弟茂德後書 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提摩太后书 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提摩太後書 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提摩斐後》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("弟茂德後書》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提摩太后书》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提摩太後書》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("티모테오2서 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tym 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tím 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Тим 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 طيم 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 तीम 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β' Τι 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ Τι 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ Τι 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β΄ Τι 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β’ Τι 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提摩斐後 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("テモテ 2 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("テモテ後書 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("弟茂德後書 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提摩太后书 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提摩太後書 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提摩斐後》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("디모데2서 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("디모데후서 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Ti 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 Tm 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ทธ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2Tim 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提后》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提後》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("二テモテ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提摩斐後 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2티모 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提后 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提後 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提后》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提後》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提后 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提後 1:1").osis()).toEqual("2Tim.1.1")
		p.include_apocrypha(false)
		expect(p.parse("2-ГЕ. ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ДРУГА ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ДРУГЕ ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-А. ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ГЕ ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ГЕ. ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е. ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ДРУГА ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ДРУГЕ ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-А ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-А. ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ГЕ ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е. ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-А ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHE POSLANNJA APOSTOLA PAVLA DO TYMOFIJA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ВТОРО ПОСЛАНИЕ НА СВ. АП. ПАВЛА ДО ТИМОТЕЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("திமொத்தேயுவுக்கு எழுதிய இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("திமோத்தேயுவுக்கு எழுதிய இரண்டாம் திருமுகம் 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTEYUVUKKU ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTEYUVUKKU ELUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTEYUVUKKU ELUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTEYUVUKKU ELUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTEYUVUKKU ELUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTEYUVUKKU ELUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTEYUVUKKU ELUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTEYUVUKKU ELUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTEYUVUKKU EḺUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTEYUVUKKU EḺUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTEYUVUKKU EḺUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTEYUVUKKU EḺUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTEYUVUKKU EḺUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTEYUVUKKU EḺUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTEYUVUKKU EḺUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTEYUVUKKU EḺUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTĒYUVUKKU ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTĒYUVUKKU ELUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTĒYUVUKKU ELUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTĒYUVUKKU ELUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTĒYUVUKKU ELUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTĒYUVUKKU ELUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTĒYUVUKKU ELUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTĒYUVUKKU ELUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTĒYUVUKKU EḺUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTĒYUVUKKU EḺUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTĒYUVUKKU EḺUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTĒYUVUKKU EḺUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTĒYUVUKKU EḺUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTĒYUVUKKU EḺUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTĒYUVUKKU EḺUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTTĒYUVUKKU EḺUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTEYUVUKKU ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTEYUVUKKU ELUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTEYUVUKKU ELUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTEYUVUKKU ELUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTEYUVUKKU ELUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTEYUVUKKU ELUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTEYUVUKKU ELUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTEYUVUKKU ELUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTEYUVUKKU EḺUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTEYUVUKKU EḺUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTEYUVUKKU EḺUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTEYUVUKKU EḺUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTEYUVUKKU EḺUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTEYUVUKKU EḺUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTEYUVUKKU EḺUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTEYUVUKKU EḺUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTĒYUVUKKU ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTĒYUVUKKU ELUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTĒYUVUKKU ELUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTĒYUVUKKU ELUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTĒYUVUKKU ELUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTĒYUVUKKU ELUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTĒYUVUKKU ELUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTĒYUVUKKU ELUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTĒYUVUKKU EḺUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTĒYUVUKKU EḺUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTĒYUVUKKU EḺUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTĒYUVUKKU EḺUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTĒYUVUKKU EḺUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTĒYUVUKKU EḺUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTĒYUVUKKU EḺUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMŌTTĒYUVUKKU EḺUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTEYUVUKKU ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTEYUVUKKU ELUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTEYUVUKKU ELUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTEYUVUKKU ELUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTEYUVUKKU ELUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTEYUVUKKU ELUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTEYUVUKKU ELUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTEYUVUKKU ELUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTEYUVUKKU EḺUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTEYUVUKKU EḺUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTEYUVUKKU EḺUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTEYUVUKKU EḺUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTEYUVUKKU EḺUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTEYUVUKKU EḺUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTEYUVUKKU EḺUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTEYUVUKKU EḺUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTĒYUVUKKU ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTĒYUVUKKU ELUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTĒYUVUKKU ELUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTĒYUVUKKU ELUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTĒYUVUKKU ELUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTĒYUVUKKU ELUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTĒYUVUKKU ELUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTĒYUVUKKU ELUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTĒYUVUKKU EḺUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTĒYUVUKKU EḺUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTĒYUVUKKU EḺUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTĒYUVUKKU EḺUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTĒYUVUKKU EḺUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTĒYUVUKKU EḺUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTĒYUVUKKU EḺUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMOTTĒYUVUKKU EḺUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTEYUVUKKU ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTEYUVUKKU ELUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTEYUVUKKU ELUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTEYUVUKKU ELUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTEYUVUKKU ELUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTEYUVUKKU ELUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTEYUVUKKU ELUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTEYUVUKKU ELUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTEYUVUKKU EḺUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTEYUVUKKU EḺUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTEYUVUKKU EḺUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTEYUVUKKU EḺUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTEYUVUKKU EḺUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTEYUVUKKU EḺUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTEYUVUKKU EḺUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTEYUVUKKU EḺUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTĒYUVUKKU ELUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTĒYUVUKKU ELUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTĒYUVUKKU ELUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTĒYUVUKKU ELUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTĒYUVUKKU ELUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTĒYUVUKKU ELUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTĒYUVUKKU ELUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTĒYUVUKKU ELUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTĒYUVUKKU EḺUTIYA IRANTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTĒYUVUKKU EḺUTIYA IRANTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTĒYUVUKKU EḺUTIYA IRANṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTĒYUVUKKU EḺUTIYA IRANṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTĒYUVUKKU EḺUTIYA IRAṆTAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTĒYUVUKKU EḺUTIYA IRAṆTĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTĒYUVUKKU EḺUTIYA IRAṆṬAVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMŌTTĒYUVUKKU EḺUTIYA IRAṆṬĀVATU NIRUPAM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ВТОРО ПОСЛАНИЕ НА СВ АП. ПАВЛА ДО ТИМОТЕЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ВТОРО ПОСЛАНИЕ НА СВ. АП ПАВЛА ДО ТИМОТЕЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("தீமோத்தேயுவுக்கு எழுதிய இரண்டாவது நிருபம் 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ГЕ. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ВТОРО ПОСЛАНИЕ НА СВ АП ПАВЛА ДО ТИМОТЕЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ДРУГА ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ДРУГЕ ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("تیِمُتھِیُس کے نام پولس رسول کا دوسرا خط 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-А. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ГЕ ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ВТОРА ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ТИМОТЕЈ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ВТОРО ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ТИМОТЕЈ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("தீமோத்தேயுவுக்கு எழுதிய இரண்டாம் கடிதம் 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-А ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("رسالة بولس الرسول الثانية إلى تيموثاوس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ТИМОТЕЈ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ТИМОТЕЈ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ТИМОТЕЈ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ТИМОТЕЈ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUGA LIST SW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUGA LIST ŚW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUGI LIST SW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUGI LIST ŚW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUGA LIST SW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUGA LIST ŚW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUGI LIST SW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUGI LIST ŚW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. LIST SW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. LIST ŚW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("PAULUS' ANDET BREV TIL TIMOTHEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("PAULUS’ ANDET BREV TIL TIMOTHEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("PAVLOVA DRUGA POSLANICA TIMOTEJU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. LIST SW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. LIST ŚW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II LIST SW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II LIST ŚW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. LIST SW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. LIST ŚW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("PAULUS’ ANDRE BREV TIL TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BREF PALS TIL TIMOTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BREF PALS TIL TIMÓTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BREF PALS TIL TÍMOTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BREF PALS TIL TÍMÓTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BREF PÁLS TIL TIMOTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BREF PÁLS TIL TIMÓTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BREF PÁLS TIL TÍMOTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BREF PÁLS TIL TÍMÓTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BRÉF PALS TIL TIMOTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BRÉF PALS TIL TIMÓTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BRÉF PALS TIL TÍMOTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BRÉF PALS TIL TÍMÓTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BRÉF PÁLS TIL TIMOTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BRÉF PÁLS TIL TIMÓTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BRÉF PÁLS TIL TÍMOTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BRÉF PÁLS TIL TÍMÓTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BREF PALS TIL TIMOTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BREF PALS TIL TIMÓTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BREF PALS TIL TÍMOTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BREF PALS TIL TÍMÓTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BREF PÁLS TIL TIMOTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BREF PÁLS TIL TIMÓTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BREF PÁLS TIL TÍMOTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BREF PÁLS TIL TÍMÓTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BRÉF PALS TIL TIMOTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BRÉF PALS TIL TIMÓTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BRÉF PALS TIL TÍMOTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BRÉF PALS TIL TÍMÓTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BRÉF PÁLS TIL TIMOTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BRÉF PÁLS TIL TIMÓTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BRÉF PÁLS TIL TÍMOTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BRÉF PÁLS TIL TÍMÓTEUSAR 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 LIST SW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 LIST ŚW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. LIST SW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. LIST ŚW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II LIST SW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II LIST ŚW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMUTʰIYUS KE NĀM KĀ DŪSRĀ ḪAṬ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("تِیمُتھِیُس کے نام کا دوسرا خط 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 LIST SW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 LIST ŚW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("الرسالة الثانية إلى تيموثاوس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("तिमोथीलाई पावलको दोस्रो पत्र 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("WARAKA WA PILI KWA TIMOTHEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("אגרת פולוס השנייה אל-טימותי 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("पौलाचे तीमथ्थाला दुसरे पत्र 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ତୀମଥିଙ୍କ ପ୍ରତି ଦ୍ୱିତୀୟ ପତ୍ର 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("BARUA YA PILI KWA TIMOTHEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TOINEN KIRJE TIMOTEUKSELLE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ВТОРО ПОСЛАНИЕ КЪМ ТИМОТЕИ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ВТОРО ПОСЛАНИЕ КЪМ ТИМОТЕЙ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("تیمتھیس کے نام کا دوسرا خط 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ГЕ. ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ГЕ. ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECONDA LETTERA A TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BREF PALS TIL TIMO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BREF PALS TIL TIMÓ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BREF PALS TIL TÍMO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BREF PALS TIL TÍMÓ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BREF PÁLS TIL TIMO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BREF PÁLS TIL TIMÓ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BREF PÁLS TIL TÍMO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BREF PÁLS TIL TÍMÓ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BRÉF PALS TIL TIMO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BRÉF PALS TIL TIMÓ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BRÉF PALS TIL TÍMO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BRÉF PALS TIL TÍMÓ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BRÉF PÁLS TIL TIMO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BRÉF PÁLS TIL TIMÓ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BRÉF PÁLS TIL TÍMO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA BRÉF PÁLS TIL TÍMÓ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BREF PALS TIL TIMO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BREF PALS TIL TIMÓ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BREF PALS TIL TÍMO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BREF PALS TIL TÍMÓ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BREF PÁLS TIL TIMO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BREF PÁLS TIL TIMÓ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BREF PÁLS TIL TÍMO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BREF PÁLS TIL TÍMÓ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BRÉF PALS TIL TIMO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BRÉF PALS TIL TIMÓ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BRÉF PALS TIL TÍMO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BRÉF PALS TIL TÍMÓ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BRÉF PÁLS TIL TIMO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BRÉF PÁLS TIL TIMÓ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BRÉF PÁLS TIL TÍMO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA BRÉF PÁLS TIL TÍMÓ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTʰIUS NŪ̃ DŪJĪ PATTRĪ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ДРУГА ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ДРУГА ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ДРУГЕ ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ДРУГЕ ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("האיגרת השנייה אל טימותיוס 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-А. ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-А. ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ГЕ ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ГЕ ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е. ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е. ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUGA LIST DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUGA TIMOTEJU POSLANICA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUGA POSLANICA TIMOTEJU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUGI LIST DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("EPISTULA II AD TIMOTHEUM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("EPISTULA AD TIMOTHEUM II 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ДРУГА ПОСЛАНИЦА ТИМОТЕЈУ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ਤਿਮੋਥਿਉਸ ਨੂੰ ਦੂਜੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-А ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-А ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. KIRJE TIMOTEUKSELLE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMATʰTʰALA DUSRE PATRA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMATʰTʰALĀ DUSRE PATRA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMATʰTʰĀLA DUSRE PATRA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMATʰTʰĀLĀ DUSRE PATRA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTʰILAI DOSTRO PATRA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTʰILAĪ DOSTRO PATRA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTʰILĀI DOSTRO PATRA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTʰILĀĪ DOSTRO PATRA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTʰĪLAI DOSTRO PATRA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTʰĪLAĪ DOSTRO PATRA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTʰĪLĀI DOSTRO PATRA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTʰĪLĀĪ DOSTRO PATRA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMATʰTʰALA DUSRE PATRA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMATʰTʰALĀ DUSRE PATRA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMATʰTʰĀLA DUSRE PATRA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TĪMATʰTʰĀLĀ DUSRE PATRA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("तिमोथीलाई दोस्त्रो पत्र 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ГЕ. ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. KIRJE TIMOTEUKSELLE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHA KNIHA TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHÁ KNIHA TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II KIRJE TIMOTEUKSELLE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. LIST DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEJU POSLANICA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. ПОСЛАНИЦА ТИМОТЕЈУ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ДРУГА ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ДРУГЕ ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 KIRJE TIMOTEUKSELLE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-А. ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ГЕ ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е. ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. LIST DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEJU POSLANICA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ПОСЛАНИЦА ТИМОТЕЈУ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ANDRA TIMOTHEOSBREVET 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHA KNIHA TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHY LIST TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHÁ KNIHA TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHÝ LIST TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II LIST DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEJU POSLANICA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II ПОСЛАНИЦА ТИМОТЕЈУ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("IKALAWANG KAY TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA TIMOTEUSARBREF 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA TIMOTEUSARBRÉF 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA TIMÓTEUSARBREF 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA TIMÓTEUSARBRÉF 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA TÍMOTEUSARBREF 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA TÍMOTEUSARBRÉF 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA TÍMÓTEUSARBREF 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SIÐARA TÍMÓTEUSARBRÉF 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA TIMOTEUSARBREF 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA TIMOTEUSARBRÉF 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA TIMÓTEUSARBREF 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA TIMÓTEUSARBRÉF 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA TÍMOTEUSARBREF 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA TÍMOTEUSARBRÉF 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA TÍMÓTEUSARBREF 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SÍÐARA TÍMÓTEUSARBRÉF 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 LIST DO TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEJU POSLANICA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ПОСЛАНИЦА ТИМОТЕЈУ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-А ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ANDRA TIMOTEUSBREVET 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHA LIST TIMETEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHA LIST TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHY LIST TIMETEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHY LIST TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHÁ LIST TIMETEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHÁ LIST TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHÝ LIST TIMETEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHÝ LIST TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TOINEN TIMOTEUKSELLE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TOINEN TIMOTEUSKIRJE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("तीमथ्थाला दुसरे पत्र 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ANDEN TIMOTHEUSBREV 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ANDET TIMOTHEUSBREV 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MASODIK TIMOTEUSHOZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MASODIK TIMOTEUSNAK 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MASODIK TIMÓTEUSHOZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MASODIK TIMÓTEUSNAK 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MÁSODIK TIMOTEUSHOZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MÁSODIK TIMOTEUSNAK 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MÁSODIK TIMÓTEUSHOZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MÁSODIK TIMÓTEUSNAK 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("השנייה אל טימותיאוס 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTHEOSBREVET 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ANDRE TIMOTEUSBREV 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DEUXIEMES TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DEUXIEMES TIMOTHÉE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DEUXIÈMES TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DEUXIÈMES TIMOTHÉE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. LIST TIMETEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. LIST TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MASODIK TIMOTHEOSZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MASODIK TIMÓTHEOSZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MÁSODIK TIMOTHEOSZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MÁSODIK TIMÓTHEOSZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("השנייה אל טימותיוס 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTHEOSBREVET 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEUSBREVET 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. LIST TIMETEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. LIST TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DEUXIEME TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DEUXIEME TIMOTHÉE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DEUXIÈME TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DEUXIÈME TIMOTHÉE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II LIST TIMETEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II LIST TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEUKSELLE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEUSKIRJE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("IKALAWANG TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEUSBREVET 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTTEYUVUKKU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTTĒYUVUKKU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMŌTTEYUVUKKU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMŌTTĒYUVUKKU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TĪMOTTEYUVUKKU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TĪMOTTĒYUVUKKU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TĪMŌTTEYUVUKKU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TĪMŌTTĒYUVUKKU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 LIST TIMETEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 LIST TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TEEMUATHAIYUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEUKSELLE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEUSKIRJE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTHEUSBREV 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUGA TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUGI TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHA TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHY TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHÁ TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHÝ TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEUKSELLE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEUSKIRJE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MASODIK TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MASODIK TIMÓTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MÁSODIK TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MÁSODIK TIMÓTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTEYOS LABAAD 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TWEEDE TIMOTHEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TWEEDE TIMOTHEÜS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ZWEITE TIMOTHEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ΠΡΟΣ ΤΙΜΟΘΕΟΝ Β' 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ΠΡΟΣ ΤΙΜΟΘΕΟΝ Βʹ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ΠΡΟΣ ΤΙΜΟΘΕΟΝ Βʹ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ΠΡΟΣ ΤΙΜΟΘΕΟΝ Β΄ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ΠΡΟΣ ΤΙΜΟΘΕΟΝ Β’ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ΠΡΟΣ ΤΙΜΌΘΕΟΝ Β' 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ΠΡΟΣ ΤΙΜΌΘΕΟΝ Βʹ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ΠΡΟΣ ΤΙΜΌΘΕΟΝ Βʹ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ΠΡΟΣ ΤΙΜΌΘΕΟΝ Β΄ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ΠΡΟΣ ΤΙΜΌΘΕΟΝ Β’ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("تيموثاوس الثانية 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ତୀମଥିଙ୍କ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ﺍﻟﺜﺎﻧﻴﺔ ﺗﻴﻤﻮﺛﺎﻭﺱ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TEEMUATHAIYUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEUKSELLE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEUSKIRJE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTHEUSBREV 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 K. TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. KANG TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEUSBREV 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHA TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHY TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHÁ TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHÝ TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. KAY TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEUSHOZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEUSNAK 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMÓTEUSHOZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMÓTEUSNAK 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND THIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECONDA TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECONDO TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SEGUNDA TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SEGUNDA TIMÓTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SEGUNDO TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SEGUNDO TIMÓTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TWEEDE TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TWEEDE TIMOTEÜS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("AD TIMOTHEUM II 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("دوم تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("دوم تیِمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("دوم-تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("티모테오에게 보낸 둘째 서간 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 KANG TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEUSBREV 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 K TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 K. TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ਤਿਮੋਥਿਉਸ ਨੂੰ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ГЕ. ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е. К ТИМОФЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Я. К ТИМОФЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. KAY TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEUSHOZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEUSNAK 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMÓTEUSHOZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMÓTEUSNAK 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. تیِمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2.-تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2EME. TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2EME. TIMOTHÉE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ÈME. TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ÈME. TIMOTHÉE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ANDEN TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ANDRE TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUGA TIMOTEJU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHA TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHY TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHÁ TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHÝ TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II KAY TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEUSHOZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEUSNAK 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMÓTEUSHOZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMÓTEUSNAK 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTHEOSZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMÓTHEOSZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND THIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND TIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND TOMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ДРУГА ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ДРУГА ТИМОТЕЈУ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ДРУГЕ ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 KAY TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEUSHOZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEUSNAK 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMÓTEUSHOZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMÓTEUSNAK 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 E. TIMOTEUT 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 I. TIMOTEUT 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 K TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMATʰTʰALA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMATʰTʰALĀ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMATʰTʰĀLA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMATʰTʰĀLĀ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TĪMATʰTʰALA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TĪMATʰTʰALĀ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TĪMATʰTʰĀLA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TĪMATʰTʰĀLĀ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 تیِمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-А. ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ГЕ ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ГЕ. ТИМОТЕИ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ГЕ. ТИМОТЕЙ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ГЕ. ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е К ТИМОФЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е. ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Я К ТИМОФЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTHEOSZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMÓTHEOSZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTʰILAI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTʰILAĪ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTʰILĀI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTʰILĀĪ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTʰĪLAI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTʰĪLAĪ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTʰĪLĀI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTʰĪLĀĪ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. तीमुाथैयुस 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2DE. TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2DE. TIMOTHÉE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2E. TIMOTHEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2E. TIMOTHEÜS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2EME TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2EME TIMOTHÉE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. THIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ÈME TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ÈME TIMOTHÉE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2Е. К ТИМОФЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2Я. К ТИМОФЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DEZYEM TIMOTE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DEZYÈM TIMOTE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTHEOSZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMÓTHEOSZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TI-MÔ-THÊ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEYOS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTHEUM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTHEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTHEÜS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("PILI TIMOTHEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND TIMOTH 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND TIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ВТОРА ТИМОТЕИ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ВТОРА ТИМОТЕЙ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ВТОРА ТИМОТЕЈ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ВТОРО ТИМОТЕЈ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ДРУГА ТИМОТЕИ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ДРУГА ТИМОТЕЙ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ДРУГА ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ДРУГЕ ТИМОТЕИ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ДРУГЕ ТИМОТЕЙ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ДРУГЕ ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("دوم تیمِتھُیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("۲ تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("۲ تیِمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("۲-تِیمُتھِیُس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEJOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTHEOSZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMÓTHEOSZ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TYMOTEUSZA 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 E TIMOTEUT 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 I TIMOTEUT 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTʰILAI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTʰILAĪ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTʰILĀI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTʰILĀĪ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTʰĪLAI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTʰĪLAĪ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTʰĪLĀI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTʰĪLĀĪ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 तीमुाथैयुस 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 திமொத்தேயு 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 தீமோத்தேயு 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-А ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-А. ТИМОТЕИ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-А. ТИМОТЕЙ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-А. ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ГЕ ТИМОТЕИ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ГЕ ТИМОТЕЙ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-ГЕ ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е. ТИМЕТЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е. ТИМОТЕИ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е. ТИМОТЕЙ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е. ТИМОФЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е. ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Я. ТИМЕТЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Я. ТИМОФЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TI-MÔ-THÊ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEYOS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTHEUM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTHEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTHEÜS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. К ТИМОФЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. تیمِتھُیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. तिमुथियुस 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. तिमोथीलाई 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. तीमुथियुस 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2.O. TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2.º. TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2D. TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2D. TIMOTHÉE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2DE TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2DE TIMOTHÉE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2E TIMOTHEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2E TIMOTHEÜS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2E. TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2E. TIMOTEÜS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2E. TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2E. TIMOTHÉE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND THIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. THIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. TIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. TOMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2Е К ТИМОФЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2Я К ТИМОФЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TI-MÔ-THÊ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEYOS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTHEUM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTHEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTHEÜS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. THIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEJU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEÜS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTHEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTHÉE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTIUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMÓTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. ТИМОТЕЈУ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTHEUM II 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TI-MÔ-THÊ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEOVI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEYOS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTHEUM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTHEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTHEÜS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTʰIUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 К ТИМОФЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 تیمِتھُیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 तिमुथियुस 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 तिमोथीलाई 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 तीमथ्थाला 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 तीमुथियुस 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-А ТИМОТЕИ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-А ТИМОТЕЙ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-А ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е ТИМЕТЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е ТИМОТЕИ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е ТИМОТЕЙ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е ТИМОФЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Е ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Я ТИМЕТЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2-Я ТИМОФЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. THIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEJU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEUT 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEÜS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTHEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTHÉE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTIUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMÓTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ТИМОТЕЈУ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ତୀମଥିଙ୍କ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2.O TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2.º TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2A. TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2A. TIMÓTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2D TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2D TIMOTHÉE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2E TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2E TIMOTEÜS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2E TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2E TIMOTHÉE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND THIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND TIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND TOMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. TIMOTH 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. TIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2O. TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2O. TIMÓTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2°. TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2º. TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2Е. ТИМЕТЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2Е. ТИМОФЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2Я. ТИМЕТЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2Я. ТИМОФЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II THIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEJU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEÜS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTHEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTHÉE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTIUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMÓTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II ТИМОТЕЈУ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. THIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMÓTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMÔTHÊ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TOMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. ТИМОТЕИ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. ТИМОТЕЙ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. ТИМОТЕЈ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MASODIK TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("MÁSODIK TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TIMOTHEO II 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("دوم۔تیمتھیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("۲ تیمِتھُیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 THIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEJU 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEUT 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEÜS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTHEE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTHEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTHÉE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTIUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMÓTEUS 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ТИ­МОФІЯ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ТИМОТЕЈУ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ତୀମଥିଙ୍କ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. THIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMÓTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMÔTHÊ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TOMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ТИМЕТЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ТИМОТЕИ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ТИМОТЕЙ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ТИМОТЕЈ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ТИМОФЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2.۔تیمتھیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2A TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2A TIMÓTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND TIMOTH 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND TIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2O TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2O TIMÓTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2° TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2º TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2Е ТИМЕТЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2Е ТИМОФЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2Я ТИМЕТЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2Я ТИМОФЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II THIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMÓTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMÔTHÊ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TOMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II ТИМОТЕИ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II ТИМОТЕЙ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II ТИМОТЕЈ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTH 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("TWEEDE TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β' ΤΙΜΟΘΕΟ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β' ΤΙΜΌΘΕΟ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ ΤΙΜΟΘΕΟ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ ΤΙΜΌΘΕΟ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ ΤΙΜΟΘΕΟ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ ΤΙΜΌΘΕΟ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β΄ ΤΙΜΟΘΕΟ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β΄ ΤΙΜΌΘΕΟ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β’ ΤΙΜΟΘΕΟ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β’ ΤΙΜΌΘΕΟ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("テモテヘの第二の手紙 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 THIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMÓTEO 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMÔTHÊ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TOMOTHY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ТИМЕТЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ТИМОТЕИ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ТИМОТЕЙ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ТИМОТЕЈ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ТИМОФЕЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ТИМОФІЮ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTH 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. तिमोथी 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ทิโมธี 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2۔تیمتھیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ANDEN TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ANDRE TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHA TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHY TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHÁ TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHÝ TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTH 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND TI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("SECOND TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("ВТОРА ТИМ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("۲۔تیمتھیس 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTE 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTH 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIMOTY 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 तिमोथी 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 தீமோத் 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ทิโมธี 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHA TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHY TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHÁ TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("DRUHÝ TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("PILI TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("テモテへの後の書 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("テモテへの手紙二 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2E. TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. TI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND. TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TÍM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. ТИМ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《弟茂德後書》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提摩太后书》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提摩太後書》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 திமொ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TÍM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. ТИМ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. तीम 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2E TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND TI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2ND TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TÍM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II ТИМ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II. TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β' ΤΙΜ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ ΤΙΜ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ ΤΙΜ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β΄ ΤΙΜ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β’ ΤΙΜ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《弟茂德後書 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提摩太后书 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提摩太後書 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提摩斐後》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("弟茂德後書》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提摩太后书》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提摩太後書》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("티모테오2서 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TYM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TÍM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ТИМ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 طيم 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 तीम 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2. TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("II TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β' ΤΙ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ ΤΙ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Βʹ ΤΙ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β΄ ΤΙ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("Β’ ΤΙ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提摩斐後 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("テモテ 2 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("テモテ後書 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("弟茂德後書 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提摩太后书 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提摩太後書 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提摩斐後》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("디모데2서 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("디모데후서 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TI 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 TM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2 ทธ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2TIM 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提后》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提後》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("二テモテ 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提摩斐後 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("2티모 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提后 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("《提後 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提后》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提後》 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提后 1:1").osis()).toEqual("2Tim.1.1")
		expect(p.parse("提後 1:1").osis()).toEqual("2Tim.1.1")
		`
		true
describe "Localized book 1Tim (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Tim (full)", ->
		`
		expect(p.parse("1-ше. послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перша послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перше послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а. послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше. послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перша послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перше послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а. послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Perse poslannja apostola Pavla do Tymofija 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Perše poslannja apostola Pavla do Tymofija 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Първо послание на св. ап. Павла до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timotteyuvukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timotteyuvukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timotteyuvukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timotteyuvukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timottēyuvukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timottēyuvukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timottēyuvukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timottēyuvukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timōtteyuvukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timōtteyuvukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timōtteyuvukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timōtteyuvukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timōttēyuvukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timōttēyuvukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timōttēyuvukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timōttēyuvukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Първо послание на св ап. Павла до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Първо послание на св. ап Павла до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше. послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перша послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перше послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Първо послание на св ап Павла до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("تِیمُتھِیُس کے نام پولُس رسول کا پہلا خط 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("தீமோத்தேயுவுக்கு எழுதிய முதலாவது நிருபம் 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а. послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("திமொத்தேயுவுக்கு எழுதிய முதல் திருமுகம் 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("திமோத்தேயுவுக்கு எழுதிய முதல் திருமுகம் 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Прва писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Прво писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("தீமோத்தேயுவுக்கு எழுதிய முதலாம் கடிதம் 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsza List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsza List św. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsze List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsze List św. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwszy List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwszy List św. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("رسالة بولس الرسول الأولى إلى تيموثاوس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsza List sw Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsza List św Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsze List sw Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsze List św Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwszy List sw Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwszy List św Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Paulus' Første Brev til Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Paulus’ Første Brev til Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Paulus’ første brev til Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. List św. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Ensimmainen Kirje Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Ensimmäinen Kirje Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. List św. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pavlova prva poslanica Timoteju 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 List św. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. List sw Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. List św Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Pals til Timoteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Pals til Timóteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Pals til Tímoteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Pals til Tímóteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Páls til Timoteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Páls til Timóteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Páls til Tímoteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Páls til Tímóteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Pals til Timoteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Pals til Timóteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Pals til Tímoteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Pals til Tímóteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Páls til Timoteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Páls til Timóteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Páls til Tímoteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Páls til Tímóteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I List św. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. List sw Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. List św Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("tīmutʰiyus ke nām kā pahlā ḫaṭ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 List sw Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 List św Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I List sw Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I List św Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Paulus' 1. Brev til Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Paulus’ 1. Brev til Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Waraka wa Kwanza kwa Timotheo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("تِیمُتھِیُس کے نام کا پہلا خط 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("तिमोथीलाईर् पावलको पहिलो पत्र 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Barua ya Kwanza kwa Timotheo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Paulus' 1 Brev til Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Paulus’ 1 Brev til Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsza List do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsze List do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwszy List do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timotʰius nū̃ pahilī pattrī 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("אגרת פולוס הראשונה אל-טימות 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("الرسالة الأولى إلى تيموثاوس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("पौलाचे तीमथ्याला पहिले पत्र 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Първо послание към Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Първо послание към Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("האיגרת הראשונה אל טימותיוס 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше. послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше. послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Ensimmainen Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Ensimmainen Timoteuskirje 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Ensimmäinen Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Ensimmäinen Timoteuskirje 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Pals til Timot 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Pals til Timót 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Pals til Tímot 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Pals til Tímót 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Páls til Timot 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Páls til Timót 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Páls til Tímot 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Páls til Tímót 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Pals til Timot 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Pals til Timót 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Pals til Tímot 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Pals til Tímót 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Páls til Timot 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Páls til Timót 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Páls til Tímot 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Páls til Tímót 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перша послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перша послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перше послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перше послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("تیمتھیس کے نام کا پہلا خط 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ਤਿਮੋਥਿਉਸ ਨੂੰ ਪਹਿਲੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ତୀମଥିଙ୍କ ପ୍ରତି ପ୍ରଥମ ପତ୍ର 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а. послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а. послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timatʰtʰala pahile patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timatʰtʰalā pahile patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timatʰtʰāla pahile patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timatʰtʰālā pahile patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("tīmatʰtʰala pahile patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("tīmatʰtʰalā pahile patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("tīmatʰtʰāla pahile patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("tīmatʰtʰālā pahile patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Epistula I ad Timotheum 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Epistula ad Timotheum I 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prima lettera a Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prva Timoteju Poslanica 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prva poslanica Timoteju 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timotʰilai pahilo patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timotʰilaī pahilo patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timotʰilāi pahilo patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timotʰilāī pahilo patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timotʰīlai pahilo patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timotʰīlaī pahilo patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timotʰīlāi pahilo patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timotʰīlāī pahilo patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Прва посланица Тимотеју 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше. послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Kirje Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Forsta Timotheosbrevet 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Första Timotheosbrevet 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Kirje Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перша послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перше послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Kirje Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а. послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. List do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteju Poslanica 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. посланица Тимотеју 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Forsta Timoteusbrevet 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Första Timoteusbrevet 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Kirje Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. List do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteju Poslanica 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. посланица Тимотеју 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prva kniha Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvá kniha Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 List do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteju Poslanica 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 посланица Тимотеју 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra Timoteusarbref 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra Timoteusarbréf 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra Timóteusarbref 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra Timóteusarbréf 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra Tímoteusarbref 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra Tímoteusarbréf 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra Tímóteusarbref 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra Tímóteusarbréf 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Første Timotheusbrev 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I List do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteju Poslanica 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I посланица Тимотеју 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prva kniha Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvni list Timeteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvni list Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("První list Timeteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("První list Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvy list Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvá kniha Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvý list Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("הראשונה אל טימותיאוס 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("तिमोथीलाई पहिलो पत्र 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("तीमथ्थाला पहिले पत्र 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Første Timoteusbrev 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsza Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsze Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwszy Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvy list Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvý list Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("הראשונה אל טימותיוס 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotheosbrevet 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premieres Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premieres Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premières Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premières Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotheosbrevet 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteusbrevet 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. list Timeteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. list Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. list Timeteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. list Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premiere Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premiere Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premiers Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premiers Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Première Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Première Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Unang Kay Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteusbrevet 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotteyuvukku 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timottēyuvukku 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timōtteyuvukku 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timōttēyuvukku 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tīmotteyuvukku 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tīmottēyuvukku 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tīmōtteyuvukku 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tīmōttēyuvukku 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 list Timeteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 list Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Teemuathaiyus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteuskirje 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotheusbrev 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Eerste Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Eerste Timotheüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Timoteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Timoteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Timóteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Timóteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Első Timoteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Első Timoteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Első Timóteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Első Timóteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I list Timeteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I list Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteuskirje 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premier Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premier Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Primeira Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Primeira Timóteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Primeiro Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Primeiro Timóteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timoteyos Kowaad 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Προς Τιμοθεον Α' 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Προς Τιμοθεον Αʹ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Προς Τιμοθεον Αʹ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Προς Τιμοθεον Α΄ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Προς Τιμοθεον Α’ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Προς Τιμόθεον Α' 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Προς Τιμόθεον Αʹ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Προς Τιμόθεον Αʹ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Προς Τιμόθεον Α΄ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Προς Τιμόθεον Α’ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("اوّل تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("اوّل-تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Teemuathaiyus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteuskirje 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotheusbrev 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 k. Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Kang Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteusbrev 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Eerste Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Eerste Timoteüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Timotheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Timótheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Első Timotheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Első Timótheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Erste Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Første Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteuskirje 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Kwanza Timotheo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Primero Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prva Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvni Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("První Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvy Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvá Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvý Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Una Kay Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("تيموثاوس الأولى 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("티모테오에게 보낸 첫째 서간 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Kang Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteusbrev 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 k Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 k. Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ਤਿਮੋਥਿਉਸ ਨੂੰ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. к Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше. Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-я. к Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Kay Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timóteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timóteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1.-تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ere. Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ere. Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ère. Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ère. Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Kay Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timóteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timóteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Primer Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prva Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvni Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("První Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvy Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvá Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvý Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ad Timotheum I 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перша Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перше Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("اوّل تیمِتھُیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ପ୍ରଥମ ତୀମଥିଙ୍କ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Kay Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timóteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timóteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 e. Timoteut 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 i. Timoteut 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 k Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timatʰtʰala 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timatʰtʰalā 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timatʰtʰāla 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timatʰtʰālā 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 tīmatʰtʰala 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 tīmatʰtʰalā 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 tīmatʰtʰāla 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 tīmatʰtʰālā 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а. Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е к Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше. Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше. Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше. Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-я к Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timótheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. timotʰilai 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. timotʰilaī 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. timotʰilāi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. timotʰilāī 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. timotʰīlai 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. timotʰīlaī 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. timotʰīlāi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. timotʰīlāī 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. तीमुाथैयुस 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e. Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e. Timotheüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1er. Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1er. Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ere Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ere Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1re. Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1re. Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ère Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ère Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1е. к Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1я. к Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Timóteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Első Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Első Timóteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Kay Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timóteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timóteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timótheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premye Timote 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prima Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Primo Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prva Timoteju 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Unang Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перша Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перша Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перша Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перше Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перше Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перше Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Прва Тимотеју 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Първа Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Първа Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("۱ تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("۱-تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ﺍﻻﻭﻝ ﺗﻴﻤﻮﺛﺎﻭﺱ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timótheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 e Timoteut 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 i Timoteut 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timotʰilai 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timotʰilaī 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timotʰilāi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timotʰilāī 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timotʰīlai 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timotʰīlaī 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timotʰīlāi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timotʰīlāī 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तीमुाथैयुस 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 திமொத்தேயு 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 தீமோத்தேயு 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а. Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а. Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а. Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. Тиметею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-я. Тиметею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-я. Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Ti-mô-thê 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteyos 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotheum 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotheüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. к Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. تیمِتھُیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. तिमुथियुस 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. तिमोथीलाई 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. तीमुथियुस 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1.o. Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1.º. Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e Timotheüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e. Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e. Timoteüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1er Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1er Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1re Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1re Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1е к Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1я к Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timótheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Ti-mô-thê 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteyos 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotheum 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotheüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsza Tym 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsze Tym 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwszy Tym 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Прва Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Прво Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("اوّل۔تیمتھیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Ti-mô-thê 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteyos 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotheum 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotheüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timotʰius 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 к Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 تیمِتھُیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तिमुथियुस 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तिमोथीलाई 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तीमथ्थाला 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तीमथ्याला 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तीमुथियुस 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е Тиметею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-я Тиметею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-я Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteju 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteut 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotheo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotius 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timóteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Тимотеју 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ତୀମଥିଙ୍କ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1.o Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1.º Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1a. Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1a. Timóteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e Timoteüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1o. Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1o. Timóteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1°. Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1º. Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1е. Тиметею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1е. Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1я. Тиметею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1я. Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Ti-mô-thê 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteyos 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotheum 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotheüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteju 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotheo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotius 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timóteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Тимотеју 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timotheum I 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Una Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("۱ تیمِتھُیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteju 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteut 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotheo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotius 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timóteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Тимотеју 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ତୀମଥିଙ୍କ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotei 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timóteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timôthê 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Тиметею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1.۔تیمتھیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1a Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1a Timóteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1o Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1o Timóteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1° Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1º Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1е Тиметею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1е Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1я Тиметею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1я Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Eerste Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Første Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteju 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotheo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotius 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timóteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Тимотеју 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotei 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timóteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timôthê 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Kwanza Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timotheo I 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α' Τιμοθεο 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α' Τιμόθεο 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ Τιμοθεο 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ Τιμόθεο 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ Τιμοθεο 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ Τιμόθεο 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α΄ Τιμοθεο 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α΄ Τιμόθεο 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α’ Τιμοθεο 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α’ Τιμόθεο 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("テモテヘの第一の手紙 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotei 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timóteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timôthê 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Тиметею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timote 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. तिमोथी 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ทิโมธี 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1۔تیمتھیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotei 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timóteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timôthê 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timote 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvni Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("První Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Първа Тим 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("۱۔تیمتھیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timote 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तिमोथी 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 தீமோத் 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ทิโมธี 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Első Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timote 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvni Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("První Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("テモテへの前の書 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("テモテへの手紙一 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e. Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《弟茂德前書》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提摩太前书》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提摩太前書》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 திமொ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Tym 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Tím 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Тим 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. तीम 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Tym 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Tím 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Тим 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α' Τιμ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ Τιμ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ Τιμ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α΄ Τιμ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α’ Τιμ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《弟茂德前書 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提摩太前书 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提摩太前書 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提摩斐前》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("弟茂德前書》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提摩太前书》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提摩太前書》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("티모테오1서 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tym 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tím 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Тим 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 طيم 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तीम 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Tym 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Tím 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Тим 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α' Τι 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ Τι 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ Τι 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α΄ Τι 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α’ Τι 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提摩斐前 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("テモテ 1 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("テモテ前書 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("弟茂德前書 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提摩太前书 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提摩太前書 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提摩斐前》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("디모데1서 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ทธ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提前》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("一テモテ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提摩斐前 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1티모 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提前 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提前》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提前 1:1").osis()).toEqual("1Tim.1.1")
		`
		true
	it "should handle non-Latin digits in book: 1Tim (full)", ->
		p.set_options non_latin_digits_strategy: "replace"
		`
		expect(p.parse("1-ше. послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перша послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перше послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а. послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше. послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перша послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перше послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а. послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Perse poslannja apostola Pavla do Tymofija 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Perše poslannja apostola Pavla do Tymofija 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Първо послание на св. ап. Павла до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I послання св. апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timotteyuvukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timotteyuvukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timotteyuvukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timotteyuvukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timottēyuvukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timottēyuvukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timottēyuvukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timottēyuvukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timōtteyuvukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timōtteyuvukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timōtteyuvukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timōtteyuvukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timōttēyuvukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timōttēyuvukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timōttēyuvukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timōttēyuvukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmotteyuvukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmottēyuvukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmōtteyuvukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Elutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Elutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Eḻutiya Mutalavatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Tīmōttēyuvukku Eḻutiya Mutalāvatu Nirupam 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Първо послание на св ап. Павла до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Първо послание на св. ап Павла до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше. послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I послання св апостола Павла до Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перша послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перше послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Първо послание на св ап Павла до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("تِیمُتھِیُس کے نام پولُس رسول کا پہلا خط 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("தீமோத்தேயுவுக்கு எழுதிய முதலாவது நிருபம் 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а. послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("திமொத்தேயுவுக்கு எழுதிய முதல் திருமுகம் 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("திமோத்தேயுவுக்கு எழுதிய முதல் திருமுகம் 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Прва писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Прво писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("தீமோத்தேயுவுக்கு எழுதிய முதலாம் கடிதம் 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsza List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsza List św. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsze List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsze List św. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwszy List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwszy List św. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("رسالة بولس الرسول الأولى إلى تيموثاوس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I послання апостола Павла до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsza List sw Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsza List św Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsze List sw Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsze List św Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwszy List sw Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwszy List św Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I писмо од апостол Павле до Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Paulus' Første Brev til Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Paulus’ Første Brev til Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Paulus’ første brev til Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. List św. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Ensimmainen Kirje Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Ensimmäinen Kirje Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. List św. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pavlova prva poslanica Timoteju 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 List św. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. List sw Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. List św Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Pals til Timoteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Pals til Timóteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Pals til Tímoteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Pals til Tímóteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Páls til Timoteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Páls til Timóteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Páls til Tímoteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Páls til Tímóteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Pals til Timoteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Pals til Timóteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Pals til Tímoteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Pals til Tímóteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Páls til Timoteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Páls til Timóteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Páls til Tímoteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Páls til Tímóteusar 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I List sw. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I List św. Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. List sw Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. List św Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("tīmutʰiyus ke nām kā pahlā ḫaṭ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 List sw Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 List św Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I List sw Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I List św Pawła do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Paulus' 1. Brev til Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Paulus’ 1. Brev til Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Waraka wa Kwanza kwa Timotheo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("تِیمُتھِیُس کے نام کا پہلا خط 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("तिमोथीलाईर् पावलको पहिलो पत्र 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Barua ya Kwanza kwa Timotheo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Paulus' 1 Brev til Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Paulus’ 1 Brev til Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsza List do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsze List do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwszy List do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timotʰius nū̃ pahilī pattrī 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("אגרת פולוס הראשונה אל-טימות 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("الرسالة الأولى إلى تيموثاوس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("पौलाचे तीमथ्याला पहिले पत्र 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Първо послание към Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Първо послание към Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("האיגרת הראשונה אל טימותיוס 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше. послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше. послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Ensimmainen Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Ensimmainen Timoteuskirje 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Ensimmäinen Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Ensimmäinen Timoteuskirje 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Pals til Timot 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Pals til Timót 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Pals til Tímot 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Pals til Tímót 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Páls til Timot 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Páls til Timót 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Páls til Tímot 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bref Páls til Tímót 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Pals til Timot 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Pals til Timót 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Pals til Tímot 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Pals til Tímót 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Páls til Timot 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Páls til Timót 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Páls til Tímot 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra bréf Páls til Tímót 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перша послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перша послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перше послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перше послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("تیمتھیس کے نام کا پہلا خط 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ਤਿਮੋਥਿਉਸ ਨੂੰ ਪਹਿਲੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ତୀମଥିଙ୍କ ପ୍ରତି ପ୍ରଥମ ପତ୍ର 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а. послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а. послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timatʰtʰala pahile patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timatʰtʰalā pahile patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timatʰtʰāla pahile patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timatʰtʰālā pahile patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("tīmatʰtʰala pahile patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("tīmatʰtʰalā pahile patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("tīmatʰtʰāla pahile patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("tīmatʰtʰālā pahile patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Epistula I ad Timotheum 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Epistula ad Timotheum I 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prima lettera a Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prva Timoteju Poslanica 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prva poslanica Timoteju 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timotʰilai pahilo patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timotʰilaī pahilo patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timotʰilāi pahilo patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timotʰilāī pahilo patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timotʰīlai pahilo patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timotʰīlaī pahilo patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timotʰīlāi pahilo patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("timotʰīlāī pahilo patra 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Прва посланица Тимотеју 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше. послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Kirje Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Forsta Timotheosbrevet 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Första Timotheosbrevet 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Kirje Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перша послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перше послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Kirje Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а. послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. List do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteju Poslanica 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. посланица Тимотеју 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Forsta Timoteusbrevet 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Första Timoteusbrevet 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Kirje Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I послання до Тимотея 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I послання до Тимофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. List do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteju Poslanica 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. посланица Тимотеју 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prva kniha Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvá kniha Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 List do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteju Poslanica 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 посланица Тимотеју 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra Timoteusarbref 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra Timoteusarbréf 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra Timóteusarbref 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra Timóteusarbréf 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra Tímoteusarbref 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra Tímoteusarbréf 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra Tímóteusarbref 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Fyrra Tímóteusarbréf 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Første Timotheusbrev 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I List do Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteju Poslanica 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I посланица Тимотеју 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prva kniha Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvni list Timeteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvni list Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("První list Timeteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("První list Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvy list Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvá kniha Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvý list Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("הראשונה אל טימותיאוס 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("तिमोथीलाई पहिलो पत्र 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("तीमथ्थाला पहिले पत्र 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Første Timoteusbrev 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsza Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsze Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwszy Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvy list Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvý list Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("הראשונה אל טימותיוס 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotheosbrevet 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I послання Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premieres Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premieres Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premières Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premières Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotheosbrevet 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteusbrevet 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. list Timeteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. list Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. list Timeteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. list Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premiere Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premiere Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premiers Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premiers Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Première Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Première Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Unang Kay Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteusbrevet 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotteyuvukku 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timottēyuvukku 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timōtteyuvukku 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timōttēyuvukku 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tīmotteyuvukku 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tīmottēyuvukku 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tīmōtteyuvukku 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tīmōttēyuvukku 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 list Timeteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 list Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Teemuathaiyus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteuskirje 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotheusbrev 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Eerste Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Eerste Timotheüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Timoteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Timoteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Timóteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Timóteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Első Timoteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Első Timoteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Első Timóteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Első Timóteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I list Timeteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I list Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteuskirje 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premier Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premier Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Primeira Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Primeira Timóteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Primeiro Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Primeiro Timóteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timoteyos Kowaad 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Προς Τιμοθεον Α' 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Προς Τιμοθεον Αʹ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Προς Τιμοθεον Αʹ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Προς Τιμοθεον Α΄ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Προς Τιμοθεον Α’ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Προς Τιμόθεον Α' 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Προς Τιμόθεον Αʹ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Προς Τιμόθεον Αʹ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Προς Τιμόθεον Α΄ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Προς Τιμόθεον Α’ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("اوّل تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("اوّل-تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Teemuathaiyus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteuskirje 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotheusbrev 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 k. Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Kang Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteusbrev 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Eerste Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Eerste Timoteüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Timotheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Timótheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Első Timotheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Első Timótheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Erste Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Første Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteukselle 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteuskirje 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Kwanza Timotheo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Primero Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prva Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvni Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("První Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvy Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvá Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvý Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Una Kay Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("تيموثاوس الأولى 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("티모테오에게 보낸 첫째 서간 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Kang Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteusbrev 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 k Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 k. Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ਤਿਮੋਥਿਉਸ ਨੂੰ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. к Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше. Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-я. к Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Kay Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timóteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timóteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1.-تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ere. Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ere. Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ère. Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ère. Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Kay Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timóteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timóteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Primer Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prva Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvni Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("První Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvy Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvá Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvý Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ad Timotheum I 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перша Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перше Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("اوّل تیمِتھُیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ପ୍ରଥମ ତୀମଥିଙ୍କ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Kay Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timóteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timóteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 e. Timoteut 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 i. Timoteut 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 k Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timatʰtʰala 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timatʰtʰalā 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timatʰtʰāla 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timatʰtʰālā 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 tīmatʰtʰala 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 tīmatʰtʰalā 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 tīmatʰtʰāla 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 tīmatʰtʰālā 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а. Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е к Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше. Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше. Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше. Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-я к Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timótheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. timotʰilai 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. timotʰilaī 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. timotʰilāi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. timotʰilāī 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. timotʰīlai 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. timotʰīlaī 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. timotʰīlāi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. timotʰīlāī 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. तीमुाथैयुस 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e. Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e. Timotheüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1er. Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1er. Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ere Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ere Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1re. Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1re. Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ère Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ère Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1е. к Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1я. к Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Timóteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Első Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Első Timóteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Kay Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timóteushoz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timóteusnak 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timótheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Premye Timote 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prima Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Primo Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prva Timoteju 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Unang Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перша Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перша Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перша Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перше Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перше Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Перше Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Прва Тимотеју 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Първа Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Първа Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("۱ تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("۱-تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ﺍﻻﻭﻝ ﺗﻴﻤﻮﺛﺎﻭﺱ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timótheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 e Timoteut 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 i Timoteut 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timotʰilai 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timotʰilaī 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timotʰilāi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timotʰilāī 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timotʰīlai 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timotʰīlaī 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timotʰīlāi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timotʰīlāī 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तीमुाथैयुस 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 திமொத்தேயு 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 தீமோத்தேயு 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а. Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а. Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а. Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. Тиметею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е. Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ше Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-я. Тиметею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-я. Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Ti-mô-thê 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteyos 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotheum 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotheüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. к Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. تیمِتھُیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. तिमुथियुस 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. तिमोथीलाई 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. तीमुथियुस 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1.o. Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1.º. Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e Timotheüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e. Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e. Timoteüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1er Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1er Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1re Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1re Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1е к Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1я к Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotejovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timótheosz 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Tymoteusza 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Ti-mô-thê 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteyos 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotheum 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotheüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsza Tym 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwsze Tym 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Pierwszy Tym 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Прва Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Прво Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("اوّل۔تیمتھیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Ti-mô-thê 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteyos 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotheum 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotheüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 timotʰius 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 к Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 تیمِتھُیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तिमुथियुस 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तिमोथीलाई 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तीमथ्थाला 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तीमथ्याला 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तीमुथियुस 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-а Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е Тиметею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-е Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-я Тиметею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-я Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteju 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteut 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotheo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotius 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timóteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Тимотеју 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ତୀମଥିଙ୍କ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1.o Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1.º Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1a. Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1a. Timóteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e Timoteüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1o. Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1o. Timóteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1°. Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1º. Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1е. Тиметею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1е. Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1я. Тиметею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1я. Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Ti-mô-thê 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteovi 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteyos 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotheum 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotheus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotheüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteju 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotheo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotius 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timóteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Тимотеју 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timotheum I 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Una Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("۱ تیمِتھُیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteju 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteut 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotheo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotius 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timóteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Тимотеју 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ତୀମଥିଙ୍କ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timotei 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timóteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timôthê 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Тиметею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1.۔تیمتھیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1a Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1a Timóteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1o Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1o Timóteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1° Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1º Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1е Тиметею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1е Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1я Тиметею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1я Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Eerste Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Første Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Thimothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteju 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteüs 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timothee 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotheo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timothée 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotius 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timóteus 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Ти­мофія 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Тимотеју 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timotei 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timóteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timôthê 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Kwanza Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timotheo I 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α' Τιμοθεο 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α' Τιμόθεο 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ Τιμοθεο 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ Τιμόθεο 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ Τιμοθεο 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ Τιμόθεο 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α΄ Τιμοθεο 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α΄ Τιμόθεο 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α’ Τιμοθεο 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α’ Τιμόθεο 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("テモテヘの第一の手紙 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timotei 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timóteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timôthê 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Тиметею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Тимофею 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timote 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. तिमोथी 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ทิโมธี 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1۔تیمتھیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Thimoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timotei 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timóteo 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timôthê 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Tomothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Тимотеи 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Тимотей 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Тимотеј 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Тимофію 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timote 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvni Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("První Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Първа Тим 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("۱۔تیمتھیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timote 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तिमोथी 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 தீமோத் 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ทิโมธี 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Elso Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Első Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("First Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timote 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Timoty 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Prvni Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("První Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("テモテへの前の書 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("テモテへの手紙一 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e. Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st. Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timothy 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《弟茂德前書》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提摩太前书》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提摩太前書》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 திமொ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Tym 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Tím 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Тим 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. तीम 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1e Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1st Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Tym 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Tím 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Тим 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Timoth 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α' Τιμ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ Τιμ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ Τιμ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α΄ Τιμ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α’ Τιμ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《弟茂德前書 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提摩太前书 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提摩太前書 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提摩斐前》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("弟茂德前書》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提摩太前书》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提摩太前書》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("티모테오1서 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tym 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tím 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Тим 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 طيم 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तीम 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Tym 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Tím 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Тим 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α' Τι 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ Τι 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ Τι 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α΄ Τι 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α’ Τι 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提摩斐前 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("テモテ 1 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("テモテ前書 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("弟茂德前書 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提摩太前书 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提摩太前書 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提摩斐前》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("디모데1서 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ทธ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1Tim 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Ti 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I Tm 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提前》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("一テモテ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提摩斐前 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1티모 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提前 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提前》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提前 1:1").osis()).toEqual("1Tim.1.1")
		p.include_apocrypha(false)
		expect(p.parse("1-ШЕ. ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЕРША ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЕРШЕ ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-А. ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е. ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ШЕ ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ШЕ. ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЕРША ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЕРШЕ ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-А ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-А. ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е. ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ШЕ ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-А ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PERSE POSLANNJA APOSTOLA PAVLA DO TYMOFIJA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PERŠE POSLANNJA APOSTOLA PAVLA DO TYMOFIJA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЪРВО ПОСЛАНИЕ НА СВ. АП. ПАВЛА ДО ТИМОТЕЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTTEYUVUKKU ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTTEYUVUKKU ELUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTTEYUVUKKU EḺUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTTEYUVUKKU EḺUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTTĒYUVUKKU ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTTĒYUVUKKU ELUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTTĒYUVUKKU EḺUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTTĒYUVUKKU EḺUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMŌTTEYUVUKKU ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMŌTTEYUVUKKU ELUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMŌTTEYUVUKKU EḺUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMŌTTEYUVUKKU EḺUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMŌTTĒYUVUKKU ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMŌTTĒYUVUKKU ELUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMŌTTĒYUVUKKU EḺUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMŌTTĒYUVUKKU EḺUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TĪMOTTEYUVUKKU ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TĪMOTTEYUVUKKU ELUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TĪMOTTEYUVUKKU EḺUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TĪMOTTEYUVUKKU EḺUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TĪMOTTĒYUVUKKU ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TĪMOTTĒYUVUKKU ELUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TĪMOTTĒYUVUKKU EḺUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TĪMOTTĒYUVUKKU EḺUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TĪMŌTTEYUVUKKU ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TĪMŌTTEYUVUKKU ELUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TĪMŌTTEYUVUKKU EḺUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TĪMŌTTEYUVUKKU EḺUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TĪMŌTTĒYUVUKKU ELUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TĪMŌTTĒYUVUKKU ELUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TĪMŌTTĒYUVUKKU EḺUTIYA MUTALAVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TĪMŌTTĒYUVUKKU EḺUTIYA MUTALĀVATU NIRUPAM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЪРВО ПОСЛАНИЕ НА СВ АП. ПАВЛА ДО ТИМОТЕЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЪРВО ПОСЛАНИЕ НА СВ. АП ПАВЛА ДО ТИМОТЕЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ШЕ. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЕРША ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЕРШЕ ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЪРВО ПОСЛАНИЕ НА СВ АП ПАВЛА ДО ТИМОТЕЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("تِیمُتھِیُس کے نام پولُس رسول کا پہلا خط 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("தீமோத்தேயுவுக்கு எழுதிய முதலாவது நிருபம் 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-А. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ШЕ ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("திமொத்தேயுவுக்கு எழுதிய முதல் திருமுகம் 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("திமோத்தேயுவுக்கு எழுதிய முதல் திருமுகம் 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-А ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПРВА ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ТИМОТЕЈ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПРВО ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ТИМОТЕЈ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("தீமோத்தேயுவுக்கு எழுதிய முதலாம் கடிதம் 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZA LIST SW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZA LIST ŚW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZE LIST SW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZE LIST ŚW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZY LIST SW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZY LIST ŚW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("رسالة بولس الرسول الأولى إلى تيموثاوس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ТИМОТЕЈ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ТИМОТЕЈ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZA LIST SW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZA LIST ŚW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZE LIST SW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZE LIST ŚW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZY LIST SW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZY LIST ŚW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ТИМОТЕЈ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ТИМОТЕЈ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PAULUS' FØRSTE BREV TIL TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PAULUS’ FØRSTE BREV TIL TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PAULUS’ FØRSTE BREV TIL TIMOTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. LIST SW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. LIST ŚW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ENSIMMAINEN KIRJE TIMOTEUKSELLE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ENSIMMÄINEN KIRJE TIMOTEUKSELLE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. LIST SW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. LIST ŚW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PAVLOVA PRVA POSLANICA TIMOTEJU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 LIST SW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 LIST ŚW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. LIST SW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. LIST ŚW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BREF PALS TIL TIMOTEUSAR 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BREF PALS TIL TIMÓTEUSAR 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BREF PALS TIL TÍMOTEUSAR 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BREF PALS TIL TÍMÓTEUSAR 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BREF PÁLS TIL TIMOTEUSAR 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BREF PÁLS TIL TIMÓTEUSAR 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BREF PÁLS TIL TÍMOTEUSAR 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BREF PÁLS TIL TÍMÓTEUSAR 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BRÉF PALS TIL TIMOTEUSAR 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BRÉF PALS TIL TIMÓTEUSAR 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BRÉF PALS TIL TÍMOTEUSAR 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BRÉF PALS TIL TÍMÓTEUSAR 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BRÉF PÁLS TIL TIMOTEUSAR 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BRÉF PÁLS TIL TIMÓTEUSAR 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BRÉF PÁLS TIL TÍMOTEUSAR 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BRÉF PÁLS TIL TÍMÓTEUSAR 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I LIST SW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I LIST ŚW. PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. LIST SW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. LIST ŚW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TĪMUTʰIYUS KE NĀM KĀ PAHLĀ ḪAṬ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 LIST SW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 LIST ŚW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I LIST SW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I LIST ŚW PAWŁA DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PAULUS' 1. BREV TIL TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PAULUS’ 1. BREV TIL TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("WARAKA WA KWANZA KWA TIMOTHEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("تِیمُتھِیُس کے نام کا پہلا خط 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("तिमोथीलाईर् पावलको पहिलो पत्र 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("BARUA YA KWANZA KWA TIMOTHEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PAULUS' 1 BREV TIL TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PAULUS’ 1 BREV TIL TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZA LIST DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZE LIST DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZY LIST DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTʰIUS NŪ̃ PAHILĪ PATTRĪ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("אגרת פולוס הראשונה אל-טימות 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("الرسالة الأولى إلى تيموثاوس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("पौलाचे तीमथ्याला पहिले पत्र 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЪРВО ПОСЛАНИЕ КЪМ ТИМОТЕИ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЪРВО ПОСЛАНИЕ КЪМ ТИМОТЕЙ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("האיגרת הראשונה אל טימותיוס 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ШЕ. ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ШЕ. ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ENSIMMAINEN TIMOTEUKSELLE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ENSIMMAINEN TIMOTEUSKIRJE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ENSIMMÄINEN TIMOTEUKSELLE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ENSIMMÄINEN TIMOTEUSKIRJE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BREF PALS TIL TIMOT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BREF PALS TIL TIMÓT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BREF PALS TIL TÍMOT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BREF PALS TIL TÍMÓT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BREF PÁLS TIL TIMOT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BREF PÁLS TIL TIMÓT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BREF PÁLS TIL TÍMOT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BREF PÁLS TIL TÍMÓT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BRÉF PALS TIL TIMOT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BRÉF PALS TIL TIMÓT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BRÉF PALS TIL TÍMOT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BRÉF PALS TIL TÍMÓT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BRÉF PÁLS TIL TIMOT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BRÉF PÁLS TIL TIMÓT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BRÉF PÁLS TIL TÍMOT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA BRÉF PÁLS TIL TÍMÓT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЕРША ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЕРША ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЕРШЕ ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЕРШЕ ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("تیمتھیس کے نام کا پہلا خط 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ਤਿਮੋਥਿਉਸ ਨੂੰ ਪਹਿਲੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ତୀମଥିଙ୍କ ପ୍ରତି ପ୍ରଥମ ପତ୍ର 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-А. ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-А. ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е. ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е. ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ШЕ ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ШЕ ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMATʰTʰALA PAHILE PATRA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMATʰTʰALĀ PAHILE PATRA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMATʰTʰĀLA PAHILE PATRA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMATʰTʰĀLĀ PAHILE PATRA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TĪMATʰTʰALA PAHILE PATRA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TĪMATʰTʰALĀ PAHILE PATRA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TĪMATʰTʰĀLA PAHILE PATRA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TĪMATʰTʰĀLĀ PAHILE PATRA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-А ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-А ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("EPISTULA I AD TIMOTHEUM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("EPISTULA AD TIMOTHEUM I 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRIMA LETTERA A TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVA TIMOTEJU POSLANICA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVA POSLANICA TIMOTEJU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTʰILAI PAHILO PATRA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTʰILAĪ PAHILO PATRA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTʰILĀI PAHILO PATRA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTʰILĀĪ PAHILO PATRA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTʰĪLAI PAHILO PATRA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTʰĪLAĪ PAHILO PATRA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTʰĪLĀI PAHILO PATRA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTʰĪLĀĪ PAHILO PATRA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПРВА ПОСЛАНИЦА ТИМОТЕЈУ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ШЕ. ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. KIRJE TIMOTEUKSELLE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FORSTA TIMOTHEOSBREVET 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FÖRSTA TIMOTHEOSBREVET 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. KIRJE TIMOTEUKSELLE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЕРША ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЕРШЕ ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 KIRJE TIMOTEUKSELLE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-А. ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е. ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ШЕ ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. LIST DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEJU POSLANICA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ПОСЛАНИЦА ТИМОТЕЈУ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FORSTA TIMOTEUSBREVET 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FÖRSTA TIMOTEUSBREVET 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I KIRJE TIMOTEUKSELLE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I ПОСЛАННЯ ДО ТИМОТЕЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I ПОСЛАННЯ ДО ТИМОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. LIST DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEJU POSLANICA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. ПОСЛАНИЦА ТИМОТЕЈУ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVA KNIHA TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVÁ KNIHA TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 LIST DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEJU POSLANICA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ПОСЛАНИЦА ТИМОТЕЈУ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-А ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA TIMOTEUSARBREF 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA TIMOTEUSARBRÉF 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA TIMÓTEUSARBREF 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA TIMÓTEUSARBRÉF 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA TÍMOTEUSARBREF 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA TÍMOTEUSARBRÉF 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA TÍMÓTEUSARBREF 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FYRRA TÍMÓTEUSARBRÉF 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FØRSTE TIMOTHEUSBREV 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I LIST DO TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEJU POSLANICA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I ПОСЛАНИЦА ТИМОТЕЈУ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVA KNIHA TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVNI LIST TIMETEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVNI LIST TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVNÍ LIST TIMETEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVNÍ LIST TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVY LIST TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVÁ KNIHA TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVÝ LIST TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("הראשונה אל טימותיאוס 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("तिमोथीलाई पहिलो पत्र 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("तीमथ्थाला पहिले पत्र 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FØRSTE TIMOTEUSBREV 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZA TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZE TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZY TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVY LIST TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVÝ LIST TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("הראשונה אל טימותיוס 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTHEOSBREVET 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I ПОСЛАННЯ ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PREMIERES TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PREMIERES TIMOTHÉE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PREMIÈRES TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PREMIÈRES TIMOTHÉE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTHEOSBREVET 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEUSBREVET 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. LIST TIMETEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. LIST TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. LIST TIMETEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. LIST TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PREMIERE TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PREMIERE TIMOTHÉE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PREMIERS TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PREMIERS TIMOTHÉE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PREMIÈRE TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PREMIÈRE TIMOTHÉE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("UNANG KAY TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEUSBREVET 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTTEYUVUKKU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTTĒYUVUKKU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMŌTTEYUVUKKU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMŌTTĒYUVUKKU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TĪMOTTEYUVUKKU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TĪMOTTĒYUVUKKU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TĪMŌTTEYUVUKKU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TĪMŌTTĒYUVUKKU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 LIST TIMETEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 LIST TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TEEMUATHAIYUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEUKSELLE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEUSKIRJE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTHEUSBREV 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("EERSTE TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("EERSTE TIMOTHEÜS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSO TIMOTEUSHOZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSO TIMOTEUSNAK 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSO TIMÓTEUSHOZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSO TIMÓTEUSNAK 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSŐ TIMOTEUSHOZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSŐ TIMOTEUSNAK 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSŐ TIMÓTEUSHOZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSŐ TIMÓTEUSNAK 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I LIST TIMETEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I LIST TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEUKSELLE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEUSKIRJE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PREMIER TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PREMIER TIMOTHÉE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRIMEIRA TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRIMEIRA TIMÓTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRIMEIRO TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRIMEIRO TIMÓTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTEYOS KOWAAD 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ΠΡΟΣ ΤΙΜΟΘΕΟΝ Α' 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ΠΡΟΣ ΤΙΜΟΘΕΟΝ Αʹ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ΠΡΟΣ ΤΙΜΟΘΕΟΝ Αʹ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ΠΡΟΣ ΤΙΜΟΘΕΟΝ Α΄ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ΠΡΟΣ ΤΙΜΟΘΕΟΝ Α’ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ΠΡΟΣ ΤΙΜΌΘΕΟΝ Α' 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ΠΡΟΣ ΤΙΜΌΘΕΟΝ Αʹ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ΠΡΟΣ ΤΙΜΌΘΕΟΝ Αʹ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ΠΡΟΣ ΤΙΜΌΘΕΟΝ Α΄ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ΠΡΟΣ ΤΙΜΌΘΕΟΝ Α’ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("اوّل تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("اوّل-تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TEEMUATHAIYUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEUKSELLE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEUSKIRJE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTHEUSBREV 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 K. TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. KANG TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEUSBREV 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("EERSTE TIMOTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("EERSTE TIMOTEÜS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSO TIMOTHEOSZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSO TIMÓTHEOSZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSŐ TIMOTHEOSZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSŐ TIMÓTHEOSZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ERSTE TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FØRSTE TIMOTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEUKSELLE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEUSKIRJE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("KWANZA TIMOTHEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRIMERO TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVA TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVNI TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVNÍ TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVY TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVÁ TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVÝ TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("UNA KAY TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("تيموثاوس الأولى 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("티모테오에게 보낸 첫째 서간 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 KANG TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEUSBREV 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 K TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 K. TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ਤਿਮੋਥਿਉਸ ਨੂੰ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е. К ТИМОФЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ШЕ. ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Я. К ТИМОФЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. KAY TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEUSHOZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEUSNAK 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMÓTEUSHOZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMÓTEUSNAK 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1.-تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ERE. TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ERE. TIMOTHÉE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ÈRE. TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ÈRE. TIMOTHÉE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST THIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. KAY TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEUSHOZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEUSNAK 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMÓTEUSHOZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMÓTEUSNAK 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRIMER TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVA TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVNI TIMOTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVNÍ TIMOTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVY TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVÁ TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVÝ TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("AD TIMOTHEUM I 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЕРША ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЕРШЕ ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("اوّل تیمِتھُیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ପ୍ରଥମ ତୀମଥିଙ୍କ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 KAY TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEUSHOZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEUSNAK 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMÓTEUSHOZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMÓTEUSNAK 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 E. TIMOTEUT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 I. TIMOTEUT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 K TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMATʰTʰALA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMATʰTʰALĀ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMATʰTʰĀLA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMATʰTʰĀLĀ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TĪMATʰTʰALA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TĪMATʰTʰALĀ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TĪMATʰTʰĀLA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TĪMATʰTʰĀLĀ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-А. ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е К ТИМОФЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е. ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ШЕ ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ШЕ. ТИМОТЕИ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ШЕ. ТИМОТЕЙ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ШЕ. ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Я К ТИМОФЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTHEOSZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMÓTHEOSZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTʰILAI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTʰILAĪ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTʰILĀI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTʰILĀĪ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTʰĪLAI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTʰĪLAĪ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTʰĪLĀI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTʰĪLĀĪ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. तीमुाथैयुस 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1E. TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1E. TIMOTHEÜS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ER. TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ER. TIMOTHÉE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ERE TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ERE TIMOTHÉE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1RE. TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1RE. TIMOTHÉE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. THIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ÈRE TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ÈRE TIMOTHÉE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1Е. К ТИМОФЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1Я. К ТИМОФЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSO TIMOTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSO TIMÓTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSŐ TIMOTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSŐ TIMÓTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST THIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST TOMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I KAY TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEUSHOZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEUSNAK 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMÓTEUSHOZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMÓTEUSNAK 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTHEOSZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMÓTHEOSZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PREMYE TIMOTE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRIMA TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRIMO TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVA TIMOTEJU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("UNANG TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЕРША ТИМОТЕИ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЕРША ТИМОТЕЙ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЕРША ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЕРШЕ ТИМОТЕИ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЕРШЕ ТИМОТЕЙ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЕРШЕ ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПРВА ТИМОТЕЈУ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЪРВА ТИМОТЕИ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЪРВА ТИМОТЕЙ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("۱ تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("۱-تِیمُتھِیُس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ﺍﻻﻭﻝ ﺗﻴﻤﻮﺛﺎﻭﺱ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTHEOSZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMÓTHEOSZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 E TIMOTEUT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 I TIMOTEUT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTʰILAI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTʰILAĪ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTʰILĀI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTʰILĀĪ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTʰĪLAI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTʰĪLAĪ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTʰĪLĀI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTʰĪLĀĪ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तीमुाथैयुस 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 திமொத்தேயு 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 தீமோத்தேயு 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-А ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-А. ТИМОТЕИ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-А. ТИМОТЕЙ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-А. ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е. ТИМЕТЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е. ТИМОТЕИ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е. ТИМОТЕЙ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е. ТИМОФЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е. ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ШЕ ТИМОТЕИ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ШЕ ТИМОТЕЙ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-ШЕ ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Я. ТИМЕТЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Я. ТИМОФЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TI-MÔ-THÊ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEYOS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTHEUM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTHEÜS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. К ТИМОФЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. تیمِتھُیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. तिमुथियुस 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. तिमोथीलाई 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. तीमुथियुस 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1.O. TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1.º. TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1E TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1E TIMOTHEÜS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1E. TIMOTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1E. TIMOTEÜS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ER TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ER TIMOTHÉE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1RE TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1RE TIMOTHÉE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST THIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. THIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. TOMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1Е К ТИМОФЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1Я К ТИМОФЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST TIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEJOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTHEOSZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMÓTHEOSZ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TYMOTEUSZA 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TI-MÔ-THÊ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEYOS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTHEUM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTHEÜS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZA TYM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZE TYM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PIERWSZY TYM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПРВА ТИМОТЕЈ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПРВО ТИМОТЕЈ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("اوّل۔تیمتھیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TI-MÔ-THÊ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEYOS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTHEUM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTHEÜS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTʰIUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 К ТИМОФЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 تیمِتھُیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तिमुथियुस 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तिमोथीलाई 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तीमथ्थाला 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तीमथ्याला 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तीमुथियुस 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-А ТИМОТЕИ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-А ТИМОТЕЙ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-А ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е ТИМЕТЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е ТИМОТЕИ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е ТИМОТЕЙ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е ТИМОФЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Е ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Я ТИМЕТЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1-Я ТИМОФЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. THIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEJU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEUT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEÜS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTHEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTHÉE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTIUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMÓTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ТИМОТЕЈУ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ତୀମଥିଙ୍କ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1.O TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1.º TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1A. TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1A. TIMÓTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1E TIMOTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1E TIMOTEÜS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1O. TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1O. TIMÓTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST THIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST TOMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. TIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1°. TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1º. TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1Е. ТИМЕТЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1Е. ТИМОФЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1Я. ТИМЕТЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1Я. ТИМОФЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TI-MÔ-THÊ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEOVI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEYOS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTHEUM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTHEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTHEÜS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. THIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEJU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEÜS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTHEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTHÉE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTIUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMÓTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. ТИМОТЕЈУ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTHEUM I 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("UNA TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("۱ تیمِتھُیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 THIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEJU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEUT 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEÜS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTHEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTHÉE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTIUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMÓTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ТИМОТЕЈУ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ତୀମଥିଙ୍କ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. THIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMÓTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMÔTHÊ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TOMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ТИМЕТЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ТИМОТЕИ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ТИМОТЕЙ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ТИМОТЕЈ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ТИМОФЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1.۔تیمتھیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1A TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1A TIMÓTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1O TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1O TIMÓTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST TIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1° TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1º TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1Е ТИМЕТЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1Е ТИМОФЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1Я ТИМЕТЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1Я ТИМОФЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("EERSTE TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FØRSTE TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I THIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEJU 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEÜS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTHEE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTHEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTHÉE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTIUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMÓTEUS 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I ТИ­МОФІЯ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I ТИМОТЕЈУ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. THIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMÓTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMÔTHÊ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TOMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. ТИМОТЕИ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. ТИМОТЕЙ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. ТИМОТЕЈ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("KWANZA TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTHEO I 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α' ΤΙΜΟΘΕΟ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α' ΤΙΜΌΘΕΟ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ ΤΙΜΟΘΕΟ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ ΤΙΜΌΘΕΟ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ ΤΙΜΟΘΕΟ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ ΤΙΜΌΘΕΟ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α΄ ΤΙΜΟΘΕΟ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α΄ ΤΙΜΌΘΕΟ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α’ ΤΙΜΟΘΕΟ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α’ ΤΙΜΌΘΕΟ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("テモテヘの第一の手紙 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 THIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMÓTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMÔTHÊ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TOMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ТИМЕТЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ТИМОТЕИ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ТИМОТЕЙ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ТИМОТЕЈ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ТИМОФЕЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. तिमोथी 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ทิโมธี 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1۔تیمتھیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I THIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMÓTEO 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMÔTHÊ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TOMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I ТИМОТЕИ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I ТИМОТЕЙ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I ТИМОТЕЈ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I ТИМОФІЮ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVNI TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVNÍ TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ПЪРВА ТИМ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("۱۔تیمتھیس 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तिमोथी 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 தீமோத் 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ทิโมธี 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSO TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("ELSŐ TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST TI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("FIRST TM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTE 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIMOTY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVNI TM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("PRVNÍ TM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("テモテへの前の書 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("テモテへの手紙一 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1E. TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. TI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST. TM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTHY 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《弟茂德前書》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提摩太前书》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提摩太前書》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 திமொ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TYM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TÍM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. ТИМ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. तीम 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1E TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST TI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1ST TM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TYM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TÍM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. ТИМ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("TIMOTH 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α' ΤΙΜ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ ΤΙΜ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ ΤΙΜ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α΄ ΤΙΜ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α’ ΤΙΜ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《弟茂德前書 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提摩太前书 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提摩太前書 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提摩斐前》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("弟茂德前書》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提摩太前书》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提摩太前書》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("티모테오1서 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TYM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TÍM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ТИМ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 طيم 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 तीम 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1. TM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TYM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TÍM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I ТИМ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I. TM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α' ΤΙ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ ΤΙ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Αʹ ΤΙ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α΄ ΤΙ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("Α’ ΤΙ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提摩斐前 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("テモテ 1 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("テモテ前書 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("弟茂德前書 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提摩太前书 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提摩太前書 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提摩斐前》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("디모데1서 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 TM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1 ทธ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1TIM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TI 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("I TM 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提前》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("一テモテ 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提摩斐前 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("1티모 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("《提前 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提前》 1:1").osis()).toEqual("1Tim.1.1")
		expect(p.parse("提前 1:1").osis()).toEqual("1Tim.1.1")
		`
		true
describe "Localized book Deut (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Deut (full)", ->
		`
		expect(p.parse("Ksiega Powtorzonego Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ksiega Powtórzonego Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ksiegi Powtorzonego Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ksiegi Powtórzonego Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Księga Powtorzonego Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Księga Powtórzonego Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Księgi Powtorzonego Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Księgi Powtórzonego Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Kitabu cha Tano cha Musa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Ksiega Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Ksiega Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Ksiegi Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Ksiegi Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Księga Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Księga Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Księgi Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Księgi Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piąta Ksiega Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piąta Ksiega Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piąta Ksiegi Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piąta Ksiegi Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piąta Księga Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piąta Księga Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piąta Księgi Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piąta Księgi Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Sharciga Kunoqoshadiisa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ks. Powtorzonego Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ks. Powtórzonego Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Phục truyền luật lệ ký 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Viides Mooseksen kirja 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ks Powtorzonego Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ks Powtórzonego Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata kniha Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata kniha Mojzišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata kniha Mojžisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata kniha Mojžišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Ksiega Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Ksiega Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Ksiegi Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Ksiegi Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Księga Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Księga Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Księgi Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Księgi Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Kumbukumbu la Sheria 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Kumbukumbu la Torati 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Masodik torvenykonyv 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Masodik torvenykönyv 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Masodik torvénykonyv 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Masodik torvénykönyv 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Masodik törvenykonyv 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Masodik törvenykönyv 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Masodik törvénykonyv 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Masodik törvénykönyv 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Második torvenykonyv 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Második torvenykönyv 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Második torvénykonyv 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Második torvénykönyv 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Második törvenykonyv 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Második törvenykönyv 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Második törvénykonyv 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Második törvénykönyv 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pata kniha Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pata kniha Mojzišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pata kniha Mojzísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pata kniha Mojzíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pata kniha Mojžisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pata kniha Mojžišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pata kniha Mojžísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pata kniha Mojžíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Patá kniha Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Patá kniha Mojzišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Patá kniha Mojzísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Patá kniha Mojzíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Patá kniha Mojžisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Patá kniha Mojžišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Patá kniha Mojžísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Patá kniha Mojžíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Ks. Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Ks. Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piąta Ks. Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piąta Ks. Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Páta kniha Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Páta kniha Mojzišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Páta kniha Mojzísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Páta kniha Mojzíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Páta kniha Mojžisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Páta kniha Mojžišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Páta kniha Mojžísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Páta kniha Mojžíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pátá kniha Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pátá kniha Mojzišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pátá kniha Mojzísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pátá kniha Mojzíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pátá kniha Mojžisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pátá kniha Mojžišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pátá kniha Mojžísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pátá kniha Mojžíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Ksiega Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Ksiega Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Ksiegi Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Ksiegi Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Księga Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Księga Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Księgi Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Księgi Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("П'ята книга Моисеева 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("П'ята книга Мойсеева 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Петта книга Мојсеева 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("П’ята книга Моисеева 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("П’ята книга Мойсеева 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Ksiega Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Ksiega Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Ksiegi Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Ksiegi Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Księga Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Księga Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Księgi Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Księgi Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Mozes otodik konyve 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Mozes otodik könyve 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Mozes otödik konyve 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Mozes otödik könyve 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Mozes ötodik konyve 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Mozes ötodik könyve 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Mozes ötödik konyve 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Mozes ötödik könyve 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Mózes otodik konyve 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Mózes otodik könyve 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Mózes otödik konyve 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Mózes otödik könyve 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Mózes ötodik konyve 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Mózes ötodik könyve 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Mózes ötödik konyve 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Mózes ötödik könyve 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pangandharing Toret 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Phục Truyền Luật Lệ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Ks Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Ks Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piąta Ks Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piąta Ks Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Ksiega Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Ksiega Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Ksiegi Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Ksiegi Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Księga Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Księga Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Księgi Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Księgi Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Пета книга Моисеева 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mooseksen kirja 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. kniha Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. kniha Mojzišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. kniha Mojzísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. kniha Mojzíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. kniha Mojžisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. kniha Mojžišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. kniha Mojžísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. kniha Mojžíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Dezyem liv Lalwa a 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Dezyèm liv Lalwa a 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Liber Deuteronomii 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Povtorennja Zakonu 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mooseksen kirja 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. kniha Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. kniha Mojzišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. kniha Mojzísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. kniha Mojzíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. kniha Mojžisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. kniha Mojžišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. kniha Mojžísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. kniha Mojžíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("vyavastʰako pustak 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("vyavastʰāko pustak 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mooseksen kirja 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 kniha Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 kniha Mojzišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 kniha Mojzísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 kniha Mojzíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 kniha Mojžisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 kniha Mojžišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 kniha Mojžísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 kniha Mojžíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Ks. Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Ks. Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Andharaning Toret 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Andharaning Torèt 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ksiega Powt Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ksiegi Powt Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Księga Powt Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Księgi Powt Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ligji i Perterire 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ligji i Perterirë 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ligji i Pertërire 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ligji i Pertërirë 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ligji i Përterire 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ligji i Përterirë 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ligji i Përtërire 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ligji i Përtërirë 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ligji i përtërirë 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mooseksen kirja 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V kniha Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V kniha Mojzišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V kniha Mojzísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V kniha Mojzíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V kniha Mojžisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V kniha Mojžišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V kniha Mojžísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V kniha Mojžíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Ks. Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Ks. Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Vyavasthaavivaran 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Повторення Закону 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("व्यवस्थाको पुस्तक 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("เฉลย​ธรรม​บัญญัติ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Ks. Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Ks. Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Ks Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Ks Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Funfte Buch Mose 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Fünfte Buch Mose 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piąta Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piąta Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ponovljeni zakon 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Ks. Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Ks. Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Ks Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Ks Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Viides Mooseksen 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Повторени закони 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Поновљени закони 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Ks Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Ks Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Femte Moseboken 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Fimmta bok Mose 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Fimmta bok Móse 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Fimmta bók Mose 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Fimmta bók Móse 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Mojzišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Mojžisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Mojžišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Ks Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Ks Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("เฉลยธรรมบัญญัติ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 k. Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 k. Mojzišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 k. Mojžisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 k. Mojžišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Fimmta Mosebok 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Fimmta Mosebók 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Fimmta Mósebok 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Fimmta Mósebók 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ks. Powt Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pata Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pata Mojzišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pata Mojzísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pata Mojzíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pata Mojžisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pata Mojžišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pata Mojžísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pata Mojžíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Patá Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Patá Mojzišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Patá Mojzísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Patá Mojzíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Patá Mojžisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Patá Mojžišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Patá Mojžísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Patá Mojžíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Páta Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Páta Mojzišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Páta Mojzísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Páta Mojzíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Páta Mojžisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Páta Mojžišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Páta Mojžísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Páta Mojžíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pátá Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pátá Mojzišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pátá Mojzísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pátá Mojzíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pátá Mojžisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pátá Mojžišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pátá Mojžísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pátá Mojžíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Пета Мојсијева 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("تثنية الإشتراع 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("व्यवस्था विवरण 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("व्य्वस्थाविवरन 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ବିବରଣୀ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 k Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 k Mojzišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 k Mojžisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 k Mojžišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronomium 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronomiya 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronomiyo 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronómium 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deyuteronomyo 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Diyuteronomyo 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Femte Mosebog 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Femte Mosebok 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Ks Powt Prawa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Δευτερονομιον 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Δευτερονόμιον 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("व्यवस्थाविवरण 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ବିବରଣ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Buch Mose 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mojzišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mojzísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mojzíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mojžisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mojžišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mojžísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mojžíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mooseksen 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Moseboken 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Мојсијева 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronomia 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronomio 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronomul 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronomya 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronómio 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronômio 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deutoronomio 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Dueteronomio 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Dyuteronomyo 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mojzeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mojżeszowa 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mojzišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mojzísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mojzíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mojžisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mojžišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mojžísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mojžíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mooseksen 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Мојсијева 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Vijfde Mozes 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("bivastʰā sār 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Δευτερονομιο 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Δευτερονόμιο 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Второзаконие 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Второзаконня 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Повт. Закону 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("இணைச் சட்டம் 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Buch Mose 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mojzišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mojzísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mojzíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mojžisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mojžišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mojžísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mojžíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mooseksen 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Moseboken 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Мојсијева 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deeteronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deetoronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronmio 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronoma 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronome 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronomi 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deutoronmio 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deutoronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deutronomio 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deutéronome 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Dueteronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duetoronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duuteronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duutoronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Funfte Mose 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Fünfte Mose 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Phục Truyền 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mojzisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mojzišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mojzísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mojzíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mojžisova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mojžišova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mojžísova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mojžíšova 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mooseksen 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Мојсијева 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("vyavastʰako 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("vyavastʰāko 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Đệ nhị luật 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Повт Закону 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("سفر التثنية 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Моисеева 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mosebog 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mosebok 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mosebók 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mósebok 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mósebók 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deeteronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deetoronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deetronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deuteronom 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deutoronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deutronmio 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deutronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Dueteronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duetoronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duetronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duuteronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duutoronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duutronomy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Kumbukumbu 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Mojz 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piata Mojż 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piąta Mojz 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Piąta Mojż 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mosebok 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mosebók 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mósebok 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mósebók 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("व्यवस्थाको 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ਬਿਵਸਥਾ ਸਾਰ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mosebog 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mosebok 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mosebók 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mósebok 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mósebók 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deetronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deteronom 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deteronòm 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Detewonom 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Detewonòm 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deutronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duetronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duutronmy 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Femte Mos 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mosebok 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mosebók 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mósebok 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mósebók 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Пета Мојс 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("משנה תורה 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("व्यावस्था 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mozes 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Dewariem 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Upakamam 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Upākamam 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mozes 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("istis̱nā 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Второзак 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("اِستِثنا 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("تَثنِيَة 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("व्यवस्था 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mozes 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mózes 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mojz 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mojż 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mose 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Мојс 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Mozes V 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Mózes V 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mozes 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mojz 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mojż 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Мојс 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("استثناء 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("التثنية 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("உபாகமம் 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mojz 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mojż 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Moos 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mose 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Мојс 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mos 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mós 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Sharci 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mojz 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mojż 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Мојс 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mos 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. Mós 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("anuwad 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("anuwād 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Δευτερ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("استثنا 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("अनुवाद 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ਬਿਵਸਥਾ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ବିବରଣି 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Moj 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mos 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Moz 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mós 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Móz 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. Mo 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MTorv 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MTörv 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Moj 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mos 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V Mós 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("דברים 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("《申命紀》 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("《申命記》 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("《申命记》 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mo 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 Mz 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5Mós 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deut 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Duet 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Kumb 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Phục 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Δευτ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Втор 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Повт 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Понз 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("《申命紀 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("《申命記 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("《申命记 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("申命紀》 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("申命記》 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("申命记》 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 M 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 М 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Det 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Deu 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Dtn 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Kum 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("LiP 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pnz 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Pwt 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("உபா 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ฉธบ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("《申》 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("申命紀 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("申命記 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("申命记 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("신명기 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("De 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Dt 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Δε 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("Вт 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("تث 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("இச 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("《申 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("申》 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("신명 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("申 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("신 1:1").osis()).toEqual("Deut.1.1")
		p.include_apocrypha(false)
		expect(p.parse("KSIEGA POWTORZONEGO PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KSIEGA POWTÓRZONEGO PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KSIEGI POWTORZONEGO PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KSIEGI POWTÓRZONEGO PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KSIĘGA POWTORZONEGO PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KSIĘGA POWTÓRZONEGO PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KSIĘGI POWTORZONEGO PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KSIĘGI POWTÓRZONEGO PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KITABU CHA TANO CHA MUSA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIĄTA KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIĄTA KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIĄTA KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIĄTA KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIĄTA KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIĄTA KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIĄTA KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIĄTA KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("SHARCIGA KUNOQOSHADIISA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KS. POWTORZONEGO PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KS. POWTÓRZONEGO PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PHỤC TRUYỀN LUẬT LỆ KÝ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("VIIDES MOOSEKSEN KIRJA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KS POWTORZONEGO PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KS POWTÓRZONEGO PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA KNIHA MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA KNIHA MOJŽISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KUMBUKUMBU LA SHERIA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KUMBUKUMBU LA TORATI 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MASODIK TORVENYKONYV 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MASODIK TORVENYKÖNYV 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MASODIK TORVÉNYKONYV 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MASODIK TORVÉNYKÖNYV 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MASODIK TÖRVENYKONYV 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MASODIK TÖRVENYKÖNYV 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MASODIK TÖRVÉNYKONYV 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MASODIK TÖRVÉNYKÖNYV 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MÁSODIK TORVENYKONYV 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MÁSODIK TORVENYKÖNYV 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MÁSODIK TORVÉNYKONYV 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MÁSODIK TORVÉNYKÖNYV 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MÁSODIK TÖRVENYKONYV 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MÁSODIK TÖRVENYKÖNYV 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MÁSODIK TÖRVÉNYKONYV 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MÁSODIK TÖRVÉNYKÖNYV 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATA KNIHA MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATA KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATA KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATA KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATA KNIHA MOJŽISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATA KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATA KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATA KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATÁ KNIHA MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATÁ KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATÁ KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATÁ KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATÁ KNIHA MOJŽISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATÁ KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATÁ KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATÁ KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA KS. MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA KS. MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIĄTA KS. MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIĄTA KS. MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTA KNIHA MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTA KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTA KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTA KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTA KNIHA MOJŽISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTA KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTA KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTA KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTÁ KNIHA MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTÁ KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTÁ KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTÁ KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTÁ KNIHA MOJŽISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTÁ KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTÁ KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTÁ KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("П'ЯТА КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("П'ЯТА КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ПЕТТА КНИГА МОЈСЕЕВА 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("П’ЯТА КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("П’ЯТА КНИГА МОЙСЕЕВА 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MOZES OTODIK KONYVE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MOZES OTODIK KÖNYVE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MOZES OTÖDIK KONYVE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MOZES OTÖDIK KÖNYVE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MOZES ÖTODIK KONYVE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MOZES ÖTODIK KÖNYVE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MOZES ÖTÖDIK KONYVE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MOZES ÖTÖDIK KÖNYVE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MÓZES OTODIK KONYVE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MÓZES OTODIK KÖNYVE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MÓZES OTÖDIK KONYVE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MÓZES OTÖDIK KÖNYVE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MÓZES ÖTODIK KONYVE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MÓZES ÖTODIK KÖNYVE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MÓZES ÖTÖDIK KONYVE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MÓZES ÖTÖDIK KÖNYVE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PANGANDHARING TORET 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PHỤC TRUYỀN LUẬT LỆ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA KS MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA KS MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIĄTA KS MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIĄTA KS MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KSIEGA MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KSIEGA MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KSIEGI MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KSIEGI MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KSIĘGA MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KSIĘGA MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KSIĘGI MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KSIĘGI MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ПЕТА КНИГА МОИСЕЕВА 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOOSEKSEN KIRJA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KNIHA MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KNIHA MOJŽISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEZYEM LIV LALWA A 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEZYÈM LIV LALWA A 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("LIBER DEUTERONOMII 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("POVTORENNJA ZAKONU 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOOSEKSEN KIRJA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KNIHA MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KNIHA MOJŽISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("VYAVASTʰAKO PUSTAK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("VYAVASTʰĀKO PUSTAK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOOSEKSEN KIRJA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KNIHA MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KNIHA MOJŽISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KS. MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KS. MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ANDHARANING TORET 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ANDHARANING TORÈT 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KSIEGA POWT PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KSIEGI POWT PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KSIĘGA POWT PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KSIĘGI POWT PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("LIGJI I PERTERIRE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("LIGJI I PERTERIRË 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("LIGJI I PERTËRIRE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("LIGJI I PERTËRIRË 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("LIGJI I PËRTERIRE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("LIGJI I PËRTERIRË 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("LIGJI I PËRTËRIRE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("LIGJI I PËRTËRIRË 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("LIGJI I PËRTËRIRË 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOOSEKSEN KIRJA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KNIHA MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KNIHA MOJZIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KNIHA MOJZÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KNIHA MOJZÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KNIHA MOJŽISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KNIHA MOJŽIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KNIHA MOJŽÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KNIHA MOJŽÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KS. MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KS. MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("VYAVASTHAAVIVARAN 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ПОВТОРЕННЯ ЗАКОНУ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("व्यवस्थाको पुस्तक 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("เฉลย​ธรรม​บัญญัติ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KS. MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KS. MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KS MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. KS MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FUNFTE BUCH MOSE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FÜNFTE BUCH MOSE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIĄTA MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIĄTA MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PONOVLJENI ZAKON 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KS. MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KS. MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KS MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. KS MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("VIIDES MOOSEKSEN 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ПОВТОРЕНИ ЗАКОНИ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ПОНОВЉЕНИ ЗАКОНИ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KS MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 KS MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FEMTE MOSEBOKEN 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FIMMTA BOK MOSE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FIMMTA BOK MÓSE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FIMMTA BÓK MOSE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FIMMTA BÓK MÓSE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA MOJZIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA MOJŽISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA MOJŽIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KS MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V KS MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("เฉลยธรรมบัญญัติ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 K. MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 K. MOJZIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 K. MOJŽISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 K. MOJŽIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FIMMTA MOSEBOK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FIMMTA MOSEBÓK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FIMMTA MÓSEBOK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FIMMTA MÓSEBÓK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KS. POWT PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATA MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATA MOJZIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATA MOJZÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATA MOJZÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATA MOJŽISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATA MOJŽIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATA MOJŽÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATA MOJŽÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATÁ MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATÁ MOJZIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATÁ MOJZÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATÁ MOJZÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATÁ MOJŽISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATÁ MOJŽIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATÁ MOJŽÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PATÁ MOJŽÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTA MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTA MOJZIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTA MOJZÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTA MOJZÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTA MOJŽISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTA MOJŽIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTA MOJŽÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTA MOJŽÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTÁ MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTÁ MOJZIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTÁ MOJZÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTÁ MOJZÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTÁ MOJŽISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTÁ MOJŽIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTÁ MOJŽÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PÁTÁ MOJŽÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ПЕТА МОЈСИЈЕВА 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("تثنية الإشتراع 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("व्यवस्था विवरण 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("व्य्वस्थाविवरन 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ବିବରଣୀ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 K MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 K MOJZIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 K MOJŽISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 K MOJŽIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOMIUM 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOMIYA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOMIYO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONÓMIUM 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEYUTERONOMYO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DIYUTERONOMYO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FEMTE MOSEBOG 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FEMTE MOSEBOK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KS POWT PRAWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ΔΕΥΤΕΡΟΝΟΜΙΟΝ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ΔΕΥΤΕΡΟΝΌΜΙΟΝ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("व्यवस्थाविवरण 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ଦ୍ୱିତୀୟ ବିବରଣ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. BUCH MOSE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOJZIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOJZÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOJZÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOJŽISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOJŽIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOJŽÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOJŽÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOOSEKSEN 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOSEBOKEN 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. МОЈСИЈЕВА 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOMIA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOMIO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOMUL 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOMYA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONÓMIO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONÔMIO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTORONOMIO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUETERONOMIO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DYUTERONOMYO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOJZESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOJŻESZOWA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOJZIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOJZÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOJZÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOJŽISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOJŽIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOJŽÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOJŽÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOOSEKSEN 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. МОЈСИЈЕВА 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("VIJFDE MOZES 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("BIVASTʰĀ SĀR 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ΔΕΥΤΕΡΟΝΟΜΙΟ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ΔΕΥΤΕΡΟΝΌΜΙΟ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ВТОРОЗАКОНИЕ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ВТОРОЗАКОННЯ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ПОВТ. ЗАКОНУ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("இணைச் சட்டம் 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 BUCH MOSE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOJZIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOJZÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOJZÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOJŽISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOJŽIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOJŽÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOJŽÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOOSEKSEN 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOSEBOKEN 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 МОЈСИЈЕВА 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEETERONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEETORONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONMIO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOMA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOME 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOMI 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTORONMIO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTORONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTRONOMIO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTÉRONOME 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUETERONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUETORONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUUTERONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUUTORONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FUNFTE MOSE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FÜNFTE MOSE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PHỤC TRUYỀN 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOJZISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOJZIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOJZÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOJZÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOJŽISOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOJŽIŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOJŽÍSOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOJŽÍŠOVA 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOOSEKSEN 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V МОЈСИЈЕВА 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("VYAVASTʰAKO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("VYAVASTʰĀKO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ĐỆ NHỊ LUẬT 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ПОВТ ЗАКОНУ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("سفر التثنية 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 МОИСЕЕВА 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOSEBOG 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOSEBOK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOSEBÓK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MÓSEBOK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MÓSEBÓK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEETERONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEETORONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEETRONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTERONOM 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTORONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTRONMIO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTRONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUETERONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUETORONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUETRONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUUTERONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUUTORONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUUTRONOMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KUMBUKUMBU 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA MOJZ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIATA MOJŻ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIĄTA MOJZ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PIĄTA MOJŻ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOSEBOK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOSEBÓK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MÓSEBOK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MÓSEBÓK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("व्यवस्थाको 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ਬਿਵਸਥਾ ਸਾਰ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOSEBOG 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOSEBOK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOSEBÓK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MÓSEBOK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MÓSEBÓK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEETRONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DETERONOM 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DETERONÒM 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DETEWONOM 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DETEWONÒM 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUTRONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUETRONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUUTRONMY 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("FEMTE MOS 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOSEBOK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOSEBÓK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MÓSEBOK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MÓSEBÓK 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ПЕТА МОЈС 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("משנה תורה 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("व्यावस्था 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOZES 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEWARIEM 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("UPAKAMAM 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("UPĀKAMAM 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOZES 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ISTIS̱NĀ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ВТОРОЗАК 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("اِستِثنا 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("تَثنِيَة 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("व्यवस्था 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOZES 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MÓZES 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOJZ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOJŻ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOSE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. МОЈС 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MOZES V 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MÓZES V 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOZES 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOJZ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOJŻ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. МОЈС 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("استثناء 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("التثنية 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("உபாகமம் 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOJZ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOJŻ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOOS 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOSE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 МОЈС 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MOS 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MÓS 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("SHARCI 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOJZ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOJŻ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V МОЈС 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MOS 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V. MÓS 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ANUWAD 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ANUWĀD 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ΔΕΥΤΕΡ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("استثنا 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("अनुवाद 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ਬਿਵਸਥਾ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ବିବରଣି 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOJ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOS 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MOZ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MÓS 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MÓZ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5. MO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MTORV 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("MTÖRV 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOJ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MOS 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("V MÓS 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("דברים 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("《申命紀》 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("《申命記》 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("《申命记》 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MO 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 MZ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5MÓS 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEUT 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DUET 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KUMB 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PHỤC 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ΔΕΥΤ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ВТОР 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ПОВТ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ПОНЗ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("《申命紀 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("《申命記 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("《申命记 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("申命紀》 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("申命記》 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("申命记》 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 M 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("5 М 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DET 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DEU 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DTN 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("KUM 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("LIP 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PNZ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("PWT 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("உபா 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ฉธบ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("《申》 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("申命紀 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("申命記 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("申命记 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("신명기 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DE 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("DT 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ΔΕ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("ВТ 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("تث 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("இச 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("《申 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("申》 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("신명 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("申 1:1").osis()).toEqual("Deut.1.1")
		expect(p.parse("신 1:1").osis()).toEqual("Deut.1.1")
		`
		true
describe "Localized book Titus (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Titus (full)", ->
		`
		expect(p.parse("Послання св. апостола Павла до Тита 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Послання св апостола Павла до Тита 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Послание на св. ап. Павла до Тита 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Poslannja apostola Pavla do Tyta 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Послание на св ап. Павла до Тита 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Послание на св. ап Павла до Тита 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Послание на св ап Павла до Тита 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Послання апостола Павла до Тита 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Писмо од апостол Павле до Тит 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("طِطُس کے نام پولس رسُول کا خط 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("தீத்துவுக்கு எழுதிய திருமுகம் 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("தீத்துக்கு எழுதிய திருமுகம் 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("தீத்துவுக்கு எழுதிய நிருபம் 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tittuvukku Elutiya Nirupam 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tittuvukku Eḻutiya Nirupam 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tīttuvukku Elutiya Nirupam 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tīttuvukku Eḻutiya Nirupam 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("رسالة بولس الرسول إلى تيطس 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("தீத்துவுக்கு எழுதிய கடிதம் 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("List sw. Pawła do Tytusa 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("List św. Pawła do Tytusa 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("List sw Pawła do Tytusa 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("List św Pawła do Tytusa 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Paulus' Brev til Titus 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Paulus’ Brev til Titus 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Paulus’ brev til Titus 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Pavlova poslanica Titu 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Bref Pals til Titusar 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Bref Pals til Títusar 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Bref Páls til Titusar 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Bref Páls til Títusar 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Bréf Pals til Titusar 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Bréf Pals til Títusar 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Bréf Páls til Titusar 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Bréf Páls til Títusar 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("אגרת פולוס אל-טיטוס 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("तीतसलाई पावलको पत्र 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ṭiṭus ke nām kā ḫaṭ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("طِطُس کے نام کا خط 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("पौलाचे तीताला पत्र 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ତୀତସଙ୍କ ପ୍ରତି ପତ୍ର 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Brevet till Titus 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Epistula ad Titum 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Послан ня до Тита 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Brevet til Titus 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Kirje Titukselle 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("tītus nū̃ pattrī 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Послание към Тит 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("الرسالة إلى تيطس 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ططس کے نام کا خط 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ਤੀਤੁਸ ਨੂੰ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Waraka kwa Tito 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Послание к Титу 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("האיגרת אל טיטוס 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Barua kwa Tito 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Lettera a Tito 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("List do Tytusa 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Poslanica Titu 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("titaslai patra 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("titaslaī patra 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("titaslāi patra 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("titaslāī patra 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("tītaslai patra 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("tītaslaī patra 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("tītaslāi patra 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("tītaslāī patra 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Посланица Титу 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titusarbrefið 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titusarbréfið 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Títusarbrefið 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Títusarbréfið 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("titala patra 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("titalā patra 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("titāla patra 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("titālā patra 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("tītala patra 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("tītalā patra 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("tītāla patra 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("tītālā patra 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("तीतसलाई पत्र 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("List Titovi 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("List Títovi 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titusarbref 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titusarbréf 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titusbrevet 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Títusarbref 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Títusarbréf 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("तीताला पत्र 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tittuvukku 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titukselle 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tīttuvukku 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Προς Τίτον 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Προς Τιτον 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("티토에게 보낸 서간 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Kang Tito 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tituszhoz 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ਤੀਤੁਸ ਨੂੰ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Kay Tito 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titushoz 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ad Titum 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("titaslai 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("titaslaī 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("titaslāi 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("titaslāī 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("tītaslai 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("tītaslaī 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("tītaslāi 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("tītaslāī 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("אל טיטוס 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ティトに達する書 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("テトスへのてかみ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("テトスへのてがみ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("До Тита 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("तीतसलाई 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ତୀତସଙ୍କ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("テトスへの手紙 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("テトスヘの手紙 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Teetus 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tiitos 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titovi 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titusz 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tytusa 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Títovi 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("titala 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("titalā 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("titāla 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("titālā 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("tītala 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("tītalā 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("tītāla 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("tītālā 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("К Титу 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("तीताला 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("தீத்து 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("テトスへの書 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titit 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titum 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titus 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("tītus 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("طِطُس 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("तीतुस 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ਤੀਤੁਸ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ทิตัส 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("《弟鐸書》 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("《提多书》 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("《提多書》 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("《提特書》 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tiit 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tite 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titi 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tito 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titu 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Titô 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tích 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Τίτο 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Τιτο 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Тита 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Титу 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("طيطس 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("तीतस 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("தீத் 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("《弟鐸書 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("《提多书 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("《提多書 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("《提特書 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("テトス書 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("弟鐸書》 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("提多书》 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("提多書》 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("提特書》 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ﺗﻴﻄﺲ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tit 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tyt 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tít 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Τίτ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Τιτ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Тит 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ططس 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("《多》 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("テトス 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("弟鐸書 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("提多书 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("提多書 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("提特書 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("디도서 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("티토서 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Ti 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Tt 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("Ττ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("تي 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("طي 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ทต 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("《多 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("多》 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("티토 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("多 1:1").osis()).toEqual("Titus.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ТИТА 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ТИТА 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ. АП. ПАВЛА ДО ТИТА 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("POSLANNJA APOSTOLA PAVLA DO TYTA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ АП. ПАВЛА ДО ТИТА 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ. АП ПАВЛА ДО ТИТА 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ АП ПАВЛА ДО ТИТА 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ТИТА 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ТИТ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("طِطُس کے نام پولس رسُول کا خط 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("தீத்துவுக்கு எழுதிய திருமுகம் 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("தீத்துக்கு எழுதிய திருமுகம் 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("தீத்துவுக்கு எழுதிய நிருபம் 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITTUVUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITTUVUKKU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TĪTTUVUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TĪTTUVUKKU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("رسالة بولس الرسول إلى تيطس 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("தீத்துவுக்கு எழுதிய கடிதம் 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("LIST SW. PAWŁA DO TYTUSA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("LIST ŚW. PAWŁA DO TYTUSA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("LIST SW PAWŁA DO TYTUSA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("LIST ŚW PAWŁA DO TYTUSA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("PAULUS' BREV TIL TITUS 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("PAULUS’ BREV TIL TITUS 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("PAULUS’ BREV TIL TITUS 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("PAVLOVA POSLANICA TITU 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("BREF PALS TIL TITUSAR 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("BREF PALS TIL TÍTUSAR 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("BREF PÁLS TIL TITUSAR 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("BREF PÁLS TIL TÍTUSAR 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("BRÉF PALS TIL TITUSAR 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("BRÉF PALS TIL TÍTUSAR 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("BRÉF PÁLS TIL TITUSAR 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("BRÉF PÁLS TIL TÍTUSAR 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("אגרת פולוס אל-טיטוס 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("तीतसलाई पावलको पत्र 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ṬIṬUS KE NĀM KĀ ḪAṬ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("طِطُس کے نام کا خط 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("पौलाचे तीताला पत्र 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ତୀତସଙ୍କ ପ୍ରତି ପତ୍ର 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("BREVET TILL TITUS 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("EPISTULA AD TITUM 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ПОСЛАН НЯ ДО ТИТА 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("BREVET TIL TITUS 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("KIRJE TITUKSELLE 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TĪTUS NŪ̃ PATTRĪ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ПОСЛАНИЕ КЪМ ТИТ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("الرسالة إلى تيطس 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ططس کے نام کا خط 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ਤੀਤੁਸ ਨੂੰ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("WARAKA KWA TITO 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ПОСЛАНИЕ К ТИТУ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("האיגרת אל טיטוס 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("BARUA KWA TITO 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("LETTERA A TITO 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("LIST DO TYTUSA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("POSLANICA TITU 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITASLAI PATRA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITASLAĪ PATRA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITASLĀI PATRA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITASLĀĪ PATRA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TĪTASLAI PATRA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TĪTASLAĪ PATRA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TĪTASLĀI PATRA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TĪTASLĀĪ PATRA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ПОСЛАНИЦА ТИТУ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITUSARBREFIÐ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITUSARBRÉFIÐ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TÍTUSARBREFIÐ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TÍTUSARBRÉFIÐ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITALA PATRA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITALĀ PATRA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITĀLA PATRA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITĀLĀ PATRA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TĪTALA PATRA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TĪTALĀ PATRA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TĪTĀLA PATRA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TĪTĀLĀ PATRA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("तीतसलाई पत्र 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("LIST TITOVI 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("LIST TÍTOVI 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITUSARBREF 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITUSARBRÉF 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITUSBREVET 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TÍTUSARBREF 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TÍTUSARBRÉF 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("तीताला पत्र 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITTUVUKKU 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITUKSELLE 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TĪTTUVUKKU 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ΠΡΟΣ ΤΊΤΟΝ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ΠΡΟΣ ΤΙΤΟΝ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("티토에게 보낸 서간 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("KANG TITO 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITUSZHOZ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ਤੀਤੁਸ ਨੂੰ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("KAY TITO 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITUSHOZ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("AD TITUM 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITASLAI 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITASLAĪ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITASLĀI 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITASLĀĪ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TĪTASLAI 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TĪTASLAĪ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TĪTASLĀI 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TĪTASLĀĪ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("אל טיטוס 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ティトに達する書 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("テトスへのてかみ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("テトスへのてがみ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ДО ТИТА 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("तीतसलाई 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ତୀତସଙ୍କ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("テトスへの手紙 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("テトスヘの手紙 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TEETUS 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TIITOS 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITOVI 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITUSZ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TYTUSA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TÍTOVI 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITALA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITALĀ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITĀLA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITĀLĀ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TĪTALA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TĪTALĀ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TĪTĀLA 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TĪTĀLĀ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("К ТИТУ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("तीताला 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("தீத்து 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("テトスへの書 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITIT 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITUM 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITUS 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TĪTUS 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("طِطُس 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("तीतुस 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ਤੀਤੁਸ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ทิตัส 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("《弟鐸書》 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("《提多书》 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("《提多書》 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("《提特書》 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TIIT 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITE 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITI 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITO 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITU 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TITÔ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TÍCH 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ΤΊΤΟ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ΤΙΤΟ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ТИТА 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ТИТУ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("طيطس 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("तीतस 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("தீத் 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("《弟鐸書 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("《提多书 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("《提多書 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("《提特書 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("テトス書 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("弟鐸書》 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("提多书》 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("提多書》 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("提特書》 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ﺗﻴﻄﺲ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TIT 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TYT 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TÍT 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ΤΊΤ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ΤΙΤ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ТИТ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ططس 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("《多》 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("テトス 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("弟鐸書 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("提多书 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("提多書 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("提特書 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("디도서 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("티토서 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TI 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("TT 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ΤΤ 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("تي 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("طي 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("ทต 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("《多 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("多》 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("티토 1:1").osis()).toEqual("Titus.1.1")
		expect(p.parse("多 1:1").osis()).toEqual("Titus.1.1")
		`
		true
describe "Localized book Heb (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Heb (full)", ->
		`
		expect(p.parse("Послание на св. ап. Павла до Евреите 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Послание на св ап. Павла до Евреите 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Послание на св. ап Павла до Евреите 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Послание на св ап Павла до Евреите 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("عبرانیوں کے نام پولس رسول کا خط 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("எபிரேயருக்கு எழுதிய திருமுகம் 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Epireyarukku Elutiya Nirupam 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Epireyarukku Eḻutiya Nirupam 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Pavlova poslanica Hebrejima 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("எபிரெயருக்கு எழுதிய நிருபம் 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("எபிரேயருக்கு எழுதிய கடிதம் 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ʿibrāniyōṅ ke nām kā ḫaṭ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("hibruharuko nimti patra 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("hibruharūko nimti patra 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("hibrūharuko nimti patra 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("hibrūharūko nimti patra 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("हिब्रूहरूको निम्ति पत्र 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("الرسالة إلى العبرانيين 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("عِبرانیوں کے نام کا خط 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("عبرانیوں کے نام کا خط 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Brevet til Hebræerne 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Brevet til hebreerne 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Epistula ad Hebraeos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Kirje hebrealaisille 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Kirje heprealaisille 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("List do Hebrajczykow 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("List do Hebrajczyków 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Poslannja do jevreiv 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Poslannja do jevreïv 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Waraka kwa Waebrania 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Послание към евреите 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Barua kwa Waebrania 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Poslanica Hebrejima 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zsidokhoz irt level 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zsidokhoz irt levél 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zsidokhoz írt level 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zsidokhoz írt levél 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zsidókhoz irt level 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zsidókhoz irt levél 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zsidókhoz írt level 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zsidókhoz írt levél 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ibrānīāṃ nū̃ pattrī 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Послан ня до Євреів 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Послан ня до Євреїв 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Посланица Јеврејима 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ਇਬਰਾਨੀਆਂ ਨੂੰ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Lettera agli Ebrei 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Послання до євреів 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Послання до євреїв 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("हिब्रूहरूको निम्ति 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Brefið til Hebrea 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Bréfið til Hebrea 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("hibruharuko nimti 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("hibruharūko nimti 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("hibrūharuko nimti 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("hibrūharūko nimti 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ibri lokams patra 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ibri lokaṃs patra 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ibri lokāms patra 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ibri lokāṃs patra 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ibrī lokams patra 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ibrī lokaṃs patra 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ibrī lokāms patra 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ibrī lokāṃs patra 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Послание к Евреям 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("इब्री लोकांस पत्र 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Писмо до Евреите 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("האיגרת אל העברים 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heprealaiskirje 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("האגרת אל-העברים 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heprealaisille 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Mga Hebrohanon 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebreerbrevet 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebræerbrevet 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebréerbrevet 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Layang Ibrani 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("List Hebrejom 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("List Hebrejum 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("List Hebrejům 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("List do Zydow 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("List do Zydów 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("List do Żydow 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("List do Żydów 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Προς Εβραίους 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Προς Εβραιους 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("히브리인들에게 보낸 서간 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Cibraaniyada 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Epireyarukku 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrajczykow 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrajczyków 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebreabrefið 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebreabréfið 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("इब्री लोकांस 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ਇਬਰਾਨੀਆਂ ਨੂੰ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heber level 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heber levél 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebreohanon 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Héber level 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Héber levél 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Ibraaaniyon 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ad Hebraeos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ibri lokams 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ibri lokaṃs 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ibri lokāms 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ibri lokāṃs 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ibrī lokams 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ibrī lokaṃs 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ibrī lokāms 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ibrī lokāṃs 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("List Zidum 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("List Zidům 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("List Židum 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("List Židům 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Mga Hebreo 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("العبرانيين 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("इब्रानियों 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebreerne 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrejima 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrenjve 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebræerne 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heebrewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hewbrewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hwebrewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hwwbrewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Mga Ebreo 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Waebrania 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zsidokhoz 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zsidókhoz 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Јеврејима 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("До євреів 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("До євреїв 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("אל העברים 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("عِبرانیوں 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘフライ人への手紙 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘブライ人への手紙 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebraeer 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebraeos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebreaid 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebreeen 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebreeën 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrejom 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrejum 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrejům 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heebrews 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hewbrews 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hwbrewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hwebrews 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hwwbrews 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hê-bơ-rơ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ibrānīāṃ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Εβραίους 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Εβραιους 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("К Евреям 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("عبرانیوں 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("எபிரேயர் 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘフル人への手紙 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘブル人への手紙 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Do Thái 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hbrewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebeees 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebeeos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebeers 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebeoes 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebeoos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebeors 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heberes 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heberos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heberrs 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heberws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebewes 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebewrs 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebewws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heboees 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heboeos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heboers 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebooes 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebooos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heboors 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebores 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heboros 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heborrs 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebraer 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrees 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebreos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrers 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebreus 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebreux 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrews 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebroes 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebroos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrors 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrres 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrros 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrrrs 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrrws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrwes 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebräer 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebwers 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebwres 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hwbrews 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hébreux 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Евреите 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("इब्रानि 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("इब्रानी 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘフル人への書 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘブル人への書 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hbrews 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebees 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebeos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebers 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heboes 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heboos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebors 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebreo 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebres 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrew 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebros 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrrs 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrws 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Ibrani 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zsidok 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zsidók 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Євреів 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Євреїв 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Евреям 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("हिब्रू 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《希伯來书》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《希伯來書》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《希伯来书》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《耶烏雷爾》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Ebrei 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Evrei 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebes 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebos 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebrs 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zidom 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zidum 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zidům 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zydow 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zydów 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Żydow 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Żydów 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Židom 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Židum 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Židům 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Євреі 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Євреї 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Евреи 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("इब्री 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ଏବ୍ରୀ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("எபிரே 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ฮีบรู 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《希伯來书 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《希伯來書 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《希伯来书 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《耶烏雷爾 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘフライ書 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘブライ書 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("希伯來书》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("希伯來書》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("希伯来书》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("耶烏雷爾》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Ebre 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hebr 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hepr 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hébr 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zsid 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘフライ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘフル書 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘブライ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘブル書 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("希伯來书 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("希伯來書 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("希伯来书 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("耶烏雷爾 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("히브리서 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Cib 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Ebr 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Evr 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hbr 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Heb 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Héb 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zid 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zyd 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Żyd 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Žid 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Εβρ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Євр 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Јев 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Евр 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("எபி 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《來》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《来》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Eb 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("He 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hé 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Hê 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Zd 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Žd 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Εβ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("عب 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ฮบ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("Ἑβ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《來 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《来 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("來》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("来》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("히브 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("來 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("来 1:1").osis()).toEqual("Heb.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ПОСЛАНИЕ НА СВ. АП. ПАВЛА ДО ЕВРЕИТЕ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ АП. ПАВЛА ДО ЕВРЕИТЕ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ. АП ПАВЛА ДО ЕВРЕИТЕ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ АП ПАВЛА ДО ЕВРЕИТЕ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("عبرانیوں کے نام پولس رسول کا خط 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("எபிரேயருக்கு எழுதிய திருமுகம் 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("EPIREYARUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("EPIREYARUKKU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("PAVLOVA POSLANICA HEBREJIMA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("எபிரெயருக்கு எழுதிய நிருபம் 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("எபிரேயருக்கு எழுதிய கடிதம் 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ʿIBRĀNIYŌṄ KE NĀM KĀ ḪAṬ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HIBRUHARUKO NIMTI PATRA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HIBRUHARŪKO NIMTI PATRA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HIBRŪHARUKO NIMTI PATRA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HIBRŪHARŪKO NIMTI PATRA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("हिब्रूहरूको निम्ति पत्र 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("الرسالة إلى العبرانيين 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("عِبرانیوں کے نام کا خط 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("عبرانیوں کے نام کا خط 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("BREVET TIL HEBRÆERNE 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("BREVET TIL HEBREERNE 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("EPISTULA AD HEBRAEOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("KIRJE HEBREALAISILLE 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("KIRJE HEPREALAISILLE 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("LIST DO HEBRAJCZYKOW 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("LIST DO HEBRAJCZYKÓW 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("POSLANNJA DO JEVREIV 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("POSLANNJA DO JEVREÏV 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("WARAKA KWA WAEBRANIA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ПОСЛАНИЕ КЪМ ЕВРЕИТЕ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("BARUA KWA WAEBRANIA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("POSLANICA HEBREJIMA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZSIDOKHOZ IRT LEVEL 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZSIDOKHOZ IRT LEVÉL 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZSIDOKHOZ ÍRT LEVEL 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZSIDOKHOZ ÍRT LEVÉL 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZSIDÓKHOZ IRT LEVEL 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZSIDÓKHOZ IRT LEVÉL 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZSIDÓKHOZ ÍRT LEVEL 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZSIDÓKHOZ ÍRT LEVÉL 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRĀNĪĀṂ NŪ̃ PATTRĪ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ПОСЛАН НЯ ДО ЄВРЕІВ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ПОСЛАН НЯ ДО ЄВРЕЇВ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ПОСЛАНИЦА ЈЕВРЕЈИМА 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ਇਬਰਾਨੀਆਂ ਨੂੰ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("LETTERA AGLI EBREI 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ПОСЛАННЯ ДО ЄВРЕІВ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ПОСЛАННЯ ДО ЄВРЕЇВ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("हिब्रूहरूको निम्ति 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("BREFIÐ TIL HEBREA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("BRÉFIÐ TIL HEBREA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HIBRUHARUKO NIMTI 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HIBRUHARŪKO NIMTI 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HIBRŪHARUKO NIMTI 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HIBRŪHARŪKO NIMTI 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRI LOKAMS PATRA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRI LOKAṂS PATRA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRI LOKĀMS PATRA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRI LOKĀṂS PATRA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRĪ LOKAMS PATRA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRĪ LOKAṂS PATRA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRĪ LOKĀMS PATRA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRĪ LOKĀṂS PATRA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ПОСЛАНИЕ К ЕВРЕЯМ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("इब्री लोकांस पत्र 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ПИСМО ДО ЕВРЕИТЕ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("האיגרת אל העברים 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEPREALAISKIRJE 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("האגרת אל-העברים 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEPREALAISILLE 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("MGA HEBROHANON 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREERBREVET 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRÆERBREVET 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRÉERBREVET 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("LAYANG IBRANI 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("LIST HEBREJOM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("LIST HEBREJUM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("LIST HEBREJŮM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("LIST DO ZYDOW 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("LIST DO ZYDÓW 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("LIST DO ŻYDOW 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("LIST DO ŻYDÓW 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ΠΡΟΣ ΕΒΡΑΊΟΥΣ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ΠΡΟΣ ΕΒΡΑΙΟΥΣ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("히브리인들에게 보낸 서간 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("CIBRAANIYADA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("EPIREYARUKKU 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRAJCZYKOW 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRAJCZYKÓW 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREABREFIÐ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREABRÉFIÐ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("इब्री लोकांस 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ਇਬਰਾਨੀਆਂ ਨੂੰ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBER LEVEL 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBER LEVÉL 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREOHANON 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HÉBER LEVEL 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HÉBER LEVÉL 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRAAANIYON 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("AD HEBRAEOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRI LOKAMS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRI LOKAṂS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRI LOKĀMS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRI LOKĀṂS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRĪ LOKAMS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRĪ LOKAṂS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRĪ LOKĀMS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRĪ LOKĀṂS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("LIST ZIDUM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("LIST ZIDŮM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("LIST ŽIDUM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("LIST ŽIDŮM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("MGA HEBREO 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("العبرانيين 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("इब्रानियों 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREERNE 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREJIMA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRENJVE 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRÆERNE 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEEBREWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEWBREWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HWEBREWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HWWBREWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("MGA EBREO 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("WAEBRANIA 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZSIDOKHOZ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZSIDÓKHOZ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ЈЕВРЕЈИМА 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ДО ЄВРЕІВ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ДО ЄВРЕЇВ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("אל העברים 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("عِبرانیوں 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘフライ人への手紙 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘブライ人への手紙 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRAEER 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRAEOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREAID 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREEEN 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREEËN 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREJOM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREJUM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREJŮM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEEBREWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEWBREWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HWBREWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HWEBREWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HWWBREWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HÊ-BƠ-RƠ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRĀNĪĀṂ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ΕΒΡΑΊΟΥΣ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ΕΒΡΑΙΟΥΣ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("К ЕВРЕЯМ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("عبرانیوں 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("எபிரேயர் 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘフル人への手紙 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘブル人への手紙 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("DO THÁI 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HBREWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEEES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEEOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEERS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEOES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEOOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEORS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBERES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEROS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBERRS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBERWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEWES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEWRS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEWWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBOEES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBOEOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBOERS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBOOES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBOOOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBOORS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBORES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBOROS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBORRS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRAER 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRERS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREUS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREUX 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBROES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBROOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRORS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRRES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRROS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRRRS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRRWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRWES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRÄER 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBWERS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBWRES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HWBREWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HÉBREUX 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ЕВРЕИТЕ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("इब्रानि 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("इब्रानी 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘフル人への書 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘブル人への書 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HBREWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBEOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBERS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBOES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBOOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBORS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREO 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBREW 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBROS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRRS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRWS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("IBRANI 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZSIDOK 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZSIDÓK 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ЄВРЕІВ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ЄВРЕЇВ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ЕВРЕЯМ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("हिब्रू 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《希伯來书》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《希伯來書》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《希伯来书》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《耶烏雷爾》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("EBREI 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("EVREI 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBES 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBOS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBRS 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZIDOM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZIDUM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZIDŮM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZYDOW 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZYDÓW 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ŻYDOW 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ŻYDÓW 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ŽIDOM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ŽIDUM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ŽIDŮM 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ЄВРЕІ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ЄВРЕЇ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ЕВРЕИ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("इब्री 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ଏବ୍ରୀ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("எபிரே 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ฮีบรู 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《希伯來书 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《希伯來書 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《希伯来书 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《耶烏雷爾 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘフライ書 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘブライ書 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("希伯來书》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("希伯來書》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("希伯来书》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("耶烏雷爾》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("EBRE 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEBR 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEPR 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HÉBR 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZSID 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘフライ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘフル書 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘブライ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ヘブル書 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("希伯來书 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("希伯來書 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("希伯来书 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("耶烏雷爾 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("히브리서 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("CIB 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("EBR 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("EVR 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HBR 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HEB 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HÉB 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZID 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZYD 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ŻYD 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ŽID 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ΕΒΡ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ЄВР 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ЈЕВ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ЕВР 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("எபி 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《來》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《来》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("EB 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HE 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HÉ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("HÊ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ZD 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ŽD 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ΕΒ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("عب 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ฮบ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("ἙΒ 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《來 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("《来 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("來》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("来》 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("히브 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("來 1:1").osis()).toEqual("Heb.1.1")
		expect(p.parse("来 1:1").osis()).toEqual("Heb.1.1")
		`
		true
describe "Localized book Phil (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Phil (full)", ->
		`
		expect(p.parse("Писмо од апостол Павле до христијаните во Филипи 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Послання св. апостола Павла до филип'ян 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Послання св. апостола Павла до филип’ян 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Послання св апостола Павла до филип'ян 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Послання св апостола Павла до филип’ян 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Poslannja apostola Pavla do fylyp'jan 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Poslannja apostola Pavla do fylyp’jan 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Послание на св. ап. Павла до Филипяни 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Послание на св ап. Павла до Филипяни 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Послание на св. ап Павла до Филипяни 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Послание на св ап Павла до Филипяни 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Послання апостола Павла до филип'ян 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Послання апостола Павла до филип’ян 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("فِلِپّیُوں کے نام پو لس رسُول کا خط 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("பிலிப்பியருக்கு எழுதிய திருமுகம் 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("رسالة بولس الرسول إلى أهل فيلبي 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Pavlova poslanica Filipljanima 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Pilippiyarukku Elutiya Nirupam 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Pilippiyarukku Eḻutiya Nirupam 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("பிலிப்பியருக்கு எழுதிய நிருபம் 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("பிலிப்பியருக்கு எழுதிய கடிதம் 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Paulus' Brev til Filipperne 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Paulus’ Brev til Filipperne 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Paulus’ brev til filipperne 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("אגרת פולוס השליח אל-הפיליפי 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Bref Pals til Filippimanna 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Bref Pals til Filippímanna 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Bref Páls til Filippimanna 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Bref Páls til Filippímanna 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Bréf Pals til Filippimanna 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Bréf Pals til Filippímanna 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Bréf Páls til Filippimanna 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Bréf Páls til Filippímanna 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("List sw. Pawła do Filipian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("List św. Pawła do Filipian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("फिलिप्पीहरूलाई पावलको पत्र 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Bref Pals til Filippimann 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Bref Pals til Filippímann 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Bref Páls til Filippimann 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Bref Páls til Filippímann 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Bréf Pals til Filippimann 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Bréf Pals til Filippímann 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Bréf Páls til Filippimann 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Bréf Páls til Filippímann 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("List sw Pawła do Filipian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("List św Pawła do Filipian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("पौलाचे फिलिप्पैकरांस पत्र 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ଫିଲି‌ପ୍‌ପୀୟଙ୍କ ପ୍ରତି ପତ୍ର 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Epistula ad Philippenses 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("filippiyōṅ ke nām kā ḫaṭ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Послание към филипяните 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("فِلِپِّیوں کے نام کا خط 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Poslanica Filipljanima 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Sulat sa mga Filipense 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Sulat sa mga Pilipense 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Sulat sa mga Pilipyano 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Послание к Филиппиицам 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Послание к Филиппийцам 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Kirje filippilaisille 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Kirje filippiläisille 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippaikarams patra 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippaikaraṃs patra 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippaikarāms patra 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippaikarāṃs patra 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippiharulai patra 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippiharulaī patra 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippiharulāi patra 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippiharulāī patra 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippiharūlai patra 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippiharūlaī patra 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippiharūlāi patra 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippiharūlāī patra 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippīharulai patra 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippīharulaī patra 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippīharulāi patra 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippīharulāī patra 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippīharūlai patra 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippīharūlaī patra 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippīharūlāi patra 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippīharūlāī patra 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Посланица Филипљанима 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("الرسالة إلى أهل فيلبي 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ਫ਼ਿਲਿੱਪੀਆਂ ਨੂੰ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Layang Paulus Filipi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Lettera ai Filippesi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("filippīāṃ nū̃ pattrī 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Послання до Філіп'ян 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Послання до Філіп’ян 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Послання до филип'ян 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Послання до филип’ян 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Waraka kwa Wafilipi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("فلپیوں کے نام کا خط 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("फिलिप्पीहरूलाई पत्र 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Barua kwa Wafilipi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("האיגרת אל הפיליפים 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("फिलिप्पैकरांस पत्र 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Mga Taga- Filipos 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Mga Taga- Pilipos 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippibeliekhez 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Προς Φιλιππησίους 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Προς Φιλιππησιους 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filippilaiskirje 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filippiläiskirje 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("List do Filipian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Mga Taga Filipos 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Mga Taga Pilipos 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Mga Taga-Filipos 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filippilaisille 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filippiläisille 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ad Philippenses 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippaikarams 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippaikaraṃs 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippaikarāms 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippaikarāṃs 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippiharulai 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippiharulaī 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippiharulāi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippiharulāī 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippiharūlai 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippiharūlaī 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippiharūlāi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippiharūlāī 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippīharulai 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippīharulaī 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippīharulāi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippīharulāī 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippīharūlai 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippīharūlaī 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippīharūlāi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("pʰilippīharūlāī 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("필리피 신자들에게 보낸 서간 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipperbrevet 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("List Filipanom 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("List Filipskym 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("List Filipským 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Pilippiyarukku 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("फिलिप्पीहरूलाई 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ਫ਼ਿਲਿੱਪੀਆਂ ਨੂੰ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ଫିଲି‌ପ୍‌ପୀୟଙ୍କ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filippenserne 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filippibrefið 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filippibréfið 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filippíbrefið 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filippíbréfið 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Mga Filipense 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Mga Pilipense 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Mga Pilipyano 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippiains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippieans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippiians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipppians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philllipiians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philllippians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Taga- Filipos 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Taga- Pilipos 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("К Филиппиицам 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("К Филиппийцам 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("फिलिप्पैकरांस 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipljanima 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filippiekhez 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippaians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippenses 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippiaans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippiains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippiians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipppians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipaians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipiaans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipiains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipieans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipiians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippeans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philllipians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philllppians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Taga Filipos 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Taga Pilipos 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Taga-Filipos 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Φιλιππησίους 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Φιλιππησιους 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipenskym 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipenským 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipianeve 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipianëve 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filippaiyon 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filippenzen 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Flippiekhez 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipaians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipiians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippeans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippiens 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipppian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipeans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipiens 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippean 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillippins 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philllipian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philllpians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillppians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philppiians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpppians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("До филип'ян 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("До филип’ян 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Филиппиицам 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Филиппийцам 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Филипјаните 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Филипљанима 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("אל הפיליפים 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("رسالة فيلبي 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("फिलिप्पियों 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("பிலிப்பியர் 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("フィリヒの信徒への手紙 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("フィリピの信徒への手紙 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipenses 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipensow 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipensów 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipperne 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipeans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipiaid 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipiens 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippean 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippins 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipain 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipean 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipins 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillpians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillpiens 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillppian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philppians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phlippians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Филипяните 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("فِلِپّیُوں 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipanom 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filippesi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipskym 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipským 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipain 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipens 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipins 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippan 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipper 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philippin 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillipan 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillpans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillpian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpains 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpeans 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philppian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philípphê 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phlipians 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("filippīāṃ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Филип'яни 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Филипјани 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Филип’яни 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("फिलिप्‍पी 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("フィリヒ人への手紙 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("フィリピ人への手紙 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipeni 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipyen 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipan 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpian 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpins 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Wafilipi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Филип'ян 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Филипяни 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Филип’ян 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("فِلپّیوں 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("फिलिप्पि 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("फिलिप्पी 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ヒリヒ人への手紙 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ヒリピ人への手紙 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ピリヒ人への手紙 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ピリピ人への手紙 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filiboy 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipos 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filippi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phi-líp 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philipp 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phillip 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpan 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ฟีลิปปี 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ヒリヒ人への書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ヒリピ人への書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ピリヒ人への書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ピリピ人への書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filipi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philip 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philli 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philpp 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phlipp 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("فلپیوں 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("பிலிப் 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("《斐理伯書》 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("《腓立比书》 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("《腓立比書》 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ﻓﻴﻠﻴﺒﻲ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Filip 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phili 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Philp 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phlip 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phlpp 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("《斐理伯書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("《肥利批》 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("《腓立比书 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("《腓立比書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("フィリヒ書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("フィリピ書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("斐理伯書》 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("腓立比书》 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("腓立比書》 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Fili 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phil 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phlp 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("பிலி 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("《肥利批 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ヒリヒ書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ヒリピ書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ピリヒ書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ピリピ書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("フィリヒ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("フィリピ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("斐理伯書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("肥利批》 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("腓立比书 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("腓立比書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("빌립보서 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("필리피서 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Flp 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phi 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Php 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Фил 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Флп 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("《腓》 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("肥利批 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Fl 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Fp 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Φι 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("فل 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("في 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ฟป 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("《腓 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("腓》 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("필리 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("腓 1:1").osis()).toEqual("Phil.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ПИСМО ОД АПОСТОЛ ПАВЛЕ ДО ХРИСТИЈАНИТЕ ВО ФИЛИПИ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ФИЛИП'ЯН 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ПОСЛАННЯ СВ. АПОСТОЛА ПАВЛА ДО ФИЛИП’ЯН 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ФИЛИП'ЯН 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ПОСЛАННЯ СВ АПОСТОЛА ПАВЛА ДО ФИЛИП’ЯН 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("POSLANNJA APOSTOLA PAVLA DO FYLYP'JAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("POSLANNJA APOSTOLA PAVLA DO FYLYP’JAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ. АП. ПАВЛА ДО ФИЛИПЯНИ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ АП. ПАВЛА ДО ФИЛИПЯНИ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ. АП ПАВЛА ДО ФИЛИПЯНИ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ПОСЛАНИЕ НА СВ АП ПАВЛА ДО ФИЛИПЯНИ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ФИЛИП'ЯН 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ПОСЛАННЯ АПОСТОЛА ПАВЛА ДО ФИЛИП’ЯН 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("فِلِپّیُوں کے نام پو لس رسُول کا خط 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("பிலிப்பியருக்கு எழுதிய திருமுகம் 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("رسالة بولس الرسول إلى أهل فيلبي 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PAVLOVA POSLANICA FILIPLJANIMA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PILIPPIYARUKKU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PILIPPIYARUKKU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("பிலிப்பியருக்கு எழுதிய நிருபம் 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("பிலிப்பியருக்கு எழுதிய கடிதம் 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PAULUS' BREV TIL FILIPPERNE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PAULUS’ BREV TIL FILIPPERNE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PAULUS’ BREV TIL FILIPPERNE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("אגרת פולוס השליח אל-הפיליפי 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("BREF PALS TIL FILIPPIMANNA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("BREF PALS TIL FILIPPÍMANNA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("BREF PÁLS TIL FILIPPIMANNA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("BREF PÁLS TIL FILIPPÍMANNA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("BRÉF PALS TIL FILIPPIMANNA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("BRÉF PALS TIL FILIPPÍMANNA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("BRÉF PÁLS TIL FILIPPIMANNA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("BRÉF PÁLS TIL FILIPPÍMANNA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("LIST SW. PAWŁA DO FILIPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("LIST ŚW. PAWŁA DO FILIPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("फिलिप्पीहरूलाई पावलको पत्र 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("BREF PALS TIL FILIPPIMANN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("BREF PALS TIL FILIPPÍMANN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("BREF PÁLS TIL FILIPPIMANN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("BREF PÁLS TIL FILIPPÍMANN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("BRÉF PALS TIL FILIPPIMANN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("BRÉF PALS TIL FILIPPÍMANN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("BRÉF PÁLS TIL FILIPPIMANN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("BRÉF PÁLS TIL FILIPPÍMANN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("LIST SW PAWŁA DO FILIPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("LIST ŚW PAWŁA DO FILIPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("पौलाचे फिलिप्पैकरांस पत्र 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ଫିଲି‌ପ୍‌ପୀୟଙ୍କ ପ୍ରତି ପତ୍ର 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("EPISTULA AD PHILIPPENSES 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPIYŌṄ KE NĀM KĀ ḪAṬ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ПОСЛАНИЕ КЪМ ФИЛИПЯНИТЕ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("فِلِپِّیوں کے نام کا خط 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("POSLANICA FILIPLJANIMA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("SULAT SA MGA FILIPENSE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("SULAT SA MGA PILIPENSE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("SULAT SA MGA PILIPYANO 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ПОСЛАНИЕ К ФИЛИППИИЦАМ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ПОСЛАНИЕ К ФИЛИППИЙЦАМ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("KIRJE FILIPPILAISILLE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("KIRJE FILIPPILÄISILLE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPAIKARAMS PATRA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPAIKARAṂS PATRA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPAIKARĀMS PATRA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPAIKARĀṂS PATRA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPIHARULAI PATRA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPIHARULAĪ PATRA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPIHARULĀI PATRA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPIHARULĀĪ PATRA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPIHARŪLAI PATRA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPIHARŪLAĪ PATRA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPIHARŪLĀI PATRA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPIHARŪLĀĪ PATRA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPĪHARULAI PATRA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPĪHARULAĪ PATRA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPĪHARULĀI PATRA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPĪHARULĀĪ PATRA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPĪHARŪLAI PATRA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPĪHARŪLAĪ PATRA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPĪHARŪLĀI PATRA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPĪHARŪLĀĪ PATRA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ПОСЛАНИЦА ФИЛИПЉАНИМА 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("الرسالة إلى أهل فيلبي 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ਫ਼ਿਲਿੱਪੀਆਂ ਨੂੰ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("LAYANG PAULUS FILIPI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("LETTERA AI FILIPPESI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPĪĀṂ NŪ̃ PATTRĪ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ПОСЛАННЯ ДО ФІЛІП'ЯН 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ПОСЛАННЯ ДО ФІЛІП’ЯН 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ПОСЛАННЯ ДО ФИЛИП'ЯН 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ПОСЛАННЯ ДО ФИЛИП’ЯН 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("WARAKA KWA WAFILIPI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("فلپیوں کے نام کا خط 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("फिलिप्पीहरूलाई पत्र 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("BARUA KWA WAFILIPI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("האיגרת אל הפיליפים 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("फिलिप्पैकरांस पत्र 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("MGA TAGA- FILIPOS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("MGA TAGA- PILIPOS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIBELIEKHEZ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ΠΡΟΣ ΦΙΛΙΠΠΗΣΊΟΥΣ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ΠΡΟΣ ΦΙΛΙΠΠΗΣΙΟΥΣ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPILAISKIRJE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPILÄISKIRJE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("LIST DO FILIPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("MGA TAGA FILIPOS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("MGA TAGA PILIPOS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("MGA TAGA-FILIPOS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPILAISILLE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPILÄISILLE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("AD PHILIPPENSES 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPAIKARAMS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPAIKARAṂS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPAIKARĀMS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPAIKARĀṂS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPIHARULAI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPIHARULAĪ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPIHARULĀI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPIHARULĀĪ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPIHARŪLAI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPIHARŪLAĪ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPIHARŪLĀI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPIHARŪLĀĪ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPĪHARULAI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPĪHARULAĪ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPĪHARULĀI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPĪHARULĀĪ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPĪHARŪLAI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPĪHARŪLAĪ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPĪHARŪLĀI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PʰILIPPĪHARŪLĀĪ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("필리피 신자들에게 보낸 서간 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPERBREVET 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("LIST FILIPANOM 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("LIST FILIPSKYM 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("LIST FILIPSKÝM 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PILIPPIYARUKKU 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("फिलिप्पीहरूलाई 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ਫ਼ਿਲਿੱਪੀਆਂ ਨੂੰ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ଫିଲି‌ପ୍‌ପୀୟଙ୍କ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPENSERNE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPIBREFIÐ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPIBRÉFIÐ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPÍBREFIÐ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPÍBRÉFIÐ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("MGA FILIPENSE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("MGA PILIPENSE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("MGA PILIPYANO 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPIAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPIEANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPIIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLLIPIIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLLIPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("TAGA- FILIPOS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("TAGA- PILIPOS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("К ФИЛИППИИЦАМ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("К ФИЛИППИЙЦАМ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("फिलिप्पैकरांस 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPLJANIMA 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPIEKHEZ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPAIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPENSES 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIAANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPAIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPIAANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPIAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPIEANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPIIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPEANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLLIPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLLPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("TAGA FILIPOS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("TAGA PILIPOS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("TAGA-FILIPOS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ΦΙΛΙΠΠΗΣΊΟΥΣ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ΦΙΛΙΠΠΗΣΙΟΥΣ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPENSKYM 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPENSKÝM 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPIANEVE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPIANËVE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPAIYON 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPENZEN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FLIPPIEKHEZ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPAIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPIIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPEANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIENS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPEANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPIENS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPEAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPPINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLLIPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLLPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPPIIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ДО ФИЛИП'ЯН 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ДО ФИЛИП’ЯН 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ФИЛИППИИЦАМ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ФИЛИППИЙЦАМ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ФИЛИПЈАНИТЕ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ФИЛИПЉАНИМА 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("אל הפיליפים 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("رسالة فيلبي 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("फिलिप्पियों 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("பிலிப்பியர் 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("フィリヒの信徒への手紙 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("フィリピの信徒への手紙 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPENSES 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPENSOW 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPENSÓW 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPERNE 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPEANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPIAID 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPIENS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPEAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPAIN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPEAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLPIENS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLPPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHLIPPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ФИЛИПЯНИТЕ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("فِلِپّیُوں 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPANOM 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPESI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPSKYM 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPSKÝM 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPAIN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPENS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPER 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPPIN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIPAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLPANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPAINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPEANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILÍPPHÊ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHLIPIANS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPĪĀṂ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ФИЛИП'ЯНИ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ФИЛИПЈАНИ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ФИЛИП’ЯНИ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("फिलिप्‍पी 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("フィリヒ人への手紙 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("フィリピ人への手紙 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPENI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPYEN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPIAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPINS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("WAFILIPI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ФИЛИП'ЯН 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ФИЛИПЯНИ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ФИЛИП’ЯН 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("فِلپّیوں 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("फिलिप्पि 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("फिलिप्पी 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ヒリヒ人への手紙 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ヒリピ人への手紙 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ピリヒ人への手紙 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ピリピ人への手紙 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIBOY 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPOS 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPPI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHI-LÍP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIPP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLIP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPAN 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ฟีลิปปี 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ヒリヒ人への書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ヒリピ人への書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ピリヒ人への書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ピリピ人への書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIPI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILIP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILLI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILPP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHLIPP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("فلپیوں 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("பிலிப் 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("《斐理伯書》 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("《腓立比书》 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("《腓立比書》 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ﻓﻴﻠﻴﺒﻲ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILIP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHILP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHLIP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHLPP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("《斐理伯書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("《肥利批》 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("《腓立比书 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("《腓立比書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("フィリヒ書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("フィリピ書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("斐理伯書》 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("腓立比书》 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("腓立比書》 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FILI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHIL 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHLP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("பிலி 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("《肥利批 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ヒリヒ書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ヒリピ書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ピリヒ書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ピリピ書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("フィリヒ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("フィリピ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("斐理伯書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("肥利批》 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("腓立比书 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("腓立比書 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("빌립보서 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("필리피서 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FLP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHI 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ФИЛ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ФЛП 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("《腓》 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("肥利批 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FL 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("FP 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ΦΙ 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("فل 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("في 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("ฟป 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("《腓 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("腓》 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("필리 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("腓 1:1").osis()).toEqual("Phil.1.1")
		`
		true
describe "Localized book Dan (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Dan (full)", ->
		`
		expect(p.parse("Книга на пророк Даниила 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Книга на пророк Даниил 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Книга пророка Даниила 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Книга пророка Даниіла 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Книга пророка Даниїла 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("தானியேலின் புத்தகம் 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Prophetia Danielis 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ଦାନିୟେଲଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("daniyalko pustak 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("dāniyalko pustak 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("दानियलको पुस्तक 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Danielin kirja 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Ksiega Daniela 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Ksiegi Daniela 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Księga Daniela 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Księgi Daniela 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Liv Danyel la 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Liv Danyèl la 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Daniels Bog 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Daniels bok 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Ks. Daniela 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Ks Daniela 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("سفر دانيال 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Daaniyyel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("daniyalko 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("dāniyalko 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("दानिय्येल 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Daanyeel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Danielin 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Ða-ni-ên 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Đa-ni-ên 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("دانی ایل 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("دانی‌ایل 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("दानियलको 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("दानिय्यल 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("दानीएल्र 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ଦାନିୟେଲଙ 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("தானியேல் 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Daniela 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Daniele 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Danieli 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Dhaniel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Taniyel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Taniyēl 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Taṉiyel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Taṉiyēl 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Tāniyel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Tāniyēl 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Tāṉiyel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Tāṉiyēl 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("dānīʾīl 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Đa-niên 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Даниила 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Даниіла 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Даниїла 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ดาเนียล 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Danial 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Daniel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Danièl 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Daniël 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Danyel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Danyil 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Danyèl 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Danyïl 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Daníel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Dániel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("daniel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("danīel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("dāniel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("dānīel 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Đanien 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Δανιήλ 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Δανιηλ 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Данаил 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Даниел 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Даниил 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Данило 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Даниял 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Даниіл 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Даниїл 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("دانيال 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("دانیال 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("दानियल 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("दानीएल 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ਦਾਨੀਏਲ 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("《但以理书》 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("《但以理書》 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Данил 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("דניאל 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("《但以理书 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("《但以理書 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("《達尼爾》 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("タニエル書 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ダニエル書 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("但以理书》 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("但以理書》 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Daan 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("दानि 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("தானி 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("《達尼爾 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("タニエル 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ダニエル 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("但以理书 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("但以理書 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("達尼爾》 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("다니엘서 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Dan 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Dán 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Δαν 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Дан 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Дон 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ดนล 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("《但》 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("達尼爾 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("다니엘 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Da 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Dl 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Dn 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Đa 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Δα 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("Δν 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("دا 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("《但 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("但》 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("다니 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("但 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("단 1:1").osis()).toEqual("Dan.1.1")
		p.include_apocrypha(false)
		expect(p.parse("КНИГА НА ПРОРОК ДАНИИЛА 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("КНИГА НА ПРОРОК ДАНИИЛ 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("КНИГА ПРОРОКА ДАНИИЛА 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("КНИГА ПРОРОКА ДАНИІЛА 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("КНИГА ПРОРОКА ДАНИЇЛА 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("தானியேலின் புத்தகம் 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("PROPHETIA DANIELIS 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ଦାନିୟେଲଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIYALKO PUSTAK 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DĀNIYALKO PUSTAK 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("दानियलको पुस्तक 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIELIN KIRJA 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("KSIEGA DANIELA 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("KSIEGI DANIELA 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("KSIĘGA DANIELA 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("KSIĘGI DANIELA 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("LIV DANYEL LA 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("LIV DANYÈL LA 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIELS BOG 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIELS BOK 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("KS. DANIELA 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("KS DANIELA 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("سفر دانيال 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DAANIYYEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIYALKO 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DĀNIYALKO 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("दानिय्येल 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DAANYEEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIELIN 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ÐA-NI-ÊN 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ĐA-NI-ÊN 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("دانی ایل 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("دانی‌ایل 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("दानियलको 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("दानिय्यल 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("दानीएल्र 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ଦାନିୟେଲଙ 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("தானியேல் 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIELA 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIELE 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIELI 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DHANIEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("TANIYEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("TANIYĒL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("TAṈIYEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("TAṈIYĒL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("TĀNIYEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("TĀNIYĒL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("TĀṈIYEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("TĀṈIYĒL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DĀNĪʾĪL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ĐA-NIÊN 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ДАНИИЛА 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ДАНИІЛА 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ДАНИЇЛА 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ดาเนียล 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIAL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIÈL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIËL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANYEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANYIL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANYÈL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANYÏL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANÍEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DÁNIEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANIEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DANĪEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DĀNIEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DĀNĪEL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ĐANIEN 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ΔΑΝΙΉΛ 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ΔΑΝΙΗΛ 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ДАНАИЛ 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ДАНИЕЛ 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ДАНИИЛ 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ДАНИЛО 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ДАНИЯЛ 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ДАНИІЛ 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ДАНИЇЛ 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("دانيال 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("دانیال 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("दानियल 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("दानीएल 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ਦਾਨੀਏਲ 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("《但以理书》 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("《但以理書》 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ДАНИЛ 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("דניאל 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("《但以理书 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("《但以理書 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("《達尼爾》 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("タニエル書 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ダニエル書 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("但以理书》 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("但以理書》 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DAAN 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("दानि 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("தானி 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("《達尼爾 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("タニエル 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ダニエル 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("但以理书 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("但以理書 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("達尼爾》 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("다니엘서 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DAN 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DÁN 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ΔΑΝ 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ДАН 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ДОН 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ดนล 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("《但》 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("達尼爾 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("다니엘 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DA 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DL 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("DN 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ĐA 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ΔΑ 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("ΔΝ 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("دا 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("《但 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("但》 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("다니 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("但 1:1").osis()).toEqual("Dan.1.1")
		expect(p.parse("단 1:1").osis()).toEqual("Dan.1.1")
		`
		true
describe "Localized book Jude (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Jude (full)", ->
		`
		expect(p.parse("List powszechny Swietego Iudasa Apostoła 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("List powszechny Swiętego Iudasa Apostoła 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("List powszechny Świetego Iudasa Apostoła 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("List powszechny Świętego Iudasa Apostoła 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Соборне послання св. апостола Юди 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Соборне послання св апостола Юди 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Съборно послание на св. ап. Иуда 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Съборно послание на св ап. Иуда 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Съборно послание на св. ап Иуда 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Съборно послание на св ап Иуда 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Hið almenna bref Judasar 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Hið almenna bref Júdasar 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Hið almenna bréf Judasar 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Hið almenna bréf Júdasar 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Послание на апостол Јуда 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Poslanica Jude apostola 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Poslannja apostola Judy 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Писмо од апостол Јуда 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Послання апостола Юди 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yuta Elutiya Nirupam 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yuta Eḻutiya Nirupam 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yutā Elutiya Nirupam 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yutā Eḻutiya Nirupam 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yūta Elutiya Nirupam 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yūta Eḻutiya Nirupam 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yūtā Elutiya Nirupam 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yūtā Eḻutiya Nirupam 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Соборне послання Юди 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("யூதா எழுதிய நிருபம் 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahūdāh kā ʿām ḫaṭ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("رسالى القديس يهوذا 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("யூதா எழுதிய கடிதம் 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahūdāh dī pattrī 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("یہُوداہ کا عام خط 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judina poslanica 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Lettera di Giuda 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Посланица Јудина 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("یہوداہ کا عام خط 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ਯਹੂਦਾਹ ਦੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Juudaksen kirje 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahudacem patra 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahudaceṃ patra 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahudācem patra 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahudāceṃ patra 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahūdacem patra 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahūdaceṃ patra 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahūdācem patra 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahūdāceṃ patra 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Послание на Юда 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Epistula Iudae 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahudako patra 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahudāko patra 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahūdako patra 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahūdāko patra 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ଯିହୂଦାଙ୍କ ପତ୍ର 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("யூதா திருமுகம் 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Barua ya Yuda 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judas epistel 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judasarbrefið 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judasarbréfið 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Júdasarbrefið 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Júdasarbréfið 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("List sw. Judy 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("List św. Judy 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Послание Иуды 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Послання Іуди 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("यहूदाचें पत्र 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Layang Yudas 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("List sw Judy 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("List św Judy 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Послання Юди 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("यहूदाको पत्र 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judas' Brev 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judasarbref 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judasarbréf 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judasbrevet 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judas’ Brev 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judas’ brev 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Júdasarbref 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Júdasarbréf 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("איגרת יהודה 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("رسالة يهوذا 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judas brev 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judov List 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Júdov List 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("List Juduv 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("List Judův 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Јаковљевог 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("אגרת יהודה 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Juudaksen 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("List Judy 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("San Judas 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahudacem 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahudaceṃ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahudācem 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahudāceṃ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahūdacem 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahūdaceṃ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahūdācem 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahūdāceṃ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ଯିହୂଦାଙ୍କ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahudako 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahudāko 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahūdako 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahūdāko 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("यहूदाचें 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yahooda 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("yahūdāh 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("یہُوداہ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("यहूदाको 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ユタからの手紙 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ユダからの手紙 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Giu-đe 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judina 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judova 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yuudas 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Јудина 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("یہوداہ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ਯਹੂਦਾਹ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Giuda 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Giuđa 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Hudas 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Iudae 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judas 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judov 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judás 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Jwdas 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Júdas 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Júdov 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Júdás 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yudas 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Ιουδα 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Ιούδα 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("يهوذا 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("यहूदा 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《伊屋達》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《犹大书》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《猶大書》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《猶達書》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ユタの手紙 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ユダの手紙 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("유다 서간 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Iuda 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Jdas 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Juda 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Jude 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Judy 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Juud 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yuda 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yuta 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yutā 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yuud 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yūta 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yūtā 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Јуда 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Јуде 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Иуда 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Иуды 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("யூதா 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ยูดา 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《伊屋達 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《犹大书 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《猶大書 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《猶達書 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ユタの書 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ユダの書 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("伊屋達》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("犹大书》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("猶大書》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("猶達書》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Jde 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Jid 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Jwd 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Júd 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Yud 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Іуд 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Иуд 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Юда 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("يهو 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("᾿Ιδ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《犹》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《猶》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("伊屋達 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("犹大书 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("猶大書 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("猶達書 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("유다서 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Gd 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Јд 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Юд 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("يه 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ยด 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《犹 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《猶 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ユタ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ユダ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("犹》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("猶》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("유다 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("犹 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("猶 1:1").osis()).toEqual("Jude.1.1")
		p.include_apocrypha(false)
		expect(p.parse("LIST POWSZECHNY SWIETEGO IUDASA APOSTOŁA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("LIST POWSZECHNY SWIĘTEGO IUDASA APOSTOŁA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("LIST POWSZECHNY ŚWIETEGO IUDASA APOSTOŁA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("LIST POWSZECHNY ŚWIĘTEGO IUDASA APOSTOŁA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ЮДИ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ЮДИ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("СЪБОРНО ПОСЛАНИЕ НА СВ. АП. ИУДА 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("СЪБОРНО ПОСЛАНИЕ НА СВ АП. ИУДА 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("СЪБОРНО ПОСЛАНИЕ НА СВ. АП ИУДА 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("СЪБОРНО ПОСЛАНИЕ НА СВ АП ИУДА 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("HIÐ ALMENNA BREF JUDASAR 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("HIÐ ALMENNA BREF JÚDASAR 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("HIÐ ALMENNA BRÉF JUDASAR 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("HIÐ ALMENNA BRÉF JÚDASAR 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ПОСЛАНИЕ НА АПОСТОЛ ЈУДА 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("POSLANICA JUDE APOSTOLA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("POSLANNJA APOSTOLA JUDY 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ПИСМО ОД АПОСТОЛ ЈУДА 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ПОСЛАННЯ АПОСТОЛА ЮДИ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YUTA ELUTIYA NIRUPAM 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YUTA EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YUTĀ ELUTIYA NIRUPAM 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YUTĀ EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YŪTA ELUTIYA NIRUPAM 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YŪTA EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YŪTĀ ELUTIYA NIRUPAM 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YŪTĀ EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("СОБОРНЕ ПОСЛАННЯ ЮДИ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("யூதா எழுதிய நிருபம் 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHŪDĀH KĀ ʿĀM ḪAṬ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("رسالى القديس يهوذا 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("யூதா எழுதிய கடிதம் 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHŪDĀH DĪ PATTRĪ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("یہُوداہ کا عام خط 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDINA POSLANICA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("LETTERA DI GIUDA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ПОСЛАНИЦА ЈУДИНА 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("یہوداہ کا عام خط 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ਯਹੂਦਾਹ ਦੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUUDAKSEN KIRJE 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHUDACEM PATRA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHUDACEṂ PATRA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHUDĀCEM PATRA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHUDĀCEṂ PATRA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHŪDACEM PATRA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHŪDACEṂ PATRA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHŪDĀCEM PATRA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHŪDĀCEṂ PATRA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ПОСЛАНИЕ НА ЮДА 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("EPISTULA IUDAE 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHUDAKO PATRA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHUDĀKO PATRA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHŪDAKO PATRA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHŪDĀKO PATRA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ଯିହୂଦାଙ୍କ ପତ୍ର 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("யூதா திருமுகம் 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("BARUA YA YUDA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDAS EPISTEL 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDASARBREFIÐ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDASARBRÉFIÐ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JÚDASARBREFIÐ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JÚDASARBRÉFIÐ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("LIST SW. JUDY 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("LIST ŚW. JUDY 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ПОСЛАНИЕ ИУДЫ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ПОСЛАННЯ ІУДИ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("यहूदाचें पत्र 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("LAYANG YUDAS 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("LIST SW JUDY 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("LIST ŚW JUDY 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ПОСЛАННЯ ЮДИ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("यहूदाको पत्र 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDAS' BREV 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDASARBREF 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDASARBRÉF 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDASBREVET 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDAS’ BREV 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDAS’ BREV 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JÚDASARBREF 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JÚDASARBRÉF 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("איגרת יהודה 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("رسالة يهوذا 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDAS BREV 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDOV LIST 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JÚDOV LIST 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("LIST JUDUV 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("LIST JUDŮV 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ЈАКОВЉЕВОГ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("אגרת יהודה 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUUDAKSEN 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("LIST JUDY 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("SAN JUDAS 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHUDACEM 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHUDACEṂ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHUDĀCEM 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHUDĀCEṂ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHŪDACEM 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHŪDACEṂ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHŪDĀCEM 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHŪDĀCEṂ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ଯିହୂଦାଙ୍କ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHUDAKO 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHUDĀKO 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHŪDAKO 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHŪDĀKO 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("यहूदाचें 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHOODA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YAHŪDĀH 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("یہُوداہ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("यहूदाको 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ユタからの手紙 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ユダからの手紙 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("GIU-ĐE 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDINA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDOVA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YUUDAS 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ЈУДИНА 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("یہوداہ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ਯਹੂਦਾਹ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("GIUDA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("GIUĐA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("HUDAS 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("IUDAE 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDAS 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDOV 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDÁS 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JWDAS 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JÚDAS 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JÚDOV 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JÚDÁS 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YUDAS 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ΙΟΥΔΑ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ΙΟΎΔΑ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("يهوذا 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("यहूदा 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《伊屋達》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《犹大书》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《猶大書》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《猶達書》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ユタの手紙 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ユダの手紙 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("유다 서간 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("IUDA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JDAS 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDE 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUDY 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JUUD 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YUDA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YUTA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YUTĀ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YUUD 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YŪTA 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YŪTĀ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ЈУДА 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ЈУДЕ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ИУДА 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ИУДЫ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("யூதா 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ยูดา 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《伊屋達 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《犹大书 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《猶大書 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《猶達書 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ユタの書 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ユダの書 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("伊屋達》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("犹大书》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("猶大書》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("猶達書》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JDE 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JID 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JWD 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JÚD 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("YUD 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ІУД 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ИУД 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ЮДА 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("يهو 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("᾿ΙΔ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《犹》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《猶》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("伊屋達 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("犹大书 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("猶大書 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("猶達書 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("유다서 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("GD 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ЈД 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ЮД 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("يه 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ยด 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《犹 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("《猶 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ユタ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("ユダ 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("犹》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("猶》 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("유다 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("犹 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("猶 1:1").osis()).toEqual("Jude.1.1")
		`
		true
describe "Localized book 2Macc (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Macc (full)", ->
		`
		expect(p.parse("Druga knjiga o Makabejcima 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Secondo libro dei Maccabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Вторая книга Маккавеиская 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Вторая книга Маккавейская 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druga Ksiega Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druga Ksiegi Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druga Księga Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druga Księgi Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Drugi Ksiega Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Drugi Ksiegi Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Drugi Księga Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Drugi Księgi Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Kitabu cha Wamakabayo II 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Втора книга на Макавеите 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druha kniha Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhá kniha Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Toinen makkabilaiskirja 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druha kniha Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhy list Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhá kniha Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhý list Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Ksiega Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Ksiegi Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Księga Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Księgi Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Втора книга Макавеиска 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Втора книга Макавейска 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Ksiega Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Ksiegi Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Księga Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Księgi Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druga Ks. Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Drugi Ks. Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhy list Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhý list Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Ksiega Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Ksiegi Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Księga Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Księgi Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Ikalawang Mga Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Liber II Maccabaeorum 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Liber Maccabaeorum II 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Ksiega Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Ksiegi Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Księga Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Księgi Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-ге. книга Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-ге. книга Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Andra Mackabeerboken 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Andra Mackabéerboken 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druga Ks Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Drugi Ks Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. makkabilaiskirja 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Друга книга Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Друга книга Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Друге книга Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Друге книга Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-а. книга Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-а. книга Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-ге книга Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-ге книга Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-е. книга Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-е. книга Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. makkabilaiskirja 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Deuxiemes Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Deuxiemes Maccabées 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Deuxièmes Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Deuxièmes Maccabées 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II makkabilaiskirja 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Ks. Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Masodik Makkabeusok 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Második Makkabeusok 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Maccabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("سفر المكابين الثاني 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 makkabilaiskirja 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-а книга Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-а книга Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-е книга Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-е книга Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Ks. Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Anden Makkabæerbog 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Andre Makkabeerbok 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Deuxieme Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Deuxieme Maccabées 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Deuxième Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Deuxième Maccabées 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Ks. Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Ks Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. книга Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. книга Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Ikalawang Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Macabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Maccabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Maccabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Maccabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Ks. Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Ks Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Mackabeerboken 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Mackabéerboken 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. книга Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. книга Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druha Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhy Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhá Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhý Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Ks Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II книга Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II книга Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Ikalawang Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Onnur Makkabeabok 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Onnur Makkabeabók 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Macabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Macabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Macabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Maccabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Maccabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Maccabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Tweede Makkabeeen 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Tweede Makkabeeën 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Önnur Makkabeabok 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Önnur Makkabeabók 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Ks Machabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Mackabeerboken 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Mackabéerboken 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 k. Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 книга Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 книга Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Maccabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º. Maccabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druha Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druha Makabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druha Makabejská 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhy Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhy Makabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhy Makabejská 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhá Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhá Makabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhá Makabejská 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhý Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhý Makabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhý Makabejská 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Machabaeorum 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Seconda Maccabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Secondo Maccabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segunda Macabeus 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Macabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Macabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Macabeus 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Maccabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Zweite Makkabaer 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Zweite Makkabäer 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Друга Макабејаца 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Друга Макавејска 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 k Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 k. Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Machabaeorum 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Makkabeerbok 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Makkabæerbog 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Maccabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Macabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Maccabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Maccabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Maccabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º Maccabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º. Macabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º. Maccabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º. Maccabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º. Maccabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2eme. Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2eme. Maccabées 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Maccabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º. Maccabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2ème. Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2ème. Maccabées 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Machabaeorum 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabaeorum 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Makkabeusok 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Mga Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Machabaeorum II 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Pili Wamakabayo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Segundo Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("المكابين الثاني 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Machabaeorum 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Makkabeerbok 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Makkabæerbog 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 k Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-ге. Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-ге. Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-е. Маккавеев 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-я. Маккавеев 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabaeorum 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Makkabeusok 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Mga Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Macabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Maccabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Maccabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Maccabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Macabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Macabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Macabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Maccabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Maccabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Maccabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º Macabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º Maccabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º Maccabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º Maccabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º. Macabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º. Macabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º. Macabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º. Maccabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º. Maccabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º. Maccabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2de. Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2de. Maccabées 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2e. Makkabeeen 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2e. Makkabeeën 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2eme Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2eme Maccabées 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Maccabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Macabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Maccabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Maccabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Maccabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º Maccabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º. Macabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º. Maccabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º. Maccabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º. Maccabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2ème Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2ème Maccabées 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabaeorum 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Makkabeusok 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Mga Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Makabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Makabejská 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Makkabeeen 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Makkabeeën 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Wamakabayo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Макабејаца 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Макавејска 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Makkabeusok II 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Друга Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Друга Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Друга Макавеја 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Друге Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Друге Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabaeorum 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Machabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Makkabeusok 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Mga Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-а. Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-а. Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-ге Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-ге Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-е Маккавеев 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-е. Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-е. Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-я Маккавеев 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Makabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Makabejská 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Makkabeeen 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Makkabeeën 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Wamakabayo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Макабејаца 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Макавејска 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Macabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Macabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Macabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Maccabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Maccabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Maccabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Macabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Macabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Maccabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º Macabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º Macabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º Macabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º Maccabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º Maccabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º Maccabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º. Macabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º. Macabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º. Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º. Maccabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2d. Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2d. Maccabées 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2de Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2de Maccabées 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2e Makkabeeen 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2e Makkabeeën 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2e. Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2e. Maccabées 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Macabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Maccabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Maccabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Maccabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Macabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Macabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Macabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Maccabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Maccabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Maccabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º Macabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º Maccabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º Maccabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º Maccabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º. Macabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º. Macabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º. Macabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º. Maccabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º. Maccabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º. Maccabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2е. Маккавеев 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2я. Маккавеев 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Makabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Makabejská 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Makkabeeen 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Makkabeeën 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Wamakabayo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Макабејаца 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Макавејска 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabeaid 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabées 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Wamakabayo II 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Β' Μακκαβαίων 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Β' Μακκαβαιων 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Βʹ Μακκαβαίων 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Βʹ Μακκαβαιων 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Βʹ Μακκαβαίων 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Βʹ Μακκαβαιων 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Β΄ Μακκαβαίων 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Β΄ Μακκαβαιων 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Β’ Μακκαβαίων 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Β’ Μακκαβαιων 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Μακκαβαίων Β' 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Μακκαβαίων Βʹ 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Μακκαβαίων Βʹ 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Μακκαβαίων Β΄ 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Μακκαβαίων Β’ 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Μακκαβαιων Β' 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Μακκαβαιων Βʹ 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Μακκαβαιων Βʹ 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Μακκαβαιων Β΄ 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Μακκαβαιων Β’ 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Втора Макавеи 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Makabejcov 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Makabejska 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Makabejská 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Makkabeeen 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Makkabeeën 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Wamakabayo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Макабејаца 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Макавејска 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-а Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-а Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-е Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2-е Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabeaid 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabées 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Makkabaer 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Makkabäer 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Маккавеев 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Macabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Macabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Maccabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o. Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º Macabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º Macabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º Maccabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º. Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2a. Macabeus 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2d Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2d Maccabées 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2e Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2e Maccabées 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Macabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Macabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Macabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Maccabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Maccabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Maccabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Macabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Macabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Macabeus 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Maccabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2°. Maccabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º Macabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º Macabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º Macabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º Maccabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º Maccabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º Maccabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º. Macabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º. Macabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º. Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º. Maccabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2е Маккавеев 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2я Маккавеев 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabeaid 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabées 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabeus 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Макавеја 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Maccc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("ספר מקבים ב' 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("ספר מקבים ב’ 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabeaid 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabeees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabeeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabées 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Makkabaer 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Makkabäer 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Маккавеев 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 المكابيين 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 மக்கபேயர் 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabeus 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Макавеја 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.o Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2.º Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2a Macabeus 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Macabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Macabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Macabeus 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Maccabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o. Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2° Maccabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º Macabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º Macabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º Maccabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º. Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabeus 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Макавеја 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Макавеи 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Masodik Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Második Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("חשמונאים ב' 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("חשמונאים ב’ 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabeee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabeeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabees 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabeos 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabeus 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Макавеів 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Макавеїв 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Макавеја 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Макавеи 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. มัคคาบี 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Maccc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2o Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2º Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Anden Makk 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Andre Makk 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Макавеи 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Makabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Second Mac 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Tweede Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabbe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabee 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabei 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabeo 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabes 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Макавеи 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 มัคคาบี 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Makabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Maccc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druha Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhy Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhá Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Druhý Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Makabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Maccc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Makabe 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Maccc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd. Mac 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Maccc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Makk 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Pili Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("마카베오기 하권 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Maccc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Makk 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2e. Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2nd Mac 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Makk 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Mac 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II. Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Β' Μακκ 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Βʹ Μακκ 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Βʹ Μακκ 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Β΄ Μακκ 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("Β’ Μακκ 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("מקבים ב 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("マカヒー第二書 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("マカビー第二書 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Mach 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Mack 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Makk 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 makk 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Макк 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Mac 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2. Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2e Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Mac 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("II Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("《瑪加伯下》 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("マカハイ 2 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("マカハイ記2 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("マカハイ記下 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("マカバイ 2 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("マカバイ記2 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("マカバイ記下 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Mac 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Mak 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Mcb 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Mch 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Мак 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 மக் 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2Macc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("《瑪加伯下 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("マカハイ下 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("マカバイ下 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("瑪加伯下》 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("마카베오하 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Ma 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Mc 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 Мк 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 مك 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("瑪加伯下 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2 M 1:1").osis()).toEqual("2Macc.1.1")
		expect(p.parse("2마카 1:1").osis()).toEqual("2Macc.1.1")
		`
		true
describe "Localized book 3Macc (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 3Macc (full)", ->
		`
		expect(p.parse("Treca knjiga o Makabejcima 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Treća knjiga o Makabejcima 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Trzecia Ksiega Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Trzecia Ksiegi Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Trzecia Księga Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Trzecia Księgi Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Kitabu cha Wamakabayo III 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Trzeci Ksiega Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Trzeci Ksiegi Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Trzeci Księga Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Trzeci Księgi Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Третья книга Маккавеиская 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Третья книга Маккавейская 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Terzo libro dei Maccabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tretia kniha Machabejcov 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Трето книга на Макавеите 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Ksiega Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Ksiegi Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Księga Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Księgi Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Kolmas makkabilaiskirja 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Trzecia Ks. Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Ksiega Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Ksiegi Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Księga Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Księgi Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Liber III Maccabaeorum 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Liber Maccabaeorum III 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Trzeci Ks. Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Trzecia Ks Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Трета книга Макавеиска 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Трета книга Макавейска 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Ksiega Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Ksiegi Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Księga Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Księgi Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. makkabilaiskirja 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tredje Mackabeerboken 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tredje Mackabéerboken 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Trzeci Ks Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Ksiega Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Ksiegi Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Księga Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Księgi Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-тє. книга Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-тє. книга Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Harmadik Makkabeusok 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III makkabilaiskirja 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Ks. Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Ikatlong Mga Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Troisiemes Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Troisiemes Maccabées 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Troisièmes Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Troisièmes Maccabées 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Третя книга Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Третя книга Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Третє книга Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Третє книга Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-а. книга Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-а. книга Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-е. книга Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-е. книга Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-тє книга Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-тє книга Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. makkabilaiskirja 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Ks. Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Ks Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. книга Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. книга Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tredje Makkabeerbok 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tredje Makkabæerbog 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Troisieme Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Troisieme Maccabées 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Troisième Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Troisième Maccabées 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 makkabilaiskirja 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-а книга Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-а книга Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-е книга Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-е книга Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Ks. Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3e. Mackabeerboken 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3e. Mackabéerboken 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Ks Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III книга Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III книга Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tretia Machabejcov 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Þriðja Makkabeabok 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Þriðja Makkabeabók 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Ks. Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Ks Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Mackabeerboken 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Mackabéerboken 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. книга Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. книга Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3e Mackabeerboken 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3e Mackabéerboken 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Machabaeorum 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Ikatlong Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Terceira Macabeus 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Terceiro Macabeus 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Treti Machabejcov 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tretí Machabejcov 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Трећом Макабејаца 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Трећом Макавејска 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Ks Machabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Mackabeerboken 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Mackabéerboken 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 k. Machabejcov 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 книга Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 книга Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º. Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Derde Makkabeeen 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Derde Makkabeeën 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Dritte Makkabaer 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Dritte Makkabäer 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Machabaeorum 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabaeorum 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Machabejcov 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Makkabeusok 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Mga Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Ikatlong Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Machabaeorum III 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Treti Makabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Treti Makabejská 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tretí Makabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tretí Makabejská 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Třeti Makabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Třeti Makabejská 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Třetí Makabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Třetí Makabejská 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Трећа Макабејаца 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Трећа Макавејска 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 k Machabejcov 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Machabaeorum 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Makkabeerbok 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Makkabæerbog 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º. Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º. Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º. Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º. Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3eme. Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3eme. Maccabées 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º. Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3ème. Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3ème. Maccabées 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabaeorum 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Machabejcov 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Makkabeusok 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Mga Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Makabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Makabejská 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Makkabeeen 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Makkabeeën 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Wamakabayo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Макабејаца 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Макавејска 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Makkabeusok III 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tatu Wamakabayo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercero Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Трећом Макавеја 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("المكابين الثالث 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Machabaeorum 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Makkabeerbok 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Makkabæerbog 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-е. Маккавеев 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-тє. Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-тє. Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-я. Маккавеев 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabaeorum 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Machabejcov 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Makkabeusok 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Mga Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º. Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º. Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º. Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º. Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º. Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º. Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3e. Makkabeeen 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3e. Makkabeeën 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3eme Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3eme Maccabées 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º. Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º. Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º. Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º. Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3ème Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3ème Maccabées 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Makabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Makabejská 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Makkabeeen 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Makkabeeën 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Wamakabayo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Макабејаца 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Макавејска 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabeaid 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabées 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tercer Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Terza Maccabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Terzo Maccabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Wamakabayo III 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Третя Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Третя Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Третє Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Третє Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Трећа Макавеја 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabaeorum 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Machabejcov 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Makkabeusok 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Mga Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-а. Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-а. Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-е Маккавеев 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-е. Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-е. Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-тє Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-тє Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-я Маккавеев 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Makabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Makabejská 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Makkabeeen 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Makkabeeën 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Wamakabayo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Макабејаца 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Макавејска 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º. Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º. Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º. Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º. Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3e Makkabeeen 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3e Makkabeeën 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3e. Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3e. Maccabées 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º. Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º. Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º. Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º. Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º. Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º. Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3е. Маккавеев 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3я. Маккавеев 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabeaid 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabées 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabeus 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Макавеја 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Γ' Μακκαβαίων 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Γ' Μακκαβαιων 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Γʹ Μακκαβαίων 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Γʹ Μακκαβαιων 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Γʹ Μακκαβαίων 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Γʹ Μακκαβαιων 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Γ΄ Μακκαβαίων 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Γ΄ Μακκαβαιων 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Γ’ Μακκαβαίων 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Γ’ Μακκαβαιων 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Μακκαβαίων Γ' 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Μακκαβαίων Γʹ 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Μακκαβαίων Γʹ 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Μακκαβαίων Γ΄ 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Μακκαβαίων Γ’ 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Μακκαβαιων Γ' 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Μακκαβαιων Γʹ 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Μακκαβαιων Γʹ 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Μακκαβαιων Γ΄ 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Μακκαβαιων Γ’ 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Трето Макавеи 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Makabejska 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Makabejská 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Makkabeeen 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Makkabeeën 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Wamakabayo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Макабејаца 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Макавејска 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-а Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-а Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-е Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3-е Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabeaid 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabées 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Makkabaer 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Makkabäer 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Маккавеев 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o. Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º. Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3a. Macabeus 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3e Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3e Maccabées 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Macabeus 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3°. Maccabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º. Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º. Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º. Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º. Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3е Маккавеев 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3я Маккавеев 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Harmadik Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabeus 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Макавеја 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Макавеи 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("ספר מקבים ג' 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("ספר מקבים ג’ 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabeaid 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabeees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabeeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabées 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Makkabaer 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Makkabäer 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Маккавеев 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 மக்கபேயர் 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabeus 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Макавеја 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.o Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3.º Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3a Macabeus 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Macabeus 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o. Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3° Maccabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º. Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Макавеи 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Makabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Maccc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tredje Makk 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("חשמונאים ג' 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("חשמונאים ג’ 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabeee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabeeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabees 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabeos 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabeus 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Макавеів 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Макавеїв 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Макавеја 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Макавеи 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. มัคคาบี 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3o Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Maccc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3º Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Makabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Maccc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabbe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabee 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabei 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabeo 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabes 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Макавеи 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 มัคคาบี 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Makabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Maccc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Derde Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Maccc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Makk 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Third Mac 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Treti Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tretí Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Třeti Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Třetí Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Makabe 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Maccc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd. Mac 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Makk 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Mac 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III. Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Tatu Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Maccc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Makk 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3e. Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3rd Mac 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Mac 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("III Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Γ' Μακκ 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Γʹ Μακκ 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Γʹ Μακκ 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Γ΄ Μακκ 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("Γ’ Μακκ 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("מקבים ג 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("《3Macc》 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("マカヒー第三書 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("マカビー第三書 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("마카베오 3서 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Mach 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Mack 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Makk 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 makk 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Макк 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Mac 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3. Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3Macc》 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3e Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("《3Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("マカハイ 3 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("マカハイ記3 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("マカバイ 3 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("マカバイ記3 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Mac 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Mak 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Mcb 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Mch 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Мак 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 மக் 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3Macc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Mc 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 Мк 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3 M 1:1").osis()).toEqual("3Macc.1.1")
		expect(p.parse("3마카 1:1").osis()).toEqual("3Macc.1.1")
		`
		true
describe "Localized book 4Macc (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 4Macc (full)", ->
		`
		expect(p.parse("Четвърта книга на Макавеите 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Czwarta Ksiega Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Czwarta Ksiegi Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Czwarta Księga Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Czwarta Księgi Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Quarto libro dei Maccabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Kitabu cha Wamakabayo IV 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Stvrta kniha Machabejcov 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Stvrtá kniha Machabejcov 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Štvrta kniha Machabejcov 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Štvrtá kniha Machabejcov 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Czwarta Ks. Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Neljas makkabilaiskirja 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Neljäs makkabilaiskirja 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Четверта книга Макавеів 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Четверта книга Макавеїв 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Czwarta Ks Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Ksiega Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Ksiegi Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Księga Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Księgi Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Ksiega Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Ksiegi Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Księga Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Księgi Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fjarde Mackabeerboken 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fjarde Mackabéerboken 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fjärde Mackabeerboken 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fjärde Mackabéerboken 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Ksiega Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Ksiegi Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Księga Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Księgi Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Liber IV Maccabaeorum 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Liber Maccabaeorum IV 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Ksiega Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Ksiegi Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Księga Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Księgi Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. makkabilaiskirja 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Quatriemes Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Quatriemes Maccabées 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Quatrièmes Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Quatrièmes Maccabées 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. makkabilaiskirja 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fjerde Makkabeerbok 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fjerde Makkabæerbog 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV makkabilaiskirja 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Ks. Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Ikaapat Mga Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Quatrieme Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Quatrieme Maccabées 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Quatrième Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Quatrième Maccabées 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 makkabilaiskirja 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Ks. Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Maccabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fjorða Makkabeabok 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fjorða Makkabeabók 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fjórða Makkabeabok 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fjórða Makkabeabók 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Ks. Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Ks Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. книга Макавеів 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. книга Макавеїв 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Stvrta Machabejcov 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Stvrtá Machabejcov 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Štvrta Machabejcov 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Štvrtá Machabejcov 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Четврта Макабејаца 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Четврта Макавејска 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Ks. Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Ks Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Mackabeerboken 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Mackabéerboken 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. книга Макавеів 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. книга Макавеїв 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Ctvrta Makabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Ctvrta Makabejská 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Ctvrtá Makabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Ctvrtá Makabejská 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Macabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Maccabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Maccabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Maccabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Ks Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV книга Макавеів 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV книга Макавеїв 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Vierde Makkabeeen 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Vierde Makkabeeën 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Čtvrta Makabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Čtvrta Makabejská 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Čtvrtá Makabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Čtvrtá Makabejská 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Четверта Макавеів 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Четверта Макавеїв 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Ks Machabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Mackabeerboken 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Mackabéerboken 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 k. Machabejcov 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 книга Макавеів 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 книга Макавеїв 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Maccabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º. Maccabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Macabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Macabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Macabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Maccabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Maccabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Maccabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Machabaeorum 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Ikaapat Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Vierte Makkabaer 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Vierte Makkabäer 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Четврта Макавеја 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Четвърта Макавеи 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 k Machabejcov 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Machabaeorum 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Makkabeerbok 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Makkabæerbog 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Maccabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Macabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Maccabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Maccabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Maccabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º Maccabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º. Macabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º. Maccabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º. Maccabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º. Maccabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4eme. Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4eme. Maccabées 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Maccabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º. Maccabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4ème. Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4ème. Maccabées 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Macabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Macabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Maccabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Machabaeorum 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabaeorum 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Machabejcov 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Makkabeusok 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Mga Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Ikaapat Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Machabaeorum IV 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Quarta Macabeus 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Quarta Maccabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Quarto Macabeus 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Quarto Maccabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("المكابين الرابع 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Machabaeorum 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Makkabeerbok 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Makkabæerbog 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4-е. Маккавеев 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4-я. Маккавеев 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabaeorum 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Machabejcov 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Makkabeusok 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Mga Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Macabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Maccabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Maccabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Maccabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Macabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Macabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Macabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Maccabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Maccabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Maccabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º Macabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º Maccabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º Maccabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º Maccabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º. Macabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º. Macabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º. Macabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º. Maccabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º. Maccabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º. Maccabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4eme Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4eme Maccabées 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Maccabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Macabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Maccabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Maccabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Maccabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º Maccabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º. Macabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º. Maccabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º. Maccabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º. Maccabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4ème Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4ème Maccabées 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Cuarto Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabaeorum 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Machabejcov 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Makkabeusok 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Mga Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Makabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Makabejská 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Makkabeeen 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Makkabeeën 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Wamakabayo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Макабејаца 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Макавејска 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Makkabeusok IV 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Nne Wamakabayo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabaeorum 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Machabejcov 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Makkabeusok 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Mga Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4-е Маккавеев 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4-я Маккавеев 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Makabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Makabejská 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Makkabeeen 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Makkabeeën 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Wamakabayo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Макабејаца 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Макавејска 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Macabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Macabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Macabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Maccabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Maccabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Maccabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Macabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Macabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Maccabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º Macabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º Macabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º Macabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º Maccabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º Maccabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º Maccabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º. Macabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º. Macabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º. Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º. Maccabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4e. Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4e. Maccabées 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Macabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Maccabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Maccabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Maccabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Macabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Macabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Macabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Maccabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Maccabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Maccabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º Macabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º Maccabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º Maccabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º Maccabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º. Macabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º. Macabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º. Macabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º. Maccabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º. Maccabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º. Maccabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4е. Маккавеев 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4я. Маккавеев 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Makabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Makabejská 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Makkabeeen 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Makkabeeën 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Wamakabayo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Макабејаца 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Макавејска 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabeaid 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabées 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Wamakabayo IV 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Δ' Μακκαβαίων 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Δ' Μακκαβαιων 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Δʹ Μακκαβαίων 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Δʹ Μακκαβαιων 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Δʹ Μακκαβαίων 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Δʹ Μακκαβαιων 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Δ΄ Μακκαβαίων 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Δ΄ Μακκαβαιων 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Δ’ Μακκαβαίων 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Δ’ Μακκαβαιων 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Μακκαβαίων Δ' 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Μακκαβαίων Δʹ 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Μακκαβαίων Δʹ 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Μακκαβαίων Δ΄ 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Μακκαβαίων Δ’ 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Μακκαβαιων Δ' 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Μακκαβαιων Δʹ 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Μακκαβαιων Δʹ 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Μακκαβαιων Δ΄ 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Μακκαβαιων Δ’ 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Makabejska 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Makabejská 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Makkabeeen 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Makkabeeën 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Wamakabayo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Макабејаца 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Макавејска 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabeaid 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabées 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Makkabaer 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Makkabäer 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Маккавеев 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Macabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Macabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Maccabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o. Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º Macabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º Macabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º Maccabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º. Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4a. Macabeus 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4e Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4e Maccabées 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Macabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Macabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Macabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Maccabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Maccabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Maccabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Macabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Macabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Macabeus 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Maccabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4°. Maccabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º Macabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º Macabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º Macabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º Maccabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º Maccabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º Maccabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º. Macabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º. Macabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º. Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º. Maccabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4е Маккавеев 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4я Маккавеев 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Maccc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabeaid 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabées 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabeus 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Макавеів 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Макавеїв 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Макавеја 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("ספר מקבים ד' 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("ספר מקבים ד’ 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabeaid 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabeees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabeeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabées 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Makkabaer 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Makkabäer 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Маккавеев 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 மக்கபேயர் 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabeus 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Макавеів 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Макавеїв 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Макавеја 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.o Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4.º Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4a Macabeus 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Macabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Macabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Macabeus 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Maccabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o. Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4° Maccabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º Macabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º Macabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º Maccabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º. Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fjerde Makk 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabeus 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Макавеів 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Макавеїв 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Макавеја 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Макавеи 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("חשמונאים ד' 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("חשמונאים ד’ 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabeee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabeeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabees 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabeos 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabeus 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Макавеів 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Макавеїв 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Макавеја 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Макавеи 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. มัคคาบี 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4o Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Maccc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4º Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Ctvrta Mak 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Ctvrtá Mak 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Fourth Mac 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Макавеи 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Makabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Vierde Mak 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Čtvrta Mak 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Čtvrtá Mak 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabbe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabee 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabei 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabeo 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabes 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Макавеи 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 มัคคาบี 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Makabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Maccc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Makabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Maccc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Makabe 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Maccc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th. Mac 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Maccc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Makk 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Maccc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Makk 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4th Mac 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Makk 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Mac 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV. Mak 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Nne Mak 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Δ' Μακκ 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Δʹ Μακκ 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Δʹ Μακκ 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Δ΄ Μακκ 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("Δ’ Μακκ 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("מקבים ד 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("《4Macc》 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("マカヒー第四書 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("マカビー第四書 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("마카베오 4서 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Mach 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Mack 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Makk 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 makk 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Макк 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Mac 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4. Mak 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4Macc》 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Mac 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("IV Mak 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("《4Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("マカハイ 4 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("マカハイ記4 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("マカバイ 4 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("マカバイ記4 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Mac 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Mak 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Mcb 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Mch 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Мак 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 மக் 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4Macc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Mc 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 Мк 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4 M 1:1").osis()).toEqual("4Macc.1.1")
		expect(p.parse("4마카 1:1").osis()).toEqual("4Macc.1.1")
		`
		true
describe "Localized book 1Macc (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Macc (full)", ->
		`
		expect(p.parse("Ensimmainen makkabilaiskirja 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Ensimmäinen makkabilaiskirja 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwsza Ksiega Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwsza Ksiegi Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwsza Księga Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwsza Księgi Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwsze Ksiega Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwsze Ksiegi Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwsze Księga Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwsze Księgi Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwszy Ksiega Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwszy Ksiegi Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwszy Księga Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwszy Księgi Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prva knjiga o Makabejcima 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Первая книга Маккавеиская 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Первая книга Маккавейская 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwsza Ks. Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwsze Ks. Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwszy Ks. Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primo libro dei Maccabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Първа книга на Макавеите 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Kitabu cha Wamakabayo I 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwsza Ks Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwsze Ks Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Pierwszy Ks Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prva kniha Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prvá kniha Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Първа книга Макавеиска 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Първа книга Макавейска 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Ksiega Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Ksiegi Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Księga Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Księgi Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Forsta Mackabeerboken 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Forsta Mackabéerboken 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Första Mackabeerboken 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Första Mackabéerboken 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Ksiega Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Ksiegi Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Księga Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Księgi Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prvy list Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prvý list Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Ksiega Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Ksiegi Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Księga Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Księgi Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-ше. книга Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-ше. книга Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Ksiega Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Ksiegi Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Księga Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Księgi Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Liber I Maccabaeorum 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Liber Maccabaeorum I 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Перша книга Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Перша книга Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Перше книга Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Перше книга Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-а. книга Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-а. книга Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-е. книга Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-е. книга Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-ше книга Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-ше книга Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. makkabilaiskirja 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Første Makkabeerbok 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Første Makkabæerbog 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. makkabilaiskirja 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Premieres Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Premieres Maccabées 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Premières Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Premières Maccabées 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 makkabilaiskirja 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-а книга Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-а книга Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-е книга Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-е книга Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Ks. Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Fyrsta Makkabeabok 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Fyrsta Makkabeabók 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I makkabilaiskirja 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Ks. Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Premiere Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Premiere Maccabées 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Premiers Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Premiers Maccabées 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Première Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Première Maccabées 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("سفر المكابين الأول 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Ks. Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Ks Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Mackabeerboken 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Mackabéerboken 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. книга Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. книга Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Eerste Makkabeeen 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Eerste Makkabeeën 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Ks. Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Ks Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. книга Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. книга Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Kwanza Wamakabayo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Premier Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Premier Maccabées 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primeira Macabeus 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primeiro Macabeus 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Unang Mga Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Ks Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Mackabeerboken 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Mackabéerboken 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 k. Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 книга Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 книга Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º. Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Elso Makkabeusok 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Első Makkabeusok 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Ks Machabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I книга Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I книга Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prva Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prvni Makabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prvni Makabejská 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("První Makabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("První Makabejská 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prvy Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prvá Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prvý Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 k Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Machabaeorum 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Makkabeerbok 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Makkabæerbog 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º. Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º. Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º. Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º. Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1ere. Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1ere. Maccabées 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º. Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1ère. Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1ère. Maccabées 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Erste Makkabaer 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Erste Makkabäer 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Machabaeorum 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primero Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prva Makabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prvá Makabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Una Mga Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Прва Макабејаца 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Прва Макавејска 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Machabaeorum 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Makkabeerbok 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Makkabæerbog 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-е. Маккавеев 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-ше. Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-ше. Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-я. Маккавеев 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabaeorum 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Makkabeusok 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Mga Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º. Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º. Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º. Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º. Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º. Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º. Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1e. Makkabeeen 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1e. Makkabeeën 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1er. Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1er. Maccabées 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1ere Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1ere Maccabées 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1re. Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1re. Maccabées 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º. Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º. Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º. Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º. Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1ère Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1ère Maccabées 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Machabaeorum 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabaeorum 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Makkabeusok 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Mga Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Machabaeorum I 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prima Maccabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primer Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Primo Maccabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Unang Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Перша Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Перша Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Перше Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Перше Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("المكابين الأول 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabaeorum 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Makkabeusok 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Mga Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-а. Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-а. Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-е Маккавеев 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-е. Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-е. Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-ше Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-ше Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-я Маккавеев 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Makabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Makabejská 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Makkabeeen 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Makkabeeën 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Wamakabayo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Макабејаца 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Макавејска 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º. Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º. Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º. Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º. Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1e Makkabeeen 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1e Makkabeeën 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1er Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1er Maccabées 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1re Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1re Maccabées 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º. Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º. Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º. Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º. Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º. Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º. Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1е. Маккавеев 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1я. Маккавеев 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabaeorum 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Machabejcov 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Makkabeusok 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Mga Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Makabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Makabejská 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Makkabeeen 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Makkabeeën 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Wamakabayo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Макабејаца 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Макавејска 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Makkabeusok I 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Unang Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Α' Μακκαβαίων 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Α' Μακκαβαιων 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Αʹ Μακκαβαίων 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Αʹ Μακκαβαιων 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Αʹ Μακκαβαίων 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Αʹ Μακκαβαιων 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Α΄ Μακκαβαίων 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Α΄ Μακκαβαιων 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Α’ Μακκαβαίων 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Α’ Μακκαβαιων 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Μακκαβαίων Α' 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Μακκαβαίων Αʹ 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Μακκαβαίων Αʹ 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Μακκαβαίων Α΄ 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Μακκαβαίων Α’ 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Μακκαβαιων Α' 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Μακκαβαιων Αʹ 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Μακκαβαιων Αʹ 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Μακκαβαιων Α΄ 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Μακκαβαιων Α’ 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Прва Макавеја 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Първа Макавеи 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Makabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Makabejská 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Makkabeeen 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Makkabeeën 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Wamakabayo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Макабејаца 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Макавејска 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-а Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-а Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-е Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1-е Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabeaid 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabées 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Makkabaer 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Makkabäer 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Маккавеев 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o. Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º. Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1a. Macabeus 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Macabeus 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1°. Maccabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º. Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º. Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º. Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º. Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1е Маккавеев 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1я Маккавеев 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Makabejska 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Makabejská 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Makkabeeen 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Makkabeeën 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Wamakabayo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Макабејаца 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Макавејска 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabeaid 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabées 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Una Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Wamakabayo I 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("ספר מקבים א' 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("ספר מקבים א’ 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabeaid 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabées 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Makkabaer 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Makkabäer 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Маккавеев 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 المكابيين 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 மக்கபேயர் 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabeus 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Макавеја 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.o Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1.º Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1a Macabeus 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Macabeus 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o. Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1° Maccabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º. Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Maccc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Første Makk 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabeaid 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabeees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabeeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabées 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabeus 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Макавеја 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Una Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("חשמונאים א' 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("חשמונאים א’ 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabeus 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Макавеја 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Макавеи 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. มัคคาบี 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1o Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Maccc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1º Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Eerste Mak 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabeee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabeeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabeos 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabeus 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Макавеів 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Макавеїв 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Макавеја 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Макавеи 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Kwanza Mak 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Макавеи 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 มัคคาบี 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Makabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Maccc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("First Mac 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabbe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabee 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabei 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabeo 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabes 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Макавеи 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Makabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Maccabees 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Prvni Mak 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("První Mak 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Makabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Maccc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st. Mac 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Elso Mak 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Első Mak 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Makabe 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Maccc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("마카베오기 상권 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Maccc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Makk 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1e. Mak 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1st Mac 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Maccc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Makk 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Α' Μακκ 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Αʹ Μακκ 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Αʹ Μακκ 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Α΄ Μακκ 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("Α’ Μακκ 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("מקבים א 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("マカヒー第一書 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("マカビー第一書 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Mach 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Mack 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Makk 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 makk 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Макк 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Mac 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1. Mak 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1e Mak 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Makk 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Mac 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I. Mak 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("《瑪加伯上》 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("マカハイ 1 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("マカハイ記1 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("マカハイ記上 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("マカバイ 1 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("マカバイ記1 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("マカバイ記上 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Mac 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Mak 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Mcb 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Mch 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Мак 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 மக் 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1Macc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Mac 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("I Mak 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("《瑪加伯上 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("マカハイ上 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("マカバイ上 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("瑪加伯上》 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("마카베오상 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Ma 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Mc 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 Мк 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 مك 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("瑪加伯上 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1 M 1:1").osis()).toEqual("1Macc.1.1")
		expect(p.parse("1마카 1:1").osis()).toEqual("1Macc.1.1")
		`
		true
describe "Localized book Mark (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Mark (full)", ->
		`
		expect(p.parse("Mabuting Balita ayon kay San Marcos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mabuting Balita ayon kay San Markos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Saint Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Saint Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Saint Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Saint Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Saint Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St. Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mabuting Balita ayon kay Marcos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mabuting Balita ayon kay Markos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St. Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St. Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Saint Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St. Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St. Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markane lihilele subʰavartaman 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markane lihilele subʰavartamān 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markane lihilele ŝubʰavartaman 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markane lihilele ŝubʰavartamān 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markāne lihilele subʰavartaman 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markāne lihilele subʰavartamān 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markāne lihilele ŝubʰavartaman 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markāne lihilele ŝubʰavartamān 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("mārkane lihilele subʰavartaman 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("mārkane lihilele subʰavartamān 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("mārkane lihilele ŝubʰavartaman 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("mārkane lihilele ŝubʰavartamān 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("mārkāne lihilele subʰavartaman 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("mārkāne lihilele subʰavartamān 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("mārkāne lihilele ŝubʰavartaman 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("mārkāne lihilele ŝubʰavartamān 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Saint Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Saint Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to St Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Evankeliumi Markuksen mukaan 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Saint Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Saint Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St. Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("मार्काने लिहिलेले शुभवर्तमान 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St. Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St. Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ebanghelyo ayon kay Marcos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Evangelium secundum Marcum 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ewangelia według sw. Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ewangelia według św. Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St. Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St. Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel according to Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ewangelia według sw Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ewangelia według św Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to St Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markusle lekʰeko susmacar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markusle lekʰeko susmacār 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markusle lekʰeko susmācar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markusle lekʰeko susmācār 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markūsle lekʰeko susmacar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markūsle lekʰeko susmacār 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markūsle lekʰeko susmācar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markūsle lekʰeko susmācār 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ebanghelyo ni San Marcos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ebanghelyo ni San Markos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Evangelie volgens Marcus 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Evangelie volgens Markus 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Saint Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Евангелието според Марко 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("От Марка свето Евангелие 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("मर्कूसले लेखेको सुसमाचार 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Evangeliet etter Markus 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Saint Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Saint Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Євангелія від св. Марка 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Євангеліє від св. Марка 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("மாற்கு எழுதிய சுவிசேஷம் 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("மாற்கு எழுதிய நற்செய்தி 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("El Evangelio de Marcos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Evangelium podle Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Evanjelium Podla Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Evanjelium Podľa Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ewangelia wg sw. Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ewangelia wg św. Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel according to Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Saint Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Saint Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St. Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Євангелія від св Марка 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Євангеліє від св Марка 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Евангелие според Марко 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ewangelia wg sw Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ewangelia wg św Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Jevanhelije vid Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Markuksen evankeliumi 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St. Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St. Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ମାର୍କ ଲିଖିତ ସୁସମାଗ୍ଭର 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ebanghelyo ni Marcos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ebanghelyo ni Markos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Saint Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St. Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St. Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Vangelo di San Marco 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Evangelio de Marcos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Saint Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Saint Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Jevanđelje po Marku 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Sulat ni San Marcos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of St Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Євангелія від Марка 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Євангеліє від Марка 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("พระวรสารนักบุญมาร์ค 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Evanðelje po Marku 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Evanđelje po Marku 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Saint Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Saint Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St. Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Markovo evangelium 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Јеванђеље по Марку 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Евангелие от Марка 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Евангелие от Марко 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("הבשורה על פי מרקוס 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("הבשורה על-פי מרקוס 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St. Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St. Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Markus evangelium 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Markusarguðspjall 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Markúsarguðspjall 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ungjilli i Markut 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Еванђеље по Марку 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("मर्कूसको सुसमाचार 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St. Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St. Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Markusevangeliet 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("The Gospel of Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Vangelo di Marco 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("மாற்கு நற்செய்தி 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ewangelia Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of St Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Injili ya Marko 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("marqus kī injīl 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marku Narceyti 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marku Naṛceyti 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Maṛku Narceyti 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Maṛku Naṛceyti 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mārku Narceyti 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mārku Naṛceyti 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Māṛku Narceyti 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Māṛku Naṛceyti 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markus dī ĩjīl 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("مرقُس کی انجیل 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ਮਰਕੁਸ ਦੀ ਇੰਜੀਲ 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("مرقس کی انجیل 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Gospel of Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Injil Markus 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Κατά Μάρκον 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Κατά Μαρκον 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Κατα Μάρκον 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Κατα Μαρκον 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Saint Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("San Marcos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("إنجيل مرقس 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ew. Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Markuksen 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Saint Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Saint Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Від Марка 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("マルコによる福音書 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ew Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Saint Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Saint Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St. Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markusle 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markūsle 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("От Марка 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("मर्कूसले 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("मार्काने 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marakus 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St. Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St. Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markane 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markāne 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("mārkane 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("mārkāne 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("《馬爾谷福音》 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("マルコ傳福音書 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("마르코 복음서 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Ew Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marcos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marcus 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Markos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Markus 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St. Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St. Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("markus 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Μάρκος 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Μαρκος 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("मर्कुस 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("मर्कूश 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("मर्कूस 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("र्मकूस 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("மாற்கு 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("มาระโก 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("《馬可福音》 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("《馬爾谷福音 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("《马可福音》 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("マルコ福音書 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("馬爾谷福音》 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("마르코 복음 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marco 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marcu 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marek 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marka 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marko 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marku 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Maṛku 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mrcos 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Máccô 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mārku 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Māṛku 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("St Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Маркo 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Марка 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Марко 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("मरकुस 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("मार्क 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("र्मकस 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ਮਰਕੁਸ 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ମାର୍କ 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("《瑪爾克》 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("《馬可福音 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("《马可福音 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("馬可福音》 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("馬爾谷福音 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("马可福音》 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("마가복음서 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Marc 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mark 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Márk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Μάρκ 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Μαρκ 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Марк 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("مرقس 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("மாற் 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("《瑪爾克 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("マルコ伝 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("マルコ書 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("瑪爾克》 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("馬可福音 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("马可福音 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("마가복음 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mar 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mrc 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mrk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mác 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("《可》 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("瑪爾克 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mc 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mk 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Mr 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Μρ 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Мк 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("Мр 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("مر 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("มก 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("《可 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("可》 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("마가 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("마르 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("可 1:1").osis()).toEqual("Mark.1.1")
		p.include_apocrypha(false)
		expect(p.parse("MABUTING BALITA AYON KAY SAN MARCOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MABUTING BALITA AYON KAY SAN MARKOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO SAINT MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MABUTING BALITA AYON KAY MARCOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MABUTING BALITA AYON KAY MARKOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST. MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKANE LIHILELE SUBʰAVARTAMAN 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKANE LIHILELE SUBʰAVARTAMĀN 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKANE LIHILELE ŜUBʰAVARTAMAN 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKANE LIHILELE ŜUBʰAVARTAMĀN 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKĀNE LIHILELE SUBʰAVARTAMAN 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKĀNE LIHILELE SUBʰAVARTAMĀN 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKĀNE LIHILELE ŜUBʰAVARTAMAN 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKĀNE LIHILELE ŜUBʰAVARTAMĀN 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MĀRKANE LIHILELE SUBʰAVARTAMAN 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MĀRKANE LIHILELE SUBʰAVARTAMĀN 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MĀRKANE LIHILELE ŜUBʰAVARTAMAN 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MĀRKANE LIHILELE ŜUBʰAVARTAMĀN 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MĀRKĀNE LIHILELE SUBʰAVARTAMAN 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MĀRKĀNE LIHILELE SUBʰAVARTAMĀN 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MĀRKĀNE LIHILELE ŜUBʰAVARTAMAN 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MĀRKĀNE LIHILELE ŜUBʰAVARTAMĀN 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO ST MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EVANKELIUMI MARKUKSEN MUKAAN 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO SAINT MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("मार्काने लिहिलेले शुभवर्तमान 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EBANGHELYO AYON KAY MARCOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EVANGELIUM SECUNDUM MARCUM 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EWANGELIA WEDŁUG SW. MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EWANGELIA WEDŁUG ŚW. MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST. MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL ACCORDING TO MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EWANGELIA WEDŁUG SW MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EWANGELIA WEDŁUG ŚW MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO ST MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKUSLE LEKʰEKO SUSMACAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKUSLE LEKʰEKO SUSMACĀR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKUSLE LEKʰEKO SUSMĀCAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKUSLE LEKʰEKO SUSMĀCĀR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKŪSLE LEKʰEKO SUSMACAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKŪSLE LEKʰEKO SUSMACĀR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKŪSLE LEKʰEKO SUSMĀCAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKŪSLE LEKʰEKO SUSMĀCĀR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EBANGHELYO NI SAN MARCOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EBANGHELYO NI SAN MARKOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EVANGELIE VOLGENS MARCUS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EVANGELIE VOLGENS MARKUS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ЕВАНГЕЛИЕТО СПОРЕД МАРКО 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ОТ МАРКА СВЕТО ЕВАНГЕЛИЕ 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("मर्कूसले लेखेको सुसमाचार 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EVANGELIET ETTER MARKUS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ЄВАНГЕЛІЯ ВІД СВ. МАРКА 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ЄВАНГЕЛІЄ ВІД СВ. МАРКА 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("மாற்கு எழுதிய சுவிசேஷம் 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("மாற்கு எழுதிய நற்செய்தி 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EL EVANGELIO DE MARCOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EVANGELIUM PODLE MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EVANJELIUM PODLA MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EVANJELIUM PODĽA MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EWANGELIA WG SW. MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EWANGELIA WG ŚW. MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL ACCORDING TO MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF SAINT MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST. MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ЄВАНГЕЛІЯ ВІД СВ МАРКА 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ЄВАНГЕЛІЄ ВІД СВ МАРКА 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ЕВАНГЕЛИЕ СПОРЕД МАРКО 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EWANGELIA WG SW MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EWANGELIA WG ŚW MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("JEVANHELIJE VID MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKUKSEN EVANKELIUMI 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST. MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST. MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ମାର୍କ ଲିଖିତ ସୁସମାଗ୍ଭର 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EBANGHELYO NI MARCOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EBANGHELYO NI MARKOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF SAINT MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST. MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST. MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("VANGELO DI SAN MARCO 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EVANGELIO DE MARCOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF SAINT MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF SAINT MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("JEVANĐELJE PO MARKU 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("SULAT NI SAN MARCOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF ST MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ЄВАНГЕЛІЯ ВІД МАРКА 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ЄВАНГЕЛІЄ ВІД МАРКА 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("พระวรสารนักบุญมาร์ค 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EVANÐELJE PO MARKU 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EVANĐELJE PO MARKU 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF SAINT MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF SAINT MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST. MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKOVO EVANGELIUM 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ЈЕВАНЂЕЉЕ ПО МАРКУ 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ЕВАНГЕЛИЕ ОТ МАРКА 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ЕВАНГЕЛИЕ ОТ МАРКО 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("הבשורה על פי מרקוס 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("הבשורה על-פי מרקוס 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST. MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST. MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKUS EVANGELIUM 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKUSARGUÐSPJALL 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKÚSARGUÐSPJALL 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("UNGJILLI I MARKUT 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ЕВАНЂЕЉЕ ПО МАРКУ 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("मर्कूसको सुसमाचार 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST. MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST. MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKUSEVANGELIET 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("THE GOSPEL OF MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("VANGELO DI MARCO 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("மாற்கு நற்செய்தி 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EWANGELIA MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF ST MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("INJILI YA MARKO 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARQUS KĪ INJĪL 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKU NARCEYTI 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKU NAṚCEYTI 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MAṚKU NARCEYTI 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MAṚKU NAṚCEYTI 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MĀRKU NARCEYTI 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MĀRKU NAṚCEYTI 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MĀṚKU NARCEYTI 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MĀṚKU NAṚCEYTI 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKUS DĪ ĨJĪL 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("مرقُس کی انجیل 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ਮਰਕੁਸ ਦੀ ਇੰਜੀਲ 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("مرقس کی انجیل 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("GOSPEL OF MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("INJIL MARKUS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ΚΑΤΆ ΜΆΡΚΟΝ 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ΚΑΤΆ ΜΑΡΚΟΝ 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ΚΑΤΑ ΜΆΡΚΟΝ 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ΚΑΤΑ ΜΑΡΚΟΝ 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("SAINT MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("SAN MARCOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("إنجيل مرقس 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EW. MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKUKSEN 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("SAINT MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("SAINT MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ВІД МАРКА 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("マルコによる福音書 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EW MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("SAINT MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("SAINT MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST. MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKUSLE 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKŪSLE 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ОТ МАРКА 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("मर्कूसले 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("मार्काने 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARAKUS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST. MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST. MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKANE 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKĀNE 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MĀRKANE 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MĀRKĀNE 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("《馬爾谷福音》 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("マルコ傳福音書 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("마르코 복음서 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("EW MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARCOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARCUS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKUS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST. MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST. MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKUS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ΜΆΡΚΟΣ 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ΜΑΡΚΟΣ 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("मर्कुस 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("मर्कूश 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("मर्कूस 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("र्मकूस 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("மாற்கு 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("มาระโก 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("《馬可福音》 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("《馬爾谷福音 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("《马可福音》 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("マルコ福音書 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("馬爾谷福音》 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("마르코 복음 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARCO 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARCU 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MAREK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKA 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKO 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARKU 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MAṚKU 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MRCOS 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MÁCCÔ 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MĀRKU 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MĀṚKU 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ST MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("МАРКO 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("МАРКА 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("МАРКО 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("मरकुस 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("मार्क 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("र्मकस 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ਮਰਕੁਸ 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ମାର୍କ 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("《瑪爾克》 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("《馬可福音 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("《马可福音 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("馬可福音》 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("馬爾谷福音 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("马可福音》 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("마가복음서 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARC 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MARK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MÁRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ΜΆΡΚ 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ΜΑΡΚ 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("МАРК 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("مرقس 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("மாற் 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("《瑪爾克 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("マルコ伝 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("マルコ書 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("瑪爾克》 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("馬可福音 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("马可福音 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("마가복음 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MAR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MRC 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MRK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MÁC 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("《可》 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("瑪爾克 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MC 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MK 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("MR 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("ΜΡ 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("МК 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("МР 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("مر 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("มก 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("《可 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("可》 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("마가 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("마르 1:1").osis()).toEqual("Mark.1.1")
		expect(p.parse("可 1:1").osis()).toEqual("Mark.1.1")
		`
		true
describe "Localized book Jas (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Jas (full)", ->
		`
		expect(p.parse("List powszechny Swietego Iakuba Apostoła 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("List powszechny Swiętego Iakuba Apostoła 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("List powszechny Świetego Iakuba Apostoła 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("List powszechny Świętego Iakuba Apostoła 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Соборне послання св. апостола Якова 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Соборне послання св апостола Якова 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Съборно послание на св. ап. Иакова 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Съборно послание на св ап. Иакова 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Съборно послание на св. ап Иакова 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Съборно послание на св ап Иакова 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Poslannja apostola Jakova 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Послание на апостол Јаков 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("யாக்கோபு எழுதிய திருமுகம் 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Hið almenna bref Jakobs 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Hið almenna bréf Jakobs 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yakkopu Elutiya Nirupam 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yakkopu Eḻutiya Nirupam 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yakkōpu Elutiya Nirupam 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yakkōpu Eḻutiya Nirupam 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yākkopu Elutiya Nirupam 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yākkopu Eḻutiya Nirupam 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yākkōpu Elutiya Nirupam 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yākkōpu Eḻutiya Nirupam 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Послання апостола Якова 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("யாக்கோபு எழுதிய நிருபம் 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Писмо од апостол Јаков 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Соборне послання Якова 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("யாக்கோபு எழுதிய கடிதம் 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakovljeva poslanica 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Посланица Јаковљева 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Lettera di Giacomo 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("رسالة القديس يعقوب 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("யாகப்பர் திருமுகம் 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("யாக்கோபு திருமுகம் 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yaʿqūb kā ʿām ḫaṭ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Waraka wa Yakobo 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Послание на Яков 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("یعقوب کا عا م خط 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("یعقُوب کا عام خط 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Barua ya Yakobo 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Epistula Iacobi 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("List sw. Jakuba 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("List św. Jakuba 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yakobacem patra 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yakobaceṃ patra 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yakobācem patra 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yakobāceṃ patra 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yākobacem patra 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yākobaceṃ patra 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yākobācem patra 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yākobāceṃ patra 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yākūb dī pattrī 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Послание Иакова 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("یعقوب کا عام خط 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ਯਾਕੂਬ ਦੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jaakobin kirje 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakobs epistel 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Layang Yakobus 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("List sw Jakuba 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("List św Jakuba 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Послання Якова 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("याकोबाचें पत्र 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yakubko patra 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yakūbko patra 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yākubko patra 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yākūbko patra 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ଯାକୁବଙ୍କ ପତ୍ର 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakobsbrefið 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakobsbrevet 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakobsbréfið 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakobusbrief 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakubov List 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("List Jakubuv 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("List Jakubův 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("याकूबको पत्र 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakobs Brev 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakobs brev 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("List Jakuba 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("رسالة يعقوب 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakovljeva 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("איגרת יעקב 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yakobacem 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yakobaceṃ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yakobācem 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yakobāceṃ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yākobacem 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yākobaceṃ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yākobācem 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yākobāceṃ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Јаковљева 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("אגרת יעקב 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("याकोबाचें 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jaakobin 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Santiago 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Јаковова 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ଯାକୁବଙ୍କ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("யாக்கோபு 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ヤコフからの手紙 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ヤコブからの手紙 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Giacomo 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Giacôbê 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jacques 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakobit 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakobus 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakubov 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yacquub 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yakkopu 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yakkōpu 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yakobus 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yākkopu 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yākkōpu 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yakubko 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yakūbko 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yākubko 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yākūbko 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Ιακωβου 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Ιακώβου 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("याकूबको 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Gia-cơ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Iacobi 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jacobo 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakobi 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakobs 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakuba 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jaques 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yakobo 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yakoob 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Иакова 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("یعقُوب 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("《雅各伯書》 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ヤコフの手紙 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ヤコブの手紙 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("야고보 서간 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Iacob 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Iacov 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakab 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakob 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jakub 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("James 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Tiago 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("yākūb 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Јаков 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Якова 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("يعقوب 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("یعقوب 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("याकूब 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("याकोब 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ਯਾਕੂਬ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ยากอบ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("《亞适烏》 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("《雅各书》 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("《雅各伯書 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("《雅各書》 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ヤコフの書 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ヤコブの書 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("雅各伯書》 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Iago 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jaak 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jacq 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jame 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Sant 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yacq 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Яков 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Якуб 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("யாக் 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("《亞适烏 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("《雅各书 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("《雅各書 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ヤコフ書 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ヤコブ書 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("亞适烏》 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("雅各书》 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("雅各伯書 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("雅各書》 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("야고보서 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Iac 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Iag 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jac 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jak 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jam 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jas 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jms 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("San 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Stg 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yac 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Yak 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Јак 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Иак 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("᾿Ια 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("《雅》 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ヤコフ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ヤコブ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("亞适烏 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("雅各书 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("雅各書 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Gc 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Gm 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Ja 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jk 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Jm 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("St 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Tg 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("Як 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("يع 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ยก 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ยบ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("《雅 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("雅》 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("야고 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("雅 1:1").osis()).toEqual("Jas.1.1")
		p.include_apocrypha(false)
		expect(p.parse("LIST POWSZECHNY SWIETEGO IAKUBA APOSTOŁA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("LIST POWSZECHNY SWIĘTEGO IAKUBA APOSTOŁA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("LIST POWSZECHNY ŚWIETEGO IAKUBA APOSTOŁA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("LIST POWSZECHNY ŚWIĘTEGO IAKUBA APOSTOŁA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("СОБОРНЕ ПОСЛАННЯ СВ. АПОСТОЛА ЯКОВА 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("СОБОРНЕ ПОСЛАННЯ СВ АПОСТОЛА ЯКОВА 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("СЪБОРНО ПОСЛАНИЕ НА СВ. АП. ИАКОВА 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("СЪБОРНО ПОСЛАНИЕ НА СВ АП. ИАКОВА 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("СЪБОРНО ПОСЛАНИЕ НА СВ. АП ИАКОВА 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("СЪБОРНО ПОСЛАНИЕ НА СВ АП ИАКОВА 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("POSLANNJA APOSTOLA JAKOVA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ПОСЛАНИЕ НА АПОСТОЛ ЈАКОВ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("யாக்கோபு எழுதிய திருமுகம் 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("HIÐ ALMENNA BREF JAKOBS 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("HIÐ ALMENNA BRÉF JAKOBS 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKKOPU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKKOPU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKKŌPU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKKŌPU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YĀKKOPU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YĀKKOPU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YĀKKŌPU ELUTIYA NIRUPAM 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YĀKKŌPU EḺUTIYA NIRUPAM 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ПОСЛАННЯ АПОСТОЛА ЯКОВА 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("யாக்கோபு எழுதிய நிருபம் 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ПИСМО ОД АПОСТОЛ ЈАКОВ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("СОБОРНЕ ПОСЛАННЯ ЯКОВА 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("யாக்கோபு எழுதிய கடிதம் 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOVLJEVA POSLANICA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ПОСЛАНИЦА ЈАКОВЉЕВА 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("LETTERA DI GIACOMO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("رسالة القديس يعقوب 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("யாகப்பர் திருமுகம் 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("யாக்கோபு திருமுகம் 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAʿQŪB KĀ ʿĀM ḪAṬ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("WARAKA WA YAKOBO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ПОСЛАНИЕ НА ЯКОВ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("یعقوب کا عا م خط 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("یعقُوب کا عام خط 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("BARUA YA YAKOBO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("EPISTULA IACOBI 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("LIST SW. JAKUBA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("LIST ŚW. JAKUBA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKOBACEM PATRA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKOBACEṂ PATRA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKOBĀCEM PATRA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKOBĀCEṂ PATRA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YĀKOBACEM PATRA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YĀKOBACEṂ PATRA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YĀKOBĀCEM PATRA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YĀKOBĀCEṂ PATRA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YĀKŪB DĪ PATTRĪ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ПОСЛАНИЕ ИАКОВА 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("یعقوب کا عام خط 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ਯਾਕੂਬ ਦੀ ਪੱਤ੍ਰੀ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAAKOBIN KIRJE 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOBS EPISTEL 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("LAYANG YAKOBUS 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("LIST SW JAKUBA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("LIST ŚW JAKUBA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ПОСЛАННЯ ЯКОВА 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("याकोबाचें पत्र 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKUBKO PATRA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKŪBKO PATRA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YĀKUBKO PATRA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YĀKŪBKO PATRA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ଯାକୁବଙ୍କ ପତ୍ର 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOBSBREFIÐ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOBSBREVET 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOBSBRÉFIÐ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOBUSBRIEF 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKUBOV LIST 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("LIST JAKUBUV 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("LIST JAKUBŮV 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("याकूबको पत्र 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOBS BREV 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOBS BREV 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("LIST JAKUBA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("رسالة يعقوب 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOVLJEVA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("איגרת יעקב 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKOBACEM 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKOBACEṂ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKOBĀCEM 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKOBĀCEṂ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YĀKOBACEM 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YĀKOBACEṂ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YĀKOBĀCEM 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YĀKOBĀCEṂ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ЈАКОВЉЕВА 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("אגרת יעקב 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("याकोबाचें 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAAKOBIN 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("SANTIAGO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ЈАКОВОВА 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ଯାକୁବଙ୍କ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("யாக்கோபு 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ヤコフからの手紙 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ヤコブからの手紙 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("GIACOMO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("GIACÔBÊ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JACQUES 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOBIT 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOBUS 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKUBOV 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YACQUUB 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKKOPU 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKKŌPU 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKOBUS 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YĀKKOPU 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YĀKKŌPU 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKUBKO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKŪBKO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YĀKUBKO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YĀKŪBKO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ΙΑΚΩΒΟΥ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ΙΑΚΏΒΟΥ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("याकूबको 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("GIA-CƠ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("IACOBI 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JACOBO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOBI 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOBS 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKUBA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAQUES 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKOBO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAKOOB 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ИАКОВА 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("یعقُوب 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("《雅各伯書》 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ヤコフの手紙 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ヤコブの手紙 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("야고보 서간 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("IACOB 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("IACOV 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKAB 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKOB 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAKUB 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAMES 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("TIAGO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YĀKŪB 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ЈАКОВ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ЯКОВА 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("يعقوب 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("یعقوب 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("याकूब 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("याकोब 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ਯਾਕੂਬ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ยากอบ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("《亞适烏》 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("《雅各书》 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("《雅各伯書 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("《雅各書》 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ヤコフの書 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ヤコブの書 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("雅各伯書》 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("IAGO 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAAK 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JACQ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAME 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("SANT 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YACQ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ЯКОВ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ЯКУБ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("யாக் 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("《亞适烏 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("《雅各书 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("《雅各書 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ヤコフ書 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ヤコブ書 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("亞适烏》 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("雅各书》 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("雅各伯書 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("雅各書》 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("야고보서 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("IAC 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("IAG 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAC 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAK 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAM 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JAS 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JMS 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("SAN 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("STG 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAC 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("YAK 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ЈАК 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ИАК 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("᾿ΙΑ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("《雅》 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ヤコフ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ヤコブ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("亞适烏 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("雅各书 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("雅各書 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("GC 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("GM 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JA 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JK 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("JM 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ST 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("TG 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ЯК 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("يع 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ยก 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("ยบ 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("《雅 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("雅》 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("야고 1:1").osis()).toEqual("Jas.1.1")
		expect(p.parse("雅 1:1").osis()).toEqual("Jas.1.1")
		`
		true
describe "Localized book Amos (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Amos (full)", ->
		`
		expect(p.parse("ଆମୋଷ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Книга на пророк Амоса 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Книга на пророк Амос 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Книга пророка Амоса 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Aamoksen kirja 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Prophetia Amos 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("आमोसको पुस्तक 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Ksiega Amosa 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Ksiegi Amosa 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Księga Amosa 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Księgi Amosa 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Liv Amos la 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Liv Amòs la 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amos' Bog 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amos' bok 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amos’ Bog 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amos’ bok 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Ks. Amosa 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("سفر عاموس 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Aamoksen 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Ks Amosa 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Caamoos 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("عامُوس 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("《阿摩司书》 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("《阿摩司書》 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("A-mốt 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amosa 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amosi 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amosz 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Ámosz 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("ʿāmōs 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Амоса 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("عاموس 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("ஆமோஸ் 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("อาโมส 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("《亞毛斯》 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("《阿摩司书 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("《阿摩司書 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("アモスしょ 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("阿摩司书》 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("阿摩司書》 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amos 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amòs 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amós 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amōs 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Caam 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("amos 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Ámos 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Ámós 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Āmos 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Āmōs 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("āmos 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Αμως 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Αμώς 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Амос 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("עמוס 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("अमोस 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("आमोस 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("ਆਮੋਸ 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("ଆମୋଷ 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("《亞毛斯 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("アモス書 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("亞毛斯》 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("阿摩司书 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("阿摩司書 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("아모스서 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Aam 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amo 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Ams 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Amó 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("ஆமோ 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("อมส 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("《摩》 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("アモス 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("亞毛斯 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("아모스 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Am 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Ám 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Αμ 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Ам 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("عا 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("Ἀμ 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("《摩 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("摩》 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("아모 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("摩 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("암 1:1").osis()).toEqual("Amos.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ଆମୋଷ ଭବିଷ୍ୟ‌ଦ୍‌ବକ୍ତାଙ୍କ ପୁସ୍ତକ 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("КНИГА НА ПРОРОК АМОСА 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("КНИГА НА ПРОРОК АМОС 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("КНИГА ПРОРОКА АМОСА 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AAMOKSEN KIRJA 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("PROPHETIA AMOS 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("आमोसको पुस्तक 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("KSIEGA AMOSA 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("KSIEGI AMOSA 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("KSIĘGA AMOSA 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("KSIĘGI AMOSA 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("LIV AMOS LA 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("LIV AMÒS LA 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMOS' BOG 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMOS' BOK 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMOS’ BOG 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMOS’ BOK 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("KS. AMOSA 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("سفر عاموس 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AAMOKSEN 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("KS AMOSA 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("CAAMOOS 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("عامُوس 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("《阿摩司书》 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("《阿摩司書》 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("A-MỐT 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMOSA 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMOSI 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMOSZ 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("ÁMOSZ 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("ʿĀMŌS 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("АМОСА 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("عاموس 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("ஆமோஸ் 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("อาโมส 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("《亞毛斯》 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("《阿摩司书 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("《阿摩司書 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("アモスしょ 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("阿摩司书》 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("阿摩司書》 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMOS 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMÒS 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMÓS 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMŌS 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("CAAM 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMOS 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("ÁMOS 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("ÁMÓS 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("ĀMOS 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("ĀMŌS 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("ĀMOS 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("ΑΜΩΣ 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("ΑΜΏΣ 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("АМОС 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("עמוס 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("अमोस 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("आमोस 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("ਆਮੋਸ 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("ଆମୋଷ 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("《亞毛斯 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("アモス書 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("亞毛斯》 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("阿摩司书 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("阿摩司書 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("아모스서 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AAM 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMO 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMS 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AMÓ 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("ஆமோ 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("อมส 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("《摩》 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("アモス 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("亞毛斯 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("아모스 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("AM 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("ÁM 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("ΑΜ 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("АМ 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("عا 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("ἈΜ 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("《摩 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("摩》 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("아모 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("摩 1:1").osis()).toEqual("Amos.1.1")
		expect(p.parse("암 1:1").osis()).toEqual("Amos.1.1")
		`
		true
describe "Localized book Tob (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Tob (full)", ->
		`
		expect(p.parse("Cartea lui Tobit 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Ksiega Tobiasza 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Ksiegi Tobiasza 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Księga Tobiasza 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Księgi Tobiasza 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Книга на Товита 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Книга за Тобия 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Книга на Товит 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Књига Товијина 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("தொபியாசு ஆகமம் 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Ksiega Tobita 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Ksiegi Tobita 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Księga Tobita 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Księgi Tobita 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobiaan kirja 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobitin kirja 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Ks. Tobiasza 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Liber Thobis 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Liber Tobiae 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobian kirja 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Книга Товита 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Ks Tobiasza 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobias' bok 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobias’ bok 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Ks. Tobita 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobits Bog 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobits bok 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Ks Tobita 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobitsbok 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobitsbók 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobítsbok 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobítsbók 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tóbitsbok 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tóbitsbók 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tóbítsbok 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tóbítsbók 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("سفر طوبيا 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("தோபித்து 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobiaan 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobijas 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobijaš 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobijás 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobijáš 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobiolo 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobitin 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tóbijas 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tóbijaš 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tóbijás 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tóbijáš 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobiae 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobian 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobias 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobiaš 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobija 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobiti 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobiás 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobiáš 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobías 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tóbias 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tóbiás 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Тобија 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Товита 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("《多俾亞傳》 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobia 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobie 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobit 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobía 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tóbit 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Τωβίτ 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Τωβιτ 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Тобия 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Товит 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("טוביה 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("طوبيا 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("โทบิต 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("《多俾亞傳 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("多俾亞傳》 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobi 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tobt 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("தோபி 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("トヒト書 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("トヒト記 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("トビト書 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("トビト記 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("多俾亞傳 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tho 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tob 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tób 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Τωβ 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Тов 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("トヒト 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("トビト 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("토비트 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("토빗기 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("Tb 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("طو 1:1").osis()).toEqual("Tob.1.1")
		expect(p.parse("토빗 1:1").osis()).toEqual("Tob.1.1")
		`
		true
describe "Localized book Jdt (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Jdt (full)", ->
		`
		expect(p.parse("Kniha Juditina 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Книга за Юдита 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Књига о Јудити 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Juditin kirja 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Ksiega Judyty 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Ksiegi Judyty 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Księga Judyty 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Księgi Judyty 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Liber Iudith 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("K. Juditina 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Kitab Yudit 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Книга Иудит 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Книга Юдити 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Juditarbok 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Juditarbók 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judits Bog 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judits bok 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judítarbok 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judítarbók 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Júditarbok 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Júditarbók 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Júdítarbok 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Júdítarbók 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("K Juditina 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Ks. Judyty 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("سفر يهوديت 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Ks Judyty 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Giuditta 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("யூதித்து 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Juditin 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Yudithi 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Iudita 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Iudith 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judita 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judite 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judith 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judyty 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Yudith 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Yuditi 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Ιουδίθ 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Ιουδιθ 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Јудита 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("יהודית 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("يهوديت 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("《友弟德傳》 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Jdith 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judit 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judth 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Júdit 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Yudit 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Иудит 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Юдити 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Юдифь 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("ยูดิธ 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("《友弟德傳 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("ユティト記 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("ユディト記 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("友弟德傳》 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Jdit 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Jdth 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Judt 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Júdt 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Yudt 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("யூதி 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("ユティト 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("ユテト書 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("ユディト 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("ユデト書 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("友弟德傳 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Gdt 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Idt 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Jdt 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Ιδθ 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Јуд 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("Юди 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("يـه 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("유딧기 1:1").osis()).toEqual("Jdt.1.1")
		expect(p.parse("유딧 1:1").osis()).toEqual("Jdt.1.1")
		`
		true
describe "Localized book Bar (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Bar (full)", ->
		`
		expect(p.parse("Книга на пророк Варуха 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Книга пророка Вару́ха 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Proroctvo Baruchovo 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Kniha Baruchova 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Kniha Báruchova 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baarukin kirja 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Kniha Barukova 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Kniha Bárukova 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Ksiega Barucha 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Ksiegi Barucha 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Księga Barucha 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Księgi Barucha 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Книга на Барух 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Barukin kirja 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Kitab Barukh 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Liber Baruch 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Книга Варуха 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("พระธรรมบารุค 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Ks. Barucha 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baruks Bog 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baruks bok 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Ks Barucha 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baruksbok 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baruksbók 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Barúksbok 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Barúksbók 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("سفر باروخ 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baarukin 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("ספר ברוך 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("பாரூக்கு 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Barucha 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Barukin 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baruque 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Бару́ха 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("ワルフの預言書 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baruch 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Barukh 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baruku 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Báruch 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Βαρουχ 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Βαρούχ 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Варуха 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baruc 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baruh 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Baruk 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Báruk 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Барух 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Варух 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("باروك 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("บารุค 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("《巴路克》 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("ברוך 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("பாரூ 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("《巴路克 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("ハルク書 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("バルク書 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("巴路克》 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Bar 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Bár 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Βαρ 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Вар 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("ハルク 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("バルク 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("巴路克 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("바룩서 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Ba 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Br 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("Βρ 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("با 1:1").osis()).toEqual("Bar.1.1")
		expect(p.parse("바룩 1:1").osis()).toEqual("Bar.1.1")
		`
		true
describe "Localized book 1Kgs, (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 1Kgs, (full)", ->
		`
		expect(p.parse("1. Ks 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. Re 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. Ks 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Ks 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 Re 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I Ks 1:1").osis()).toEqual("1Kgs.1.1")
		p.include_apocrypha(false)
		expect(p.parse("1. KS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1. RE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I. KS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 KS 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("1 RE 1:1").osis()).toEqual("1Kgs.1.1")
		expect(p.parse("I KS 1:1").osis()).toEqual("1Kgs.1.1")
		`
		true
describe "Localized book 2Kgs, (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: 2Kgs, (full)", ->
		`
		expect(p.parse("II. Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. Re 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Ks 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 Re 1:1").osis()).toEqual("2Kgs.1.1")
		p.include_apocrypha(false)
		expect(p.parse("II. KS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. KS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2. RE 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("II KS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 KS 1:1").osis()).toEqual("2Kgs.1.1")
		expect(p.parse("2 RE 1:1").osis()).toEqual("2Kgs.1.1")
		`
		true
describe "Localized book Acts, (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Acts, (full)", ->
		`
		expect(p.parse("Апостол 1:1").osis()).toEqual("Acts.1.1")
		p.include_apocrypha(false)
		expect(p.parse("АПОСТОЛ 1:1").osis()).toEqual("Acts.1.1")
		`
		true
describe "Localized book Ezek,Ezra (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Ezek,Ezra (full)", ->
		`
		expect(p.parse("Ez 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("Ез 1:1").osis()).toEqual("Ezek.1.1")
		p.include_apocrypha(false)
		expect(p.parse("EZ 1:1").osis()).toEqual("Ezek.1.1")
		expect(p.parse("ЕЗ 1:1").osis()).toEqual("Ezek.1.1")
		`
		true
describe "Localized book Ezra, (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Ezra, (full)", ->
		`
		expect(p.parse("拉 1:1").osis()).toEqual("Ezra.1.1")
		p.include_apocrypha(false)
		expect(p.parse("拉 1:1").osis()).toEqual("Ezra.1.1")
		`
		true
describe "Localized book Hab,Hag (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Hab,Hag (full)", ->
		`
		expect(p.parse("Ha 1:1").osis()).toEqual("Hab.1.1")
		p.include_apocrypha(false)
		expect(p.parse("HA 1:1").osis()).toEqual("Hab.1.1")
		`
		true
describe "Localized book Heb,Hab (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Heb,Hab (full)", ->
		`
		expect(p.parse("Hb 1:1").osis()).toEqual("Heb.1.1")
		p.include_apocrypha(false)
		expect(p.parse("HB 1:1").osis()).toEqual("Heb.1.1")
		`
		true
describe "Localized book Job, (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Job, (full)", ->
		`
		expect(p.parse("伯 1:1").osis()).toEqual("Job.1.1")
		p.include_apocrypha(false)
		expect(p.parse("伯 1:1").osis()).toEqual("Job.1.1")
		`
		true
describe "Localized book John, (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: John, (full)", ->
		`
		expect(p.parse("Jan 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("約 1:1").osis()).toEqual("John.1.1")
		p.include_apocrypha(false)
		expect(p.parse("JAN 1:1").osis()).toEqual("John.1.1")
		expect(p.parse("約 1:1").osis()).toEqual("John.1.1")
		`
		true
describe "Localized book John,Jonah (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: John,Jonah (full)", ->
		`
		expect(p.parse("Yn 1:1").osis()).toEqual("John.1.1")
		p.include_apocrypha(false)
		expect(p.parse("YN 1:1").osis()).toEqual("John.1.1")
		`
		true
describe "Localized book John,Jonah,Job,Josh,Joel (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: John,Jonah,Job,Josh,Joel (full)", ->
		`
		expect(p.parse("Jo 1:1").osis()).toEqual("John.1.1")
		p.include_apocrypha(false)
		expect(p.parse("JO 1:1").osis()).toEqual("John.1.1")
		`
		true
describe "Localized book John,Josh,Joel,Jonah (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: John,Josh,Joel,Jonah (full)", ->
		`
		expect(p.parse("யோ 1:1").osis()).toEqual("John.1.1")
		p.include_apocrypha(false)
		expect(p.parse("யோ 1:1").osis()).toEqual("John.1.1")
		`
		true
describe "Localized book Jonah,Joel (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Jonah,Joel (full)", ->
		`
		expect(p.parse("Yoo 1:1").osis()).toEqual("Jonah.1.1")
		p.include_apocrypha(false)
		expect(p.parse("YOO 1:1").osis()).toEqual("Jonah.1.1")
		`
		true
describe "Localized book Josh, (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Josh, (full)", ->
		`
		expect(p.parse("書 1:1").osis()).toEqual("Josh.1.1")
		p.include_apocrypha(false)
		expect(p.parse("書 1:1").osis()).toEqual("Josh.1.1")
		`
		true
describe "Localized book Jude,Judg (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Jude,Judg (full)", ->
		`
		expect(p.parse("Jud 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Jd 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("Ju 1:1").osis()).toEqual("Jude.1.1")
		p.include_apocrypha(false)
		expect(p.parse("JUD 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JD 1:1").osis()).toEqual("Jude.1.1")
		expect(p.parse("JU 1:1").osis()).toEqual("Jude.1.1")
		`
		true
describe "Localized book Lam, (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Lam, (full)", ->
		`
		expect(p.parse("La 1:1").osis()).toEqual("Lam.1.1")
		p.include_apocrypha(false)
		expect(p.parse("LA 1:1").osis()).toEqual("Lam.1.1")
		`
		true
describe "Localized book Lev, (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Lev, (full)", ->
		`
		expect(p.parse("利 1:1").osis()).toEqual("Lev.1.1")
		p.include_apocrypha(false)
		expect(p.parse("利 1:1").osis()).toEqual("Lev.1.1")
		`
		true
describe "Localized book Matt, (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Matt, (full)", ->
		`
		expect(p.parse("太 1:1").osis()).toEqual("Matt.1.1")
		p.include_apocrypha(false)
		expect(p.parse("太 1:1").osis()).toEqual("Matt.1.1")
		`
		true
describe "Localized book Matt,Mark,Mal (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Matt,Mark,Mal (full)", ->
		`
		expect(p.parse("Ma 1:1").osis()).toEqual("Matt.1.1")
		p.include_apocrypha(false)
		expect(p.parse("MA 1:1").osis()).toEqual("Matt.1.1")
		`
		true
describe "Localized book Mic, (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Mic, (full)", ->
		`
		expect(p.parse("Mi 1:1").osis()).toEqual("Mic.1.1")
		p.include_apocrypha(false)
		expect(p.parse("MI 1:1").osis()).toEqual("Mic.1.1")
		`
		true
describe "Localized book Phil,Phlm (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Phil,Phlm (full)", ->
		`
		expect(p.parse("Fil 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Phl 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("Ph 1:1").osis()).toEqual("Phil.1.1")
		p.include_apocrypha(false)
		expect(p.parse("FIL 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PHL 1:1").osis()).toEqual("Phil.1.1")
		expect(p.parse("PH 1:1").osis()).toEqual("Phil.1.1")
		`
		true
describe "Localized book Rev, (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Rev, (full)", ->
		`
		expect(p.parse("Re 1:1").osis()).toEqual("Rev.1.1")
		p.include_apocrypha(false)
		expect(p.parse("RE 1:1").osis()).toEqual("Rev.1.1")
		`
		true
describe "Localized book Song, (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Song, (full)", ->
		`
		expect(p.parse("Songs 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("歌 1:1").osis()).toEqual("Song.1.1")
		p.include_apocrypha(false)
		expect(p.parse("SONGS 1:1").osis()).toEqual("Song.1.1")
		expect(p.parse("歌 1:1").osis()).toEqual("Song.1.1")
		`
		true
describe "Localized book Zeph,Zech (full)", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore",book_sequence_strategy: "ignore",osis_compaction_strategy: "bc",captive_end_digits_strategy: "delete"
		p.include_apocrypha true
	it "should handle book: Zeph,Zech (full)", ->
		`
		expect(p.parse("Ze 1:1").osis()).toEqual("Zeph.1.1")
		p.include_apocrypha(false)
		expect(p.parse("ZE 1:1").osis()).toEqual("Zeph.1.1")
		`
		true

describe "Miscellaneous tests", ->
	p = {}
	beforeEach ->
		p = new bcv_parser
		p.set_options book_alone_strategy: "ignore", book_sequence_strategy: "ignore", osis_compaction_strategy: "bc", captive_end_digits_strategy: "delete"
		p.include_apocrypha true

	it "should handle ranges (full)", ->
		expect(p.parse("Titus 1:1 through 2").osis()).toEqual "Titus.1.1-Titus.1.2"
		expect(p.parse("Matt 1through2").osis()).toEqual "Matt.1-Matt.2"
		expect(p.parse("Phlm 2 THROUGH 3").osis()).toEqual "Phlm.1.2-Phlm.1.3"
		expect(p.parse("Titus 1:1 thru 2").osis()).toEqual "Titus.1.1-Titus.1.2"
		expect(p.parse("Matt 1thru2").osis()).toEqual "Matt.1-Matt.2"
		expect(p.parse("Phlm 2 THRU 3").osis()).toEqual "Phlm.1.2-Phlm.1.3"
		expect(p.parse("Titus 1:1 to 2").osis()).toEqual "Titus.1.1-Titus.1.2"
		expect(p.parse("Matt 1to2").osis()).toEqual "Matt.1-Matt.2"
		expect(p.parse("Phlm 2 TO 3").osis()).toEqual "Phlm.1.2-Phlm.1.3"
	it "should handle chapters (full)", ->
		expect(p.parse("Titus 1:1, chapters 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPTERS 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chapter 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPTER 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chapts. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPTS. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chapts 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPTS 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chpts. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHPTS. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chpts 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHPTS 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chapt. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPT. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chapt 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPT 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chaps. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPS. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chaps 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAPS 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chap. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAP. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chap 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHAP 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chp. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHP. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chp 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHP 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chs. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHS. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, chs 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHS 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, cha. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHA. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, cha 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CHA 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, ch. 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CH. 6").osis()).toEqual "Matt.3.4,Matt.6"
		expect(p.parse("Titus 1:1, ch 2").osis()).toEqual "Titus.1.1,Titus.2"
		expect(p.parse("Matt 3:4 CH 6").osis()).toEqual "Matt.3.4,Matt.6"
	it "should handle verses (full)", ->
		expect(p.parse("Exod 1:1 verses 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VERSES 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 verse 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VERSE 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 ver. 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VER. 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 ver 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VER 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 vss. 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VSS. 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 vss 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VSS 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 vs. 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VS. 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 vs 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VS 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 vv. 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VV. 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 vv 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm VV 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 v. 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm V. 6").osis()).toEqual "Phlm.1.6"
		expect(p.parse("Exod 1:1 v 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm V 6").osis()).toEqual "Phlm.1.6"
	it "should handle 'and' (full)", ->
		expect(p.parse("Exod 1:1 and 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm 2 AND 6").osis()).toEqual "Phlm.1.2,Phlm.1.6"
		expect(p.parse("Exod 1:1 compare 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm 2 COMPARE 6").osis()).toEqual "Phlm.1.2,Phlm.1.6"
		expect(p.parse("Exod 1:1 cf. 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm 2 CF. 6").osis()).toEqual "Phlm.1.2,Phlm.1.6"
		expect(p.parse("Exod 1:1 cf 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm 2 CF 6").osis()).toEqual "Phlm.1.2,Phlm.1.6"
		expect(p.parse("Exod 1:1 see also 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm 2 SEE ALSO 6").osis()).toEqual "Phlm.1.2,Phlm.1.6"
		expect(p.parse("Exod 1:1 also 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm 2 ALSO 6").osis()).toEqual "Phlm.1.2,Phlm.1.6"
		expect(p.parse("Exod 1:1 see 3").osis()).toEqual "Exod.1.1,Exod.1.3"
		expect(p.parse("Phlm 2 SEE 6").osis()).toEqual "Phlm.1.2,Phlm.1.6"
	it "should handle titles (full)", ->
		expect(p.parse("Ps 3 title, 4:2, 5:title").osis()).toEqual "Ps.3.1,Ps.4.2,Ps.5.1"
		expect(p.parse("PS 3 TITLE, 4:2, 5:TITLE").osis()).toEqual "Ps.3.1,Ps.4.2,Ps.5.1"
	it "should handle 'ff' (full)", ->
		expect(p.parse("Rev 3ff, 4:2ff").osis()).toEqual "Rev.3-Rev.22,Rev.4.2-Rev.4.11"
		expect(p.parse("REV 3 FF, 4:2 FF").osis()).toEqual "Rev.3-Rev.22,Rev.4.2-Rev.4.11"
		expect(p.parse("Rev 3f, 4:2f").osis()).toEqual "Rev.3-Rev.22,Rev.4.2-Rev.4.11"
		expect(p.parse("REV 3 F, 4:2 F").osis()).toEqual "Rev.3-Rev.22,Rev.4.2-Rev.4.11"
	it "should handle translations (full)", ->
		expect(p.parse("Lev 1 (AMP)").osis_and_translations()).toEqual [["Lev.1", "AMP"]]
		expect(p.parse("lev 1 amp").osis_and_translations()).toEqual [["Lev.1", "AMP"]]
		expect(p.parse("Lev 1 (ASV)").osis_and_translations()).toEqual [["Lev.1", "ASV"]]
		expect(p.parse("lev 1 asv").osis_and_translations()).toEqual [["Lev.1", "ASV"]]
		expect(p.parse("Lev 1 (CEB)").osis_and_translations()).toEqual [["Lev.1", "CEB"]]
		expect(p.parse("lev 1 ceb").osis_and_translations()).toEqual [["Lev.1", "CEB"]]
		expect(p.parse("Lev 1 (CEV)").osis_and_translations()).toEqual [["Lev.1", "CEV"]]
		expect(p.parse("lev 1 cev").osis_and_translations()).toEqual [["Lev.1", "CEV"]]
		expect(p.parse("Lev 1 (ERV)").osis_and_translations()).toEqual [["Lev.1", "ERV"]]
		expect(p.parse("lev 1 erv").osis_and_translations()).toEqual [["Lev.1", "ERV"]]
		expect(p.parse("Lev 1 (ESV)").osis_and_translations()).toEqual [["Lev.1", "ESV"]]
		expect(p.parse("lev 1 esv").osis_and_translations()).toEqual [["Lev.1", "ESV"]]
		expect(p.parse("Lev 1 (HCSB)").osis_and_translations()).toEqual [["Lev.1", "HCSB"]]
		expect(p.parse("lev 1 hcsb").osis_and_translations()).toEqual [["Lev.1", "HCSB"]]
		expect(p.parse("Lev 1 (KJV)").osis_and_translations()).toEqual [["Lev.1", "KJV"]]
		expect(p.parse("lev 1 kjv").osis_and_translations()).toEqual [["Lev.1", "KJV"]]
		expect(p.parse("Lev 1 (MSG)").osis_and_translations()).toEqual [["Lev.1", "MSG"]]
		expect(p.parse("lev 1 msg").osis_and_translations()).toEqual [["Lev.1", "MSG"]]
		expect(p.parse("Lev 1 (NAB)").osis_and_translations()).toEqual [["Lev.1", "NAB"]]
		expect(p.parse("lev 1 nab").osis_and_translations()).toEqual [["Lev.1", "NAB"]]
		expect(p.parse("Lev 1 (NABRE)").osis_and_translations()).toEqual [["Lev.1", "NABRE"]]
		expect(p.parse("lev 1 nabre").osis_and_translations()).toEqual [["Lev.1", "NABRE"]]
		expect(p.parse("Lev 1 (NAS)").osis_and_translations()).toEqual [["Lev.1", "NASB"]]
		expect(p.parse("lev 1 nas").osis_and_translations()).toEqual [["Lev.1", "NASB"]]
		expect(p.parse("Lev 1 (NASB)").osis_and_translations()).toEqual [["Lev.1", "NASB"]]
		expect(p.parse("lev 1 nasb").osis_and_translations()).toEqual [["Lev.1", "NASB"]]
		expect(p.parse("Lev 1 (NIRV)").osis_and_translations()).toEqual [["Lev.1", "NIRV"]]
		expect(p.parse("lev 1 nirv").osis_and_translations()).toEqual [["Lev.1", "NIRV"]]
		expect(p.parse("Lev 1 (NIV)").osis_and_translations()).toEqual [["Lev.1", "NIV"]]
		expect(p.parse("lev 1 niv").osis_and_translations()).toEqual [["Lev.1", "NIV"]]
		expect(p.parse("Lev 1 (NKJV)").osis_and_translations()).toEqual [["Lev.1", "NKJV"]]
		expect(p.parse("lev 1 nkjv").osis_and_translations()).toEqual [["Lev.1", "NKJV"]]
		expect(p.parse("Lev 1 (NLT)").osis_and_translations()).toEqual [["Lev.1", "NLT"]]
		expect(p.parse("lev 1 nlt").osis_and_translations()).toEqual [["Lev.1", "NLT"]]
		expect(p.parse("Lev 1 (NRSV)").osis_and_translations()).toEqual [["Lev.1", "NRSV"]]
		expect(p.parse("lev 1 nrsv").osis_and_translations()).toEqual [["Lev.1", "NRSV"]]
		expect(p.parse("Lev 1 (RSV)").osis_and_translations()).toEqual [["Lev.1", "RSV"]]
		expect(p.parse("lev 1 rsv").osis_and_translations()).toEqual [["Lev.1", "RSV"]]
		expect(p.parse("Lev 1 (TNIV)").osis_and_translations()).toEqual [["Lev.1", "TNIV"]]
		expect(p.parse("lev 1 tniv").osis_and_translations()).toEqual [["Lev.1", "TNIV"]]
	it "should handle boundaries (full)", ->
		p.set_options {book_alone_strategy: "full"}
		expect(p.parse("\u2014Matt\u2014").osis()).toEqual "Matt.1-Matt.28"
		expect(p.parse("\u201cMatt 1:1\u201d").osis()).toEqual "Matt.1.1"
